/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 04146
 |        NATIONAL DRUG ABUSE TREATMENT SYSTEM SURVEY, WAVES II-IV
 |                     (DATASET 0001: WAVE II, 1988)
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\04146-0001-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE v4004fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4005fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v4006fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4007fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4008fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v4009fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4010fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4011fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4012fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4013fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v4014fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4015fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HIINCOME' 2='2. LOINCOME'
                  3='3. YOUTH' 4='4. SENIORS' 5='5. WOMEN' 6='6. MINORITY'
                  7='7. VETERANS' 11='11. COURTCAS' 12='12. ORGMEMBE'
                  13='13. AMERIND' 19='19. OTHATARG' 21='21. HEROIN'
                  22='22. ALCOHOL' 29='29. OTHDRUG' 41='41. REHABSRV'
                  42='42. DETOX' 43='43. AFTRCARE' 51='51. METHMAIN'
                  52='52. METHDETX' 53='53. COUNSEL' 54='54. CODEPEND'
                  55='55. HOLISTIC' 56='56. AA/NA' 59='59. TREATMNT'
                  71='71. PREVENTN' 72='72. ALT2RESD' 73='73. REFERRAL'
                  74='74. CRISIS' 75='75. MENHEALT' 76='76. EVALUATN'
                  91='91. EMPLYXAD' 97='97. OTHER' ;
  VALUE v4016fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HIINCOME' 2='2. LOINCOME'
                  3='3. YOUTH' 4='4. SENIORS' 5='5. WOMEN' 6='6. MINORITY'
                  7='7. VETERANS' 11='11. COURTCAS' 12='12. ORGMEMBE'
                  13='13. AMERIND' 19='19. OTHATARG' 21='21. HEROIN'
                  22='22. ALCOHOL' 29='29. OTHDRUG' 41='41. REHABSRV'
                  42='42. DETOX' 43='43. AFTRCARE' 51='51. METHMAIN'
                  52='52. METHDETX' 53='53. COUNSEL' 54='54. CODEPEND'
                  55='55. HOLISTIC' 56='56. AA/NA' 59='59. TREATMNT'
                  71='71. PREVENTN' 72='72. ALT2RESD' 73='73. REFERRAL'
                  74='74. CRISIS' 75='75. MENHEALT' 76='76. EVALUATN'
                  91='91. EMPLYXAD' 97='97. OTHER' ;
  VALUE v4017fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4018fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4019fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 10='10. CHANGPOP'
                  11='11. AGERANGE' 12='12. OUTREACH' 13='13. LOINCOME'
                  19='19. OTHTARGT' 21='21. INCALCOH' 22='22. ALCO+OTH'
                  29='29. OTHDRUGS' 31='31. MAIN2FRE' 41='41. BROADTX'
                  42='42. >EDUCATN' 43='43. SATRTMT' 44='44. TARGET'
                  49='49. BRODPROG' 51='51. REFERRAL' 52='52. AIDSED'
                  81='81. <NON-SA' 97='97. OTHER' ;
  VALUE v4020fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 10='10. CHANGPOP'
                  11='11. AGERANGE' 12='12. OUTREACH' 13='13. LOINCOME'
                  19='19. OTHTARGT' 21='21. INCALCOH' 22='22. ALCO+OTH'
                  29='29. OTHDRUGS' 31='31. MAIN2FRE' 41='41. BROADTX'
                  42='42. >EDUCATN' 43='43. SATRTMT' 44='44. TARGET'
                  49='49. BRODPROG' 51='51. REFERRAL' 52='52. AIDSED'
                  81='81. <NON-SA' 97='97. OTHER' ;
  VALUE v4021fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4022fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. Strongly Disagree'
                  2='2. Somewhat Disagree' 3='3. Not Agr or Disagr'
                  4='4. Somewhat Agree' 5='5. Strongly Agree' ;
  VALUE v4023fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. Strongly Disagree'
                  2='2. Somewhat Disagree' 3='3. Not Agr or Disagr'
                  4='4. Somewhat Agree' 5='5. Strongly Agree' ;
  VALUE v4024fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. Strongly Disagree'
                  2='2. Somewhat Disagree' 3='3. Not Agr or Disagr'
                  4='4. Somewhat Agree' 5='5. Strongly Agree' ;
  VALUE v4025fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. Strongly Disagree'
                  2='2. Somewhat Disagree' 3='3. Not Agr or Disagr'
                  4='4. Somewhat Agree' 5='5. Strongly Agree' ;
  VALUE v4026fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. Strongly Disagree'
                  2='2. Somewhat Disagree' 3='3. Not Agr or Disagr'
                  4='4. Somewhat Agree' 5='5. Strongly Agree' ;
  VALUE v4027fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. Strongly Disagree'
                  2='2. Somewhat Disagree' 3='3. Not Agr or Disagr'
                  4='4. Somewhat Agree' 5='5. Strongly Agree' ;
  VALUE v4028fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. Strongly Disagree'
                  2='2. Somewhat Disagree' 3='3. Not Agr or Disagr'
                  4='4. Somewhat Agree' 5='5. Strongly Agree' ;
  VALUE v4029fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. Strongly Disagree'
                  2='2. Somewhat Disagree' 3='3. Not Agr or Disagr'
                  4='4. Somewhat Agree' 5='5. Strongly Agree' ;
  VALUE v4030fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. Strongly Disagree'
                  2='2. Somewhat Disagree' 3='3. Not Agr or Disagr'
                  4='4. Somewhat Agree' 5='5. Strongly Agree' ;
  VALUE v4031fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4032fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4033fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PREVENTN' 2='2. AIDS ED'
                  3='3. CRISIS' 11='11. EVALUATN' 12='12. REFERRAL'
                  13='13. AFTRCARE' 14='14. REHABLTN' 21='21. JOB/EAP'
                  22='22. EDUC/GED' 23='23. FAMILY' 31='31. BASCNEED'
                  32='32. DAYCARE' 33='33. INDEPLIV' 34='34. PARENTED'
                  35='35. EXERCISE' 36='36. >#TRTLOC' 37='37. RELIGION'
                  41='41. AA/NA' 42='42. CO-DEPND' 43='43. DUALDIAG'
                  44='44. GENRL MH' 51='51. MEDICAL' 52='52. DETOX'
                  53='53. METHADON' 54='54. ANTABUSE' 55='55. TREXAN'
                  56='56. SYMMETRL' 59='59. OTHR MED' 61='61. AIDS TX'
                  62='62. DWI/DUI' 63='63. ALCOHOL' 64='64. COCAINE'
                  65='65. EATDISOR' 66='66. MULTDRUG' 67='67. PRISONER'
                  69='69. 9OTHRDRU' 70='70. MEN' 71='71. WOMEN' 72='72.TEENS'
                  73='73. ELDERLY' 74='74. MINORITY' 75='75. HOMOSEX'
                  76='76. VETERANS' 77='77. POOR' 78='78. HANDICAP'
                  79='79. OTHTARGT' 81='81. INPTTRMT' 82='82. INPTALCO'
                  83='83. INPTDETX' 84='84. INPTMETH' 85='85. INPT MH'
                  89='89. OTHINPT' 91='91. THERAPY' 92='92. INDTHRPY'
                  93='93. GRPTHRPY' 94='94. INTENSIV' 95='95. PARTHOSP'
                  97='97. OTHER' ;
  VALUE v4034fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PREVENTN' 2='2. AIDS ED'
                  3='3. CRISIS' 11='11. EVALUATN' 12='12. REFERRAL'
                  13='13. AFTRCARE' 14='14. REHABLTN' 21='21. JOB/EAP'
                  22='22. EDUC/GED' 23='23. FAMILY' 31='31. BASCNEED'
                  32='32. DAYCARE' 33='33. INDEPLIV' 34='34. PARENTED'
                  35='35. EXERCISE' 36='36. >#TRTLOC' 37='37. RELIGION'
                  41='41. AA/NA' 42='42. CO-DEPND' 43='43. DUALDIAG'
                  44='44. GENRL MH' 51='51. MEDICAL' 52='52. DETOX'
                  53='53. METHADON' 54='54. ANTABUSE' 55='55. TREXAN'
                  56='56. SYMMETRL' 59='59. OTHR MED' 61='61. AIDS TX'
                  62='62. DWI/DUI' 63='63. ALCOHOL' 64='64. COCAINE'
                  65='65. EATDISOR' 66='66. MULTDRUG' 67='67. PRISONER'
                  69='69. 9OTHRDRU' 70='70. MEN' 71='71. WOMEN' 72='72.TEENS'
                  73='73. ELDERLY' 74='74. MINORITY' 75='75. HOMOSEX'
                  76='76. VETERANS' 77='77. POOR' 78='78. HANDICAP'
                  79='79. OTHTARGT' 81='81. INPTTRMT' 82='82. INPTALCO'
                  83='83. INPTDETX' 84='84. INPTMETH' 85='85. INPT MH'
                  89='89. OTHINPT' 91='91. THERAPY' 92='92. INDTHRPY'
                  93='93. GRPTHRPY' 94='94. INTENSIV' 95='95. PARTHOSP'
                  97='97. OTHER' ;
  VALUE v4035fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PREVENTN' 2='2. AIDS ED'
                  3='3. CRISIS' 11='11. EVALUATN' 12='12. REFERRAL'
                  13='13. AFTRCARE' 14='14. REHABLTN' 21='21. JOB/EAP'
                  22='22. EDUC/GED' 23='23. FAMILY' 31='31. BASCNEED'
                  32='32. DAYCARE' 33='33. INDEPLIV' 34='34. PARENTED'
                  35='35. EXERCISE' 36='36. >#TRTLOC' 37='37. RELIGION'
                  41='41. AA/NA' 42='42. CO-DEPND' 43='43. DUALDIAG'
                  44='44. GENRL MH' 51='51. MEDICAL' 52='52. DETOX'
                  53='53. METHADON' 54='54. ANTABUSE' 55='55. TREXAN'
                  56='56. SYMMETRL' 59='59. OTHR MED' 61='61. AIDS TX'
                  62='62. DWI/DUI' 63='63. ALCOHOL' 64='64. COCAINE'
                  65='65. EATDISOR' 66='66. MULTDRUG' 67='67. PRISONER'
                  69='69. 9OTHRDRU' 70='70. MEN' 71='71. WOMEN' 72='72.TEENS'
                  73='73. ELDERLY' 74='74. MINORITY' 75='75. HOMOSEX'
                  76='76. VETERANS' 77='77. POOR' 78='78. HANDICAP'
                  79='79. OTHTARGT' 81='81. INPTTRMT' 82='82. INPTALCO'
                  83='83. INPTDETX' 84='84. INPTMETH' 85='85. INPT MH'
                  89='89. OTHINPT' 91='91. THERAPY' 92='92. INDTHRPY'
                  93='93. GRPTHRPY' 94='94. INTENSIV' 95='95. PARTHOSP'
                  97='97. OTHER' ;
  VALUE v4036fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PREVENTN' 2='2. AIDS ED'
                  3='3. CRISIS' 11='11. EVALUATN' 12='12. REFERRAL'
                  13='13. AFTRCARE' 14='14. REHABLTN' 21='21. JOB/EAP'
                  22='22. EDUC/GED' 23='23. FAMILY' 31='31. BASCNEED'
                  32='32. DAYCARE' 33='33. INDEPLIV' 34='34. PARENTED'
                  35='35. EXERCISE' 36='36. >#TRTLOC' 37='37. RELIGION'
                  41='41. AA/NA' 42='42. CO-DEPND' 43='43. DUALDIAG'
                  44='44. GENRL MH' 51='51. MEDICAL' 52='52. DETOX'
                  53='53. METHADON' 54='54. ANTABUSE' 55='55. TREXAN'
                  56='56. SYMMETRL' 59='59. OTHR MED' 61='61. AIDS TX'
                  62='62. DWI/DUI' 63='63. ALCOHOL' 64='64. COCAINE'
                  65='65. EATDISOR' 66='66. MULTDRUG' 67='67. PRISONER'
                  69='69. 9OTHRDRU' 70='70. MEN' 71='71. WOMEN' 72='72.TEENS'
                  73='73. ELDERLY' 74='74. MINORITY' 75='75. HOMOSEX'
                  76='76. VETERANS' 77='77. POOR' 78='78. HANDICAP'
                  79='79. OTHTARGT' 81='81. INPTTRMT' 82='82. INPTALCO'
                  83='83. INPTDETX' 84='84. INPTMETH' 85='85. INPT MH'
                  89='89. OTHINPT' 91='91. THERAPY' 92='92. INDTHRPY'
                  93='93. GRPTHRPY' 94='94. INTENSIV' 95='95. PARTHOSP'
                  97='97. OTHER' ;
  VALUE v4037fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4038fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4039fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4040fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v4041fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4042fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4043fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v4044fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4045fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4046fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4047fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v4048fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4049fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4050fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v4051fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4052fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4053fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4054fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4055fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4056fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4057fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4058fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4059fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4060fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4061fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4062fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4063fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4064fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4065fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4066fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4067fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4068fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4069fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4070fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4071fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4072fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4073fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4074fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4075fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4076fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4077fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4078fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4079fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4080fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4081fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4082fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4083fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4084fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4085fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4086fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4087fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4088fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4089fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4090fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4091fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4092fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4093fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4094fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4095fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4096fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4097fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4098fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4099fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4100fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4101fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4102fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4103fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4104fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4105fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4106fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4107fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4108fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4109fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4110fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4111fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4112fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4113fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4114fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4115fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4116fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4117fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4118fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4119fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4120fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4121fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4122fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4123fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4124fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4125fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4126fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4127fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4128fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4129fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4130fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4131fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4132fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4133fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4134fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4135fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME W/CL'
                  4='4. COMB 1 & 2' 11='11. PER DAY' 13='13. PER DOSE METH'
                  15='15. PER COURSE TRTMT' 71='71. PER WEEK'
                  72='72. PER MONTH' 78='78. FLAT FEE' 79='79. SLIDE SCALE'
                  97='97. OTHER' ;
  VALUE v4136fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME W/CL'
                  4='4. COMB 1 & 2' 11='11. PER DAY' 13='13. PER DOSE METH'
                  15='15. PER COURSE TRTMT' 71='71. PER WEEK'
                  72='72. PER MONTH' 78='78. FLAT FEE' 79='79. SLIDE SCALE'
                  97='97. OTHER' ;
  VALUE v4137fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4138fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4139fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4140fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4141fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4142fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4143fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4144fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4145fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4146fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4147fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4148fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4149fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4150fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4151fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4152fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4153fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4154fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4155fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4156fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4157fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4158fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4159fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4160fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4161fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v4162fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4163fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4164fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4165fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4166fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4167fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4168fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4169fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4170fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4171fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4172fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4173fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4174fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4175fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4176fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4177fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4178fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4179fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4180fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4181fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. RENT' 2='2. OWN'
                  3='3. NEITHER' 4='4. BOTH 1 & 2' ;
  VALUE v4182fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4183fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4184fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4185fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4186fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4187fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4188fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4189fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4190fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4191fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4192fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4193fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4194fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 994='994. FLATRATE'
                  995='995. SLIDSCAL' 996='996. NOCHARGE' ;
  VALUE v4195fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4196fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4197fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4198fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4199fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4200fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4201fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4202fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 994='994. FLATRATE'
                  995='995. SLIDSCAL' 996='996. NOCHARGE' ;
  VALUE v4203fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4204fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4205fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4206fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4207fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4208fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4209fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4210fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4211fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 994='994. FLATRATE'
                  995='995. SLIDSCAL' 996='996. NOCHARGE' ;
  VALUE v4212fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4213fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4214fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4215fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4216fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4217fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4218fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 994='994. FLATRATE'
                  995='995. SLIDSCAL' 996='996. NOCHARGE' ;
  VALUE v4219fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4220fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4221fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PREVENTN' 2='2. AIDS ED'
                  3='3. CRISIS' 11='11. EVALUATN' 12='12. REFERRAL'
                  13='13. AFTRCARE' 14='14. REHABLTN' 21='21. JOB/EAP'
                  22='22. EDUC/GED' 23='23. FAMILY' 31='31. BASCNEED'
                  32='32. DAYCARE' 33='33. INDEPLIV' 34='34. PARENTED'
                  35='35. EXERCISE' 36='36. >#TRTLOC' 37='37. RELIGION'
                  41='41. AA/NA' 42='42. CO-DEPND' 43='43. DUALDIAG'
                  44='44. GENRL MH' 51='51. MEDICAL' 52='52. DETOX'
                  53='53. METHADON' 54='54. ANTABUSE' 55='55. TREXAN'
                  56='56. SYMMETRL' 59='59. OTHR MED' 61='61. AIDS TX'
                  62='62. DWI/DUI' 63='63. ALCOHOL' 64='64. COCAINE'
                  65='65. EATDISOR' 66='66. MULTDRUG' 67='67. PRISONER'
                  69='69. 9OTHRDRU' 70='70. MEN' 71='71. WOMEN' 72='72.TEENS'
                  73='73. ELDERLY' 74='74. MINORITY' 75='75. HOMOSEX'
                  76='76. VETERANS' 77='77. POOR' 78='78. HANDICAP'
                  79='79. OTHTARGT' 81='81. INPTTRMT' 82='82. INPTALCO'
                  83='83. INPTDETX' 84='84. INPTMETH' 85='85. INPT MH'
                  89='89. OTHINPT' 91='91. THERAPY' 92='92. INDTHRPY'
                  93='93. GRPTHRPY' 94='94. INTENSIV' 95='95. PARTHOSP'
                  97='97. OTHER' ;
  VALUE v4222fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4223fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4224fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4225fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4226fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4227fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PREVENTN' 2='2. AIDS ED'
                  3='3. CRISIS' 11='11. EVALUATN' 12='12. REFERRAL'
                  13='13. AFTRCARE' 14='14. REHABLTN' 21='21. JOB/EAP'
                  22='22. EDUC/GED' 23='23. FAMILY' 31='31. BASCNEED'
                  32='32. DAYCARE' 33='33. INDEPLIV' 34='34. PARENTED'
                  35='35. EXERCISE' 36='36. >#TRTLOC' 37='37. RELIGION'
                  41='41. AA/NA' 42='42. CO-DEPND' 43='43. DUALDIAG'
                  44='44. GENRL MH' 51='51. MEDICAL' 52='52. DETOX'
                  53='53. METHADON' 54='54. ANTABUSE' 55='55. TREXAN'
                  56='56. SYMMETRL' 59='59. OTHR MED' 61='61. AIDS TX'
                  62='62. DWI/DUI' 63='63. ALCOHOL' 64='64. COCAINE'
                  65='65. EATDISOR' 66='66. MULTDRUG' 67='67. PRISONER'
                  69='69. 9OTHRDRU' 70='70. MEN' 71='71. WOMEN' 72='72.TEENS'
                  73='73. ELDERLY' 74='74. MINORITY' 75='75. HOMOSEX'
                  76='76. VETERANS' 77='77. POOR' 78='78. HANDICAP'
                  79='79. OTHTARGT' 81='81. INPTTRMT' 82='82. INPTALCO'
                  83='83. INPTDETX' 84='84. INPTMETH' 85='85. INPT MH'
                  89='89. OTHINPT' 91='91. THERAPY' 92='92. INDTHRPY'
                  93='93. GRPTHRPY' 94='94. INTENSIV' 95='95. PARTHOSP'
                  97='97. OTHER' ;
  VALUE v4228fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4229fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4230fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4231fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4232fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4233fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PREVENTN' 2='2. AIDS ED'
                  3='3. CRISIS' 11='11. EVALUATN' 12='12. REFERRAL'
                  13='13. AFTRCARE' 14='14. REHABLTN' 21='21. JOB/EAP'
                  22='22. EDUC/GED' 23='23. FAMILY' 31='31. BASCNEED'
                  32='32. DAYCARE' 33='33. INDEPLIV' 34='34. PARENTED'
                  35='35. EXERCISE' 36='36. >#TRTLOC' 37='37. RELIGION'
                  41='41. AA/NA' 42='42. CO-DEPND' 43='43. DUALDIAG'
                  44='44. GENRL MH' 51='51. MEDICAL' 52='52. DETOX'
                  53='53. METHADON' 54='54. ANTABUSE' 55='55. TREXAN'
                  56='56. SYMMETRL' 59='59. OTHR MED' 61='61. AIDS TX'
                  62='62. DWI/DUI' 63='63. ALCOHOL' 64='64. COCAINE'
                  65='65. EATDISOR' 66='66. MULTDRUG' 67='67. PRISONER'
                  69='69. 9OTHRDRU' 70='70. MEN' 71='71. WOMEN' 72='72.TEENS'
                  73='73. ELDERLY' 74='74. MINORITY' 75='75. HOMOSEX'
                  76='76. VETERANS' 77='77. POOR' 78='78. HANDICAP'
                  79='79. OTHTARGT' 81='81. INPTTRMT' 82='82. INPTALCO'
                  83='83. INPTDETX' 84='84. INPTMETH' 85='85. INPT MH'
                  89='89. OTHINPT' 91='91. THERAPY' 92='92. INDTHRPY'
                  93='93. GRPTHRPY' 94='94. INTENSIV' 95='95. PARTHOSP'
                  97='97. OTHER' ;
  VALUE v4234fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4235fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4236fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4237fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4238fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4239fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PREVENTN' 2='2. AIDS ED'
                  3='3. CRISIS' 11='11. EVALUATN' 12='12. REFERRAL'
                  13='13. AFTRCARE' 14='14. REHABLTN' 21='21. JOB/EAP'
                  22='22. EDUC/GED' 23='23. FAMILY' 31='31. BASCNEED'
                  32='32. DAYCARE' 33='33. INDEPLIV' 34='34. PARENTED'
                  35='35. EXERCISE' 36='36. >#TRTLOC' 37='37. RELIGION'
                  41='41. AA/NA' 42='42. CO-DEPND' 43='43. DUALDIAG'
                  44='44. GENRL MH' 51='51. MEDICAL' 52='52. DETOX'
                  53='53. METHADON' 54='54. ANTABUSE' 55='55. TREXAN'
                  56='56. SYMMETRL' 59='59. OTHR MED' 61='61. AIDS TX'
                  62='62. DWI/DUI' 63='63. ALCOHOL' 64='64. COCAINE'
                  65='65. EATDISOR' 66='66. MULTDRUG' 67='67. PRISONER'
                  69='69. 9OTHRDRU' 70='70. MEN' 71='71. WOMEN' 72='72.TEENS'
                  73='73. ELDERLY' 74='74. MINORITY' 75='75. HOMOSEX'
                  76='76. VETERANS' 77='77. POOR' 78='78. HANDICAP'
                  79='79. OTHTARGT' 81='81. INPTTRMT' 82='82. INPTALCO'
                  83='83. INPTDETX' 84='84. INPTMETH' 85='85. INPT MH'
                  89='89. OTHINPT' 91='91. THERAPY' 92='92. INDTHRPY'
                  93='93. GRPTHRPY' 94='94. INTENSIV' 95='95. PARTHOSP'
                  97='97. OTHER' ;
  VALUE v4240fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4241fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4242fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4243fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4244fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4245fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PREVENTN' 2='2. AIDS ED'
                  3='3. CRISIS' 11='11. EVALUATN' 12='12. REFERRAL'
                  13='13. AFTRCARE' 14='14. REHABLTN' 21='21. JOB/EAP'
                  22='22. EDUC/GED' 23='23. FAMILY' 31='31. BASCNEED'
                  32='32. DAYCARE' 33='33. INDEPLIV' 34='34. PARENTED'
                  35='35. EXERCISE' 36='36. >#TRTLOC' 37='37. RELIGION'
                  41='41. AA/NA' 42='42. CO-DEPND' 43='43. DUALDIAG'
                  44='44. GENRL MH' 51='51. MEDICAL' 52='52. DETOX'
                  53='53. METHADON' 54='54. ANTABUSE' 55='55. TREXAN'
                  56='56. SYMMETRL' 59='59. OTHR MED' 61='61. AIDS TX'
                  62='62. DWI/DUI' 63='63. ALCOHOL' 64='64. COCAINE'
                  65='65. EATDISOR' 66='66. MULTDRUG' 67='67. PRISONER'
                  69='69. 9OTHRDRU' 70='70. MEN' 71='71. WOMEN' 72='72.TEENS'
                  73='73. ELDERLY' 74='74. MINORITY' 75='75. HOMOSEX'
                  76='76. VETERANS' 77='77. POOR' 78='78. HANDICAP'
                  79='79. OTHTARGT' 81='81. INPTTRMT' 82='82. INPTALCO'
                  83='83. INPTDETX' 84='84. INPTMETH' 85='85. INPT MH'
                  89='89. OTHINPT' 91='91. THERAPY' 92='92. INDTHRPY'
                  93='93. GRPTHRPY' 94='94. INTENSIV' 95='95. PARTHOSP'
                  97='97. OTHER' ;
  VALUE v4246fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4247fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4248fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4249fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4250fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4251fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PREVENTN' 2='2. AIDS ED'
                  3='3. CRISIS' 11='11. EVALUATN' 12='12. REFERRAL'
                  13='13. AFTRCARE' 14='14. REHABLTN' 21='21. JOB/EAP'
                  22='22. EDUC/GED' 23='23. FAMILY' 31='31. BASCNEED'
                  32='32. DAYCARE' 33='33. INDEPLIV' 34='34. PARENTED'
                  35='35. EXERCISE' 36='36. >#TRTLOC' 37='37. RELIGION'
                  41='41. AA/NA' 42='42. CO-DEPND' 43='43. DUALDIAG'
                  44='44. GENRL MH' 51='51. MEDICAL' 52='52. DETOX'
                  53='53. METHADON' 54='54. ANTABUSE' 55='55. TREXAN'
                  56='56. SYMMETRL' 59='59. OTHR MED' 61='61. AIDS TX'
                  62='62. DWI/DUI' 63='63. ALCOHOL' 64='64. COCAINE'
                  65='65. EATDISOR' 66='66. MULTDRUG' 67='67. PRISONER'
                  69='69. 9OTHRDRU' 70='70. MEN' 71='71. WOMEN' 72='72.TEENS'
                  73='73. ELDERLY' 74='74. MINORITY' 75='75. HOMOSEX'
                  76='76. VETERANS' 77='77. POOR' 78='78. HANDICAP'
                  79='79. OTHTARGT' 81='81. INPTTRMT' 82='82. INPTALCO'
                  83='83. INPTDETX' 84='84. INPTMETH' 85='85. INPT MH'
                  89='89. OTHINPT' 91='91. THERAPY' 92='92. INDTHRPY'
                  93='93. GRPTHRPY' 94='94. INTENSIV' 95='95. PARTHOSP'
                  97='97. OTHER' ;
  VALUE v4252fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4253fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4254fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4255fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4256fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4257fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4258fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 96='96. ALL' ;
  VALUE v4259fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PRIVATE FOR PROFIT'
                  2='2. PRIVATE NONPROFIT' 3='3. PUBLIC' ;
  VALUE v4260fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PROF CORP' 2='2. OTHR CORP'
                  3='3. PARTNERS' 4='4. SINGLE OWN' 97='97. SOMETHING ELSE' ;
  VALUE v4261fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4262fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4263fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4264fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. YES TO B55'
                  2='2. YES TO B56' 3='3. YES TO B57' 4='4. NO TO B55-57' ;
  VALUE v4265fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. PRIVATE OWN'
                  1='1. PUBLIC OWN' ;
  VALUE v4266fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. FEDERAL' 2='2. STATE'
                  3='3. LOCAL' ;
  VALUE v4267fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4268fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4269fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PROF CORP' 2='2. OTHR CORP'
                  3='3. PARTNERS' 4='4. SINGLE OWN' 97='97. SOMETHING ELSE' ;
  VALUE v4270fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. PRIVATE OWN'
                  1='1. PUBLIC OWN' ;
  VALUE v4271fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. FEDERAL' 2='2. STATE'
                  3='3. LOCAL' ;
  VALUE v4272fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4273fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NOT FOR PROFIT'
                  1='1. FOR PROFIT' ;
  VALUE v4274fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PROF CORP' 2='2. OTHR CORP'
                  3='3. PARTNERS' 4='4. SINGLE OWN' 97='97. SOMETHING ELSE' ;
  VALUE v4275fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. PRIVATE OWN'
                  1='1. PUBLIC OWN' ;
  VALUE v4276fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. FEDERAL' 2='2. STATE'
                  3='3. LOCAL' ;
  VALUE v4277fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4278fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NOT FOR PROFIT'
                  1='1. FOR PROFIT' ;
  VALUE v4279fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PROF CORP' 2='2. OTHR CORP'
                  3='3. PARTNERS' 4='4. SINGLE OWN' 97='97. SOMETHING ELSE' ;
  VALUE v4280fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4281fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4282fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4283fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4284fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4285fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4286fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4287fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4288fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4289fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4290fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4291fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4292fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4293fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4294fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 2 YR OR LESS'
                  2='2. ANNUALLY' 3='3. SEMI-ANNUAL' 4='4. QUARTERLY'
                  5='5. MONTHLY' 6='6. RANDOM' 7='7. OTHER' ;
  VALUE v4295fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4296fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 2 YR OR LESS'
                  2='2. ANNUALLY' 3='3. SEMI-ANNUAL' 4='4. QUARTERLY'
                  5='5. MONTHLY' 6='6. RANDOM' 7='7. OTHER' ;
  VALUE v4297fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4298fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 2 YR OR LESS'
                  2='2. ANNUALLY' 3='3. SEMI-ANNUAL' 4='4. QUARTERLY'
                  5='5. MONTHLY' 6='6. RANDOM' 7='7. OTHER' ;
  VALUE v4299fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4300fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 2 YR OR LESS'
                  2='2. ANNUALLY' 3='3. SEMI-ANNUAL' 4='4. QUARTERLY'
                  5='5. MONTHLY' 6='6. RANDOM' 7='7. OTHER' ;
  VALUE v4301fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4302fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 2 YR OR LESS'
                  2='2. ANNUALLY' 3='3. SEMI-ANNUAL' 4='4. QUARTERLY'
                  5='5. MONTHLY' 6='6. RANDOM' 7='7. OTHER' ;
  VALUE v4303fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4304fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 2 YR OR LESS'
                  2='2. ANNUALLY' 3='3. SEMI-ANNUAL' 4='4. QUARTERLY'
                  5='5. MONTHLY' 6='6. RANDOM' 7='7. OTHER' ;
  VALUE v4305fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4306fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 2 YR OR LESS'
                  2='2. ANNUALLY' 3='3. SEMI-ANNUAL' 4='4. QUARTERLY'
                  5='5. MONTHLY' 6='6. RANDOM' 7='7. OTHER' ;
  VALUE v4307fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4308fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 2 YR OR LESS'
                  2='2. ANNUALLY' 3='3. SEMI-ANNUAL' 4='4. QUARTERLY'
                  5='5. MONTHLY' 6='6. RANDOM' 7='7. OTHER' ;
  VALUE v4309fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4310fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4311fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4312fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4313fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4314fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4315fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4316fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4317fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4318fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4319fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4320fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4321fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4322fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4323fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4324fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4325fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4326fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4327fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4328fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4329fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4330fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4331fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4332fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4333fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4334fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4335fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4336fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4337fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. CHECK LIC' 2='2. ACCREDIT'
                  3='3. ADMINSTR' 5='5. NOT CHECK' ;
  VALUE v4338fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4339fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v4340fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4341fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. CHECK LIC' 2='2. ACCREDIT'
                  3='3. ADMINSTR' 5='5. NOT CHECK' ;
  VALUE v4342fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4343fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v4344fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4345fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. CHECK LIC' 2='2. ACCREDIT'
                  3='3. ADMINSTR' 5='5. NOT CHECK' ;
  VALUE v4346fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4347fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v4348fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4349fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4350fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4351fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4352fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. CHECK LIC' 2='2. ACCREDIT'
                  3='3. ADMINSTR' 5='5. NOT CHECK' ;
  VALUE v4353fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4354fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4355fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v4356fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4357fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. CHECK LIC' 2='2. ACCREDIT'
                  3='3. ADMINSTR' 5='5. NOT CHECK' ;
  VALUE v4358fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4359fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4360fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v4361fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4362fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. CHECK LIC' 2='2. ACCREDIT'
                  3='3. ADMINSTR' 5='5. NOT CHECK' ;
  VALUE v4363fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4364fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4365fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v4366fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4367fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4368fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4369fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4370fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. CHECK LIC' 2='2. ACCREDIT'
                  3='3. ADMINSTR' 5='5. NOT CHECK' ;
  VALUE v4371fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4372fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4373fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v4374fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4375fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. CHECK LIC' 2='2. ACCREDIT'
                  3='3. ADMINSTR' 5='5. NOT CHECK' ;
  VALUE v4376fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4377fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4378fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v4379fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4380fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. CHECK LIC' 2='2. ACCREDIT'
                  3='3. ADMINSTR' 5='5. NOT CHECK' ;
  VALUE v4381fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4382fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4383fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v4384fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4385fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4386fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4387fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4388fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4389fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4390fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. CHECK LIC' 2='2. ACCREDIT'
                  3='3. ADMINSTR' 5='5. NOT CHECK' ;
  VALUE v4391fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4392fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v4393fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4394fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. CHECK LIC' 2='2. ACCREDIT'
                  3='3. ADMINSTR' 5='5. NOT CHECK' ;
  VALUE v4395fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4396fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v4397fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4398fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. CHECK LIC' 2='2. ACCREDIT'
                  3='3. ADMINSTR' 5='5. NOT CHECK' ;
  VALUE v4399fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4400fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v4401fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4402fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4403fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4404fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4405fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. CHECK LIC' 2='2. ACCREDIT'
                  3='3. ADMINSTR' 5='5. NOT CHECK' ;
  VALUE v4406fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4407fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4408fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v4409fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4410fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. CHECK LIC' 2='2. ACCREDIT'
                  3='3. ADMINSTR' 5='5. NOT CHECK' ;
  VALUE v4411fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4412fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4413fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v4414fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4415fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. CHECK LIC' 2='2. ACCREDIT'
                  3='3. ADMINSTR' 5='5. NOT CHECK' ;
  VALUE v4416fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4417fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4418fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v4419fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4420fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4421fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4422fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4423fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. CHECK LIC' 2='2. ACCREDIT'
                  3='3. ADMINSTR' 5='5. NOT CHECK' ;
  VALUE v4424fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4425fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4426fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v4427fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4428fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. CHECK LIC' 2='2. ACCREDIT'
                  3='3. ADMINSTR' 5='5. NOT CHECK' ;
  VALUE v4429fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4430fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4431fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v4432fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4433fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. CHECK LIC' 2='2. ACCREDIT'
                  3='3. ADMINSTR' 5='5. NOT CHECK' ;
  VALUE v4434fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4435fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4436fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v4437fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4438fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4439fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4440fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4441fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4442fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4443fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. CHECK LIC' 2='2. ACCREDIT'
                  3='3. ADMINSTR' 5='5. NOT CHECK' ;
  VALUE v4444fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4445fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v4446fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4447fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. CHECK LIC' 2='2. ACCREDIT'
                  3='3. ADMINSTR' 5='5. NOT CHECK' ;
  VALUE v4448fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4449fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v4450fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4451fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. CHECK LIC' 2='2. ACCREDIT'
                  3='3. ADMINSTR' 5='5. NOT CHECK' ;
  VALUE v4452fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4453fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v4454fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4455fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4456fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4457fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4458fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. CHECK LIC' 2='2. ACCREDIT'
                  3='3. ADMINSTR' 5='5. NOT CHECK' ;
  VALUE v4459fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4460fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4461fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v4462fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4463fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. CHECK LIC' 2='2. ACCREDIT'
                  3='3. ADMINSTR' 5='5. NOT CHECK' ;
  VALUE v4464fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4465fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4466fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v4467fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4468fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. CHECK LIC' 2='2. ACCREDIT'
                  3='3. ADMINSTR' 5='5. NOT CHECK' ;
  VALUE v4469fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4470fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4471fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v4472fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4473fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4474fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4475fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4476fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. CHECK LIC' 2='2. ACCREDIT'
                  3='3. ADMINSTR' 5='5. NOT CHECK' ;
  VALUE v4477fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4478fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4479fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v4480fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4481fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. CHECK LIC' 2='2. ACCREDIT'
                  3='3. ADMINSTR' 5='5. NOT CHECK' ;
  VALUE v4482fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4483fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4484fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v4485fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4486fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. CHECK LIC' 2='2. ACCREDIT'
                  3='3. ADMINSTR' 5='5. NOT CHECK' ;
  VALUE v4487fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4488fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4489fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v4490fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4491fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4492fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4493fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4494fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LACK STAFF'
                  2='2. NOT ENOUGH $$' 11='11. CLI PRIVACY' 12='12. TRANSENT'
                  51='51. STATE DATA' 52='52. NOT REQUIRED'
                  95='95. NOT GOTTEN TO YET' 96='96. DO NOT USE'
                  97='97. OTHER' ;
  VALUE v4495fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LACK STAFF'
                  2='2. NOT ENOUGH $$' 11='11. CLI PRIVACY' 12='12. TRANSENT'
                  51='51. STATE DATA' 52='52. NOT REQUIRED'
                  95='95. NOT GOTTEN TO YET' 96='96. DO NOT USE'
                  97='97. OTHER' ;
  VALUE v4496fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4497fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4498fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4499fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4500fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4501fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4502fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v4503fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4504fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4505fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4506fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4507fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4508fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4509fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4510fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4511fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4512fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4513fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4514fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4515fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. OTHER CLI TRT'
                  2='2. CHANGE IN FAM' 3='3. FAM INFO' 11='11. AIDS INFO'
                  12='12. MENTAL HEALTH' 97='97. OTHER' ;
  VALUE v4516fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. OTHER CLI TRT'
                  2='2. CHANGE IN FAM' 3='3. FAM INFO' 11='11. AIDS INFO'
                  12='12. MENTAL HEALTH' 97='97. OTHER' ;
  VALUE v4517fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4518fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4519fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4520fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4521fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LETTERS' 2='2. FRND/REL'
                  3='3. CLIENTS' 11='11. OTHER AGY' 97='97. OTHER' ;
  VALUE v4522fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LETTERS' 2='2. FRND/REL'
                  3='3. CLIENTS' 11='11. OTHER AGY' 97='97. OTHER' ;
  VALUE v4523fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4524fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VOLUNTER' 2='2. CLERICAL'
                  97='97. OTHER' ;
  VALUE v4525fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VOLUNTER' 2='2. CLERICAL'
                  97='97. OTHER' ;
  VALUE v4526fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4527fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4528fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4529fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PUBLIC' 2='2. PRIVATE'
                  3='3. BOTH' ;
  VALUE v4530fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4531fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PUBLIC' 2='2. PRIVATE'
                  3='3. BOTH' ;
  VALUE v4532fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4533fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PUBLIC' 2='2. PRIVATE'
                  3='3. BOTH' ;
  VALUE v4534fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4535fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4536fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4537fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4538fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4539fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4540fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4541fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4542fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4543fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4544fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4545fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4546fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4547fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4548fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4549fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. INCREASE GREAT DEAL'
                  2='2. INCREASE SOME' 3='3. REMAIN SAME'
                  4='4. DECREASE SOME' 5='5. DECREASE GREAT DEAL' ;
  VALUE v4550fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LESS $' 2='2. MORE $'
                  3='3. PROFITS' 4='4. MARKETNG' 11='11. MOREWORK'
                  12='12. MORE AGY' 13='13. FEWRSTAF' 14='14. FEWERAGY'
                  21='21. MORE COOPERAT' 97='97. OTHER' ;
  VALUE v4551fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LESS $' 2='2. MORE $'
                  3='3. PROFITS' 4='4. MARKETNG' 11='11. MOREWORK'
                  12='12. MORE AGY' 13='13. FEWRSTAF' 14='14. FEWERAGY'
                  21='21. MORE COOPERAT' 97='97. OTHER' ;
  VALUE v4552fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 1 HR OR LESS' ;
  VALUE v4553fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 1 HR OR LESS' ;
  VALUE v4554fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 1 HR OR LESS' ;
  VALUE v4555fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 1 HR OR LESS' ;
  VALUE v4556fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 1 HR OR LESS' ;
  VALUE v4557fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 1 HR OR LESS' ;
  VALUE v4558fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 1 HR OR LESS' ;
  VALUE v4559fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 1 HR OR LESS' ;
  VALUE v4560fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. OWNSTAFF' 2='2. ORGOWNSU'
                  3='3. CONTRACT' 4='4. INFARRNG' 5='5. OTHARRNG'
                  6='6. NOTAPPLY' 7='7. MULTI CHKS' ;
  VALUE v4561fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. OWNSTAFF' 2='2. ORGOWNSU'
                  3='3. CONTRACT' 4='4. INFARRNG' 5='5. OTHARRNG'
                  6='6. NOTAPPLY' 7='7. MULTI CHKS' ;
  VALUE v4562fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. OWNSTAFF' 2='2. ORGOWNSU'
                  3='3. CONTRACT' 4='4. INFARRNG' 5='5. OTHARRNG'
                  6='6. NOTAPPLY' 7='7. MULTI CHKS' ;
  VALUE v4563fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. OWNSTAFF' 2='2. ORGOWNSU'
                  3='3. CONTRACT' 4='4. INFARRNG' 5='5. OTHARRNG'
                  6='6. NOTAPPLY' 7='7. MULTI CHKS' ;
  VALUE v4564fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. OWNSTAFF' 2='2. ORGOWNSU'
                  3='3. CONTRACT' 4='4. INFARRNG' 5='5. OTHARRNG'
                  6='6. NOTAPPLY' 7='7. MULTI CHKS' ;
  VALUE v4565fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. OWNSTAFF' 2='2. ORGOWNSU'
                  3='3. CONTRACT' 4='4. INFARRNG' 5='5. OTHARRNG'
                  6='6. NOTAPPLY' 7='7. MULTI CHKS' ;
  VALUE v4566fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. OWNSTAFF' 2='2. ORGOWNSU'
                  3='3. CONTRACT' 4='4. INFARRNG' 5='5. OTHARRNG'
                  6='6. NOTAPPLY' 7='7. MULTI CHKS' ;
  VALUE v4567fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. OWNSTAFF' 2='2. ORGOWNSU'
                  3='3. CONTRACT' 4='4. INFARRNG' 5='5. OTHARRNG'
                  6='6. NOTAPPLY' 7='7. MULTI CHKS' ;
  VALUE v4568fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. OWNSTAFF' 2='2. ORGOWNSU'
                  3='3. CONTRACT' 4='4. INFARRNG' 5='5. OTHARRNG'
                  6='6. NOTAPPLY' 7='7. MULTI CHKS' ;
  VALUE v4569fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. OWNSTAFF' 2='2. ORGOWNSU'
                  3='3. CONTRACT' 4='4. INFARRNG' 5='5. OTHARRNG'
                  6='6. NOTAPPLY' 7='7. MULTI CHKS' ;
  VALUE v4570fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. OWNSTAFF' 2='2. ORGOWNSU'
                  3='3. CONTRACT' 4='4. INFARRNG' 5='5. OTHARRNG'
                  6='6. NOTAPPLY' 7='7. MULTI CHKS' ;
  VALUE v4571fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO REFERRAL'
                  1='1. ORG MENTION' ;
  VALUE v4572fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4573fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4574fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4575fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4576fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4577fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4578fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4579fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4580fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4581fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4582fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4583fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4584fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 51='51. HMO' 52='52. REFRLORG'
                  53='53. RESIDFAC' 61='61. OTHGOVTU' 62='62. OTHOSATU'
                  97='97. OTHER' ;
  VALUE v4585fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4586fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4587fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4588fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4589fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4590fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v4591fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. SERVICES' 2='2. QUALITY'
                  3='3. STAFF' 4='4. COST' 11='11. AVAILABL'
                  12='12. ONLYSOUR' 21='21. COMMGOAL' 22='22. FAMILIAR'
                  31='31. GRT NEED' 81='81. PARENT' 82='82. PROFIT'
                  97='97. OTHER' ;
  VALUE v4592fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4593fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4594fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4595fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4596fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4597fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4598fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4599fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4600fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. REPORTNG' 2='2. REQUIRED'
                  3='3. OPTREFUS' 4='4. QUALITY' 5='5. PAYMENT'
                  21='21. EVALUATN' 22='22. SEECLJAL' 23='23. URINAL'
                  24='24. DRUGEDUC' 51='51. COOPERAT' 52='52. MUSTREFR'
                  95='95. INFAGREE' 96='96. NONE' 97='97. OTHER' ;
  VALUE v4601fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. REPORTNG' 2='2. REQUIRED'
                  3='3. OPTREFUS' 4='4. QUALITY' 5='5. PAYMENT'
                  21='21. EVALUATN' 22='22. SEECLJAL' 23='23. URINAL'
                  24='24. DRUGEDUC' 51='51. COOPERAT' 52='52. MUSTREFR'
                  95='95. INFAGREE' 96='96. NONE' 97='97. OTHER' ;
  VALUE v4602fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4603fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4604fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4605fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4606fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4607fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4608fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4609fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4610fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4611fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4612fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4613fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4614fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4615fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4616fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. ONLYTYPE' 1='1. NAME'
                  997='997. OTHER' ;
  VALUE v4617fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HOSPITLU' 2='2. MHCENTRU'
                  3='3. FRESTAND' 7='7. OTHER' ;
  VALUE v4618fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. PRIVATE' 1='1. PUBLIC' ;
  VALUE v4619fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4620fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4621fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4622fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4623fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4624fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4625fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4626fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4627fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4628fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4629fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. EXCHANGE REF'
                  2='2. WORK TOGETHER' 3='3. REF TO THEM' 4='4. REFER TO US'
                  95='95. NO CONTRACT' 96='96. NO OTR FEATRS,NONE'
                  97='97. OTHER' ;
  VALUE v4630fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. EXCHANGE REF'
                  2='2. WORK TOGETHER' 3='3. REF TO THEM' 4='4. REFER TO US'
                  95='95. NO CONTRACT' 96='96. NO OTR FEATRS,NONE'
                  97='97. OTHER' ;
  VALUE v4631fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4632fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4633fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4634fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4635fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4636fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4637fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4638fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4639fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4640fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4641fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4642fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4643fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4644fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4645fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4646fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4647fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4648fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4649fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v4650fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. ALLOTHER' 1='1. HAS PARENT' ;
  VALUE v4651fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4652fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MUCH LOWER'
                  2='2. SOMEWHAT LOWER' 3='3. ABOUT SAME'
                  4='4. SOMEWHAT HIGHER' 5='5. MUCH HIGHER' ;
  VALUE v4653fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MUCH LOWER'
                  2='2. SOMEWHAT LOWER' 3='3. ABOUT SAME'
                  4='4. SOMEWHAT HIGHER' 5='5. MUCH HIGHER' ;
  VALUE v4654fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MUCH LOWER'
                  2='2. SOMEWHAT LOWER' 3='3. ABOUT SAME'
                  4='4. SOMEWHAT HIGHER' 5='5. MUCH HIGHER' ;
  VALUE v4655fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MUCH LOWER'
                  2='2. SOMEWHAT LOWER' 3='3. ABOUT SAME'
                  4='4. SOMEWHAT HIGHER' 5='5. MUCH HIGHER' ;
  VALUE v4656fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MUCH LOWER'
                  2='2. SOMEWHAT LOWER' 3='3. ABOUT SAME'
                  4='4. SOMEWHAT HIGHER' 5='5. MUCH HIGHER' ;
  VALUE v4657fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MUCH LOWER'
                  2='2. SOMEWHAT LOWER' 3='3. ABOUT SAME'
                  4='4. SOMEWHAT HIGHER' 5='5. MUCH HIGHER' ;
  VALUE v4658fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NO ACCCEPTANCE'
                  2='2. LITTLE ACCEPTANCE' 3='3. SOME ACCEPTANCE'
                  4='4. CONSIDERABLE ACCEPTANCE' 5='5. COMPLETE ACCEPTANCE' ;
  VALUE v4659fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. SERVICES' 2='2. QUALITY'
                  3='3. STAFF' 4='4. COSTS' 11='11. AVAILABL'
                  21='21. COMMGOAL' 22='22. FAMILIAR' 51='51. LACKGOAL'
                  52='52. LACKPROX' 53='53. STIGMA' 67='67. OTHREASN'
                  97='97. OTHER' ;
  VALUE v4660fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. SERVICES' 2='2. QUALITY'
                  3='3. STAFF' 4='4. COSTS' 11='11. AVAILABL'
                  21='21. COMMGOAL' 22='22. FAMILIAR' 51='51. LACKGOAL'
                  52='52. LACKPROX' 53='53. STIGMA' 67='67. OTHREASN'
                  97='97. OTHER' ;
  VALUE v4661fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MUCH LOWER'
                  2='2. SOMEWHAT LOWER' 3='3. ABOUT SAME'
                  4='4. SOMEWHAT HIGHER' 5='5. MUCH HIGHER' ;
  VALUE v4662fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MUCH LOWER'
                  2='2. SOMEWHAT LOWER' 3='3. ABOUT SAME'
                  4='4. SOMEWHAT HIGHER' 5='5. MUCH HIGHER' ;
  VALUE v4663fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MUCH LOWER'
                  2='2. SOMEWHAT LOWER' 3='3. ABOUT SAME'
                  4='4. SOMEWHAT HIGHER' 5='5. MUCH HIGHER' ;
  VALUE v4664fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MUCH LOWER'
                  2='2. SOMEWHAT LOWER' 3='3. ABOUT SAME'
                  4='4. SOMEWHAT HIGHER' 5='5. MUCH HIGHER' ;
  VALUE v4665fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MUCH LOWER'
                  2='2. SOMEWHAT LOWER' 3='3. ABOUT SAME'
                  4='4. SOMEWHAT HIGHER' 5='5. MUCH HIGHER' ;
  VALUE v4666fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MUCH LOWER'
                  2='2. SOMEWHAT LOWER' 3='3. ABOUT SAME'
                  4='4. SOMEWHAT HIGHER' 5='5. MUCH HIGHER' ;
  VALUE v4667fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4668fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4669fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4670fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4671fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4672fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4673fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4674fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4675fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4676fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4677fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4678fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4679fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4680fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4681fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4682fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4683fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4684fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4685fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4686fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4687fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4688fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4689fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4690fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4691fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4692fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4693fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4694fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4695fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4696fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4697fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4698fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4699fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4700fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4701fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4702fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4703fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4704fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4705fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4706fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PREVENTN' 2='2. AIDS ED'
                  3='3. CRISIS' 11='11. EVALUATN' 12='12. REFERRAL'
                  13='13. AFTRCARE' 14='14. REHABLTN' 21='21. JOB/EAP'
                  22='22. EDUC/GED' 23='23. FAMILY' 31='31. BASCNEED'
                  32='32. DAYCARE' 33='33. INDEPLIV' 34='34. PARENTED'
                  35='35. EXERCISE' 36='36. >#TRTLOC' 37='37. RELIGION'
                  41='41. AA/NA' 42='42. CO-DEPND' 43='43. DUALDIAG'
                  44='44. GENRL MH' 51='51. MEDICAL' 52='52. DETOX'
                  53='53. METHADON' 54='54. ANTABUSE' 55='55. TREXAN'
                  56='56. SYMMETRL' 59='59. OTHR MED' 61='61. AIDS TX'
                  62='62. DWI/DUI' 63='63. ALCOHOL' 64='64. COCAINE'
                  65='65. EATDISOR' 66='66. MULTDRUG' 67='67. PRISONER'
                  69='69. 9OTHRDRU' 70='70. MEN' 71='71. WOMEN' 72='72.TEENS'
                  73='73. ELDERLY' 74='74. MINORITY' 75='75. HOMOSEX'
                  76='76. VETERANS' 77='77. POOR' 78='78. HANDICAP'
                  79='79. OTHTARGT' 81='81. INPTTRMT' 82='82. INPTALCO'
                  83='83. INPTDETX' 84='84. INPTMETH' 85='85. INPT MH'
                  89='89. OTHINPT' 91='91. THERAPY' 92='92. INDTHRPY'
                  93='93. GRPTHRPY' 94='94. INTENSIV' 95='95. PARTHOSP'
                  97='97. OTHER' ;
  VALUE v4707fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PREVENTN' 2='2. AIDS ED'
                  3='3. CRISIS' 11='11. EVALUATN' 12='12. REFERRAL'
                  13='13. AFTRCARE' 14='14. REHABLTN' 21='21. JOB/EAP'
                  22='22. EDUC/GED' 23='23. FAMILY' 31='31. BASCNEED'
                  32='32. DAYCARE' 33='33. INDEPLIV' 34='34. PARENTED'
                  35='35. EXERCISE' 36='36. >#TRTLOC' 37='37. RELIGION'
                  41='41. AA/NA' 42='42. CO-DEPND' 43='43. DUALDIAG'
                  44='44. GENRL MH' 51='51. MEDICAL' 52='52. DETOX'
                  53='53. METHADON' 54='54. ANTABUSE' 55='55. TREXAN'
                  56='56. SYMMETRL' 59='59. OTHR MED' 61='61. AIDS TX'
                  62='62. DWI/DUI' 63='63. ALCOHOL' 64='64. COCAINE'
                  65='65. EATDISOR' 66='66. MULTDRUG' 67='67. PRISONER'
                  69='69. 9OTHRDRU' 70='70. MEN' 71='71. WOMEN' 72='72.TEENS'
                  73='73. ELDERLY' 74='74. MINORITY' 75='75. HOMOSEX'
                  76='76. VETERANS' 77='77. POOR' 78='78. HANDICAP'
                  79='79. OTHTARGT' 81='81. INPTTRMT' 82='82. INPTALCO'
                  83='83. INPTDETX' 84='84. INPTMETH' 85='85. INPT MH'
                  89='89. OTHINPT' 91='91. THERAPY' 92='92. INDTHRPY'
                  93='93. GRPTHRPY' 94='94. INTENSIV' 95='95. PARTHOSP'
                  97='97. OTHER' ;
  VALUE v4708fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PREVENTN' 2='2. AIDS ED'
                  3='3. CRISIS' 11='11. EVALUATN' 12='12. REFERRAL'
                  13='13. AFTRCARE' 14='14. REHABLTN' 21='21. JOB/EAP'
                  22='22. EDUC/GED' 23='23. FAMILY' 31='31. BASCNEED'
                  32='32. DAYCARE' 33='33. INDEPLIV' 34='34. PARENTED'
                  35='35. EXERCISE' 36='36. >#TRTLOC' 37='37. RELIGION'
                  41='41. AA/NA' 42='42. CO-DEPND' 43='43. DUALDIAG'
                  44='44. GENRL MH' 51='51. MEDICAL' 52='52. DETOX'
                  53='53. METHADON' 54='54. ANTABUSE' 55='55. TREXAN'
                  56='56. SYMMETRL' 59='59. OTHR MED' 61='61. AIDS TX'
                  62='62. DWI/DUI' 63='63. ALCOHOL' 64='64. COCAINE'
                  65='65. EATDISOR' 66='66. MULTDRUG' 67='67. PRISONER'
                  69='69. 9OTHRDRU' 70='70. MEN' 71='71. WOMEN' 72='72.TEENS'
                  73='73. ELDERLY' 74='74. MINORITY' 75='75. HOMOSEX'
                  76='76. VETERANS' 77='77. POOR' 78='78. HANDICAP'
                  79='79. OTHTARGT' 81='81. INPTTRMT' 82='82. INPTALCO'
                  83='83. INPTDETX' 84='84. INPTMETH' 85='85. INPT MH'
                  89='89. OTHINPT' 91='91. THERAPY' 92='92. INDTHRPY'
                  93='93. GRPTHRPY' 94='94. INTENSIV' 95='95. PARTHOSP'
                  97='97. OTHER' ;
  VALUE v4709fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PREVENTN' 2='2. AIDS ED'
                  3='3. CRISIS' 11='11. EVALUATN' 12='12. REFERRAL'
                  13='13. AFTRCARE' 14='14. REHABLTN' 21='21. JOB/EAP'
                  22='22. EDUC/GED' 23='23. FAMILY' 31='31. BASCNEED'
                  32='32. DAYCARE' 33='33. INDEPLIV' 34='34. PARENTED'
                  35='35. EXERCISE' 36='36. >#TRTLOC' 37='37. RELIGION'
                  41='41. AA/NA' 42='42. CO-DEPND' 43='43. DUALDIAG'
                  44='44. GENRL MH' 51='51. MEDICAL' 52='52. DETOX'
                  53='53. METHADON' 54='54. ANTABUSE' 55='55. TREXAN'
                  56='56. SYMMETRL' 59='59. OTHR MED' 61='61. AIDS TX'
                  62='62. DWI/DUI' 63='63. ALCOHOL' 64='64. COCAINE'
                  65='65. EATDISOR' 66='66. MULTDRUG' 67='67. PRISONER'
                  69='69. 9OTHRDRU' 70='70. MEN' 71='71. WOMEN' 72='72.TEENS'
                  73='73. ELDERLY' 74='74. MINORITY' 75='75. HOMOSEX'
                  76='76. VETERANS' 77='77. POOR' 78='78. HANDICAP'
                  79='79. OTHTARGT' 81='81. INPTTRMT' 82='82. INPTALCO'
                  83='83. INPTDETX' 84='84. INPTMETH' 85='85. INPT MH'
                  89='89. OTHINPT' 91='91. THERAPY' 92='92. INDTHRPY'
                  93='93. GRPTHRPY' 94='94. INTENSIV' 95='95. PARTHOSP'
                  97='97. OTHER' ;
  VALUE v4710fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4711fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PREVENTN' 2='2. AIDS ED'
                  3='3. CRISIS' 11='11. EVALUATN' 12='12. REFERRAL'
                  13='13. AFTRCARE' 14='14. REHABLTN' 21='21. JOB/EAP'
                  22='22. EDUC/GED' 23='23. FAMILY' 31='31. BASCNEED'
                  32='32. DAYCARE' 33='33. INDEPLIV' 34='34. PARENTED'
                  35='35. EXERCISE' 36='36. >#TRTLOC' 37='37. RELIGION'
                  41='41. AA/NA' 42='42. CO-DEPND' 43='43. DUALDIAG'
                  44='44. GENRL MH' 51='51. MEDICAL' 52='52. DETOX'
                  53='53. METHADON' 54='54. ANTABUSE' 55='55. TREXAN'
                  56='56. SYMMETRL' 59='59. OTHR MED' 61='61. AIDS TX'
                  62='62. DWI/DUI' 63='63. ALCOHOL' 64='64. COCAINE'
                  65='65. EATDISOR' 66='66. MULTDRUG' 67='67. PRISONER'
                  69='69. 9OTHRDRU' 70='70. MEN' 71='71. WOMEN' 72='72.TEENS'
                  73='73. ELDERLY' 74='74. MINORITY' 75='75. HOMOSEX'
                  76='76. VETERANS' 77='77. POOR' 78='78. HANDICAP'
                  79='79. OTHTARGT' 81='81. INPTTRMT' 82='82. INPTALCO'
                  83='83. INPTDETX' 84='84. INPTMETH' 85='85. INPT MH'
                  89='89. OTHINPT' 91='91. THERAPY' 92='92. INDTHRPY'
                  93='93. GRPTHRPY' 94='94. INTENSIV' 95='95. PARTHOSP'
                  97='97. OTHER' ;
  VALUE v4712fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PREVENTN' 2='2. AIDS ED'
                  3='3. CRISIS' 11='11. EVALUATN' 12='12. REFERRAL'
                  13='13. AFTRCARE' 14='14. REHABLTN' 21='21. JOB/EAP'
                  22='22. EDUC/GED' 23='23. FAMILY' 31='31. BASCNEED'
                  32='32. DAYCARE' 33='33. INDEPLIV' 34='34. PARENTED'
                  35='35. EXERCISE' 36='36. >#TRTLOC' 37='37. RELIGION'
                  41='41. AA/NA' 42='42. CO-DEPND' 43='43. DUALDIAG'
                  44='44. GENRL MH' 51='51. MEDICAL' 52='52. DETOX'
                  53='53. METHADON' 54='54. ANTABUSE' 55='55. TREXAN'
                  56='56. SYMMETRL' 59='59. OTHR MED' 61='61. AIDS TX'
                  62='62. DWI/DUI' 63='63. ALCOHOL' 64='64. COCAINE'
                  65='65. EATDISOR' 66='66. MULTDRUG' 67='67. PRISONER'
                  69='69. 9OTHRDRU' 70='70. MEN' 71='71. WOMEN' 72='72.TEENS'
                  73='73. ELDERLY' 74='74. MINORITY' 75='75. HOMOSEX'
                  76='76. VETERANS' 77='77. POOR' 78='78. HANDICAP'
                  79='79. OTHTARGT' 81='81. INPTTRMT' 82='82. INPTALCO'
                  83='83. INPTDETX' 84='84. INPTMETH' 85='85. INPT MH'
                  89='89. OTHINPT' 91='91. THERAPY' 92='92. INDTHRPY'
                  93='93. GRPTHRPY' 94='94. INTENSIV' 95='95. PARTHOSP'
                  97='97. OTHER' ;
  VALUE v4713fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PREVENTN' 2='2. AIDS ED'
                  3='3. CRISIS' 11='11. EVALUATN' 12='12. REFERRAL'
                  13='13. AFTRCARE' 14='14. REHABLTN' 21='21. JOB/EAP'
                  22='22. EDUC/GED' 23='23. FAMILY' 31='31. BASCNEED'
                  32='32. DAYCARE' 33='33. INDEPLIV' 34='34. PARENTED'
                  35='35. EXERCISE' 36='36. >#TRTLOC' 37='37. RELIGION'
                  41='41. AA/NA' 42='42. CO-DEPND' 43='43. DUALDIAG'
                  44='44. GENRL MH' 51='51. MEDICAL' 52='52. DETOX'
                  53='53. METHADON' 54='54. ANTABUSE' 55='55. TREXAN'
                  56='56. SYMMETRL' 59='59. OTHR MED' 61='61. AIDS TX'
                  62='62. DWI/DUI' 63='63. ALCOHOL' 64='64. COCAINE'
                  65='65. EATDISOR' 66='66. MULTDRUG' 67='67. PRISONER'
                  69='69. 9OTHRDRU' 70='70. MEN' 71='71. WOMEN' 72='72.TEENS'
                  73='73. ELDERLY' 74='74. MINORITY' 75='75. HOMOSEX'
                  76='76. VETERANS' 77='77. POOR' 78='78. HANDICAP'
                  79='79. OTHTARGT' 81='81. INPTTRMT' 82='82. INPTALCO'
                  83='83. INPTDETX' 84='84. INPTMETH' 85='85. INPT MH'
                  89='89. OTHINPT' 91='91. THERAPY' 92='92. INDTHRPY'
                  93='93. GRPTHRPY' 94='94. INTENSIV' 95='95. PARTHOSP'
                  97='97. OTHER' ;
  VALUE v4714fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PREVENTN' 2='2. AIDS ED'
                  3='3. CRISIS' 11='11. EVALUATN' 12='12. REFERRAL'
                  13='13. AFTRCARE' 14='14. REHABLTN' 21='21. JOB/EAP'
                  22='22. EDUC/GED' 23='23. FAMILY' 31='31. BASCNEED'
                  32='32. DAYCARE' 33='33. INDEPLIV' 34='34. PARENTED'
                  35='35. EXERCISE' 36='36. >#TRTLOC' 37='37. RELIGION'
                  41='41. AA/NA' 42='42. CO-DEPND' 43='43. DUALDIAG'
                  44='44. GENRL MH' 51='51. MEDICAL' 52='52. DETOX'
                  53='53. METHADON' 54='54. ANTABUSE' 55='55. TREXAN'
                  56='56. SYMMETRL' 59='59. OTHR MED' 61='61. AIDS TX'
                  62='62. DWI/DUI' 63='63. ALCOHOL' 64='64. COCAINE'
                  65='65. EATDISOR' 66='66. MULTDRUG' 67='67. PRISONER'
                  69='69. 9OTHRDRU' 70='70. MEN' 71='71. WOMEN' 72='72.TEENS'
                  73='73. ELDERLY' 74='74. MINORITY' 75='75. HOMOSEX'
                  76='76. VETERANS' 77='77. POOR' 78='78. HANDICAP'
                  79='79. OTHTARGT' 81='81. INPTTRMT' 82='82. INPTALCO'
                  83='83. INPTDETX' 84='84. INPTMETH' 85='85. INPT MH'
                  89='89. OTHINPT' 91='91. THERAPY' 92='92. INDTHRPY'
                  93='93. GRPTHRPY' 94='94. INTENSIV' 95='95. PARTHOSP'
                  97='97. OTHER' ;
  VALUE v4715fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4716fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4717fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4718fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4719fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4720fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4721fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4722fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4723fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4724fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4725fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4726fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4727fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4728fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4729fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4730fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4731fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4732fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4733fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4734fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. DIRECTOR' 2='2. ASSOCDIR'
                  3='3. FINANDIR' 4='4. PLANNER' 5='5. ADMNASST'
                  6='6. OFFICMGR' 7='7. CLERK' 9='9. PUBRELAT'
                  10='10. LEGALSRV' 19='19. OTHADMIN' 21='21. OUTPTDIR'
                  22='22. ASSTHEAD' 23='23. CCLINSUP' 31='31. PROBOFFC'
                  32='32. COUNSELR' 34='34. CLERGY' 38='38. ADVISOR'
                  41='41. PHYSICAN' 42='42. NURSE' 43='43. OTHPRO'
                  44='44. PSYCHGST' 45='45. SOCWORKR' 71='71. VOLUNTER'
                  72='72. STUDENT' 73='73. PUBOFFCL' 74='74. PROFESOR'
                  95='95. NONE' 97='97. OTHER' ;
  VALUE v4735fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4736fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4737fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. DIRECTOR' 2='2. ASSOCDIR'
                  3='3. FINANDIR' 4='4. PLANNER' 5='5. ADMNASST'
                  6='6. OFFICMGR' 7='7. CLERK' 9='9. PUBRELAT'
                  10='10. LEGALSRV' 19='19. OTHADMIN' 21='21. OUTPTDIR'
                  22='22. ASSTHEAD' 23='23. CCLINSUP' 31='31. PROBOFFC'
                  32='32. COUNSELR' 34='34. CLERGY' 38='38. ADVISOR'
                  41='41. PHYSICAN' 42='42. NURSE' 43='43. OTHPRO'
                  44='44. PSYCHGST' 45='45. SOCWORKR' 71='71. VOLUNTER'
                  72='72. STUDENT' 73='73. PUBOFFCL' 74='74. PROFESOR'
                  95='95. NONE' 97='97. OTHER' ;
  VALUE v4738fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. OTHER ORG' 1='1. THIS UNIT' ;
  VALUE v4739fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4740fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4741fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 29 YEARS OLD OR YOUNGER'
                  2='2. 30-34 YEARS OLD' 3='3. 35-39 YEARS OLD'
                  4='4. 40-44 YEARS OLD' 5='5. 45-49 YEARS OLD'
                  6='6. 50-54 YEARS OLD' 7='7. 55-59 YEARS OLD'
                  8='8. 60 YEARS OLD OR OLDER' ;
  VALUE v4742fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. Female' 1='1. Male' ;
  VALUE v4743fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. YES' 5='5. NO' ;
  VALUE v4744fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. WHITE' 2='2. BLACK'
                  5='5. OTHER' ;
  VALUE v4745fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MARRIED' 2='2. SEPARATE'
                  3='3. DIVORCED' 4='4. WIDOWED' 5='5. NEVER MAR' ;
  VALUE v4746fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4747fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4748fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4749fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4750fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v4751fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4752fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4753fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. A.A.2YR' 2='2. R.N.'
                  3='3. BA/BS' 4='4. MA/MS' 5='5. MD' 6='6. PH.D.'
                  7='7. OTHER' ;
  VALUE v4754fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v4755fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. A.A.2YR' 2='2. R.N.'
                  3='3. BA/BS' 4='4. MA/MS' 5='5. MD' 6='6. PH.D.'
                  7='7. OTHER' ;
  VALUE v4756fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v4757fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. A.A.2YR' 2='2. R.N.'
                  3='3. BA/BS' 4='4. MA/MS' 5='5. MD' 6='6. PH.D.'
                  7='7. OTHER' ;
  VALUE v4758fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v4759fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v4764fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4765fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4766fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4767fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4768fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4769fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4770fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4771fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4772fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4773fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4774fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4775fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4776fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4777fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4778fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4779fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4780fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4781fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4782fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4783fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4784fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4785fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4786fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4787fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4788fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4789fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v4790fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v5004fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5005fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5006fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5007fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5008fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5009fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5010fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5011fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5012fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5013fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5014fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5015fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5016fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5017fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5018fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5019fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5020fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5021fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5022fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5023fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5024fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5025fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5026fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5027fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5028fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 51='51. INPT FAC' 52='52. AA'
                  53='53. HMO' 54='54. HOTLINE' 61='61. DUI/DWI'
                  62='62. PROBDEPT' 63='63. CHILDSRV' 64='64. EMPLOYER'
                  71='71. OTHRCNSL' 72='72. LAWYERS' 73='73. OTHROSAT'
                  74='74. ASSESORG' 75='75. SOCLSERV' 81='81. CL REFRL'
                  97='97. OTHER' ;
  VALUE v5029fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 51='51. INPT FAC' 52='52. AA'
                  53='53. HMO' 54='54. HOTLINE' 61='61. DUI/DWI'
                  62='62. PROBDEPT' 63='63. CHILDSRV' 64='64. EMPLOYER'
                  71='71. OTHRCNSL' 72='72. LAWYERS' 73='73. OTHROSAT'
                  74='74. ASSESORG' 75='75. SOCLSERV' 81='81. CL REFRL'
                  97='97. OTHER' ;
  VALUE v5030fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VOCREHAB' 2='2. COURTS'
                  3='3. HOSPITAL' 4='4. PRIVCLIN' 5='5. PHYSICAN' 6='6. DSS'
                  7='7. MH AGNCY' 8='8. EAP' 9='9. POLICE' 10='10. SCHOOLS'
                  11='11. CHURCHES' 12='12. SELF_REF' 13='13. FRIENDS'
                  14='14. FAMILY' 51='51. INPT FAC' 52='52. AA' 53='53. HMO'
                  54='54. HOTLINE' 61='61. DUI/DWI' 62='62. PAROLE'
                  63='63. DEPT CHILD' 71='71. PROFCNSL' 72='72. LAWYERS'
                  73='73. OTHOSAT' 74='74. INTAKERE' 75='75. SERVPROV'
                  97='97. OTHER' ;
  VALUE v5031fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. FEWSOURC' 2='2. LARGE %'
                  3='3. EXCHANGE' 4='4. GOODCAND' 5='5. QUALREFR'
                  6='6. MOTIV CL' 7='7. FUNDING' 8='8. GOOD REP'
                  9='9. TARGTPOP' 21='21. ONLYAVAL' 22='22. CL REFRL'
                  29='29. OTHER CL' 51='51. FINANCAL' 95='95. NOT CRIT'
                  97='97. OTHR AGY' ;
  VALUE v5032fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. FEWSOURC' 2='2. LARGE %'
                  3='3. EXCHANGE' 4='4. GOODCAND' 5='5. QUALREFR'
                  6='6. MOTIV CL' 7='7. FUNDING' 8='8. GOOD REP'
                  9='9. TARGTPOP' 21='21. ONLYAVAL' 22='22. CL REFRL'
                  29='29. OTHER CL' 51='51. FINANCAL' 95='95. NOT CRIT'
                  97='97. OTHR AGY' ;
  VALUE v5033fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. ALL OTHERS'
                  1='1. SELF REF/FRIEND/FAM' ;
  VALUE v5034fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. TAKE ALL' 2='2. LIC/CERT'
                  3='3. GO2COURT' 11='11. ASSESMNT' 12='12. MEDICAL'
                  13='13. CNSL/TRT' 21='21. PROG REP' 22='22. PAPERWRK'
                  31='31. CLCONFID' 95='95. NOTHING' 97='97. OTHER' ;
  VALUE v5035fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. TAKE ALL' 2='2. LIC/CERT'
                  3='3. GO2COURT' 11='11. ASSESMNT' 12='12. MEDICAL'
                  13='13. CNSL/TRT' 21='21. PROG REP' 22='22. PAPERWRK'
                  31='31. CLCONFID' 95='95. NOTHING' 97='97. OTHER' ;
  VALUE v5036fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5037fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5038fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5039fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5040fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5041fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5042fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5043fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5044fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5045fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5046fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5047fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HOSPITAL' 2='2. PRIVCLIN'
                  3='3. PHYSICAN' 4='4. VOCREHAB' 5='5. DSS' 6='6. MH AGNCY'
                  7='7. OTHROSAT' 8='8. SCHOOLS' 9='9. CHURCHES'
                  10='10. AA/NA' 51='51. SELFHELP' 52='52. INPATENT'
                  53='53. SUPPORT' 54='54. CRISIS' 61='61. AIDS'
                  62='62. MH TRMT' 71='71. MEDICAL' 72='72. LEGAL'
                  73='73. EMPLOYMT' 74='74. HOUSING' 75='75. PAROLE'
                  76='76. FINANCAL' 77='77. EDUCATON' 97='97. OTHER' ;
  VALUE v5048fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HOSPITAL' 2='2. PRIVCLIN'
                  3='3. PHYSICAN' 4='4. VOCREHAB' 5='5. DSS' 6='6. MH AGNCY'
                  7='7. OTHROSAT' 8='8. SCHOOLS' 9='9. CHURCHES'
                  10='10. AA/NA' 51='51. SELFHELP' 52='52. INPATENT'
                  53='53. SUPPORT' 54='54. CRISIS' 61='61. AIDS'
                  62='62. MH TRMT' 71='71. MEDICAL' 72='72. LEGAL'
                  73='73. EMPLOYMT' 74='74. HOUSING' 75='75. PAROLE'
                  76='76. FINANCAL' 77='77. EDUCATON' 97='97. OTHER' ;
  VALUE v5049fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HOSPITAL' 2='2. PRIVCLIN'
                  3='3. PHYSICAN' 4='4. VOCREHAB' 5='5. DSS' 6='6. MH AGNCY'
                  7='7. OTHROSAT' 8='8. SCHOOLS' 9='9. CHURCHES'
                  10='10. AA/NA' 51='51. SELFHELP' 52='52. INPATENT'
                  53='53. SUPPORT' 54='54. CRISIS' 61='61. AIDS'
                  62='62. MH TRMT' 71='71. MEDICAL' 72='72. LEGAL'
                  73='73. EMPLOYMT' 74='74. HOUSING' 75='75. PAROLE'
                  76='76. FINANCAL' 77='77. EDUCATON' 97='97. OTHER' ;
  VALUE v5050fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LIKE US' 2='2. COMPLMNT'
                  3='3. MORECOMP' 11='11. INPATENT' 12='12. MAINTNCE'
                  14='14. MEDICAL' 15='15. HOUSING' 16='16. EMPLOYMT'
                  17='17. MH THRPY' 31='31. LOW COST' 32='32. QUALSERV'
                  33='33. QUALSTAF' 34='34. ACCESSBL' 35='35. PARTPROG'
                  36='36. AVAILABL' 39='39. BEST' 41='41. REMOVECL'
                  42='42. INTEGRCL' 43='43. CL PROGR' 97='97. OTHER' ;
  VALUE v5051fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LIKE US' 2='2. COMPLMNT'
                  3='3. MORECOMP' 11='11. INPATENT' 12='12. MAINTNCE'
                  14='14. MEDICAL' 15='15. HOUSING' 16='16. EMPLOYMT'
                  17='17. MH THRPY' 31='31. LOW COST' 32='32. QUALSERV'
                  33='33. QUALSTAF' 34='34. ACCESSBL' 35='35. PARTPROG'
                  36='36. AVAILABL' 39='39. BEST' 41='41. REMOVECL'
                  42='42. INTEGRCL' 43='43. CL PROGR' 97='97. OTHER' ;
  VALUE v5052fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NEVER' 2='2. RARELY'
                  3='3. SOMETIME' 4='4. OFTEN' 5='5. ALWAYS' ;
  VALUE v5053fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NEVER' 2='2. RARELY'
                  3='3. SOMETIME' 4='4. OFTEN' 5='5. ALWAYS' ;
  VALUE v5054fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NEVER' 2='2. RARELY'
                  3='3. SOMETIME' 4='4. OFTEN' 5='5. ALWAYS' ;
  VALUE v5055fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NEVER' 2='2. RARELY'
                  3='3. SOMETIME' 4='4. OFTEN' 5='5. ALWAYS' ;
  VALUE v5056fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NEVER' 2='2. RARELY'
                  3='3. SOMETIME' 4='4. OFTEN' 5='5. ALWAYS' ;
  VALUE v5057fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NEVER' 2='2. RARELY'
                  3='3. SOMETIME' 4='4. OFTEN' 5='5. ALWAYS' ;
  VALUE v5058fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NEVER' 2='2. RARELY'
                  3='3. SOMETIME' 4='4. OFTEN' 5='5. ALWAYS' ;
  VALUE v5059fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MONTMETH' 2='2. MAINTNCL'
                  3='3. INTRO CL' 4='4. STAF_STF' 5='5. RECORDS'
                  6='6. CLRELEAS' 11='11. MAKEAPPT' 12='12. GETREPRT'
                  97='97. OTHER' ;
  VALUE v5060fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5061fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5062fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5063fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5064fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5065fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5066fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5067fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5068fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5069fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5070fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5071fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5072fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5073fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5074fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5075fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v5076fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v5077fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5078fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5079fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v5080fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v5081fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5082fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5083fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v5084fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v5085fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v5086fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v5087fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v5088fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5089fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5090fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5091fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5092fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5093fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5094fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5095fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5096fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5097fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5098fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5099fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5100fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5101fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5102fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5103fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5104fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5105fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5106fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5107fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5108fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO PROF STAFF'
                  1='1. MASTERS DEG +' ;
  VALUE v5109fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5110fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5111fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5112fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5113fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5114fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v5115fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5116fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5117fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5118fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v5119fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5120fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5121fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5122fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v5123fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5124fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5125fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5126fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5127fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5128fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5129fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5130fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v5131fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5132fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5133fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5134fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5135fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v5136fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5137fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5138fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5139fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5140fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v5141fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5142fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5143fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5144fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5145fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5146fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5147fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5148fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v5149fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5150fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5151fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5152fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5153fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v5154fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5155fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5156fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5157fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5158fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v5159fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5160fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5161fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5162fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v5163fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v5164fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v5165fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v5166fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v5167fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v5168fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v5169fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v5170fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v5171fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v5172fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. Not Done/Never'
                  1='1. LT Once/Yr' 2='2. Annual' 3='3. Semi-annual'
                  4='4. Quarterly' 5='5. Monthly' ;
  VALUE v5173fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. Much Too Low'
                  2='2. Too Low' 3='3. About Right' 4='4. Too High'
                  5='5. Much Too High' ;
  VALUE v5174fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v5175fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v5176fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v5177fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v5178fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5179fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5180fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5181fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5182fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5183fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5184fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5185fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. ALL OTHR' 1='1. NONE C6&C7' ;
  VALUE v5186fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5187fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5188fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5189fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5190fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5191fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5192fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5193fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. COUNSELR' 97='97. OTHER' ;
  VALUE v5194fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 996='996. REFEROUT' ;
  VALUE v5195fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO' 1='1. YES'
                  6='6. REFEROUT' ;
  VALUE v5196fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 6='6. 16 PERS FACTORS (16PF)'
                  7='7. BECK DEP INV' 8='8. DRAW PICT' 9='9. MILLON TESTS'
                  10='10. MMPI/MMP' 11='11. RORSCHACH' 12='12. TAT'
                  13='13. HOUSE TREE PERS' 14='14. WPI' 15='15. SCL 90R'
                  16='16. OTR PROJECTIVE' 17='17. OTR PERS PROFIL'
                  19='19. OTR NOT 16,17' 20='20. WAIS' 21='21. WISC'
                  22='22. GESTALT' 23='23. SHIPLEY' 24='24. SENTCOMP'
                  25='25. WECH MEM' 27='27. IQ TESTS' 28='28. ACHIEVE'
                  29='29. OTHER IQ' 30='30. MAST' 31='31. MORT_FIL'
                  32='32. MANSON' 33='33. WASI' 39='39. OTR ALC/DRUG'
                  40='40. HISTORIES' 50='50. UNIT OWN QNAIRE'
                  60='60. Employ/Vocational' 96='96. DK TEST OUTSIDE'
                  97='97. OTHER' ;
  VALUE v5197fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 6='6. 16 PERS FACTORS (16PF)'
                  7='7. BECK DEP INV' 8='8. DRAW PICT' 9='9. MILLON TESTS'
                  10='10. MMPI/MMP' 11='11. RORSCHACH' 12='12. TAT'
                  13='13. HOUSE TREE PERS' 14='14. WPI' 15='15. SCL 90R'
                  16='16. OTR PROJECTIVE' 17='17. OTR PERS PROFIL'
                  19='19. OTR NOT 16,17' 20='20. WAIS' 21='21. WISC'
                  22='22. GESTALT' 23='23. SHIPLEY' 24='24. SENTCOMP'
                  25='25. WECH MEM' 27='27. IQ TESTS' 28='28. ACHIEVE'
                  29='29. OTHER IQ' 30='30. MAST' 31='31. MORT_FIL'
                  32='32. MANSON' 33='33. WASI' 39='39. OTR ALC/DRUG'
                  40='40. HISTORIES' 50='50. UNIT OWN QNAIRE'
                  60='60. Employ/Vocational' 96='96. DK TEST OUTSIDE'
                  97='97. OTHER' ;
  VALUE v5198fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 6='6. 16 PERS FACTORS (16PF)'
                  7='7. BECK DEP INV' 8='8. DRAW PICT' 9='9. MILLON TESTS'
                  10='10. MMPI/MMP' 11='11. RORSCHACH' 12='12. TAT'
                  13='13. HOUSE TREE PERS' 14='14. WPI' 15='15. SCL 90R'
                  16='16. OTR PROJECTIVE' 17='17. OTR PERS PROFIL'
                  19='19. OTR NOT 16,17' 20='20. WAIS' 21='21. WISC'
                  22='22. GESTALT' 23='23. SHIPLEY' 24='24. SENTCOMP'
                  25='25. WECH MEM' 27='27. IQ TESTS' 28='28. ACHIEVE'
                  29='29. OTHER IQ' 30='30. MAST' 31='31. MORT_FIL'
                  32='32. MANSON' 33='33. WASI' 39='39. OTR ALC/DRUG'
                  40='40. HISTORIES' 50='50. UNIT OWN QNAIRE'
                  60='60. Employ/Vocational' 96='96. DK TEST OUTSIDE'
                  97='97. OTHER' ;
  VALUE v5199fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5200fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5201fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5202fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5203fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5204fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5205fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5206fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. COUNSELR' 2='2. MASTERS'
                  51='51. HIPHD/MD' 52='52. HI MASTR' 53='53. HIBAORNA'
                  61='61. LPNAIDE' 97='97. OTHER' ;
  VALUE v5207fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 996='996. REFEROUT' ;
  VALUE v5208fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5209fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5210fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5211fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5212fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5213fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5214fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5215fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. COUNSLOR' 2='2. CLINICAN'
                  3='3. CLNC.SUP' 4='4. MA.PERS' 95='95. ANY/ALL'
                  97='97. OTHER' ;
  VALUE v5216fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5217fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5218fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5219fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5220fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5221fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NOT AT ALL IMPORTANT'
                  2='2. LITTLE IMPORTANT' 3='3. SOMEWT IMPORTANT'
                  4='4. VERY IMPORTANT' 5='5. EXTREMELY IMPORTANT' ;
  VALUE v5222fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NOT AT ALL IMPORTANT'
                  2='2. LITTLE IMPORTANT' 3='3. SOMEWT IMPORTANT'
                  4='4. VERY IMPORTANT' 5='5. EXTREMELY IMPORTANT' ;
  VALUE v5223fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NOT AT ALL IMPORTANT'
                  2='2. LITTLE IMPORTANT' 3='3. SOMEWT IMPORTANT'
                  4='4. VERY IMPORTANT' 5='5. EXTREMELY IMPORTANT' ;
  VALUE v5224fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NOT AT ALL IMPORTANT'
                  2='2. LITTLE IMPORTANT' 3='3. SOMEWT IMPORTANT'
                  4='4. VERY IMPORTANT' 5='5. EXTREMELY IMPORTANT' ;
  VALUE v5225fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NOT AT ALL IMPORTANT'
                  2='2. LITTLE IMPORTANT' 3='3. SOMEWT IMPORTANT'
                  4='4. VERY IMPORTANT' 5='5. EXTREMELY IMPORTANT' ;
  VALUE v5226fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NOT AT ALL IMPORTANT'
                  2='2. LITTLE IMPORTANT' 3='3. SOMEWT IMPORTANT'
                  4='4. VERY IMPORTANT' 5='5. EXTREMELY IMPORTANT' ;
  VALUE v5227fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NOT AT ALL IMPORTANT'
                  2='2. LITTLE IMPORTANT' 3='3. SOMEWT IMPORTANT'
                  4='4. VERY IMPORTANT' 5='5. EXTREMELY IMPORTANT' ;
  VALUE v5228fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5229fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 95='95. 95 DAYS +' ;
  VALUE v5230fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5231fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. EMERGNCY' 2='2. HIRISKCL'
                  3='3. MEDICAL' 4='4. RECNTREL' 5='5. SEVERLY'
                  6='6. DUALDIAG' 11='11. DETOX' 12='12. SELF_REF'
                  21='21. CHILDREN' 22='22. PREGNA' 23='23. AIDS'
                  24='24. MINORITY' 25='25. EAP REFR' 31='31. HEROIN'
                  32='32. ALCOHOL' 33='33. METHADON' 41='41. COURTREF'
                  42='42. OTHRREFR' 51='51. $/INSURE' 52='52. FIT TRMT'
                  97='97. OTHER' ;
  VALUE v5232fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. EMERGNCY' 2='2. HIRISKCL'
                  3='3. MEDICAL' 4='4. RECNTREL' 5='5. SEVERLY'
                  6='6. DUALDIAG' 11='11. DETOX' 12='12. SELF_REF'
                  21='21. CHILDREN' 22='22. PREGNA' 23='23. AIDS'
                  24='24. MINORITY' 25='25. EAP REFR' 31='31. HEROIN'
                  32='32. ALCOHOL' 33='33. METHADON' 41='41. COURTREF'
                  42='42. OTHRREFR' 51='51. $/INSURE' 52='52. FIT TRMT'
                  97='97. OTHER' ;
  VALUE v5233fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. FAMILIAL' 2='2. PEER'
                  3='3. ENVIRONT' 4='4. PSY_SOCL' 5='5. SELF_EST'
                  6='6. AVAILBLY' 7='7. BOREDOM' 8='8. REBELION'
                  9='9. PSY/PERS' 10='10. CHEM DEP' 11='11. GENETICS'
                  12='12. ECONOMIC' 13='13. LACKKNOW' 14='14. DISEASE'
                  15='15. SELF_MED' 16='16. ADDICTON' 17='17. LEARNDBH'
                  90='90. SYMPTOM' 91='91. SUBSTANC' 92='92. PERSON'
                  97='97. OTHER' ;
  VALUE v5234fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. FAMILIAL' 2='2. PEER'
                  3='3. ENVIRONT' 4='4. PSY_SOCL' 5='5. SELF_EST'
                  6='6. AVAILBLY' 7='7. BOREDOM' 8='8. REBELION'
                  9='9. PSY/PERS' 10='10. CHEM DEP' 11='11. GENETICS'
                  12='12. ECONOMIC' 13='13. LACKKNOW' 14='14. DISEASE'
                  15='15. SELF_MED' 16='16. ADDICTON' 17='17. LEARNDBH'
                  90='90. SYMPTOM' 91='91. SUBSTANC' 92='92. PERSON'
                  97='97. OTHER' ;
  VALUE v5235fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. FAMILIAL' 2='2. PEER'
                  3='3. ENVIRONT' 4='4. PSY_SOCL' 5='5. SELF_EST'
                  6='6. AVAILBLY' 7='7. BOREDOM' 8='8. REBELION'
                  9='9. PSY/PERS' 10='10. CHEM DEP' 11='11. GENETICS'
                  12='12. ECONOMIC' 13='13. LACKKNOW' 14='14. DISEASE'
                  15='15. SELF_MED' 16='16. ADDICTON' 17='17. LEARNDBH'
                  90='90. SYMPTOM' 91='91. SUBSTANC' 92='92. PERSON'
                  97='97. OTHER' ;
  VALUE v5236fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. FAMILIAL' 2='2. PEER'
                  3='3. ENVIRONT' 4='4. PSY_SOCL' 5='5. SELF_EST'
                  6='6. AVAILBLY' 7='7. BOREDOM' 8='8. REBELION'
                  9='9. PSY/PERS' 10='10. CHEM DEP' 11='11. GENETICS'
                  12='12. ECONOMIC' 13='13. LACKKNOW' 14='14. DISEASE'
                  15='15. SELF_MED' 16='16. ADDICTON' 17='17. LEARNDBH'
                  90='90. SYMPTOM' 91='91. SUBSTANC' 92='92. PERSON'
                  97='97. OTHER' ;
  VALUE v5237fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. FAMILIAL' 2='2. PEER'
                  3='3. ENVIRONT' 4='4. PSY_SOCL' 5='5. SELF_EST'
                  6='6. AVAILBLY' 7='7. BOREDOM' 8='8. REBELION'
                  9='9. PSY/PERS' 10='10. CHEM DEP' 11='11. GENETICS'
                  12='12. ECONOMIC' 13='13. LACKKNOW' 14='14. DISEASE'
                  15='15. SELF_MED' 16='16. ADDICTON' 17='17. LEARNDBH'
                  90='90. SYMPTOM' 91='91. SUBSTANC' 92='92. PERSON'
                  97='97. OTHER' ;
  VALUE v5238fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 11='11. DESIRE' 12='12. INSIGHT'
                  13='13. BOTOMOUT' 14='14. CONFIDNC' 15='15. LERNCOPE'
                  16='16. FEAR' 17='17. MATURING' 18='18. COSBENFT'
                  19='19. RELIGION' 29='29. OTHRINDV' 50='50. COUNSEL'
                  51='51. THERAPY' 52='52. SUPPORT' 53='53. EDUCATON'
                  54='54. JOBS' 55='55. MOVE' 56='56. PEERPRES'
                  57='57. OTHRPRES' 58='58. SOCPRESS' 67='67. OTHREXTR'
                  97='97. OTHER' ;
  VALUE v5239fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 11='11. DESIRE' 12='12. INSIGHT'
                  13='13. BOTOMOUT' 14='14. CONFIDNC' 15='15. LERNCOPE'
                  16='16. FEAR' 17='17. MATURING' 18='18. COSBENFT'
                  19='19. RELIGION' 29='29. OTHRINDV' 50='50. COUNSEL'
                  51='51. THERAPY' 52='52. SUPPORT' 53='53. EDUCATON'
                  54='54. JOBS' 55='55. MOVE' 56='56. PEERPRES'
                  57='57. OTHRPRES' 58='58. SOCPRESS' 67='67. OTHREXTR'
                  97='97. OTHER' ;
  VALUE v5240fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 11='11. DESIRE' 12='12. INSIGHT'
                  13='13. BOTOMOUT' 14='14. CONFIDNC' 15='15. LERNCOPE'
                  16='16. FEAR' 17='17. MATURING' 18='18. COSBENFT'
                  19='19. RELIGION' 29='29. OTHRINDV' 50='50. COUNSEL'
                  51='51. THERAPY' 52='52. SUPPORT' 53='53. EDUCATON'
                  54='54. JOBS' 55='55. MOVE' 56='56. PEERPRES'
                  57='57. OTHRPRES' 58='58. SOCPRESS' 67='67. OTHREXTR'
                  97='97. OTHER' ;
  VALUE v5241fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 11='11. DESIRE' 12='12. INSIGHT'
                  13='13. BOTOMOUT' 14='14. CONFIDNC' 15='15. LERNCOPE'
                  16='16. FEAR' 17='17. MATURING' 18='18. COSBENFT'
                  19='19. RELIGION' 29='29. OTHRINDV' 50='50. COUNSEL'
                  51='51. THERAPY' 52='52. SUPPORT' 53='53. EDUCATON'
                  54='54. JOBS' 55='55. MOVE' 56='56. PEERPRES'
                  57='57. OTHRPRES' 58='58. SOCPRESS' 67='67. OTHREXTR'
                  97='97. OTHER' ;
  VALUE v5242fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. SUPRTGRP' 2='2. SELFHELP'
                  3='3. INDTHRPY' 4='4. GRPTHRPY' 5='5. OUTPATNT'
                  6='6. INPATENT' 7='7. MEDICAL' 8='8. COUNSEL'
                  9='9. CONTLBEH' 10='10. ASSESMNT' 11='11. DRUGFREE'
                  12='12. FAMTHRPY' 13='13. MULTTRMT' 14='14. OUTPTDAY'
                  15='15. AFTRCARE' 16='16. AA/NA' 17='17. 12_STEP'
                  19='19. OTHTHRPY' 21='21. EDUCATON' 22='22. ENVIRMOD'
                  23='23. CHANGBEH' 24='24. THRPQUAL' 25='25. CLRESPBL'
                  31='31. REHABLTN' 41='41. CL_DEPNT' 42='42. SUB_DETR'
                  91='91. NOT AREA' 97='97. OTHER' ;
  VALUE v5243fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. SUPRTGRP' 2='2. SELFHELP'
                  3='3. INDTHRPY' 4='4. GRPTHRPY' 5='5. OUTPATNT'
                  6='6. INPATENT' 7='7. MEDICAL' 8='8. COUNSEL'
                  9='9. CONTLBEH' 10='10. ASSESMNT' 11='11. DRUGFREE'
                  12='12. FAMTHRPY' 13='13. MULTTRMT' 14='14. OUTPTDAY'
                  15='15. AFTRCARE' 16='16. AA/NA' 17='17. 12_STEP'
                  19='19. OTHTHRPY' 21='21. EDUCATON' 22='22. ENVIRMOD'
                  23='23. CHANGBEH' 24='24. THRPQUAL' 25='25. CLRESPBL'
                  31='31. REHABLTN' 41='41. CL_DEPNT' 42='42. SUB_DETR'
                  91='91. NOT AREA' 97='97. OTHER' ;
  VALUE v5244fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. SUPRTGRP' 2='2. SELFHELP'
                  3='3. INDTHRPY' 4='4. GRPTHRPY' 5='5. OUTPATNT'
                  6='6. INPATENT' 7='7. MEDICAL' 8='8. COUNSEL'
                  9='9. CONTLBEH' 10='10. ASSESMNT' 11='11. DRUGFREE'
                  12='12. FAMTHRPY' 13='13. MULTTRMT' 14='14. OUTPTDAY'
                  15='15. AFTRCARE' 16='16. AA/NA' 17='17. 12_STEP'
                  19='19. OTHTHRPY' 21='21. EDUCATON' 22='22. ENVIRMOD'
                  23='23. CHANGBEH' 24='24. THRPQUAL' 25='25. CLRESPBL'
                  31='31. REHABLTN' 41='41. CL_DEPNT' 42='42. SUB_DETR'
                  91='91. NOT AREA' 97='97. OTHER' ;
  VALUE v5245fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 1 MO OR LESS' ;
  VALUE v5246fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5247fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5248fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5249fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5250fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5251fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5252fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5253fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5254fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5255fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5256fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5257fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PREVENTN' 2='2. AIDS ED'
                  3='3. CRISIS' 11='11. EVALUATN' 12='12. REFERRAL'
                  13='13. AFTRCARE' 14='14. REHABLTN' 21='21. JOB/EAP'
                  22='22. EDUC/GED' 23='23. FAMILY' 31='31. BASCNEED'
                  32='32. DAYCARE' 33='33. INDEPLIV' 34='34. PARENTED'
                  35='35. EXERCISE' 36='36. >#TRTLOC' 37='37. RELIGION'
                  41='41. AA/NA' 42='42. CO-DEPND' 43='43. DUALDIAG'
                  44='44. GENRL MH' 51='51. MEDICAL' 52='52. DETOX'
                  53='53. METHADON' 54='54. ANTABUSE' 55='55. TREXAN'
                  56='56. SYMMETRL' 59='59. OTHR MED' 61='61. AIDS TX'
                  62='62. DWI/DUI' 63='63. ALCOHOL' 64='64. COCAINE'
                  65='65. EATDISOR' 66='66. MULTDRUG' 67='67. PRISONER'
                  69='69. 9OTHRDRU' 70='70. MEN' 71='71. WOMEN' 72='72.TEENS'
                  73='73. ELDERLY' 74='74. MINORITY' 75='75. HOMOSEX'
                  76='76. VETERANS' 77='77. POOR' 78='78. HANDICAP'
                  79='79. OTHTARGT' 81='81. INPTTRMT' 82='82. INPTALCO'
                  83='83. INPTDETX' 84='84. INPTMETH' 85='85. INPT MH'
                  89='89. OTHINPT' 91='91. THERAPY' 92='92. INDTHRPY'
                  93='93. GRPTHRPY' 94='94. INTENSIV' 95='95. PARTHOSP'
                  97='97. OTHER' ;
  VALUE v5258fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PREVENTN' 2='2. AIDS ED'
                  3='3. CRISIS' 11='11. EVALUATN' 12='12. REFERRAL'
                  13='13. AFTRCARE' 14='14. REHABLTN' 21='21. JOB/EAP'
                  22='22. EDUC/GED' 23='23. FAMILY' 31='31. BASCNEED'
                  32='32. DAYCARE' 33='33. INDEPLIV' 34='34. PARENTED'
                  35='35. EXERCISE' 36='36. >#TRTLOC' 37='37. RELIGION'
                  41='41. AA/NA' 42='42. CO-DEPND' 43='43. DUALDIAG'
                  44='44. GENRL MH' 51='51. MEDICAL' 52='52. DETOX'
                  53='53. METHADON' 54='54. ANTABUSE' 55='55. TREXAN'
                  56='56. SYMMETRL' 59='59. OTHR MED' 61='61. AIDS TX'
                  62='62. DWI/DUI' 63='63. ALCOHOL' 64='64. COCAINE'
                  65='65. EATDISOR' 66='66. MULTDRUG' 67='67. PRISONER'
                  69='69. 9OTHRDRU' 70='70. MEN' 71='71. WOMEN' 72='72.TEENS'
                  73='73. ELDERLY' 74='74. MINORITY' 75='75. HOMOSEX'
                  76='76. VETERANS' 77='77. POOR' 78='78. HANDICAP'
                  79='79. OTHTARGT' 81='81. INPTTRMT' 82='82. INPTALCO'
                  83='83. INPTDETX' 84='84. INPTMETH' 85='85. INPT MH'
                  89='89. OTHINPT' 91='91. THERAPY' 92='92. INDTHRPY'
                  93='93. GRPTHRPY' 94='94. INTENSIV' 95='95. PARTHOSP'
                  97='97. OTHER' ;
  VALUE v5259fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PREVENTN' 2='2. AIDS ED'
                  3='3. CRISIS' 11='11. EVALUATN' 12='12. REFERRAL'
                  13='13. AFTRCARE' 14='14. REHABLTN' 21='21. JOB/EAP'
                  22='22. EDUC/GED' 23='23. FAMILY' 31='31. BASCNEED'
                  32='32. DAYCARE' 33='33. INDEPLIV' 34='34. PARENTED'
                  35='35. EXERCISE' 36='36. >#TRTLOC' 37='37. RELIGION'
                  41='41. AA/NA' 42='42. CO-DEPND' 43='43. DUALDIAG'
                  44='44. GENRL MH' 51='51. MEDICAL' 52='52. DETOX'
                  53='53. METHADON' 54='54. ANTABUSE' 55='55. TREXAN'
                  56='56. SYMMETRL' 59='59. OTHR MED' 61='61. AIDS TX'
                  62='62. DWI/DUI' 63='63. ALCOHOL' 64='64. COCAINE'
                  65='65. EATDISOR' 66='66. MULTDRUG' 67='67. PRISONER'
                  69='69. 9OTHRDRU' 70='70. MEN' 71='71. WOMEN' 72='72.TEENS'
                  73='73. ELDERLY' 74='74. MINORITY' 75='75. HOMOSEX'
                  76='76. VETERANS' 77='77. POOR' 78='78. HANDICAP'
                  79='79. OTHTARGT' 81='81. INPTTRMT' 82='82. INPTALCO'
                  83='83. INPTDETX' 84='84. INPTMETH' 85='85. INPT MH'
                  89='89. OTHINPT' 91='91. THERAPY' 92='92. INDTHRPY'
                  93='93. GRPTHRPY' 94='94. INTENSIV' 95='95. PARTHOSP'
                  97='97. OTHER' ;
  VALUE v5260fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. ALLOTHER' 1='1. METH_COV' ;
  VALUE v5261fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5262fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5263fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5264fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5265fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5266fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5267fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5268fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5269fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5270fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5271fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5272fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5273fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5274fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5275fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5276fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5277fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5278fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5279fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5280fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5281fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5282fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5283fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5284fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5285fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5286fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5287fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5288fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5289fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5290fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5291fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5292fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5293fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5294fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5295fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5296fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5297fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5298fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. Under 3 mos'
                  2='2. 3 to 6 mos' 3='3. 7 to 12 mos' 4='4. 13 to 18 mos'
                  5='5. 19 to 24 mos' 6='6. 25 to 36 mos'
                  7='7. 37 mos or more' ;
  VALUE v5299fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5300fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. Under 3 mos'
                  2='2. 3 to 6 mos' 3='3. 7 to 12 mos' 4='4. 13 to 18 mos'
                  5='5. 19 to 24 mos' 6='6. 25 to 36 mos'
                  7='7. 37 mos or more' ;
  VALUE v5301fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5302fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5303fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5304fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5305fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5306fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5307fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5308fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v5309fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5310fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5311fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5312fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v5313fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5314fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5315fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5316fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v5317fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5318fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5319fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5320fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5321fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5322fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5323fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5324fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v5325fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5326fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5327fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5328fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5329fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v5330fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5331fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5332fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5333fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5334fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v5335fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5336fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5337fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5338fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5339fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5340fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5341fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5342fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v5343fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5344fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5345fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5346fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5347fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v5348fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5349fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5350fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5351fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v5352fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v5353fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5354fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5355fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5356fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5357fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5358fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5359fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5360fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5361fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5362fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5363fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PREVENTN' 2='2. AIDS ED'
                  3='3. CRISIS' 11='11. EVALUATN' 12='12. REFERRAL'
                  13='13. AFTRCARE' 14='14. REHABLTN' 21='21. JOB/EAP'
                  22='22. EDUC/GED' 23='23. FAMILY' 31='31. BASCNEED'
                  32='32. DAYCARE' 33='33. INDEPLIV' 34='34. PARENTED'
                  35='35. EXERCISE' 36='36. >#TRTLOC' 37='37. RELIGION'
                  41='41. AA/NA' 42='42. CO-DEPND' 43='43. DUALDIAG'
                  44='44. GENRL MH' 51='51. MEDICAL' 52='52. DETOX'
                  53='53. METHADON' 54='54. ANTABUSE' 55='55. TREXAN'
                  56='56. SYMMETRL' 59='59. OTHR MED' 61='61. AIDS TX'
                  62='62. DWI/DUI' 63='63. ALCOHOL' 64='64. COCAINE'
                  65='65. EATDISOR' 66='66. MULTDRUG' 67='67. PRISONER'
                  69='69. 9OTHRDRU' 70='70. MEN' 71='71. WOMEN' 72='72.TEENS'
                  73='73. ELDERLY' 74='74. MINORITY' 75='75. HOMOSEX'
                  76='76. VETERANS' 77='77. POOR' 78='78. HANDICAP'
                  79='79. OTHTARGT' 81='81. INPTTRMT' 82='82. INPTALCO'
                  83='83. INPTDETX' 84='84. INPTMETH' 85='85. INPT MH'
                  89='89. OTHINPT' 91='91. THERAPY' 92='92. INDTHRPY'
                  93='93. GRPTHRPY' 94='94. INTENSIV' 95='95. PARTHOSP'
                  97='97. OTHER' ;
  VALUE v5364fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PREVENTN' 2='2. AIDS ED'
                  3='3. CRISIS' 11='11. EVALUATN' 12='12. REFERRAL'
                  13='13. AFTRCARE' 14='14. REHABLTN' 21='21. JOB/EAP'
                  22='22. EDUC/GED' 23='23. FAMILY' 31='31. BASCNEED'
                  32='32. DAYCARE' 33='33. INDEPLIV' 34='34. PARENTED'
                  35='35. EXERCISE' 36='36. >#TRTLOC' 37='37. RELIGION'
                  41='41. AA/NA' 42='42. CO-DEPND' 43='43. DUALDIAG'
                  44='44. GENRL MH' 51='51. MEDICAL' 52='52. DETOX'
                  53='53. METHADON' 54='54. ANTABUSE' 55='55. TREXAN'
                  56='56. SYMMETRL' 59='59. OTHR MED' 61='61. AIDS TX'
                  62='62. DWI/DUI' 63='63. ALCOHOL' 64='64. COCAINE'
                  65='65. EATDISOR' 66='66. MULTDRUG' 67='67. PRISONER'
                  69='69. 9OTHRDRU' 70='70. MEN' 71='71. WOMEN' 72='72.TEENS'
                  73='73. ELDERLY' 74='74. MINORITY' 75='75. HOMOSEX'
                  76='76. VETERANS' 77='77. POOR' 78='78. HANDICAP'
                  79='79. OTHTARGT' 81='81. INPTTRMT' 82='82. INPTALCO'
                  83='83. INPTDETX' 84='84. INPTMETH' 85='85. INPT MH'
                  89='89. OTHINPT' 91='91. THERAPY' 92='92. INDTHRPY'
                  93='93. GRPTHRPY' 94='94. INTENSIV' 95='95. PARTHOSP'
                  97='97. OTHER' ;
  VALUE v5365fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PREVENTN' 2='2. AIDS ED'
                  3='3. CRISIS' 11='11. EVALUATN' 12='12. REFERRAL'
                  13='13. AFTRCARE' 14='14. REHABLTN' 21='21. JOB/EAP'
                  22='22. EDUC/GED' 23='23. FAMILY' 31='31. BASCNEED'
                  32='32. DAYCARE' 33='33. INDEPLIV' 34='34. PARENTED'
                  35='35. EXERCISE' 36='36. >#TRTLOC' 37='37. RELIGION'
                  41='41. AA/NA' 42='42. CO-DEPND' 43='43. DUALDIAG'
                  44='44. GENRL MH' 51='51. MEDICAL' 52='52. DETOX'
                  53='53. METHADON' 54='54. ANTABUSE' 55='55. TREXAN'
                  56='56. SYMMETRL' 59='59. OTHR MED' 61='61. AIDS TX'
                  62='62. DWI/DUI' 63='63. ALCOHOL' 64='64. COCAINE'
                  65='65. EATDISOR' 66='66. MULTDRUG' 67='67. PRISONER'
                  69='69. 9OTHRDRU' 70='70. MEN' 71='71. WOMEN' 72='72.TEENS'
                  73='73. ELDERLY' 74='74. MINORITY' 75='75. HOMOSEX'
                  76='76. VETERANS' 77='77. POOR' 78='78. HANDICAP'
                  79='79. OTHTARGT' 81='81. INPTTRMT' 82='82. INPTALCO'
                  83='83. INPTDETX' 84='84. INPTMETH' 85='85. INPT MH'
                  89='89. OTHINPT' 91='91. THERAPY' 92='92. INDTHRPY'
                  93='93. GRPTHRPY' 94='94. INTENSIV' 95='95. PARTHOSP'
                  97='97. OTHER' ;
  VALUE v5366fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PREVENTN' 2='2. AIDS ED'
                  3='3. CRISIS' 11='11. EVALUATN' 12='12. REFERRAL'
                  13='13. AFTRCARE' 14='14. REHABLTN' 21='21. JOB/EAP'
                  22='22. EDUC/GED' 23='23. FAMILY' 31='31. BASCNEED'
                  32='32. DAYCARE' 33='33. INDEPLIV' 34='34. PARENTED'
                  35='35. EXERCISE' 36='36. >#TRTLOC' 37='37. RELIGION'
                  41='41. AA/NA' 42='42. CO-DEPND' 43='43. DUALDIAG'
                  44='44. GENRL MH' 51='51. MEDICAL' 52='52. DETOX'
                  53='53. METHADON' 54='54. ANTABUSE' 55='55. TREXAN'
                  56='56. SYMMETRL' 59='59. OTHR MED' 61='61. AIDS TX'
                  62='62. DWI/DUI' 63='63. ALCOHOL' 64='64. COCAINE'
                  65='65. EATDISOR' 66='66. MULTDRUG' 67='67. PRISONER'
                  69='69. 9OTHRDRU' 70='70. MEN' 71='71. WOMEN' 72='72.TEENS'
                  73='73. ELDERLY' 74='74. MINORITY' 75='75. HOMOSEX'
                  76='76. VETERANS' 77='77. POOR' 78='78. HANDICAP'
                  79='79. OTHTARGT' 81='81. INPTTRMT' 82='82. INPTALCO'
                  83='83. INPTDETX' 84='84. INPTMETH' 85='85. INPT MH'
                  89='89. OTHINPT' 91='91. THERAPY' 92='92. INDTHRPY'
                  93='93. GRPTHRPY' 94='94. INTENSIV' 95='95. PARTHOSP'
                  97='97. OTHER' ;
  VALUE v5367fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. GEN PUBLIC'
                  2='2. SEG PUB DEAL DRUG PROBS' 3='3. ALL CLIENTS'
                  5='5. CL FAMILY' 6='6. CHILDREN' 7='7. OLDER CLIENTS'
                  8='8. CODEPENDS' 9='9. LOW INCOME' 10='10. MEN'
                  11='11. WOMEN' 12='12. BLACKS' 13='13. GAYS/LESBIANS'
                  14='14. PARENT GRPS' 15='15. MINORITIES EXC BLACKS'
                  16='16. HANDICAP' 21='21. ALCOHOL' 22='22. COCAINE'
                  23='23. HEROIN/OPIATES' 27='27. DUAL DIAGNOSIS'
                  28='28. SEVERE ADDICT CLNTS' 29='29. SA/DRUG CLIENT NFS'
                  31='31. CHRONIC PAIN' 32='32. METH RECIPIENTS'
                  33='33. AIDS RELATED' 34='34. MENTAL HLTH PROBS'
                  35='35. DUI/DWI CLIENTS' 37='37. PERIPHERAL PROBS'
                  97='97. OTHER' ;
  VALUE v5368fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. GEN PUBLIC'
                  2='2. SEG PUB DEAL DRUG PROBS' 3='3. ALL CLIENTS'
                  5='5. CL FAMILY' 6='6. CHILDREN' 7='7. OLDER CLIENTS'
                  8='8. CODEPENDS' 9='9. LOW INCOME' 10='10. MEN'
                  11='11. WOMEN' 12='12. BLACKS' 13='13. GAYS/LESBIANS'
                  14='14. PARENT GRPS' 15='15. MINORITIES EXC BLACKS'
                  16='16. HANDICAP' 21='21. ALCOHOL' 22='22. COCAINE'
                  23='23. HEROIN/OPIATES' 27='27. DUAL DIAGNOSIS'
                  28='28. SEVERE ADDICT CLNTS' 29='29. SA/DRUG CLIENT NFS'
                  31='31. CHRONIC PAIN' 32='32. METH RECIPIENTS'
                  33='33. AIDS RELATED' 34='34. MENTAL HLTH PROBS'
                  35='35. DUI/DWI CLIENTS' 37='37. PERIPHERAL PROBS'
                  97='97. OTHER' ;
  VALUE v5369fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. GEN PUBLIC'
                  2='2. SEG PUB DEAL DRUG PROBS' 3='3. ALL CLIENTS'
                  5='5. CL FAMILY' 6='6. CHILDREN' 7='7. OLDER CLIENTS'
                  8='8. CODEPENDS' 9='9. LOW INCOME' 10='10. MEN'
                  11='11. WOMEN' 12='12. BLACKS' 13='13. GAYS/LESBIANS'
                  14='14. PARENT GRPS' 15='15. MINORITIES EXC BLACKS'
                  16='16. HANDICAP' 21='21. ALCOHOL' 22='22. COCAINE'
                  23='23. HEROIN/OPIATES' 27='27. DUAL DIAGNOSIS'
                  28='28. SEVERE ADDICT CLNTS' 29='29. SA/DRUG CLIENT NFS'
                  31='31. CHRONIC PAIN' 32='32. METH RECIPIENTS'
                  33='33. AIDS RELATED' 34='34. MENTAL HLTH PROBS'
                  35='35. DUI/DWI CLIENTS' 37='37. PERIPHERAL PROBS'
                  97='97. OTHER' ;
  VALUE v5370fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. GEN PUBLIC'
                  2='2. SEG PUB DEAL DRUG PROBS' 3='3. ALL CLIENTS'
                  5='5. CL FAMILY' 6='6. CHILDREN' 7='7. OLDER CLIENTS'
                  8='8. CODEPENDS' 9='9. LOW INCOME' 10='10. MEN'
                  11='11. WOMEN' 12='12. BLACKS' 13='13. GAYS/LESBIANS'
                  14='14. PARENT GRPS' 15='15. MINORITIES EXC BLACKS'
                  16='16. HANDICAP' 21='21. ALCOHOL' 22='22. COCAINE'
                  23='23. HEROIN/OPIATES' 27='27. DUAL DIAGNOSIS'
                  28='28. SEVERE ADDICT CLNTS' 29='29. SA/DRUG CLIENT NFS'
                  31='31. CHRONIC PAIN' 32='32. METH RECIPIENTS'
                  33='33. AIDS RELATED' 34='34. MENTAL HLTH PROBS'
                  35='35. DUI/DWI CLIENTS' 37='37. PERIPHERAL PROBS'
                  97='97. OTHER' ;
  VALUE v5371fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5372fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v5373fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v5374fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v5375fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v5376fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v5377fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v5378fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v5379fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v5380fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5381fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5382fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5383fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5384fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5385fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5386fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5387fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5388fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AA/NA' 2='2. DRUGFREE'
                  3='3. AWARENES' 4='4. BEHAVIOR' 5='5. CL_CENTR'
                  6='6. CODEPEND' 7='7. COGNITVE' 8='8. CONFRONT'
                  9='9. COUNSEL' 10='10. COUPLES' 11='11. CREATIVE'
                  12='12. CRITICAL' 13='13. ECLECTIC' 14='14. EDUCATON'
                  15='15. EGO_PSY' 16='16. EMPATHTC' 17='17. ENCOUNTR'
                  18='18. FAMILY' 19='19. FEEDBACK' 20='20. GESTALT'
                  21='21. GROUP' 22='22. HERE&NOW' 23='23. HOLISTIC'
                  24='24. HUMANIST' 25='25. INDIVUAL' 26='26. INSIGHT'
                  27='27. INTRVENT' 28='28. MARRIAGE' 29='29. MEDICAL'
                  30='30. NON_CONF' 31='31. PEER GRP' 32='32. PROCESS'
                  33='33. PSYCHOAN' 34='34. PSYCHOLG' 35='35. PSY_SOCL'
                  36='36. RATIONAL' 37='37. REALITY' 38='38. RECOVERY'
                  39='39. ROGERIAN' 40='40. ROLEPLAY' 41='41. SLF_ASES'
                  42='42. SELFHELP' 43='43. SPIRITUL' 44='44. SUPPORT'
                  45='45. SYSTEMS' 46='46. TASK_CEN' 47='47. TRANSACT'
                  48='48. RELAXATN' 49='49. ADLERIAN' 50='50. PROBSOLV'
                  51='51. PSYDYNMC' 52='52. INTERACT' 53='53. HYPNOSIS'
                  54='54. EXPRIENT' 55='55. PSYCHOED' 95='95. CL NEEDS'
                  97='97. OTHER' ;
  VALUE v5389fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AA/NA' 2='2. DRUGFREE'
                  3='3. AWARENES' 4='4. BEHAVIOR' 5='5. CL_CENTR'
                  6='6. CODEPEND' 7='7. COGNITVE' 8='8. CONFRONT'
                  9='9. COUNSEL' 10='10. COUPLES' 11='11. CREATIVE'
                  12='12. CRITICAL' 13='13. ECLECTIC' 14='14. EDUCATON'
                  15='15. EGO_PSY' 16='16. EMPATHTC' 17='17. ENCOUNTR'
                  18='18. FAMILY' 19='19. FEEDBACK' 20='20. GESTALT'
                  21='21. GROUP' 22='22. HERE&NOW' 23='23. HOLISTIC'
                  24='24. HUMANIST' 25='25. INDIVUAL' 26='26. INSIGHT'
                  27='27. INTRVENT' 28='28. MARRIAGE' 29='29. MEDICAL'
                  30='30. NON_CONF' 31='31. PEER GRP' 32='32. PROCESS'
                  33='33. PSYCHOAN' 34='34. PSYCHOLG' 35='35. PSY_SOCL'
                  36='36. RATIONAL' 37='37. REALITY' 38='38. RECOVERY'
                  39='39. ROGERIAN' 40='40. ROLEPLAY' 41='41. SLF_ASES'
                  42='42. SELFHELP' 43='43. SPIRITUL' 44='44. SUPPORT'
                  45='45. SYSTEMS' 46='46. TASK_CEN' 47='47. TRANSACT'
                  48='48. RELAXATN' 49='49. ADLERIAN' 50='50. PROBSOLV'
                  51='51. PSYDYNMC' 52='52. INTERACT' 53='53. HYPNOSIS'
                  54='54. EXPRIENT' 55='55. PSYCHOED' 95='95. CL NEEDS'
                  97='97. OTHER' ;
  VALUE v5390fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AA/NA' 2='2. DRUGFREE'
                  3='3. AWARENES' 4='4. BEHAVIOR' 5='5. CL_CENTR'
                  6='6. CODEPEND' 7='7. COGNITVE' 8='8. CONFRONT'
                  9='9. COUNSEL' 10='10. COUPLES' 11='11. CREATIVE'
                  12='12. CRITICAL' 13='13. ECLECTIC' 14='14. EDUCATON'
                  15='15. EGO_PSY' 16='16. EMPATHTC' 17='17. ENCOUNTR'
                  18='18. FAMILY' 19='19. FEEDBACK' 20='20. GESTALT'
                  21='21. GROUP' 22='22. HERE&NOW' 23='23. HOLISTIC'
                  24='24. HUMANIST' 25='25. INDIVUAL' 26='26. INSIGHT'
                  27='27. INTRVENT' 28='28. MARRIAGE' 29='29. MEDICAL'
                  30='30. NON_CONF' 31='31. PEER GRP' 32='32. PROCESS'
                  33='33. PSYCHOAN' 34='34. PSYCHOLG' 35='35. PSY_SOCL'
                  36='36. RATIONAL' 37='37. REALITY' 38='38. RECOVERY'
                  39='39. ROGERIAN' 40='40. ROLEPLAY' 41='41. SLF_ASES'
                  42='42. SELFHELP' 43='43. SPIRITUL' 44='44. SUPPORT'
                  45='45. SYSTEMS' 46='46. TASK_CEN' 47='47. TRANSACT'
                  48='48. RELAXATN' 49='49. ADLERIAN' 50='50. PROBSOLV'
                  51='51. PSYDYNMC' 52='52. INTERACT' 53='53. HYPNOSIS'
                  54='54. EXPRIENT' 55='55. PSYCHOED' 95='95. CL NEEDS'
                  97='97. OTHER' ;
  VALUE v5391fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AA/NA' 2='2. DRUGFREE'
                  3='3. AWARENES' 4='4. BEHAVIOR' 5='5. CL_CENTR'
                  6='6. CODEPEND' 7='7. COGNITVE' 8='8. CONFRONT'
                  9='9. COUNSEL' 10='10. COUPLES' 11='11. CREATIVE'
                  12='12. CRITICAL' 13='13. ECLECTIC' 14='14. EDUCATON'
                  15='15. EGO_PSY' 16='16. EMPATHTC' 17='17. ENCOUNTR'
                  18='18. FAMILY' 19='19. FEEDBACK' 20='20. GESTALT'
                  21='21. GROUP' 22='22. HERE&NOW' 23='23. HOLISTIC'
                  24='24. HUMANIST' 25='25. INDIVUAL' 26='26. INSIGHT'
                  27='27. INTRVENT' 28='28. MARRIAGE' 29='29. MEDICAL'
                  30='30. NON_CONF' 31='31. PEER GRP' 32='32. PROCESS'
                  33='33. PSYCHOAN' 34='34. PSYCHOLG' 35='35. PSY_SOCL'
                  36='36. RATIONAL' 37='37. REALITY' 38='38. RECOVERY'
                  39='39. ROGERIAN' 40='40. ROLEPLAY' 41='41. SLF_ASES'
                  42='42. SELFHELP' 43='43. SPIRITUL' 44='44. SUPPORT'
                  45='45. SYSTEMS' 46='46. TASK_CEN' 47='47. TRANSACT'
                  48='48. RELAXATN' 49='49. ADLERIAN' 50='50. PROBSOLV'
                  51='51. PSYDYNMC' 52='52. INTERACT' 53='53. HYPNOSIS'
                  54='54. EXPRIENT' 55='55. PSYCHOED' 95='95. CL NEEDS'
                  97='97. OTHER' ;
  VALUE v5392fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AA/NA' 2='2. DRUGFREE'
                  3='3. AWARENES' 4='4. BEHAVIOR' 5='5. CL_CENTR'
                  6='6. CODEPEND' 7='7. COGNITVE' 8='8. CONFRONT'
                  9='9. COUNSEL' 10='10. COUPLES' 11='11. CREATIVE'
                  12='12. CRITICAL' 13='13. ECLECTIC' 14='14. EDUCATON'
                  15='15. EGO_PSY' 16='16. EMPATHTC' 17='17. ENCOUNTR'
                  18='18. FAMILY' 19='19. FEEDBACK' 20='20. GESTALT'
                  21='21. GROUP' 22='22. HERE&NOW' 23='23. HOLISTIC'
                  24='24. HUMANIST' 25='25. INDIVUAL' 26='26. INSIGHT'
                  27='27. INTRVENT' 28='28. MARRIAGE' 29='29. MEDICAL'
                  30='30. NON_CONF' 31='31. PEER GRP' 32='32. PROCESS'
                  33='33. PSYCHOAN' 34='34. PSYCHOLG' 35='35. PSY_SOCL'
                  36='36. RATIONAL' 37='37. REALITY' 38='38. RECOVERY'
                  39='39. ROGERIAN' 40='40. ROLEPLAY' 41='41. SLF_ASES'
                  42='42. SELFHELP' 43='43. SPIRITUL' 44='44. SUPPORT'
                  45='45. SYSTEMS' 46='46. TASK_CEN' 47='47. TRANSACT'
                  48='48. RELAXATN' 49='49. ADLERIAN' 50='50. PROBSOLV'
                  51='51. PSYDYNMC' 52='52. INTERACT' 53='53. HYPNOSIS'
                  54='54. EXPRIENT' 55='55. PSYCHOED' 95='95. CL NEEDS'
                  97='97. OTHER' ;
  VALUE v5393fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5394fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5395fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AA/NA' 2='2. DRUGFREE'
                  3='3. AWARENES' 4='4. BEHAVIOR' 5='5. CL_CENTR'
                  6='6. CODEPEND' 7='7. COGNITVE' 8='8. CONFRONT'
                  9='9. COUNSEL' 10='10. COUPLES' 11='11. CREATIVE'
                  12='12. CRITICAL' 13='13. ECLECTIC' 14='14. EDUCATON'
                  15='15. EGO_PSY' 16='16. EMPATHTC' 17='17. ENCOUNTR'
                  18='18. FAMILY' 19='19. FEEDBACK' 20='20. GESTALT'
                  21='21. GROUP' 22='22. HERE&NOW' 23='23. HOLISTIC'
                  24='24. HUMANIST' 25='25. INDIVUAL' 26='26. INSIGHT'
                  27='27. INTRVENT' 28='28. MARRIAGE' 29='29. MEDICAL'
                  30='30. NON_CONF' 31='31. PEER GRP' 32='32. PROCESS'
                  33='33. PSYCHOAN' 34='34. PSYCHOLG' 35='35. PSY_SOCL'
                  36='36. RATIONAL' 37='37. REALITY' 38='38. RECOVERY'
                  39='39. ROGERIAN' 40='40. ROLEPLAY' 41='41. SLF_ASES'
                  42='42. SELFHELP' 43='43. SPIRITUL' 44='44. SUPPORT'
                  45='45. SYSTEMS' 46='46. TASK_CEN' 47='47. TRANSACT'
                  48='48. RELAXATN' 49='49. ADLERIAN' 50='50. PROBSOLV'
                  51='51. PSYDYNMC' 52='52. INTERACT' 53='53. HYPNOSIS'
                  54='54. EXPRIENT' 55='55. PSYCHOED' 95='95. CL NEEDS'
                  97='97. OTHER' ;
  VALUE v5396fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AA/NA' 2='2. DRUGFREE'
                  3='3. AWARENES' 4='4. BEHAVIOR' 5='5. CL_CENTR'
                  6='6. CODEPEND' 7='7. COGNITVE' 8='8. CONFRONT'
                  9='9. COUNSEL' 10='10. COUPLES' 11='11. CREATIVE'
                  12='12. CRITICAL' 13='13. ECLECTIC' 14='14. EDUCATON'
                  15='15. EGO_PSY' 16='16. EMPATHTC' 17='17. ENCOUNTR'
                  18='18. FAMILY' 19='19. FEEDBACK' 20='20. GESTALT'
                  21='21. GROUP' 22='22. HERE&NOW' 23='23. HOLISTIC'
                  24='24. HUMANIST' 25='25. INDIVUAL' 26='26. INSIGHT'
                  27='27. INTRVENT' 28='28. MARRIAGE' 29='29. MEDICAL'
                  30='30. NON_CONF' 31='31. PEER GRP' 32='32. PROCESS'
                  33='33. PSYCHOAN' 34='34. PSYCHOLG' 35='35. PSY_SOCL'
                  36='36. RATIONAL' 37='37. REALITY' 38='38. RECOVERY'
                  39='39. ROGERIAN' 40='40. ROLEPLAY' 41='41. SLF_ASES'
                  42='42. SELFHELP' 43='43. SPIRITUL' 44='44. SUPPORT'
                  45='45. SYSTEMS' 46='46. TASK_CEN' 47='47. TRANSACT'
                  48='48. RELAXATN' 49='49. ADLERIAN' 50='50. PROBSOLV'
                  51='51. PSYDYNMC' 52='52. INTERACT' 53='53. HYPNOSIS'
                  54='54. EXPRIENT' 55='55. PSYCHOED' 95='95. CL NEEDS'
                  97='97. OTHER' ;
  VALUE v5397fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AA/NA' 2='2. DRUGFREE'
                  3='3. AWARENES' 4='4. BEHAVIOR' 5='5. CL_CENTR'
                  6='6. CODEPEND' 7='7. COGNITVE' 8='8. CONFRONT'
                  9='9. COUNSEL' 10='10. COUPLES' 11='11. CREATIVE'
                  12='12. CRITICAL' 13='13. ECLECTIC' 14='14. EDUCATON'
                  15='15. EGO_PSY' 16='16. EMPATHTC' 17='17. ENCOUNTR'
                  18='18. FAMILY' 19='19. FEEDBACK' 20='20. GESTALT'
                  21='21. GROUP' 22='22. HERE&NOW' 23='23. HOLISTIC'
                  24='24. HUMANIST' 25='25. INDIVUAL' 26='26. INSIGHT'
                  27='27. INTRVENT' 28='28. MARRIAGE' 29='29. MEDICAL'
                  30='30. NON_CONF' 31='31. PEER GRP' 32='32. PROCESS'
                  33='33. PSYCHOAN' 34='34. PSYCHOLG' 35='35. PSY_SOCL'
                  36='36. RATIONAL' 37='37. REALITY' 38='38. RECOVERY'
                  39='39. ROGERIAN' 40='40. ROLEPLAY' 41='41. SLF_ASES'
                  42='42. SELFHELP' 43='43. SPIRITUL' 44='44. SUPPORT'
                  45='45. SYSTEMS' 46='46. TASK_CEN' 47='47. TRANSACT'
                  48='48. RELAXATN' 49='49. ADLERIAN' 50='50. PROBSOLV'
                  51='51. PSYDYNMC' 52='52. INTERACT' 53='53. HYPNOSIS'
                  54='54. EXPRIENT' 55='55. PSYCHOED' 95='95. CL NEEDS'
                  97='97. OTHER' ;
  VALUE v5398fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VERY DIFFICULT'
                  2='2. SOMEWT DIFFICULT' 3='3. A LITTLE DIFFICULT'
                  4='4. SOMEWT EASY' 5='5. VERY EASY' ;
  VALUE v5399fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5400fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5401fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5402fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5403fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5404fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5405fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5406fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5407fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5408fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5409fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MONITOR' 2='2. MEDRECRD'
                  3='3. PSYCHIAT' 4='4. POLICE/CRT REC' 5='5. STAFEVAL'
                  6='6. PEER' 7='7. CL BEHVR' 11='11. VISITS'
                  12='12. TESTING' 13='13. SCHL.REP' 14='14. AA/NA'
                  15='15. INFORMAL' 16='16. AGENCIES' 51='51. RECRDAPP'
                  97='97. OTHER' ;
  VALUE v5410fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MONITOR' 2='2. MEDRECRD'
                  3='3. PSYCHIAT' 4='4. POLICE/CRT REC' 5='5. STAFEVAL'
                  6='6. PEER' 7='7. CL BEHVR' 11='11. VISITS'
                  12='12. TESTING' 13='13. SCHL.REP' 14='14. AA/NA'
                  15='15. INFORMAL' 16='16. AGENCIES' 51='51. RECRDAPP'
                  97='97. OTHER' ;
  VALUE v5411fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5412fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5413fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5414fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5415fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5416fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5417fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. ATTNDNCE' 2='2. INDTHRPY'
                  3='3. SELFHELP' 4='4. FAM/FRND' 5='5. COMPLASN'
                  61='61. PROGMREQ' 62='62. PHYSEXAM' 63='63. CONDSOBR'
                  71='71. PROGRESS' 81='81. BEHAVIOR' 82='82. ATTITUDE'
                  83='83. EMPLOYMT' 84='84. PAY FEES' 97='97. OTHER' ;
  VALUE v5418fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. ATTNDNCE' 2='2. INDTHRPY'
                  3='3. SELFHELP' 4='4. FAM/FRND' 5='5. COMPLASN'
                  61='61. PROGMREQ' 62='62. PHYSEXAM' 63='63. CONDSOBR'
                  71='71. PROGRESS' 81='81. BEHAVIOR' 82='82. ATTITUDE'
                  83='83. EMPLOYMT' 84='84. PAY FEES' 97='97. OTHER' ;
  VALUE v5419fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5420fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5421fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5422fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5423fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5424fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5425fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5426fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5427fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. CL STOP' 2='2. TRANSFER'
                  3='3. COMPLETE' 4='4. MOVEAWAY' 11='11. ASKED2GO'
                  97='97. OTHER' ;
  VALUE v5428fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5429fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5430fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. ABSTAIN' 2='2. LENGTHAB'
                  3='3. LESSDOSAGE' 11='11. TRMTPLAN' 12='12. STAFEVAL'
                  13='13. LEGAL' 14='14. FOLLOWUP' 21='21. SLFREPRT'
                  30='30. LESSQUALIFE' 31='31. EMPLOYMT' 32='32. RELATONS'
                  33='33. AVOIDNEG' 34='34. SELFHELP' 35='35. MOREPHEALT'
                  97='97. OTHER' ;
  VALUE v5431fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. ABSTAIN' 2='2. LENGTHAB'
                  3='3. LESSDOSAGE' 11='11. TRMTPLAN' 12='12. STAFEVAL'
                  13='13. LEGAL' 14='14. FOLLOWUP' 21='21. SLFREPRT'
                  30='30. LESSQUALIFE' 31='31. EMPLOYMT' 32='32. RELATONS'
                  33='33. AVOIDNEG' 34='34. SELFHELP' 35='35. MOREPHEALT'
                  97='97. OTHER' ;
  VALUE v5432fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. ABSTAIN' 2='2. LENGTHAB'
                  3='3. LESSDOSAGE' 11='11. TRMTPLAN' 12='12. STAFEVAL'
                  13='13. LEGAL' 14='14. FOLLOWUP' 21='21. SLFREPRT'
                  30='30. LESSQUALIFE' 31='31. EMPLOYMT' 32='32. RELATONS'
                  33='33. AVOIDNEG' 34='34. SELFHELP' 35='35. MOREPHEALT'
                  97='97. OTHER' ;
  VALUE v5433fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. ABSTAIN' 2='2. LENGTHAB'
                  3='3. LESSDOSAGE' 11='11. TRMTPLAN' 12='12. STAFEVAL'
                  13='13. LEGAL' 14='14. FOLLOWUP' 21='21. SLFREPRT'
                  30='30. LESSQUALIFE' 31='31. EMPLOYMT' 32='32. RELATONS'
                  33='33. AVOIDNEG' 34='34. SELFHELP' 35='35. MOREPHEALT'
                  97='97. OTHER' ;
  VALUE v5434fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. ABSTAIN' 2='2. LENGTHAB'
                  3='3. LESSDOSAGE' 11='11. TRMTPLAN' 12='12. STAFEVAL'
                  13='13. LEGAL' 14='14. FOLLOWUP' 21='21. SLFREPRT'
                  30='30. LESSQUALIFE' 31='31. EMPLOYMT' 32='32. RELATONS'
                  33='33. AVOIDNEG' 34='34. SELFHELP' 35='35. MOREPHEALT'
                  97='97. OTHER' ;
  VALUE v5435fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5436fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5437fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5438fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5439fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5440fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5441fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5442fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5443fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5444fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5445fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5446fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5447fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5448fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5449fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5450fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5451fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5452fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5453fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5454fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5455fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5456fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5457fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5458fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5459fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5460fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5461fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5462fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5463fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5464fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5465fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v5466fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v5467fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5468fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HOWTEACH' 2='2. PREVENTN'
                  3='3. DIAGNOSE' 4='4. SERVICES' 5='5. FAM/FRND'
                  6='6. STATSTIC' 9='9. OTHTRAIN' 21='21. HEALCARE'
                  22='22. GOVOFFCL' 23='23. ONSITE' 31='31. 8 HR OR LESS'
                  32='32. 9-16 HRS' 33='33. 17-24 HRS'
                  34='34. 4 DAYS OR MORE' 41='41. READINGS' 42='42. INFORMAL'
                  43='43. FORMAL' 97='97. OTHER' ;
  VALUE v5469fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HOWTEACH' 2='2. PREVENTN'
                  3='3. DIAGNOSE' 4='4. SERVICES' 5='5. FAM/FRND'
                  6='6. STATSTIC' 9='9. OTHTRAIN' 21='21. HEALCARE'
                  22='22. GOVOFFCL' 23='23. ONSITE' 31='31. 8 HR OR LESS'
                  32='32. 9-16 HRS' 33='33. 17-24 HRS'
                  34='34. 4 DAYS OR MORE' 41='41. READINGS' 42='42. INFORMAL'
                  43='43. FORMAL' 97='97. OTHER' ;
  VALUE v5470fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HOWTEACH' 2='2. PREVENTN'
                  3='3. DIAGNOSE' 4='4. SERVICES' 5='5. FAM/FRND'
                  6='6. STATSTIC' 9='9. OTHTRAIN' 21='21. HEALCARE'
                  22='22. GOVOFFCL' 23='23. ONSITE' 31='31. 8 HR OR LESS'
                  32='32. 9-16 HRS' 33='33. 17-24 HRS'
                  34='34. 4 DAYS OR MORE' 41='41. READINGS' 42='42. INFORMAL'
                  43='43. FORMAL' 97='97. OTHER' ;
  VALUE v5471fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5472fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5473fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5474fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5475fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5476fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5477fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5478fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5479fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. EDUCATON' 2='2. OUTREACH'
                  3='3. COUNSEL' 4='4. FREETRMT' 5='5. FREECLIN'
                  6='6. FREETEST' 7='7. METHADON' 11='11. ABSTAIN'
                  12='12. STOPDRUG' 13='13. STOP SEX' 14='14. SAFE SEX'
                  21='21. CONDOMS' 22='22. NEEDLES' 31='31. FAMPRESS'
                  32='32. FEAR' 33='33. IDHIRISK' 41='41. INCR STAFF/$'
                  91='91. NO DISTB' 96='96. NONE' 97='97. OTHER' ;
  VALUE v5480fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. EDUCATON' 2='2. OUTREACH'
                  3='3. COUNSEL' 4='4. FREETRMT' 5='5. FREECLIN'
                  6='6. FREETEST' 7='7. METHADON' 11='11. ABSTAIN'
                  12='12. STOPDRUG' 13='13. STOP SEX' 14='14. SAFE SEX'
                  21='21. CONDOMS' 22='22. NEEDLES' 31='31. FAMPRESS'
                  32='32. FEAR' 33='33. IDHIRISK' 41='41. INCR STAFF/$'
                  91='91. NO DISTB' 96='96. NONE' 97='97. OTHER' ;
  VALUE v5481fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. EDUCATON' 2='2. OUTREACH'
                  3='3. COUNSEL' 4='4. FREETRMT' 5='5. FREECLIN'
                  6='6. FREETEST' 7='7. METHADON' 11='11. ABSTAIN'
                  12='12. STOPDRUG' 13='13. STOP SEX' 14='14. SAFE SEX'
                  21='21. CONDOMS' 22='22. NEEDLES' 31='31. FAMPRESS'
                  32='32. FEAR' 33='33. IDHIRISK' 41='41. INCR STAFF/$'
                  91='91. NO DISTB' 96='96. NONE' 97='97. OTHER' ;
  VALUE v5482fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5483fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5484fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5485fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5486fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5487fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5488fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5489fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5490fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5491fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5492fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5493fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5494fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5495fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5496fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5497fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5498fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5499fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5500fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5501fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5502fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5503fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5504fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5505fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5506fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5507fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5508fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5509fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5510fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5511fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5512fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5513fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5514fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5515fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5516fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5517fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5518fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5519fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5520fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5521fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5522fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5523fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5524fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5525fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5526fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5527fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5528fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5529fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5530fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. ALCOHOL' 2='2. STEROIDS'
                  71='71. OVER COUNTER' 72='72. PRESCRIP' 73='73. DESIGNER'
                  81='81. CAFFEINE' 82='82. NICOTINE' 97='97. OTHER' ;
  VALUE v5531fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5532fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5533fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. ALCOHOL' 2='2. STEROIDS'
                  71='71. OVER COUNTER' 72='72. PRESCRIP' 73='73. DESIGNER'
                  81='81. CAFFEINE' 82='82. NICOTINE' 97='97. OTHER' ;
  VALUE v5534fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5535fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5536fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. ALCOHOL' 2='2. STEROIDS'
                  71='71. OVER COUNTER' 72='72. PRESCRIP' 73='73. DESIGNER'
                  81='81. CAFFEINE' 82='82. NICOTINE' 97='97. OTHER' ;
  VALUE v5537fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5538fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5539fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. ALCOHOL' 2='2. STEROIDS'
                  71='71. OVER COUNTER' 72='72. PRESCRIP' 73='73. DESIGNER'
                  81='81. CAFFEINE' 82='82. NICOTINE' 97='97. OTHER' ;
  VALUE v5540fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5541fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5542fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5543fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5544fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5545fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5546fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5547fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5548fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5549fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5550fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5551fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5552fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5553fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5554fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5555fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5556fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5557fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5558fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5559fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5560fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5561fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5562fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5563fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5564fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5565fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5566fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5567fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5568fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5569fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5570fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5571fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5572fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5573fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5574fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5575fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5576fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5577fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5578fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5579fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5580fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5581fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5582fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5583fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5584fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. THEFT' 2='2. FORGE CHEK'
                  3='3. FORGE RX' 4='4. CON GAME' 5='5. SELLDRUG'
                  6='6. SELLOTHR' 7='7. ASSAULT/MURDER' 8='8. GAMBLE'
                  9='9. PROSTIT' 96='96. OTHER ILLEG BEHVR' 97='97. OTHER' ;
  VALUE v5585fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5586fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5587fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. THEFT' 2='2. FORGE CHEK'
                  3='3. FORGE RX' 4='4. CON GAME' 5='5. SELLDRUG'
                  6='6. SELLOTHR' 7='7. ASSAULT/MURDER' 8='8. GAMBLE'
                  9='9. PROSTIT' 96='96. OTHER ILLEG BEHVR' 97='97. OTHER' ;
  VALUE v5588fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5589fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5590fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. THEFT' 2='2. FORGE CHEK'
                  3='3. FORGE RX' 4='4. CON GAME' 5='5. SELLDRUG'
                  6='6. SELLOTHR' 7='7. ASSAULT/MURDER' 8='8. GAMBLE'
                  9='9. PROSTIT' 96='96. OTHER ILLEG BEHVR' 97='97. OTHER' ;
  VALUE v5591fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5592fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5593fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. THEFT' 2='2. FORGE CHEK'
                  3='3. FORGE RX' 4='4. CON GAME' 5='5. SELLDRUG'
                  6='6. SELLOTHR' 7='7. ASSAULT/MURDER' 8='8. GAMBLE'
                  9='9. PROSTIT' 96='96. OTHER ILLEG BEHVR' 97='97. OTHER' ;
  VALUE v5594fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5595fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5596fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. THEFT' 2='2. FORGE CHEK'
                  3='3. FORGE RX' 4='4. CON GAME' 5='5. SELLDRUG'
                  6='6. SELLOTHR' 7='7. ASSAULT/MURDER' 8='8. GAMBLE'
                  9='9. PROSTIT' 96='96. OTHER ILLEG BEHVR' 97='97. OTHER' ;
  VALUE v5597fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5598fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5599fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5600fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5601fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5602fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5603fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5604fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5605fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5606fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5607fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. DIRECTOR' 2='2. ASSOCDIR'
                  3='3. FINANDIR' 4='4. PLANNER' 5='5. ADMNASST'
                  6='6. OFFICMGR' 7='7. CLERK' 9='9. PUBRELAT'
                  10='10. LEGALSRV' 19='19. OTHADMIN' 21='21. OUTPTDIR'
                  22='22. ASSTHEAD' 23='23. CCLINSUP' 31='31. PROBOFFC'
                  32='32. COUNSELR' 34='34. CLERGY' 38='38. ADVISOR'
                  41='41. PHYSICAN' 42='42. NURSE' 43='43. OTHPRO'
                  44='44. PSYCHGST' 45='45. SOCWORKR' 71='71. VOLUNTER'
                  72='72. STUDENT' 73='73. PUBOFFCL' 74='74. PROFESOR'
                  95='95. NONE' 97='97. OTHER' ;
  VALUE v5608fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5609fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5610fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. DIRECTOR' 2='2. ASSOCDIR'
                  3='3. FINANDIR' 4='4. PLANNER' 5='5. ADMNASST'
                  6='6. OFFICMGR' 7='7. CLERK' 9='9. PUBRELAT'
                  10='10. LEGALSRV' 19='19. OTHADMIN' 21='21. OUTPTDIR'
                  22='22. ASSTHEAD' 23='23. CCLINSUP' 31='31. PROBOFFC'
                  32='32. COUNSELR' 34='34. CLERGY' 38='38. ADVISOR'
                  41='41. PHYSICAN' 42='42. NURSE' 43='43. OTHPRO'
                  44='44. PSYCHGST' 45='45. SOCWORKR' 71='71. VOLUNTER'
                  72='72. STUDENT' 73='73. PUBOFFCL' 74='74. PROFESOR'
                  95='95. NONE' 97='97. OTHER' ;
  VALUE v5611fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. OTHER ORG' 1='1. THIS UNIT' ;
  VALUE v5612fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5613fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5614fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5615fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. Female' 1='1. Male' ;
  VALUE v5616fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. YES' 5='5. NO' ;
  VALUE v5617fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. WHITE' 2='2. BLACK'
                  5='5. OTHER' ;
  VALUE v5618fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MARRIED' 2='2. SEPARATE'
                  3='3. DIVORCED' 4='4. WIDOWED' 5='5. NEVER MAR' ;
  VALUE v5619fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5620fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5621fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5622fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5623fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v5624fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5625fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5626fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. A.A.2YR' 2='2. R.N.'
                  3='3. BA/BS' 4='4. MA/MS' 5='5. MD' 6='6. PH.D.'
                  7='7. OTHER' ;
  VALUE v5627fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v5628fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. A.A.2YR' 2='2. R.N.'
                  3='3. BA/BS' 4='4. MA/MS' 5='5. MD' 6='6. PH.D.'
                  7='7. OTHER' ;
  VALUE v5629fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v5630fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. A.A.2YR' 2='2. R.N.'
                  3='3. BA/BS' 4='4. MA/MS' 5='5. MD' 6='6. PH.D.'
                  7='7. OTHER' ;
  VALUE v5631fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v5632fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v5665fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v5666fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v5667fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v5668fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v5669fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v5670fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v5671fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v5672fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v5673fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v5674fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v5675fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v5676fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v5677fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v5678fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v5679fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v5680fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v5681fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
  VALUE v5682fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHINSUR' 15='15. MULTINSR' 16='16. CO INS'
                  17='17. OTHPAYER' 21='21. FEDCOURT' 22='22. AMERIND'
                  23='23. NIDA' 24='24. NIAAA' 25='25. NIMH' 26='26. FDA'
                  27='27. DEA' 28='28. VA' 29='29. FOODSTMP' 30='30. HHS'
                  31='31. ADAMHA' 37='37. OTHR FED' 38='38. TITLE 20'
                  39='39. BLKGRANT' 40='40. ST BOARD PHARM' 41='41. STATCOUR'
                  42='42. DEPTHEAL' 43='43. D.SOCSRV' 44='44. SA UNIT'
                  45='45. DPUBINST' 46='46. ST 508 or 509 Funds'
                  47='47. OTHSTATE' 48='48. LICDEPT' 49='49. STATLVL'
                  51='51. CITY/CTY/LOC COURTS' 52='52. CITYCRT'
                  53='53. COURTS-NA' 54='54. LOC ALC AGCY' 55='55. COUNTY'
                  56='56. CITY' 57='57. REGIONAL' 58='58. LOCAL'
                  59='59. OTR LOC AGCY INC INTRAST/REG' 61='61. OTHGOVT'
                  71='71. BUSINESS' 72='72. UNITDWAY' 73='73. JCAHO'
                  74='74. HOSPITLS' 75='75. CODAP' 76='76. OTHCMORG'
                  77='77. PROFORG' 81='81. INTEREST' 82='82. SALES'
                  83='83. FUNDRAIS' 89='89. OTR OWN EFFORTS' 97='97. OTHFUND' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=4121;
INPUT
        CASEID 1-3              UNITID 4-8              V4004 9-12
        V4005 13-15             V4006 16-18             V4007 19-21
        V4008 22-24             V4009 25-27             V4010 28-30
        V4011 31-34             V4012 35-36             V4013 37-39
        V4014 40-42             V4015 43-45             V4016 46-48
        V4017 49-50             V4018 51-52             V4019 53-55
        V4020 56-58             V4021 59-60             V4022 61-62
        V4023 63-64             V4024 65-66             V4025 67-68
        V4026 69-70             V4027 71-72             V4028 73-74
        V4029 75-76             V4030 77-78             V4031 79-80
        V4032 81-82             V4033 83-85             V4034 86-88
        V4035 89-91             V4036 92-94             V4037 95-96
        V4038 97-100            V4039 101-104           V4040 105-107
        V4041 108-110           V4042 111-113           V4043 114-116
        V4044 117-119           V4045 120-122           V4046 123-131
        V4047 132-134           V4048 135-137           V4049 138-140
        V4050 141-143           V4051 144-146           V4052 147-149
        V4053 150-157           V4054 158-165           V4055 166-167
        V4056 168-170           V4057 171-178           V4058 179-181
        V4059 182-184           V4060 185-190           V4061 191-193
        V4062 194-196           V4063 197-202           V4064 203-205
        V4065 206-208           V4066 209-215           V4067 216-218
        V4068 219-221           V4069 222-227           V4070 228-229
        V4071 230-232           V4072 233-238           V4073 239-240
        V4074 241-249           V4075 250-251           V4076 252-254
        V4077 255-262           V4078 263-265           V4079 266-268
        V4080 269-275           V4081 276-278           V4082 279-281
        V4083 282-289           V4084 290-292           V4085 293-295
        V4086 296-302           V4087 303-305           V4088 306-308
        V4089 309-315           V4090 316-318           V4091 319-321
        V4092 322-330           V4093 331-333           V4094 334-341
        V4095 342-343           V4096 344-346           V4097 347-354
        V4098 355-357           V4099 358-360           V4100 361-367
        V4101 368-370           V4102 371-373           V4103 374-380
        V4104 381-383           V4105 384-386           V4106 387-392
        V4107 393-395           V4108 396-398           V4109 399-404
        V4110 405-407           V4111 408-410           V4112 411-416
        V4113 417-419           V4114 420-427           V4115 428-429
        V4116 430-432           V4117 433-440           V4118 441-443
        V4119 444-446           V4120 447-453           V4121 454-456
        V4122 457-459           V4123 460-466           V4124 467-469
        V4125 470-472           V4126 473-479           V4127 480-482
        V4128 483-485           V4129 486-492           V4130 493-495
        V4131 496-498           V4132 499-504           V4133 505-507
        V4134 508-514           V4135 515-517           V4136 518-520
        V4137 521-527           V4138 528-529           V4139 530-536
        V4140 537-538           V4141 539-543           V4142 544-545
        V4143 546-547           V4144 548-550           V4145 551-557
        V4146 558-560           V4147 561-563           V4148 564-570
        V4149 571-573           V4150 574-576           V4151 577-582
        V4152 583-585           V4153 586-588           V4154 589-595
        V4155 596-598           V4156 599-601           V4157 602-607
        V4158 608-610           V4159 611-613           V4160 614-617
        V4161 618-620           V4162 621-624           V4163 625-628
        V4164 629-632           V4165 633-637           V4166 638-641
        V4167 642-646           V4168 647-650           V4169 651-655
        V4170 656-659           V4171 660-663           V4172 664-667
        V4173 668-672           V4174 673-676           V4175 677-681
        V4176 682-685           V4177 686-690           V4178 691-694
        V4179 695-702           V4180 703-710           V4181 711-712
        V4182 713-719           V4183 720-726           V4184 727-734
        V4185 735-742           V4186 743-744           V4187 745-746
        V4188 747-748           V4189 749-750           V4190 751-755
        V4191 756-760           V4192 761-768 .2        V4193 769-772
        V4194 773-776           V4195 777-780           V4196 781-782
        V4197 783-787           V4198 788-793 .2        V4199 794-798
        V4200 799-806 .2        V4201 807-810           V4202 811-814
        V4203 815-817           V4204 818-819           V4205 820-823
        V4206 824-825           V4207 826-829           V4208 830-833
        V4209 834-840 .2        V4210 841-844           V4211 845-848
        V4212 849-851           V4213 852-853           V4214 854-857
        V4215 858-859           V4216 860-864           V4217 865-870
        V4218 871-874           V4219 875-876           V4220 877-878
        V4221 879-881           V4222 882-885           V4223 886-888
        V4224 889-892           V4225 893-898           V4226 899-902
        V4227 903-905           V4228 906-909           V4229 910-912
        V4230 913-916           V4231 917-922           V4232 923-926
        V4233 927-929           V4234 930-934           V4235 935-936
        V4236 937-940           V4237 941-945           V4238 946-948
        V4239 949-951           V4240 952-955           V4241 956-958
        V4242 959-962           V4243 963-967           V4244 968-971
        V4245 972-974           V4246 975-977           V4247 978-979
        V4248 980-983           V4249 984-987           V4250 988-990
        V4251 991-993           V4252 994-996           V4253 997-998
        V4254 999-1001          V4255 1002-1003         V4256 1004-1006
        V4257 1007-1011         V4258 1012-1014         V4259 1015-1016
        V4260 1017-1019         V4261 1020-1021         V4262 1022-1023
        V4263 1024-1025         V4264 1026-1027         V4265 1028-1029
        V4266 1030-1031         V4267 1032-1033         V4268 1034-1035
        V4269 1036-1038         V4270 1039-1040         V4271 1041-1042
        V4272 1043-1044         V4273 1045-1046         V4274 1047-1048
        V4275 1049-1050         V4276 1051-1052         V4277 1053-1054
        V4278 1055-1056         V4279 1057-1058         V4280 1059-1060
        V4281 1061-1063         V4282 1064-1065         V4283 1066-1067
        V4284 1068-1069         V4285 1070-1071         V4286 1072-1073
        V4287 1074-1075         V4288 1076-1077         V4289 1078-1079
        V4290 1080-1081         V4291 1082-1083         V4292 1084-1085
        V4293 1086-1087         V4294 1088-1089         V4295 1090-1091
        V4296 1092-1093         V4297 1094-1095         V4298 1096-1097
        V4299 1098-1099         V4300 1100-1101         V4301 1102-1103
        V4302 1104-1105         V4303 1106-1107         V4304 1108-1109
        V4305 1110-1111         V4306 1112-1113         V4307 1114-1115
        V4308 1116-1117         V4309 1118-1119         V4310 1120-1121
        V4311 1122-1123         V4312 1124-1125         V4313 1126-1127
        V4314 1128-1129         V4315 1130-1131         V4316 1132-1133
        V4317 1134-1135         V4318 1136-1137         V4319 1138-1139
        V4320 1140-1141         V4321 1142-1143         V4322 1144-1145
        V4323 1146-1147         V4324 1148-1149         V4325 1150-1151
        V4326 1152-1153         V4327 1154-1155         V4328 1156-1157
        V4329 1158-1159         V4330 1160-1161         V4331 1162-1163
        V4332 1164-1165         V4333 1166-1167         V4334 1168-1169
        V4335 1170-1171         V4336 1172-1173         V4337 1174-1175
        V4338 1176-1177         V4339 1178-1179         V4340 1180-1181
        V4341 1182-1183         V4342 1184-1185         V4343 1186-1187
        V4344 1188-1189         V4345 1190-1191         V4346 1192-1193
        V4347 1194-1195         V4348 1196-1197         V4349 1198-1199
        V4350 1200-1201         V4351 1202-1203         V4352 1204-1205
        V4353 1206-1207         V4354 1208-1209         V4355 1210-1211
        V4356 1212-1213         V4357 1214-1215         V4358 1216-1217
        V4359 1218-1219         V4360 1220-1221         V4361 1222-1223
        V4362 1224-1225         V4363 1226-1227         V4364 1228-1229
        V4365 1230-1231         V4366 1232-1233         V4367 1234-1235
        V4368 1236-1237         V4369 1238-1239         V4370 1240-1241
        V4371 1242-1243         V4372 1244-1245         V4373 1246-1247
        V4374 1248-1249         V4375 1250-1251         V4376 1252-1253
        V4377 1254-1255         V4378 1256-1257         V4379 1258-1259
        V4380 1260-1261         V4381 1262-1263         V4382 1264-1265
        V4383 1266-1267         V4384 1268-1269         V4385 1270-1271
        V4386 1272-1273         V4387 1274-1275         V4388 1276-1277
        V4389 1278-1279         V4390 1280-1281         V4391 1282-1283
        V4392 1284-1285         V4393 1286-1287         V4394 1288-1289
        V4395 1290-1291         V4396 1292-1293         V4397 1294-1295
        V4398 1296-1297         V4399 1298-1299         V4400 1300-1301
        V4401 1302-1303         V4402 1304-1305         V4403 1306-1307
        V4404 1308-1309         V4405 1310-1311         V4406 1312-1313
        V4407 1314-1315         V4408 1316-1317         V4409 1318-1319
        V4410 1320-1321         V4411 1322-1323         V4412 1324-1325
        V4413 1326-1327         V4414 1328-1329         V4415 1330-1331
        V4416 1332-1333         V4417 1334-1335         V4418 1336-1337
        V4419 1338-1339         V4420 1340-1341         V4421 1342-1343
        V4422 1344-1345         V4423 1346-1347         V4424 1348-1349
        V4425 1350-1351         V4426 1352-1353         V4427 1354-1355
        V4428 1356-1357         V4429 1358-1359         V4430 1360-1361
        V4431 1362-1363         V4432 1364-1365         V4433 1366-1367
        V4434 1368-1369         V4435 1370-1371         V4436 1372-1373
        V4437 1374-1375         V4438 1376-1377         V4439 1378-1379
        V4440 1380-1381         V4441 1382-1383         V4442 1384-1385
        V4443 1386-1387         V4444 1388-1389         V4445 1390-1391
        V4446 1392-1393         V4447 1394-1395         V4448 1396-1397
        V4449 1398-1399         V4450 1400-1401         V4451 1402-1403
        V4452 1404-1405         V4453 1406-1407         V4454 1408-1409
        V4455 1410-1411         V4456 1412-1413         V4457 1414-1415
        V4458 1416-1417         V4459 1418-1419         V4460 1420-1421
        V4461 1422-1423         V4462 1424-1425         V4463 1426-1427
        V4464 1428-1429         V4465 1430-1431         V4466 1432-1433
        V4467 1434-1435         V4468 1436-1437         V4469 1438-1439
        V4470 1440-1441         V4471 1442-1443         V4472 1444-1445
        V4473 1446-1447         V4474 1448-1449         V4475 1450-1451
        V4476 1452-1453         V4477 1454-1455         V4478 1456-1457
        V4479 1458-1459         V4480 1460-1461         V4481 1462-1463
        V4482 1464-1465         V4483 1466-1467         V4484 1468-1469
        V4485 1470-1471         V4486 1472-1473         V4487 1474-1475
        V4488 1476-1477         V4489 1478-1479         V4490 1480-1481
        V4491 1482-1483         V4492 1484-1485         V4493 1486-1487
        V4494 1488-1490         V4495 1491-1493         V4496 1494-1495
        V4497 1496-1497         V4498 1498-1499         V4499 1500-1501
        V4500 1502-1503         V4501 1504-1505         V4502 1506-1507
        V4503 1508-1509         V4504 1510-1511         V4505 1512-1513
        V4506 1514-1515         V4507 1516-1517         V4508 1518-1519
        V4509 1520-1521         V4510 1522-1523         V4511 1524-1525
        V4512 1526-1527         V4513 1528-1529         V4514 1530-1531
        V4515 1532-1534         V4516 1535-1537         V4517 1538-1539
        V4518 1540-1541         V4519 1542-1543         V4520 1544-1545
        V4521 1546-1548         V4522 1549-1551         V4523 1552-1553
        V4524 1554-1556         V4525 1557-1559         V4526 1560-1561
        V4527 1562-1563         V4528 1564-1565         V4529 1566-1567
        V4530 1568-1569         V4531 1570-1571         V4532 1572-1573
        V4533 1574-1575         V4534 1576-1577         V4535 1578-1579
        V4536 1580-1581         V4537 1582-1583         V4538 1584-1585
        V4539 1586-1587         V4540 1588-1589         V4541 1590-1591
        V4542 1592-1593         V4543 1594-1595         V4544 1596-1597
        V4545 1598-1599         V4546 1600-1601         V4547 1602-1603
        V4548 1604-1605         V4549 1606-1607         V4550 1608-1610
        V4551 1611-1613         V4552 1614-1616         V4553 1617-1619
        V4554 1620-1622         V4555 1623-1625         V4556 1626-1628
        V4557 1629-1631         V4558 1632-1634         V4559 1635-1637
        V4560 1638-1639         V4561 1640-1641         V4562 1642-1643
        V4563 1644-1645         V4564 1646-1647         V4565 1648-1649
        V4566 1650-1651         V4567 1652-1653         V4568 1654-1655
        V4569 1656-1657         V4570 1658-1659         V4571 1660-1661
        V4572 1662-1663         V4573 1664-1665         V4574 1666-1667
        V4575 1668-1669         V4576 1670-1671         V4577 1672-1673
        V4578 1674-1675         V4579 1676-1677         V4580 1678-1679
        V4581 1680-1681         V4582 1682-1683         V4583 1684-1685
        V4584 1686-1688         V4585 1689-1690         V4586 1691-1692
        V4587 1693-1694         V4588 1695-1696         V4589 1697-1698
        V4590 1699-1700         V4591 1701-1703         V4592 1704-1705
        V4593 1706-1707         V4594 1708-1709         V4595 1710-1711
        V4596 1712-1713         V4597 1714-1715         V4598 1716-1717
        V4599 1718-1719         V4600 1720-1722         V4601 1723-1725
        V4602 1726-1727         V4603 1728-1729         V4604 1730-1731
        V4605 1732-1733         V4606 1734-1735         V4607 1736-1737
        V4608 1738-1739         V4609 1740-1741         V4610 1742-1743
        V4611 1744-1745         V4612 1746-1747         V4613 1748-1749
        V4614 1750-1751         V4615 1752-1753         V4616 1754-1755
        V4617 1756-1757         V4618 1758-1759         V4619 1760-1761
        V4620 1762-1763         V4621 1764-1765         V4622 1766-1767
        V4623 1768-1769         V4624 1770-1771         V4625 1772-1773
        V4626 1774-1775         V4627 1776-1777         V4628 1778-1779
        V4629 1780-1782         V4630 1783-1784         V4631 1785-1786
        V4632 1787-1788         V4633 1789-1790         V4634 1791-1792
        V4635 1793-1794         V4636 1795-1796         V4637 1797-1798
        V4638 1799-1800         V4639 1801-1802         V4640 1803-1804
        V4641 1805-1806         V4642 1807-1808         V4643 1809-1810
        V4644 1811-1812         V4645 1813-1814         V4646 1815-1816
        V4647 1817-1818         V4648 1819-1820         V4649 1821-1822
        V4650 1823-1824         V4651 1825-1826         V4652 1827-1828
        V4653 1829-1830         V4654 1831-1832         V4655 1833-1834
        V4656 1835-1836         V4657 1837-1838         V4658 1839-1840
        V4659 1841-1843         V4660 1844-1846         V4661 1847-1848
        V4662 1849-1850         V4663 1851-1852         V4664 1853-1854
        V4665 1855-1856         V4666 1857-1858         V4667 1859-1863
        V4668 1864-1868         V4669 1869-1872         V4670 1873-1877
        V4671 1878-1881         V4672 1882-1885         V4673 1886-1888
        V4674 1889-1893         V4675 1894-1897         V4676 1898-1902
        V4677 1903-1906         V4678 1907-1911         V4679 1912-1915
        V4680 1916-1920         V4681 1921-1923         V4682 1924-1928
        V4683 1929-1931         V4684 1932-1935         V4685 1936-1938
        V4686 1939-1943         V4687 1944-1948         V4688 1949-1952
        V4689 1953-1957         V4690 1958-1961         V4691 1962-1965
        V4692 1966-1968         V4693 1969-1973         V4694 1974-1977
        V4695 1978-1982         V4696 1983-1986         V4697 1987-1991
        V4698 1992-1995         V4699 1996-2000         V4700 2001-2003
        V4701 2004-2008         V4702 2009-2011         V4703 2012-2015
        V4704 2016-2018         V4705 2019-2020         V4706 2021-2023
        V4707 2024-2026         V4708 2027-2029         V4709 2030-2032
        V4710 2033-2034         V4711 2035-2037         V4712 2038-2040
        V4713 2041-2043         V4714 2044-2046         V4715 2047-2051
        V4716 2052-2055         V4717 2056-2060         V4718 2061-2064
        V4719 2065-2069         V4720 2070-2073         V4721 2074-2075
        V4722 2076-2077         V4723 2078-2079         V4724 2080-2084
        V4725 2085-2088         V4726 2089-2091         V4727 2092-2094
        V4728 2095-2097         V4729 2098-2100         V4730 2101-2103
        V4731 2104-2106         V4732 2107-2109         V4733 2110-2112
        V4734 2113-2115         V4735 2116-2118         V4736 2119-2121
        V4737 2122-2124         V4738 2125-2126         V4739 2127-2129
        V4740 2130-2132         V4741 2133-2135         V4742 2136-2137
        V4743 2138-2139         V4744 2140-2141         V4745 2142-2143
        V4746 2144-2146         V4747 2147-2149         V4748 2150-2152
        V4749 2153-2155         V4750 2156-2158         V4751 2159-2160
        V4752 2161-2162         V4753 2163-2164         V4754 2165-2167
        V4755 2168-2169         V4756 2170-2172         V4757 2173-2174
        V4758 2175-2177         V4759 2178-2179         V4764 2180-2182
        V4765 2183-2185         V4766 2186-2188         V4767 2189-2191
        V4768 2192-2194         V4769 2195-2197         V4770 2198-2200
        V4771 2201-2203         V4772 2204-2206         V4773 2207-2209
        V4774 2210-2212         V4775 2213-2215         V4776 2216-2218
        V4777 2219-2221         V4778 2222-2224         V4779 2225-2227
        V4780 2228-2230         V4781 2231-2233         V4782 2234-2236
        V4783 2237-2239         V4784 2240-2242         V4785 2243-2245
        V4786 2246-2248         V4787 2249-2251         V4788 2252-2254
        V4789 2255-2257         V4790 2258-2260         V5004 2261-2264
        V5005 2265-2267         V5006 2268-2270         V5007 2271-2273
        V5008 2274-2276         V5009 2277-2279         V5010 2280-2282
        V5011 2283-2286         V5012 2287-2288         V5013 2289-2290
        V5014 2291-2292         V5015 2293-2294         V5016 2295-2296
        V5017 2297-2298         V5018 2299-2300         V5019 2301-2302
        V5020 2303-2304         V5021 2305-2306         V5022 2307-2308
        V5023 2309-2310         V5024 2311-2312         V5025 2313-2314
        V5026 2315-2316         V5027 2317-2318         V5028 2319-2321
        V5029 2322-2324         V5030 2325-2327         V5031 2328-2330
        V5032 2331-2333         V5033 2334-2335         V5034 2336-2338
        V5035 2339-2341         V5036 2342-2343         V5037 2344-2345
        V5038 2346-2347         V5039 2348-2349         V5040 2350-2351
        V5041 2352-2353         V5042 2354-2355         V5043 2356-2357
        V5044 2358-2359         V5045 2360-2361         V5046 2362-2363
        V5047 2364-2366         V5048 2367-2369         V5049 2370-2372
        V5050 2373-2375         V5051 2376-2378         V5052 2379-2380
        V5053 2381-2382         V5054 2383-2384         V5055 2385-2386
        V5056 2387-2388         V5057 2389-2390         V5058 2391-2392
        V5059 2393-2395         V5060 2396-2399         V5061 2400-2402
        V5062 2403-2408 .2      V5063 2409-2412         V5064 2413-2415
        V5065 2416-2421 .2      V5066 2422-2425         V5067 2426-2431 .2
        V5068 2432-2437 .2      V5069 2438-2443 .2      V5070 2444-2447
        V5071 2448-2452         V5072 2453-2457         V5073 2458-2460
        V5074 2461-2463         V5075 2464-2466         V5076 2467-2469
        V5077 2470-2473         V5078 2474-2475         V5079 2476-2478
        V5080 2479-2481         V5081 2482-2485         V5082 2486-2488
        V5083 2489-2491         V5084 2492-2494         V5085 2495-2497
        V5086 2498-2500         V5087 2501-2503         V5088 2504-2508
        V5089 2509-2511         V5090 2512-2515         V5091 2516-2517
        V5092 2518-2521         V5093 2522-2524         V5094 2525-2529
        V5095 2530-2532         V5096 2533-2536         V5097 2537-2539
        V5098 2540-2541         V5099 2542-2543         V5100 2544-2547
        V5101 2548-2551         V5102 2552-2554         V5103 2555-2556
        V5104 2557-2558         V5105 2559-2560         V5106 2561-2562
        V5107 2563-2564         V5108 2565-2566         V5109 2567-2568
        V5110 2569-2570         V5111 2571-2572         V5112 2573-2574
        V5113 2575-2576         V5114 2577-2578         V5115 2579-2580
        V5116 2581-2582         V5117 2583-2584         V5118 2585-2586
        V5119 2587-2588         V5120 2589-2590         V5121 2591-2592
        V5122 2593-2594         V5123 2595-2596         V5124 2597-2598
        V5125 2599-2600         V5126 2601-2602         V5127 2603-2604
        V5128 2605-2606         V5129 2607-2608         V5130 2609-2610
        V5131 2611-2612         V5132 2613-2614         V5133 2615-2616
        V5134 2617-2618         V5135 2619-2620         V5136 2621-2622
        V5137 2623-2624         V5138 2625-2626         V5139 2627-2628
        V5140 2629-2630         V5141 2631-2632         V5142 2633-2634
        V5143 2635-2636         V5144 2637-2638         V5145 2639-2640
        V5146 2641-2642         V5147 2643-2644         V5148 2645-2646
        V5149 2647-2648         V5150 2649-2650         V5151 2651-2652
        V5152 2653-2654         V5153 2655-2656         V5154 2657-2658
        V5155 2659-2660         V5156 2661-2662         V5157 2663-2664
        V5158 2665-2666         V5159 2667-2668         V5160 2669-2670
        V5161 2671-2672         V5162 2673-2674         V5163 2675-2676
        V5164 2677-2678         V5165 2679-2680         V5166 2681-2682
        V5167 2683-2684         V5168 2685-2686         V5169 2687-2688
        V5170 2689-2690         V5171 2691-2692         V5172 2693-2694
        V5173 2695-2696         V5174 2697-2698         V5175 2699-2700
        V5176 2701-2702         V5177 2703-2704         V5178 2705-2708
        V5179 2709-2712         V5180 2713-2716         V5181 2717-2720
        V5182 2721-2724         V5183 2725-2728         V5184 2729-2732
        V5185 2733-2734         V5186 2735-2736         V5187 2737-2738
        V5188 2739-2740         V5189 2741-2742         V5190 2743-2744
        V5191 2745-2746         V5192 2747-2748         V5193 2749-2751
        V5194 2752-2755         V5195 2756-2757         V5196 2758-2760
        V5197 2761-2763         V5198 2764-2766         V5199 2767-2768
        V5200 2769-2770         V5201 2771-2772         V5202 2773-2774
        V5203 2775-2776         V5204 2777-2778         V5205 2779-2780
        V5206 2781-2783         V5207 2784-2787         V5208 2788-2789
        V5209 2790-2791         V5210 2792-2793         V5211 2794-2795
        V5212 2796-2797         V5213 2798-2799         V5214 2800-2801
        V5215 2802-2804         V5216 2805-2806         V5217 2807-2808
        V5218 2809-2810         V5219 2811-2812         V5220 2813-2814
        V5221 2815-2816         V5222 2817-2818         V5223 2819-2820
        V5224 2821-2822         V5225 2823-2824         V5226 2825-2826
        V5227 2827-2828         V5228 2829-2832         V5229 2833-2835
        V5230 2836-2837         V5231 2838-2840         V5232 2841-2843
        V5233 2844-2846         V5234 2847-2849         V5235 2850-2852
        V5236 2853-2855         V5237 2856-2858         V5238 2859-2861
        V5239 2862-2864         V5240 2865-2867         V5241 2868-2870
        V5242 2871-2873         V5243 2874-2876         V5244 2877-2879
        V5245 2880-2882         V5246 2883-2886         V5247 2887-2890
        V5248 2891-2894         V5249 2895-2898         V5250 2899-2902
        V5251 2903-2906         V5252 2907-2910         V5253 2911-2914
        V5254 2915-2918         V5255 2919-2921         V5256 2922-2925
        V5257 2926-2928         V5258 2929-2931         V5259 2932-2934
        V5260 2935-2936         V5261 2937-2941         V5262 2942-2946
        V5263 2947-2951         V5264 2952-2956         V5265 2957-2960
        V5266 2961-2964         V5267 2965-2967         V5268 2968-2971
        V5269 2972-2975         V5270 2976-2979         V5271 2980-2983
        V5272 2984-2987         V5273 2988-2991         V5274 2992-2995
        V5275 2996-2998         V5276 2999-3002         V5277 3003-3005
        V5278 3006-3009         V5279 3010-3013         V5280 3014-3016
        V5281 3017-3019         V5282 3020-3021         V5283 3022-3023
        V5284 3024-3027         V5285 3028-3031         V5286 3032-3035
        V5287 3036-3039         V5288 3040-3043         V5289 3044-3046
        V5290 3047-3050         V5291 3051-3053         V5292 3054-3057
        V5293 3058-3061         V5294 3062-3063         V5295 3064-3065
        V5296 3066-3067         V5297 3068-3069         V5298 3070-3071
        V5299 3072-3073         V5300 3074-3075         V5301 3076-3077
        V5302 3078-3081         V5303 3082-3083         V5304 3084-3085
        V5305 3086-3087         V5306 3088-3089         V5307 3090-3091
        V5308 3092-3093         V5309 3094-3095         V5310 3096-3097
        V5311 3098-3099         V5312 3100-3101         V5313 3102-3103
        V5314 3104-3105         V5315 3106-3107         V5316 3108-3109
        V5317 3110-3111         V5318 3112-3113         V5319 3114-3115
        V5320 3116-3117         V5321 3118-3119         V5322 3120-3121
        V5323 3122-3123         V5324 3124-3125         V5325 3126-3127
        V5326 3128-3129         V5327 3130-3131         V5328 3132-3133
        V5329 3134-3135         V5330 3136-3137         V5331 3138-3139
        V5332 3140-3141         V5333 3142-3143         V5334 3144-3145
        V5335 3146-3147         V5336 3148-3149         V5337 3150-3151
        V5338 3152-3153         V5339 3154-3155         V5340 3156-3157
        V5341 3158-3159         V5342 3160-3161         V5343 3162-3163
        V5344 3164-3165         V5345 3166-3167         V5346 3168-3169
        V5347 3170-3171         V5348 3172-3173         V5349 3174-3175
        V5350 3176-3177         V5351 3178-3179         V5352 3180-3181
        V5353 3182-3183         V5354 3184-3185         V5355 3186-3187
        V5356 3188-3189         V5357 3190-3191         V5358 3192-3193
        V5359 3194-3195         V5360 3196-3197         V5361 3198-3199
        V5362 3200-3201         V5363 3202-3204         V5364 3205-3207
        V5365 3208-3210         V5366 3211-3213         V5367 3214-3216
        V5368 3217-3219         V5369 3220-3222         V5370 3223-3225
        V5371 3226-3227         V5372 3228-3229         V5373 3230-3231
        V5374 3232-3233         V5375 3234-3235         V5376 3236-3237
        V5377 3238-3239         V5378 3240-3241         V5379 3242-3243
        V5380 3244-3245         V5381 3246-3247         V5382 3248-3249
        V5383 3250-3251         V5384 3252-3253         V5385 3254-3255
        V5386 3256-3257         V5387 3258-3259         V5388 3260-3262
        V5389 3263-3265         V5390 3266-3268         V5391 3269-3271
        V5392 3272-3274         V5393 3275-3276         V5394 3277-3278
        V5395 3279-3281         V5396 3282-3284         V5397 3285-3287
        V5398 3288-3289         V5399 3290-3291         V5400 3292-3293
        V5401 3294-3295         V5402 3296-3297         V5403 3298-3299
        V5404 3300-3301         V5405 3302-3303         V5406 3304-3305
        V5407 3306-3307         V5408 3308-3309         V5409 3310-3312
        V5410 3313-3315         V5411 3316-3317         V5412 3318-3319
        V5413 3320-3321         V5414 3322-3323         V5415 3324-3325
        V5416 3326-3327         V5417 3328-3330         V5418 3331-3333
        V5419 3334-3337         V5420 3338-3340         V5421 3341-3343
        V5422 3344-3347         V5423 3348-3350         V5424 3351-3353
        V5425 3354-3356         V5426 3357-3359         V5427 3360-3362
        V5428 3363-3366         V5429 3367-3370         V5430 3371-3373
        V5431 3374-3376         V5432 3377-3379         V5433 3380-3382
        V5434 3383-3385         V5435 3386-3389         V5436 3390-3391
        V5437 3392-3393         V5438 3394-3395         V5439 3396-3397
        V5440 3398-3399         V5441 3400-3401         V5442 3402-3403
        V5443 3404-3405         V5444 3406-3407         V5445 3408-3409
        V5446 3410-3411         V5447 3412-3413         V5448 3414-3415
        V5449 3416-3417         V5450 3418-3419         V5451 3420-3421
        V5452 3422-3423         V5453 3424-3425         V5454 3426-3427
        V5455 3428-3429         V5456 3430-3431         V5457 3432-3433
        V5458 3434-3435         V5459 3436-3437         V5460 3438-3439
        V5461 3440-3441         V5462 3442-3443         V5463 3444-3445
        V5464 3446-3447         V5465 3448-3449         V5466 3450-3453
        V5467 3454-3455         V5468 3456-3458         V5469 3459-3461
        V5470 3462-3464         V5471 3465-3466         V5472 3467-3468
        V5473 3469-3470         V5474 3471-3472         V5475 3473-3474
        V5476 3475-3476         V5477 3477-3478         V5478 3479-3480
        V5479 3481-3483         V5480 3484-3486         V5481 3487-3489
        V5482 3490-3494         V5483 3495-3499         V5484 3500-3504
        V5485 3505-3508         V5486 3509-3513         V5487 3514-3518
        V5488 3519-3523         V5489 3524-3527         V5490 3528-3532
        V5491 3533-3536         V5492 3537-3541         V5493 3542-3545
        V5494 3546-3550         V5495 3551-3554         V5496 3555-3559
        V5497 3560-3563         V5498 3564-3568         V5499 3569-3572
        V5500 3573-3577         V5501 3578-3581         V5502 3582-3586
        V5503 3587-3589         V5504 3590-3593         V5505 3594-3596
        V5506 3597-3601         V5507 3602-3605         V5508 3606-3610
        V5509 3611-3613         V5510 3614-3618         V5511 3619-3622
        V5512 3623-3626         V5513 3627-3629         V5514 3630-3634
        V5515 3635-3637         V5516 3638-3641         V5517 3642-3644
        V5518 3645-3649         V5519 3650-3652         V5520 3653-3657
        V5521 3658-3660         V5522 3661-3665         V5523 3666-3669
        V5524 3670-3673         V5525 3674-3676         V5526 3677-3680
        V5527 3681-3683         V5528 3684-3688         V5529 3689-3692
        V5530 3693-3695         V5531 3696-3700         V5532 3701-3704
        V5533 3705-3707         V5534 3708-3711         V5535 3712-3714
        V5536 3715-3717         V5537 3718-3720         V5538 3721-3723
        V5539 3724-3726         V5540 3727-3728         V5541 3729-3730
        V5542 3731-3735         V5543 3736-3739         V5544 3740-3744
        V5545 3745-3747         V5546 3748-3752         V5547 3753-3756
        V5548 3757-3761         V5549 3762-3765         V5550 3766-3769
        V5551 3770-3772         V5552 3773-3777         V5553 3778-3781
        V5554 3782-3786         V5555 3787-3789         V5556 3790-3794
        V5557 3795-3798         V5558 3799-3803         V5559 3804-3807
        V5560 3808-3812         V5561 3813-3815         V5562 3816-3820
        V5563 3821-3823         V5564 3824-3827         V5565 3828-3830
        V5566 3831-3834         V5567 3835-3837         V5568 3838-3841
        V5569 3842-3844         V5570 3845-3849         V5571 3850-3852
        V5572 3853-3856         V5573 3857-3859         V5574 3860-3863
        V5575 3864-3865         V5576 3866-3870         V5577 3871-3874
        V5578 3875-3879         V5579 3880-3883         V5580 3884-3888
        V5581 3889-3892         V5582 3893-3897         V5583 3898-3900
        V5584 3901-3903         V5585 3904-3908         V5586 3909-3912
        V5587 3913-3915         V5588 3916-3920         V5589 3921-3923
        V5590 3924-3926         V5591 3927-3930         V5592 3931-3933
        V5593 3934-3936         V5594 3937-3940         V5595 3941-3943
        V5596 3944-3946         V5597 3947-3950         V5598 3951-3953
        V5599 3954-3956         V5600 3957-3959         V5601 3960-3962
        V5602 3963-3965         V5603 3966-3968         V5604 3969-3971
        V5605 3972-3974         V5606 3975-3977         V5607 3978-3980
        V5608 3981-3983         V5609 3984-3987         V5610 3988-3990
        V5611 3991-3992         V5612 3993-3995         V5613 3996-3998
        V5614 3999-4001         V5615 4002-4003         V5616 4004-4005
        V5617 4006-4007         V5618 4008-4009         V5619 4010-4012
        V5620 4013-4015         V5621 4016-4018         V5622 4019-4021
        V5623 4022-4024         V5624 4025-4026         V5625 4027-4028
        V5626 4029-4030         V5627 4031-4033         V5628 4034-4035
        V5629 4036-4038         V5630 4039-4040         V5631 4041-4043
        V5632 4044-4045         V5665 4046-4048         V5666 4049-4051
        V5667 4052-4054         V5668 4055-4057         V5669 4058-4060
        V5670 4061-4063         V5671 4064-4066         V5672 4067-4069
        V5673 4070-4072         V5674 4073-4075         V5675 4076-4078
        V5676 4079-4081         V5677 4082-4084         V5678 4085-4087
        V5679 4088-4090         V5680 4091-4093         V5681 4094-4096
        V5682 4097-4099         V6998 4100-4110 .8      V7000 4111-4121 .8
        ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'CASE IDENTIFICATION NUMBER'
   UNITID  = 'ID NUMBER FOR UNIT/OSAT CENTER'
   V4004   = 'FS. INTERVIEWERS ID #'
   V4005   = 'FS. MONTH BEGAN INTERVEW'
   V4006   = 'FS. DAY BEGAN INTERVIEW'
   V4007   = 'FS. YEAR BEGAN INTERVIEW'
   V4008   = 'FS. MONTH FINISH INTERVW'
   V4009   = 'FS. DAY FINISH INTERVIEW'
   V4010   = 'FS. YEAR FINISH INTERVEW'
   V4011   = 'FS. LENGTH OF INTERVIEW IN MINUTES'
   V4012   = 'IP. INSERT PAGE 3 THIS IW:Y/N?'
   V4013   = 'A1.OSAT PROGRAM START MONTH'
   V4014   = 'A1.OSAT PROGRAM START YEAR'
   V4015   = 'A2.M1:UNIT ORIGINAL MISSIONS'
   V4016   = 'A2.M2:UNIT ORIGINAL MISSIONS'
   V4017   = 'A3.EXTENT FOUNDERS INFLUENCE UNIT NOW'
   V4018   = 'A4.UNIT GOALS DIFFER NOW?:Y/N?'
   V4019   = 'A4A.M1: WAYS UNIT GOALS DIFFER'
   V4020   = 'A4A.M2: WAYS UNIT GOALS DIFFER'
   V4021   = 'A5.EXTNT UNIT GOALS FORMAL'
   V4022   = 'A6A.AMT AGREE IMP TO KEEP COST LOW'
   V4023   = 'A6B.AMT AGREE CL SELECTN IMP 4COST'
   V4024   = 'A6C.AMT AGREE IMP U MAKES PROFIT'
   V4025   = 'A6D.AMT AGREE FOR-PROFIT UNITS OK'
   V4026   = 'A6E.AMT AGREE FOR-PROFIT U MOR EFF'
   V4027   = 'A6F.AMT AGREE HI STANDRDS NOT COST'
   V4028   = 'A6G.AMT AGREE  CL ACCES CARE W/O $'
   V4029   = 'A6H.AMT AGREE FINANCE TX PUB RESP'
   V4030   = 'A6I.AMT AGREE PR SECTOR SHLD COVER'
   V4031   = 'B0. OTHER R FOR FUNDQS:Y/N?'
   V4032   = 'B1. U PROV NONOSAT SERV:Y/N?'
   V4033   = 'B1A.M1:OTHER SERV U PROV'
   V4034   = 'B1A.M2:OTHER SERV U PROV'
   V4035   = 'B1A.M3:OTHER SERV U PROV'
   V4036   = 'B1A.M4:OTHER SERV U PROV'
   V4037   = 'B2. $ FOR JUST US OSAT:Y/N?'
   V4038   = 'B2A. % TOT CL WHO GET OSAT [USE TO EST]'
   V4039   = 'B2B. % TOT REV FROM OSAT [USE TO EST]'
   V4040   = 'B3. BEGIN MO MOST REC FY [ESTIMATE]'
   V4041   = 'B3. BEGIN DY MOST REC FY [ESTIMATE]'
   V4042   = 'B3. BEGIN YR MOST REC FY [ESTIMATE]'
   V4043   = 'B3. END MO MOST REC FY [ESTIMATE]'
   V4044   = 'B3. END DY MOST REC FY [ESTIMATE]'
   V4045   = 'B3. END YR MOST REC FY [ESTIMATE]'
   V4046   = 'B3A. TOT U REV MST REC FY [ESTIMATE]'
   V4047   = 'B4. BEGIN MO MOST REC FY [REPORTED]'
   V4048   = 'B4. BEGIN DY MOST REC FY [REPORTED]'
   V4049   = 'B4. BEGIN YR MOST REC FY [REPORTED]'
   V4050   = 'B4. END MO MOST REC FY [REPORTED]'
   V4051   = 'B4. END DY MOST REC FY [REPORTED]'
   V4052   = 'B4. END YR MOST REC FY [REPORTED]'
   V4053   = 'B4A. TOT U REV MST REC FY [REPORTED]'
   V4054   = 'B5. TOT FEDERAL $ TO UNIT'
   V4055   = 'B6-8.SUMMARY. # FEDERAL $ SOURCES'
   V4056   = 'B6A.M1:FED SOURCE NAME'
   V4057   = 'B7A.M1:FED SOURCE AMOUNT'
   V4058   = 'B8A.M1:FED SOURCE PAY BASIS'
   V4059   = 'B6B.M2:FED SOURCE NAME'
   V4060   = 'B7B.M2:FED SOURCE AMOUNT'
   V4061   = 'B8B.M2:FED SOURCE PAY BASIS'
   V4062   = 'B6C.M3:FED SOURCE NAME'
   V4063   = 'B7C.M3:FED SOURCE AMOUNT'
   V4064   = 'B8C.M3:FED SOURCE PAY BASIS'
   V4065   = 'B6D.M4:FED SOURCE NAME'
   V4066   = 'B7D.M4:FED SOURCE AMOUNT'
   V4067   = 'B8D.M4:FED SOURCE PAY BASIS'
   V4068   = 'B6E.M5:FED SOURCE NAME'
   V4069   = 'B7E.M5:FED SOURCE AMOUNT'
   V4070   = 'B8E.M5:FED SOURCE PAY BASIS'
   V4071   = 'B6F.M6:FED SOURCE NAME'
   V4072   = 'B7F.M6:FED SOURCE AMOUNT'
   V4073   = 'B8F.M6:FED SOURCE PAY BASIS'
   V4074   = 'B9.TOT STATE $ TO UNIT'
   V4075   = 'B10-12. SUMMARY. # STATE $ SOURCES'
   V4076   = 'B10A.M1:STATE SOURCE NAME'
   V4077   = 'B11A.M1:STATE SOURCE AMOUNT'
   V4078   = 'B12A.M1:STATE SOURCE PAY BASIS'
   V4079   = 'B10B.M2:STATE SOURCE NAME'
   V4080   = 'B11B.M2:STATE SOURCE AMOUNT'
   V4081   = 'B12B.M2:STATE SOURCE PAY BASIS'
   V4082   = 'B10C.M3:STATE SOURCE NAME'
   V4083   = 'B11C.M3:STATE SOURCE AMOUNT'
   V4084   = 'B12C.M3:STATE SOURCE PAY BASIS'
   V4085   = 'B10D.M4:STATE SOURCE NAME'
   V4086   = 'B11D.M4:STATE SOURCE AMOUNT'
   V4087   = 'B12D.M4:STATE SOURCE PAY BASIS'
   V4088   = 'B10E.M5:STATE SOURCE NAME'
   V4089   = 'B11E.M5:STATE SOURCE AMOUNT'
   V4090   = 'B12E.M5:STATE SOURCE PAY BASIS'
   V4091   = 'B10F.M6:STATE SOURCE NAME'
   V4092   = 'B11F.M6:STATE SOURCE AMOUNT'
   V4093   = 'B12F.M6:STATE SOURCE PAY BASIS'
   V4094   = 'B13.TOT LOCAL GOV $ TO U'
   V4095   = 'B14-16 SUMMARY. # LOC GOV $ SOURCES'
   V4096   = 'B14A.M1:LOC GOV SOURCE NAME'
   V4097   = 'B15A.M1:LOC GOV SOURCE AMNT'
   V4098   = 'B16A.M1:LOC GOV PAY BASIS'
   V4099   = 'B14B.M2:LOC GOV SOURCE NAME'
   V4100   = 'B15B.M2:LOC GOV SOURCE AMNT'
   V4101   = 'B16B.M2:LOC GOV PAY BASIS'
   V4102   = 'B14C.M3:LOC GOV SOURCE NAME'
   V4103   = 'B15C.M3:LOC GOV SOURCE AMNT'
   V4104   = 'B16C.M3:LOC GOV PAY BASIS'
   V4105   = 'B14D.M4:LOC GOV SOURCE NAME'
   V4106   = 'B15D.M4:LOC GOV SOURCE AMNT'
   V4107   = 'B16D.M4:LOC GOV PAY BASIS'
   V4108   = 'B14E.M5:LOC GOV SOURCE NAME'
   V4109   = 'B15E.M5:LOC GOV SOURCE AMNT'
   V4110   = 'B16E.M5:LOC GOV PAY BASIS'
   V4111   = 'B14F.M6:LOC GOV SOURCE NAME'
   V4112   = 'B15F.M6:LOC GOV SOURCE AMNT'
   V4113   = 'B16F.M6:LOC GOV PAY BASIS'
   V4114   = 'B17.TOT PRIV INS $ TO U'
   V4115   = 'B18-20 SUMMARY. # PRIV INS SOURCES'
   V4116   = 'B18A.M1:PRIV INS NAME'
   V4117   = 'B19A.M1:PRIV INS AMOUNT'
   V4118   = 'B20A.M1:PR INS PAY BASIS'
   V4119   = 'B18B.M2:PRIV INS NAME'
   V4120   = 'B19B.M2:PRIV INS AMOUNT'
   V4121   = 'B20B.M2:PR INS PAY BASIS'
   V4122   = 'B18C.M3:PRIV INS NAME'
   V4123   = 'B19C.M3:PRIV INS AMOUNT'
   V4124   = 'B20C.M3:PR INS PAY BASIS'
   V4125   = 'B18D.M4:PRIV INS NAME'
   V4126   = 'B19D.M4:PRIV INS AMOUNT'
   V4127   = 'B20D.M4:PR INS PAY BASIS'
   V4128   = 'B18E.M5:PRIV INS NAME'
   V4129   = 'B19E.M5:PRIV INS AMOUNT'
   V4130   = 'B20E.M5:PR INS PAY BASIS'
   V4131   = 'B18F.M6:PRIV INS NAME'
   V4132   = 'B19F.M6:PRIV INS AMOUNT'
   V4133   = 'B20F.M6:PR INS PAY BASIS'
   V4134   = 'B21.TOT CL FEE $TO UNIT'
   V4135   = 'B21A.M1:CL FEE PAY BASIS'
   V4136   = 'B21A.M2:CL FEE PAY BASIS'
   V4137   = 'B22.TOT PRIV DON $-UNIT'
   V4138   = 'B23.IN-KIND PARENT SUPT:Y/N?'
   V4139   = 'B23A. $ VALUE PARENT SUPT'
   V4140   = 'B24. VOLUNTEER SUPT:Y/N?'
   V4141   = 'B24A. # TOT VOLUNTEER HRS'
   V4142   = 'B25.ANY OTHR SOURCE $-UNIT:Y/N?'
   V4143   = 'B26-28 SUMMARY. # OTR SOURCES'
   V4144   = 'B26A.M1:OTR $SOURCE NAME'
   V4145   = 'B27A.M1:OTR $SOURCE AMOUNT'
   V4146   = 'B28A.M1:OTR $SOURCE PAY BASIS'
   V4147   = 'B26B.M2:OTR $SOURCE NAME'
   V4148   = 'B27B.M2:OTR $SOURCE AMOUNT'
   V4149   = 'B28B.M2:OTR $SOURCE PAY BASIS'
   V4150   = 'B26C.M3:OTR $SOURCE NAME'
   V4151   = 'B27C.M3:OTR $SOURCE AMOUNT'
   V4152   = 'B28C.M3:OTR $SOURCE PAY BASIS'
   V4153   = 'B26D.M4:OTR $SOURCE NAME'
   V4154   = 'B27D.M4:OTR $SOURCE AMOUNT'
   V4155   = 'B28D.M4:OTR $SOURCE PAY BASIS'
   V4156   = 'B26E.M5:OTR $SOURCE NAME'
   V4157   = 'B27E.M5:OTR $SOURCE AMOUNT'
   V4158   = 'B28E.M5:OTR $SOURCE PAY BASIS'
   V4159   = 'B26F.M6:OTR $SOURCE NAME'
   V4160   = 'B27F.M6:OTR $SOURCE AMOUNT'
   V4161   = 'B28F.M6:OTR $SOURCE PAY BASIS'
   V4162   = 'B29.% OSAT CL PAY NOTHNG'
   V4163   = 'B29A.% OSAT CL PAY <MA'
   V4164   = 'B30.% TURND AWAY CNT PAY'
   V4165   = 'B31.# OSAT CL W COVERAGE'
   V4166   = 'B31.% OSAT CL W COVERAGE'
   V4167   = 'B32.# OSAT CL W PRIV INS'
   V4168   = 'B32.% OSAT CL W PRIV INS'
   V4169   = 'B32A.#PR INS CL@75%PAID'
   V4170   = 'B32A.%PR INS CL@75%PAID'
   V4171   = 'B32B.#PR INS CL <=50%PD'
   V4172   = 'B32B.%PR INS CL <=50%PD'
   V4173   = 'B33.#OSAT CL W PUB INS'
   V4174   = 'B33.%OSAT CL W PUB INS'
   V4175   = 'B33A.#PU INS CL@75%PAID'
   V4176   = 'B33A.%PU INS CL@75%PAID'
   V4177   = 'B33B.#PU INS CL <=50%PD'
   V4178   = 'B33B.%PU INS CL <=50%PD'
   V4179   = 'B34.TOT U $ XPNS MRCFY'
   V4180   = 'B34A.SUBTOT $ FOR WAGES/SALRIES'
   V4181   = 'B35.UNIT OWNS,RENTS,OTHER'
   V4182   = 'B35A.TOT $ FOR U RENTAL'
   V4183   = 'B36.# SQ FT IN TRMT UNIT'
   V4184   = 'B37.$ AMOUNT TX U ASSETS'
   V4185   = 'B38.$ AMOUNT U DEBT'
   V4186   = 'B39.UNIT HAS FINAN REPORT:Y/N?'
   V4187   = 'B39A.WILL SEND FIN REP:Y/N?'
   V4188   = 'B40.EXT USES FIN INFO'
   V4189   = 'B41.UNIT PROV OUTP IND TH:Y/N?'
   V4190   = 'B41A.# OUTP IND TH CL/WK'
   V4191   = 'B41B.#IND TH SESIONS/WK'
   V4192   = 'B41C.TOT #IND TH HRS/WK'
   V4193   = 'B41D.#MIN/SESION IND TH'
   V4194   = 'B41E.$/SESION IND THRPY'
   V4195   = 'B41F.#IND TH SESIONS/TX'
   V4196   = 'B42.U PROV OUTP GRP TH:Y/N?'
   V4197   = 'B42A.#OUTP GRP TH CL/WK'
   V4198   = 'B42B.#GRP TH SESNS/CL/WK'
   V4199   = 'B42C.#GRP TH SESIONS/WK'
   V4200   = 'B42D.TOT #GRP TH HRS/WK'
   V4201   = 'B42E.#MIN/GRP TH SESION'
   V4202   = 'B42F.$/GRP TH SESSION'
   V4203   = 'B42G.#CL/GRP TH SESSION'
   V4204   = 'B42H.#STAFF/GRP TH SESN'
   V4205   = 'B42I.#GRP TH SESIONS/TX'
   V4206   = 'B43.U PROV OUTP FAM TH:Y/N?'
   V4207   = 'B43A #FAMILIES IN TH/WK'
   V4208   = 'B43B TOT#FAM TH SSNS/WK'
   V4209   = 'B43C.TOT# FAM TH HRS/WK'
   V4210   = 'B43D.#MIN/FAM TH SESION'
   V4211   = 'B43E.$/FAM TH SESSION'
   V4212   = 'B43F.#FAM MEMBRS/SESION'
   V4213   = 'B43G.#STAFF/FAM TH SESN'
   V4214   = 'B43H.#FAM TH SESIONS/TX'
   V4215   = 'B44.U PROV OUTP METH TX:Y/N?'
   V4216   = 'B44A.#OUTP METH TX CL/WK'
   V4217   = 'B44B.TOT# METH DOSES/WK'
   V4218   = 'B44C.$/DOSE OF METHDONE'
   V4219   = 'B45.U PROV OTR OSAT SERV:Y/N?'
   V4220   = 'B46.SUMMARY # OTR OSAT SERVICES'
   V4221   = 'B46A.M1:OTR SERVICE TYPE'
   V4222   = 'B47A.M1:OTR SERV #CL/WK'
   V4223   = 'B48A.M1:OTR SV #SES/CL/WK'
   V4224   = 'B49A.M1:OTR SRV #MIN/SES'
   V4225   = 'B50A.M1:OTR SRV TOT $/WK'
   V4226   = 'B51A.M1:OTR SRV #SES/TX'
   V4227   = 'B46B.M2:OTR SERVICE TYPE'
   V4228   = 'B47B.M2:OTR SERV #CL/WK'
   V4229   = 'B48B.M2:OTR SV #SES/CL/WK'
   V4230   = 'B49B.M2:OTR SRV #MIN/SES'
   V4231   = 'B50B.M2:OTR SRV TOT $/WK'
   V4232   = 'B51B.M2:OTR SRV #SES/TX'
   V4233   = 'B46C.M3:OTR SERVICE TYPE'
   V4234   = 'B47C.M3:OTR SERV #CL/WK'
   V4235   = 'B48C.M3:OTR SV #SES/CL/WK'
   V4236   = 'B49C.M3:OTR SRV #MIN/SES'
   V4237   = 'B50C.M3:OTR SRV TOT $/WK'
   V4238   = 'B51C.M3:OTR SRV #SES/TX'
   V4239   = 'B46D.M4:OTR SERVICE TYPE'
   V4240   = 'B47D.M4:OTR SERV #CL/WK'
   V4241   = 'B48D.M4:OTR SV #SES/CL/WK'
   V4242   = 'B49D.M4:OTR SRV #MIN/SES'
   V4243   = 'B50D.M4:OTR SRV TOT $/WK'
   V4244   = 'B51D.M4:OTR SRV #SES/TX'
   V4245   = 'B46E.M5:OTR SERVICE TYPE'
   V4246   = 'B47E.M5:OTR SERV #CL/WK'
   V4247   = 'B48E.M5:OTR SV #SES/CL/WK'
   V4248   = 'B49E.M5:OTR SRV #MIN/SES'
   V4249   = 'B50E.M5:OTR SRV TOT $/WK'
   V4250   = 'B51E.M5:OTR SRV #SES/TX'
   V4251   = 'B46F.M6:OTR SERVICE TYPE'
   V4252   = 'B47F.M6:OTR SERV #CL/WK'
   V4253   = 'B48F.M6:OTR SV #SES/CL/WK'
   V4254   = 'B49F.M6:OTR SRV #MIN/SES'
   V4255   = 'B50F.M6:OTR SRV TOT $/WK'
   V4256   = 'B51F.M6:OTR SRV #SES/TX'
   V4257   = 'B52.TOT #HRS OTR SRV/WK'
   V4258   = 'B52A.OTR SRV #STAFF/WK'
   V4259   = 'B53.OUTP TX U PUB OR PR'
   V4260   = 'B54.TYPE OF PRIV UNIT'
   V4261   = 'B55.U PART OF LARGR ORG:Y/N?'
   V4262   = 'B56.U OWND BY ANOTR ORG:Y/N?'
   V4263   = 'B57.U MANAGD BY ANR ORG:Y/N?'
   V4264   = 'B58.IWER CHKPT U PARENT'
   V4265   = 'B59.PARNT ORG:PUB OR PRIV:PUB/NOT?'
   V4266   = 'B60.PUB PARENT:GOVT AUSPICE'
   V4267   = 'B61.PRIV PARENT:STOCKS:Y/N?'
   V4268   = 'B62.PRIV PARENT:PROFIT:Y/N?'
   V4269   = 'B63.PRIV PARNT:CORP TYPE'
   V4270   = 'B64.OWNR ORG:PUB OR PRIV:PUB/NOT?'
   V4271   = 'B65.PUB OWNR ORG:GOVT AUSPICE'
   V4272   = 'B66.PRI OWNR ORG:STOCKS:Y/N?'
   V4273   = 'B67.PRI OWNR ORG:PROFIT:Y/N?'
   V4274   = 'B68.PR OWNR ORG:CORP TYPE'
   V4275   = 'B69.MGMT ORG:PUB OR PRIV:PUB/NOT?'
   V4276   = 'B70.PUB MGMT ORG:GOVT AUSPICE'
   V4277   = 'B71.PRI MGMT ORG:STOCK:Y/N?'
   V4278   = 'B72.PRI MGMT ORG:PROFIT:Y/N?'
   V4279   = 'B73.PR MGMT ORG:CORP TYP'
   V4280   = 'B74.U OWN/MAN OTHER OSAT U:Y/N?'
   V4281   = 'B74A.# OSAT U OWND/MANAGED'
   V4282   = 'C1A.U LIC BY JCAHCO:Y/N?'
   V4283   = 'C1B.U LIC BY COUNCL ACCRED:Y/N?'
   V4284   = 'C1C.U LI BY FEDERAL FDA:Y/N?'
   V4285   = 'C1D.U LIC BY DEA:Y/N?'
   V4286   = 'C1E.U LIC BY A STATE AGENCY:Y/N?'
   V4287   = 'C1G.U LIC BY A CTY,CO AGENCY:Y/N?'
   V4288   = 'C1I.U LIC BY ANY OTHER ORGS:Y/N?'
   V4289   = 'C2.DOES STATE REQUIRE LIC/ACCRED:Y/N?'
   V4290   = 'C2B.CAN OTHER LIC BE SUBSTITUTED:Y/N?'
   V4291   = 'C3.DOES U NEED LIC TO RECV PAYMT:Y/N?'
   V4292   = 'C4.PERIODIC REVIEW BY OUTSDE ORGN:Y/N?'
   V4293   = 'C5A.REVIEW REQ BY JCAHCO:Y/N?'
   V4294   = 'C5B.FREQ OF REVIEW BY JCAHO'
   V4295   = 'C5C.REVIEW REQ BY COUNL ACCRD:Y/N?'
   V4296   = 'C5D.FREQ OF REVIEW BY COUNL ACCRD'
   V4297   = 'C5E.REVIEW REQ BY ST DP PUB HLTH:Y/N?'
   V4298   = 'C5F.FREQ OF REVIEW BY ST DP PUB HLTH'
   V4299   = 'C5G.REVIEW REQ BY ST DP MEN HLTH:Y/N?'
   V4300   = 'C5H.FREQ OF REVIEW BY ST DP MENT HLTH'
   V4301   = 'C5I.REVIEW REQ BY ST DP SUB ABUSE:Y/N?'
   V4302   = 'C5J.FREQ OF REVIEW BY ST DP SUB ABUSE'
   V4303   = 'C5K.REVIEW REQ BY FDA:Y/N?'
   V4304   = 'C5L.FREQ OF REVIEW BY FDA'
   V4305   = 'C5M.REVIEW REQ BY DEA:Y/N?'
   V4306   = 'C5N.FREQ OF REVIEW BY DEA'
   V4307   = 'C6.REVIEW REQ BY ANY OTHR AGENCY:Y/N?'
   V4308   = 'C6A.FREQ OF REVIEW BY OTHR AGENCY'
   V4309   = 'C7A.DOES REVW INCL FINAN RECORDS:Y/N?'
   V4310   = 'C7B.DOES REVW INCL CLIENT CONTACT:Y/N?'
   V4311   = 'C7C.DOES REVW INCL SITE VISIT:Y/N?'
   V4312   = 'C7D.DOES REVW INCL WRITTEN REPT:Y/N?'
   V4313   = 'C7E.DOES REVW INCL CLI RECORDS:Y/N?'
   V4314   = 'C7F.DOES REVW INCL POL/PROC:Y/N?'
   V4315   = 'C7G.DOES REVW INCL QUALITY ASSUR:Y/N?'
   V4316   = 'C8.EXT U SHD BE INVL IN POL DEVLP'
   V4317   = 'C8A.EXT U IS INVL IN POL DEVLOP'
   V4318   = 'C9A.EXT R RELIES ON READ PUBLICS'
   V4319   = 'C9B.EXT R RELIES ON ATTEND CONFS'
   V4320   = 'C9C.EXT R RELIES ON PARTIC SESSIONS'
   V4321   = 'C9D.EXT R RELIES ON MEMBERSHIP ASSNS'
   V4322   = 'C9E.EXT R RELIES ON PARTIC BOARDS'
   V4323   = 'C9F.EXT R RELIES ON PARTIC RESEARCH'
   V4324   = 'C9G.EXT R RELIES ON USE CONSULTANTS'
   V4325   = 'C9H.EXT R RELIES ON MARKET RESEARCH'
   V4326   = 'C9I.EXT R RELIES ON CONVERSATIONS'
   V4327   = 'C9J.EXT R RELIES ON OUTREACH,EDUC'
   V4328   = 'C10A.FORMED PARTNERSHIP IN MRCFY:Y/N?'
   V4329   = 'C10B.JOINED COALITION/ASSOCIATN:Y/N?'
   V4330   = 'C10C.DEVELOPED NEW SRV FOR SAT:Y/N?'
   V4331   = 'C10D.DEVELOPED NEW SRV FOR OTR:Y/N?'
   V4332   = 'C10E.PROVIDED SRV FOR NEW TYPE:Y/N?'
   V4333   = 'C10F.MERGED WITH ANOTHER UNIT:Y/N?'
   V4334   = 'C11.EXT M/G TO COMPLY WITH GOVT REGS'
   V4335   = 'C11A.SUMMARY  # OF GOVT AGENCIES'
   V4336   = 'C11B1.M1:A FUNDING AGENCY:C/N?'
   V4337   = 'C11B2.M1:A LICENSING AGCY'
   V4338   = 'C11B3.M1:A REFERRAL AGCY:C/N?'
   V4339   = 'C11C. M1:LOCAL/STATE/FEDERAL'
   V4340   = 'C11B1.M2:A FUNDING AGENCY:C/N?'
   V4341   = 'C11B2.M2:A LICENSING AGCY'
   V4342   = 'C11B3.M2:A REFERRAL AGCY:C/N?'
   V4343   = 'C11C. M2:LOCAL/STATE/FEDERAL'
   V4344   = 'C11B1.M3:A FUNDING AGENCY:C/N?'
   V4345   = 'C11B2.M3:A LICENSING AGCY'
   V4346   = 'C11B3.M3:A REFERRAL AGCY:C/N?'
   V4347   = 'C11C. M3:LOCAL/STATE/FEDERAL'
   V4348   = 'C12.EXT GOV AGNC HAVE CONFLICT REQ'
   V4349   = 'C13.EXT M/G DUE TO FORMAL AGREEMENT'
   V4350   = 'C13A.MSN:AGREEMENT # AGCY NAMES'
   V4351   = 'C13B.MSN:AGR-FUND AGY#1:CH/NOT?'
   V4352   = 'C13B.MSN:AGR-LICN AGY#1'
   V4353   = 'C13B.MSN:AGR-REFR AGY#1:CH/NOT?'
   V4354   = 'C13B.MSN:AGR-TX U AGY#1:CH/NOT?'
   V4355   = 'C13C.MSN:AGR-LEVL AGY#1'
   V4356   = 'C13B.MSN:AGR-FUND AGY#2:CH/NOT?'
   V4357   = 'C13B.MSN:AGR-LICN AGY#2'
   V4358   = 'C13B.MSN:AGR-REFR AGY#2:CH/NOT?'
   V4359   = 'C13B.MSN:AGR-TX U AGY#2:CH/NOT?'
   V4360   = 'C13C.MSN:AGR-LEVL AGY#2'
   V4361   = 'C13B.MSN:AGR-FUND AGY#3:CH/NOT?'
   V4362   = 'C13B.MSN:AGR-LICN AGY#3'
   V4363   = 'C13B.MSN:AGR-REFR AGY#3:CH/NOT?'
   V4364   = 'C13B.MSN:AGR-TX U AGY#3:CH/NOT?'
   V4365   = 'C13C.MSN:AGR-LEVL AGY#3'
   V4366   = 'C14.MSN:EXTN ORG CONFLCT REQ'
   V4367   = 'C15.MSN:EXTN ORG OFFERED INCENT'
   V4368   = 'C15A.MSN:INC-SUMMARY #ORG NAMES'
   V4369   = 'C15B.MSN:INC-FUND AGY#1:CH/NOT?'
   V4370   = 'C15B.MSN:INC-LICN AGY#1:CH/NOT?'
   V4371   = 'C15B.MSN:INC-REFR AGY#1:CH/NOT?'
   V4372   = 'C15B.MSN:INC-TX U AGY#1:CH/NOT?'
   V4373   = 'C15C.MSN:INC-LEVL AGY#1'
   V4374   = 'C15B.MSN:INC-FUND AGY#2:CH/NOT?'
   V4375   = 'C15B.MSN:INC-LICN AGY#2'
   V4376   = 'C15B.MSN:INC-REFR AGY#2:CH/NOT?'
   V4377   = 'C15B.MSN:INC-TX U AGY#2:CH/NOT?'
   V4378   = 'C15C.MSN:INC-LEVL AGY#2'
   V4379   = 'C15B.MSN:INC-FUND AGY#3:CH/NOT?'
   V4380   = 'C15B.MSN:INC-LICN AGY#3'
   V4381   = 'C15B.MSN:INC-REFR AGY#3:CH/NOT?'
   V4382   = 'C15B.MSN:INC-TX U AGY#3:CH/NOT?'
   V4383   = 'C15C.MSN:INC-LEVL AGY#3'
   V4384   = 'C16.MSN:EXTN ORGN HAVE CONFLCT REQ'
   V4385   = 'C17.MSN:EXTN ENHANC PUB IMAG'
   V4386   = 'C18.MSN:EXTN KEEP UP W FIELD'
   V4387   = 'C19.EXTN CLI ASSMTSS:GOV AGY RGS'
   V4388   = 'C19A.ASS:GOV-SUMMARY #AGY NAMES'
   V4389   = 'C19B.ASS:GOV-FUND AGY#1:CH/NOT?'
   V4390   = 'C19B.ASS:GOV-LICN AGY#1'
   V4391   = 'C19B.ASS:GOV-REFR AGY#1:CH/NOT?'
   V4392   = 'C19C.ASS:GOV-LEVL AGY#1'
   V4393   = 'C19B.ASS:GOV-FUND AGY#2:CH/NOT?'
   V4394   = 'C19B.ASS:GOV-LICN AGY#2'
   V4395   = 'C19B.ASS:GOV-REFR AGY#2:CH/NOT?'
   V4396   = 'C19C.ASS:GOV-LEVL AGY#2'
   V4397   = 'C19B.ASS:GOV-FUND AGY#3:CH/NOT?'
   V4398   = 'C19B.ASS:GOV-LICN AGY#3'
   V4399   = 'C19B.ASS:GOV-REFR AGY#3:CH/NOT?'
   V4400   = 'C19C.ASS:GOV-LEVL AGY#3'
   V4401   = 'C20.ASS:EXTN GOV-CONFLCT REQ'
   V4402   = 'C21.ASS:EXTN FORMAL AGREEMNT'
   V4403   = 'C21A.ASS:AGR-SUMMARY # ORG NAMES'
   V4404   = 'C21B.ASS:AGR-FUND AGY#1:CH/NOT?'
   V4405   = 'C21B.ASS:AGR-LICN AGY#1'
   V4406   = 'C21B.ASS:AGR-REFR AGY#1:CH/NOT?'
   V4407   = 'C21B.ASS:AGR-TX U AGY#1:CH/NOT?'
   V4408   = 'C21C.ASS:AGR-LEVL AGY#1'
   V4409   = 'C21B.ASS:AGR-FUND AGY#2:CH/NOT?'
   V4410   = 'C21B.ASS:AGR-LICN AGY#2'
   V4411   = 'C21B.ASS:AGR-REFR AGY#2:CH/NOT?'
   V4412   = 'C21B.ASS:AGR-TX U AGY#2:CH/NOT?'
   V4413   = 'C21C.ASS:AGR-LEVL AGY#2'
   V4414   = 'C21B.ASS:AGR-FUND AGY#3:CH/NOT?'
   V4415   = 'C21B.ASS:AGR-LICN AGY#3'
   V4416   = 'C21B.ASS:AGR-REFR AGY#3:CH/NOT?'
   V4417   = 'C21B.ASS:AGR-TX U AGY#3:CH/NOT?'
   V4418   = 'C21C.ASS:AGR-LEVL AGY#3'
   V4419   = 'C22.ASS:AGR-EXTN CONFLCT REQ'
   V4420   = 'C23.ASS:EXTN ORG OFRD INCENT'
   V4421   = 'C23A.ASS:INC-SUMMARY # ORG NAMES'
   V4422   = 'C23B.ASS:INC-FUND AGY#1:CH/NOT?'
   V4423   = 'C23B.ASS:INC-LICN AGY#1'
   V4424   = 'C23B.ASS:INC-REFR AGY#1:CH/NOT?'
   V4425   = 'C23B.ASS:INC-TX U AGY#1:CH/NOT?'
   V4426   = 'C23C.ASS:INC-LEVL AGY#1'
   V4427   = 'C23B.ASS:INC-FUND AGY#2:CH/NOT?'
   V4428   = 'C23B.ASS:INC-LICN AGY#2'
   V4429   = 'C23B.ASS:INC-REFR AGY#2:CH/NOT?'
   V4430   = 'C23B.ASS:INC-TX U AGY#2:CH/NOT?'
   V4431   = 'C23C.ASS:INC-LEVL AGY#2'
   V4432   = 'C23B.ASS:INC-FUND AGY#3:CH/NOT?'
   V4433   = 'C23B.ASS:INC-LICN AGY#3'
   V4434   = 'C23B.ASS:INC-REFR AGY#3:CH/NOT?'
   V4435   = 'C23B.ASS:INC-TX U AGY#3:CH/NOT?'
   V4436   = 'C23C.ASS:INC-LEVL AGY#3'
   V4437   = 'C24.ASS:EXTN CONFLCT REQ'
   V4438   = 'C25.ASS:EXTN ENHANC PUB IMAG'
   V4439   = 'C26.ASS:EXTN KEEP UP W FIELD'
   V4440   = 'C27.TX APPR:EXTN GOV AGY RGS'
   V4441   = 'C27A.TX:GOV-SUMMARY # AGY NAMES'
   V4442   = 'C27B.TX:GOV-FUND AGY#1:CH/NOT?'
   V4443   = 'C27B.TX:GOV-LICN AGY#1'
   V4444   = 'C27B.TX:GOV-REFR AGY#1:CH/NOT?'
   V4445   = 'C27C.TX:GOV-LEVL AGY#1'
   V4446   = 'C27B.TX:GOV-FUND AGY#2:CH/NOT?'
   V4447   = 'C27B.TX:GOV-LICN AGY#2'
   V4448   = 'C27B.TX:GOV-REFR AGY#2:CH/NOT?'
   V4449   = 'C27C.TX:GOV-LEVL AGY#2'
   V4450   = 'C27B.TX:GOV-FUND AGY#3:CH/NOT?'
   V4451   = 'C27B.TX:GOV-LICN AGY#3'
   V4452   = 'C27B.TX:GOV-REFR AGY#3:CH/NOT?'
   V4453   = 'C27C.TX:GOV-LEVL AGY#3'
   V4454   = 'C28.TX:EXTN GOV-CONFLCT REQ'
   V4455   = 'C29.TX:EXTN FORMAL AGREEMNT'
   V4456   = 'C29A.TX:AGR-SUMMARY # ORG NAMES'
   V4457   = 'C29B.TX:AGR-FUND AGY#1:CH/NOT?'
   V4458   = 'C29B.TX:AGR-LICN AGY#1'
   V4459   = 'C29B.TX:AGR-REFR AGY#1:CH/NOT?'
   V4460   = 'C29B.TX:AGR-TX U AGY#1:CH/NOT?'
   V4461   = 'C29C.TX:AGR-LEVL AGY#1'
   V4462   = 'C29B.TX:AGR-FUND AGY#2:CH/NOT?'
   V4463   = 'C29B.TX:AGR-LICN AGY#2'
   V4464   = 'C29B.TX:AGR-REFR AGY#2:CH/NOT?'
   V4465   = 'C29B.TX:AGR-TX U AGY#2:CH/NOT?'
   V4466   = 'C29C.TX:AGR-LEVL AGY#2'
   V4467   = 'C29B.TX:AGR-FUND AGY#3:CH/NOT?'
   V4468   = 'C29B.TX:AGR-LICN AGY#3'
   V4469   = 'C29B.TX:AGR-REFR AGY#3:CH/NOT?'
   V4470   = 'C29B.TX:AGR-TX U AGY#3:CH/NOT?'
   V4471   = 'C29C.TX:AGR-LEVL AGY#3'
   V4472   = 'C30.TX:EXTN AGR-CONFLCT REQ'
   V4473   = 'C31.TX:EXTN ORG OFRD INCENT'
   V4474   = 'C31A.TX:INC-SUMMARY # ORG NAMES'
   V4475   = 'C31B.TX:INC-FUND AGY#1:CH/NOT?'
   V4476   = 'C31B.TX:INC-LICN AGY#1'
   V4477   = 'C31B.TX:INC-REFR AGY#1:CH/NOT?'
   V4478   = 'C31B.TX:INC-TX U AGY#1:CH/NOT?'
   V4479   = 'C31C.TX:INC-LEVL AGY#1'
   V4480   = 'C31B.TX:INC-FUND AGY#2:CH/NOT?'
   V4481   = 'C31B.TX:INC-LICN AGY#2'
   V4482   = 'C31B.TX:INC-REFR AGY#2:CH/NOT?'
   V4483   = 'C31B.TX:INC-TX U AGY#2:CH/NOT?'
   V4484   = 'C31C.TX:INC-LEVL AGY#2'
   V4485   = 'C31B.TX:INC-FUND AGY#3:CH/NOT?'
   V4486   = 'C31B.TX:INC-LICN AGY#3'
   V4487   = 'C31B.TX:INC-REFR AGY#3:CH/NOT?'
   V4488   = 'C31B.TX:INC-TX U AGY#3:CH/NOT?'
   V4489   = 'C31C.TX:INC-LEVL AGY#3'
   V4490   = 'C32.TX:EXTN INC-CONFLCT REQ'
   V4491   = 'C33.TX:EXTN ENHANC PUB IMAG'
   V4492   = 'C34.TX:EXTN KEEP UP W FIELD'
   V4493   = 'D1.EXTN OBTAIN FOLLOWUP INFO'
   V4494   = 'D1AM1.WHY NO FOLLOWUP'
   V4495   = 'D1AM2.WHY NO FOLLOWUP'
   V4496   = 'D2A.FLW-UP 1-3MO AFTR TX:CH/NOT?'
   V4497   = 'D2B.FLW-UP 4-6MO AFTR TX:CH/NOT?'
   V4498   = 'D2C.FLW-UP 7-9MO AFTR TX:CH/NOT?'
   V4499   = 'D2D.FLW-UP 10-12 AFTR TX:CH/NOT?'
   V4500   = 'D2E.FLW-UP 13-18 AFTR TX:CH/NOT?'
   V4501   = 'D2F.FLW-UP 19-24 AFTR TX:CH/NOT?'
   V4502   = 'D2G.FLW-UP >24MO AFTR TX:CH/NOT?'
   V4503   = 'D3.EXTN FOLOW ALL CL-SUCCESS'
   V4504   = 'D4A.FOLOW:LIV ARRANGMNT:Y/N?'
   V4505   = 'D4B.FOLOW:EMPLOY STATUS:Y/N?'
   V4506   = 'D4C.FOLOW:HEALTH STATUS:Y/N?'
   V4507   = 'D4D.FOLOW:LGL PROB STAT:Y/N?'
   V4508   = 'D4E.FOLOW:FINANCL STAT:Y/N?'
   V4509   = 'D4F.FOLOW:IN RECOMND TX:Y/N?'
   V4510   = 'D4G.FOLOW:DRUG,ALC USE:Y/N?'
   V4511   = 'D4H.FOLOW:CL EVALUAT TX:Y/N?'
   V4512   = 'D4I.FOLOW:CL EVALUAT U:Y/N?'
   V4513   = 'D4J.FOLOW:GT DROPS RETN:Y/N?'
   V4514   = 'D4K.FOLOW:ANY OTH INFO?:Y/N?'
   V4515   = 'D4KM1.FLW:TYPE OTH INFO'
   V4516   = 'D4KM2.FLW:TYPE OTH INFO'
   V4517   = 'D5A.FOLOW:SELF-ADMN SUR:Y/N?'
   V4518   = 'D5B.FOLOW:PHONE:Y/N?'
   V4519   = 'D5C.FOLOW:FACE TO FACE:Y/N?'
   V4520   = 'D5D.FOLOW:OTHER MEANS:Y/N?'
   V4521   = 'D5DM1.FLW:TYP OTH MEANS'
   V4522   = 'D5DM2.FLW:TYP OTH MEANS'
   V4523   = 'D6.FLW:PRGM STAF COLECT:Y/N?'
   V4524   = 'D6AM1.FLW:WHO COLL INFO'
   V4525   = 'D6AM2.FLW:WHO COLL INFO'
   V4526   = 'D7.FOLOW:EXTN USE-COMPAR W U'
   V4527   = 'D8.FOLOW:EXTN USE-CHANG PRGM'
   V4528   = 'E1A.EXTN HOSP SATU COMPETITN'
   V4529   = 'E1B.PUB OR PRI HOSP COMP'
   V4530   = 'E1C.EXTN MNHLTH SATU COMPETN'
   V4531   = 'E1D.PUB OR PRI MH COMP'
   V4532   = 'E1E.EXTN FREE-ST SATU COMPTN'
   V4533   = 'E1F.PUB OR PR FR-ST COMP'
   V4534   = 'E2A.EXTN COMP OTH SATU:CLNTS'
   V4535   = 'E2B.EXTN COMP OTH SATU:GOV $'
   V4536   = 'E2C.EXTN COMP OTH SATU:POLIT'
   V4537   = 'E2D.EXTN COMP OTH SATU:COMTY'
   V4538   = 'E2E.EXTN COMP OTH SATU:P INS'
   V4539   = 'E2F.EXTN COMP OTH SATU:ACCRD'
   V4540   = 'E2G.EXTN COMP OTH SATU:PERNL'
   V4541   = 'E3A.EXTN COMP BASE:COST CL'
   V4542   = 'E3B.EXTN COMP BASE:COST OTH'
   V4543   = 'E3C.EXTN COMP BASE:STAF CRED'
   V4544   = 'E3D.EXTN COMP BASE:TRT SETNG'
   V4545   = 'E3E.EXTN COMP BASE:EASE ACCS'
   V4546   = 'E3F.EXTN COMP BASE:QUAL CARE'
   V4547   = 'E3G.EXTN COMP BASE:MARKETING'
   V4548   = 'E3H.EXTN COMP BASE:TRT RANGE'
   V4549   = 'E4.AMOUT COMP RESOURCES YR CHNGE'
   V4550   = 'E4AM1.Y COMP CHANGE-YR'
   V4551   = 'E4AM2.Y COMP CHANGE-YR'
   V4552   = 'E5A.# HR/WK-R:NEGOT $ AGY'
   V4553   = 'E5B.# HR/WK-R:LIASN LICEN'
   V4554   = 'E5C.# HR/WK-R:COMMTY TALK'
   V4555   = 'E5D.# HR/WK-R:IDENT NEW $'
   V4556   = 'E5E.# HR/WK-R:OTH PROVIDR'
   V4557   = 'E5F.# HR/WK-R:CNTB POLICY'
   V4558   = 'E5G.# HR/WK-R:RECRUIT STF'
   V4559   = 'E5H.# HR/WK-R:PROFL ASSOC'
   V4560   = 'E6A.HOW PROVD:DIAG SERV'
   V4561   = 'E6B.HOW PROVD:DR SERVIC'
   V4562   = 'E6C.HOW PROVD:T SERVICE'
   V4563   = 'E6D.HOW PROVD:PHAR SERV'
   V4564   = 'E6E.HOW PROVD:EVAL CL'
   V4565   = 'E6F.HOW PROVD:CL AFTERC'
   V4566   = 'E6G.HOW PROVD:VOLN SERV'
   V4567   = 'E6H.HOW PROVD:CLERICAL'
   V4568   = 'E6I.HOW PROVD:JANITORAL'
   V4569   = 'E6J.HOW PROVD:PHYS SPAC'
   V4570   = 'E6K.HOW PROVD:CL REFERL'
   V4571   = 'E7.SOU LARGST # REFERLS:ORGN/NOT?'
   V4572   = 'E8A.MJR REF SOU:POLICE:Y/N?'
   V4573   = 'E8B.MJR REF SOU:MN HLTH:Y/N?'
   V4574   = 'E8C.MJR REF SOU:EAP:Y/N?'
   V4575   = 'E8D.MJR REF SOU:HOSPTAL:Y/N?'
   V4576   = 'E8E.MJR REF SOU:CHURCH:Y/N?'
   V4577   = 'E8F.MJR REF SOU:SCHOOL:Y/N?'
   V4578   = 'E8G.MJR REF SOU:EMPLOYR:Y/N?'
   V4579   = 'E8H.MJR REF SOU:COURTS:Y/N?'
   V4580   = 'E8I.MJR REF SOU:DSS:Y/N?'
   V4581   = 'E8J.MJR REF SOU:VOC REHB:Y/N?'
   V4582   = 'E8K.MJR REF SOU:AA,NA:Y/N?'
   V4583   = 'E8L.MJR REF SOU:OTHER ORGN:Y/N?'
   V4584   = 'E8L.MJR REF SOU:SPECIFY'
   V4585   = 'E9A.EXTN Y MJ REF SOU:LEGALLY'
   V4586   = 'E9B.EXTN Y MJ REF SOU:CONTRC'
   V4587   = 'E9C.EXTN Y MJ REF SOU:ACCRED'
   V4588   = 'E9D.EXTN Y MJ REF SOU:INCENT'
   V4589   = 'E9E.EXTN Y MJ REF SOU:P IMAG'
   V4590   = 'E9F.EXTN Y MJ REF SOU:OTHER'
   V4591   = 'E9G.MJ REF SOU:SPECFY'
   V4592   = 'E10A.MJ REF SOU:INF AGR:Y/N?'
   V4593   = 'E10B.MJ REF SOU:OWNS U:Y/N?'
   V4594   = 'E10C.MJ REF SOU:CONTRCT:Y/N?'
   V4595   = 'E11A.CONTR SPEC:LICENSD:Y/N?'
   V4596   = 'E11B.CONTR SPEC:INCENTV:Y/N?'
   V4597   = 'E11C.CONTR SPEC:REF SOP:Y/N?'
   V4598   = 'E11D.CONTR SPEC:DISPUTE:Y/N?'
   V4599   = 'E11E.CONTR SPEC:FEE SCH:Y/N?'
   V4600   = 'E11FM1.ARANG W E7:OTHER'
   V4601   = 'E11FM2.ARANG W E7:OTHER'
   V4602   = 'E12A.E7:AMT AGREE REC CL CRITICAL'
   V4603   = 'E12B.E7:AMT AGREE ALTERNV SOURCES'
   V4604   = 'E12C.E7:AMT AGREE CONTROL OVER-2U'
   V4605   = 'E12D.E7:AMT AGREE U INFLUENCES E7'
   V4606   = 'E12E.E7:AMT AGREE FUTUR REF UNCER'
   V4607   = 'E12F.E7:AMT AGREE OTH U COMP REFS'
   V4608   = 'E12G.E7:AMT AGREE LONGTERM RELSHP'
   V4609   = 'E12H.E7:AMT AGREE U FREQ CONTACTS'
   V4610   = 'E12I.E7:AMT AGREE FUTURE SURVIVAL'
   V4611   = 'E12J.E7:AMT AGREE U UNDERSTAND E7'
   V4612   = 'E12K.E7:AMT AGREE U EYE TO EYE-T'
   V4613   = 'E12L.E7:AMT AGREE U SHARES BELIEF'
   V4614   = 'E12M.AMT AGREE CLIMATE COMPT-REFS'
   V4615   = 'E13.ONLY U REC CL FR E7:Y/N?'
   V4616   = 'E14.WHAT OTHER U REC CL:NAME/TYPE?'
   V4617   = 'E15.KIND OTH U REC CLIENT'
   V4618   = 'E15A.OTH U REC CL:PB/PR?'
   V4619   = 'E16A.AGR E14:SHAR CL E7:Y/N?'
   V4620   = 'E16B.ASC E14:REG DIS CL:Y/N?'
   V4621   = 'E16C.SHARED U E14:CL E7:Y/N?'
   V4622   = 'E16D.U MERG W E14:CL E7:Y/N?'
   V4623   = 'E16E.U CONTRC E14:CL E7:Y/N?'
   V4624   = 'E17A.E14 CONTR:LICENSED:Y/N?'
   V4625   = 'E17B.E14 CONTR:INCENTIV:Y/N?'
   V4626   = 'E17C.E14 CONTR:REF SOP:Y/N?'
   V4627   = 'E17D.E14 CONTR:DISPUTES:Y/N?'
   V4628   = 'E17E.E14 CONTR:FEE SCHD:Y/N?'
   V4629   = 'E17FM1.E14 ARANGE:OTHER'
   V4630   = 'E17FM2.E14 ARANGE:OTHER'
   V4631   = 'E18A.AMT AGREE COOP E14-CRITICAL'
   V4632   = 'E18B.AMT AGREE E14 CONTROL-E7 CL'
   V4633   = 'E18C.AMT AGREE LONGTERM REL W E14'
   V4634   = 'E18D.AMT AGREE FREQ CONTCTS W E14'
   V4635   = 'E18E.AMT AGREE E14:FUTURE SURVIVL'
   V4636   = 'E18F.AMT AGREE BUILD FUTURE W E14'
   V4637   = 'E18G.AMT AGREE E14:SAME RISK&BENF'
   V4638   = 'E18H.AMT AGREE E14:U UNDRSTND E14'
   V4639   = 'E18I.AMT AGREE E14:U EYE TO EYE-T'
   V4640   = 'E18J.AMT AGREE 14:U SHARE BELIEF'
   V4641   = 'E19A.AMT AGREE IN 1YR:AMT AVAIL $'
   V4642   = 'E19B.AMT AGREE IN 1YR:LEV DEM SER'
   V4643   = 'E19C.AMT AGREE IN 1YR:KND SER DEM'
   V4644   = 'E19D.AMT AGREE IN 1YR:KND STF NEE'
   V4645   = 'E19E.AMT AGREE IN 1YR:ACR AGY REQ'
   V4646   = 'E19F.AMT AGREE IN 1YR:OTH SAT OFR'
   V4647   = 'E19G.AMT AGREE IN 1YR:OTH SAT CHG'
   V4648   = 'E19H.AMT AGREE IN 1YR:OTH SAT QUL'
   V4649   = 'E19I.AMT AGREE IN 1YR:$SOU EXPECT'
   V4650   = 'F0.IWR CKPT:U PARENT:HAS/NOT?'
   V4651   = 'F1.PARENT:OTHER TX STAFF:Y/N?'
   V4652   = 'F2A.AMT COMPARE U TSTAF RE PAR:PROF'
   V4653   = 'F2B.AMT COMPARE U TSTAF RE PAR:EXPR'
   V4654   = 'F2C.AMT COMPARE U TSTF RE PAR:SA TR'
   V4655   = 'F2D.AMT COMPARE U TSTF RE PAR:P HST'
   V4656   = 'F2E.AMT COMPARE U TSTF RE PAR:COMIT'
   V4657   = 'F2F.AMT COMPARE U TSTF RE PAR:SALRY'
   V4658   = 'F3.AMT PARENT ACEPTNCE OF U'
   V4659   = 'F4M1.WHY PARENTL ACCEPT'
   V4660   = 'F4M2.WHY PARENTL ACCEPT'
   V4661   = 'F5A.AMT COMPARE U TSTAF RE OTH:PROF'
   V4662   = 'F5B.AMT COMPARE U TSTAF RE OTH:EXPR'
   V4663   = 'F5C.AMT COMPARE U TSTF RE OTH:SA TR'
   V4664   = 'F5D.AMT COMPARE U TSTF RE OTH:P HST'
   V4665   = 'F5E.AMT COMPARE U TSTF RE OTH:COMIT'
   V4666   = 'F5F.AMT COMPARE U TSTF RE OTH:SALRY'
   V4667   = 'G1.LST FYR:#SAT CLIENTS'
   V4668   = 'G1A.LFYR:# FEMALE SA CL'
   V4669   = 'G1A.LFYR:% FEMALE SA CL'
   V4670   = 'G1B.LFYR:# SA CL <20 YR'
   V4671   = 'G1B.LFYR:% SA CL <20 YR'
   V4672   = 'G1C.LFYR:# SA CL >64 YR'
   V4673   = 'G1C.LFYR:% SA CL >64 YR'
   V4674   = 'G1D.LFYR:# UNEMPL SA CL'
   V4675   = 'G1D.LFYR:% UNEMPL SA CL'
   V4676   = 'G1E.LFYR:# UNINSU SA CL'
   V4677   = 'G1E.LFYR:% UNINSU SA CL'
   V4678   = 'G1F.LFYR:#SA CL $<12500'
   V4679   = 'G1F.LFYR:%SA CL $<12500'
   V4680   = 'G1G.LFYR:#SACL$@12.5<25'
   V4681   = 'G1G.LFYR:%SACL$@12.5<25'
   V4682   = 'G1H.LFYR:#SACL$@25K<50K'
   V4683   = 'G1H.LFYR:%SACL$@25K<50K'
   V4684   = 'G1I.LFYR:#SA CL $=,>50K'
   V4685   = 'G1I.LFYR:%SA CL $=,>50K'
   V4686   = 'G2.PRV FYR:#SAT CLIENTS'
   V4687   = 'G2A.PFYR:# FEMALE SA CL'
   V4688   = 'G2A.PFYR:% FEMALE SA CL'
   V4689   = 'G2B.PFYR:# SA CL <20 YR'
   V4690   = 'G2B.PFYR:% SA CL <20 YR'
   V4691   = 'G2C.PFYR:# SA CL >64 YR'
   V4692   = 'G2C.PFYR:% SA CL >64 YR'
   V4693   = 'G2D.PFYR:# UNEMPL SA CL'
   V4694   = 'G2D.PFYR:% UNEMPL SA CL'
   V4695   = 'G2E.PFYR:# UNINSU SA CL'
   V4696   = 'G2E.PFYR:% UNINSU SA CL'
   V4697   = 'G2F.PFYR:#SA CL $<12500'
   V4698   = 'G2F.PFYR:%SA CL $<12500'
   V4699   = 'G2G.PFYR:#SACL$@12.5<25'
   V4700   = 'G2G.PFYR:%SACL$@12.5<25'
   V4701   = 'G2H.PFYR:#SACL$@25K<50K'
   V4702   = 'G2H.PFYR:%SACL$@25K<50K'
   V4703   = 'G2I.PFYR:#SA CL $=,>50K'
   V4704   = 'G2I.PFYR:%SA CL $=,>50K'
   V4705   = 'G3.LST FYR:U DV NEW PRG:Y/N?'
   V4706   = 'G3AM1.LST FYR:NEW PRGM'
   V4707   = 'G3AM2.LST FYR:NEW PRGM'
   V4708   = 'G3AM3.LST FYR:NEW PRGM'
   V4709   = 'G3AM4.LST FYR:NEW PRGM'
   V4710   = 'G4.CURNTLY PLAN NEW PRG:Y/N?'
   V4711   = 'G4AM1.PLANNING:NEW PRGM'
   V4712   = 'G4AM2.PLANNING:NEW PRGM'
   V4713   = 'G4AM3.PLANNING:NEW PRGM'
   V4714   = 'G4AM4.PLANNING:NEW PRGM'
   V4715   = 'G5.LFYR:#SA CL MEMB HMO'
   V4716   = 'G5.LFYR:%SA CL MEMB HMO'
   V4717   = 'G6.LFYR:#SA CL PRI AUTH'
   V4718   = 'G6.LFYR:%SA CL PRI AUTH'
   V4719   = 'G7.LFYR:#SA CL CONC REV'
   V4720   = 'G7.LFYR:%SA CL CONC REV'
   V4721   = 'G8A.CONCURRENT REV:COST:Y/N?'
   V4722   = 'G8B.CONCURRENT REV:QUAL:Y/N?'
   V4723   = 'G8C.CONCURRENT REV:NEED:Y/N?'
   V4724   = 'G9.LFYR:#SA CL REQ REPT'
   V4725   = 'G9.LFYR:%SA CL REQ REPT'
   V4726   = 'H1.# YRS:EMPLOYED BY U'
   V4727   = 'H1.# MOS:EMPLOYED BY U'
   V4728   = 'H2.# YRS:WORK IN FIELD'
   V4729   = 'H2.# MOS:WORK IN FIELD'
   V4730   = 'H2A.#YRS:MAINLY THERAPY'
   V4731   = 'H2A.#MOS:MAINLY THERAPY'
   V4732   = 'H2B.#YRS:MAINLY SUPERVS'
   V4733   = 'H2B.#MOS:MAINLY SUPERVS'
   V4734   = 'H3.PRESENT POSITION,JOB'
   V4735   = 'H3A.#YR:PRESNT POSITION'
   V4736   = 'H3A.#MO:PRESNT POSITION'
   V4737   = 'H4.POSITION BEFORE NOW'
   V4738   = 'H4A.PREV POSITION IN U:UNIT/OTH?'
   V4739   = 'H4B.# YRS:PREV POSITION'
   V4740   = 'H4B.# MOS:PREV POSITION'
   V4741   = 'H5.DIRECTOR OR RESP AGE - CATEGORIZED'
   V4742   = 'H6.DIRECTOR OR RESP GENDER:M/F?'
   V4743   = 'IS DIRECTOR OR RESPONDENT HISPANIC - RECODED'
   V4744   = 'H7A.DIRECTOR OR RESP RACE'
   V4745   = 'H8.DIRECTOR OR RESP MARITAL STATUS'
   V4746   = 'H9.R:# HR/WK WORK-OSATU'
   V4747   = 'H10A.R:# HR/WK-THERAPY'
   V4748   = 'H10B.R:# HR/WK-SUPERVISNG'
   V4749   = 'H10C.R:# HR/WK-REV RECORD'
   V4750   = 'H11.R:HI GRADE,YR SCHOL'
   V4751   = 'H11A.R:PASS HI SCHOOL:Y/N?'
   V4752   = 'H11B.R:COLLEGE DEGREE:Y/N?'
   V4753   = 'H11CM1.R:WHAT DEGREE'
   V4754   = 'H11DM1.R:DEGREE FIELD'
   V4755   = 'H11CM2.R:WHAT DEGREE'
   V4756   = 'H11DM2.R:DEGREE FIELD'
   V4757   = 'H11CM3.R:WHAT DEGREE'
   V4758   = 'H11DM3.R:DEGREE FIELD'
   V4759   = 'H12.R:CERTF SA COUNSEL:Y/N?'
   V4764   = 'C11A.NAME1 GOVT ORG SET GOALS'
   V4765   = 'C11A.NAME2 GOVT ORG SET GOALS'
   V4766   = 'C11A.NAME3 GOVT ORG SET GOALS'
   V4767   = 'C13A.NAME1 AGRMT W ORG SET GOALS'
   V4768   = 'C13A.NAME2 AGRMT W ORG SET GOALS'
   V4769   = 'C13A.NAME3 AGRMT W ORG SET GOALS'
   V4770   = 'C15A.NAME1 INCNTV ORG SET GOALS'
   V4771   = 'C15A.NAME2 INCNTV ORG SET GOALS'
   V4772   = 'C15A.NAME3 INCNTV ORG SET GOALS'
   V4773   = 'C19A.NAME1 GOVT ORG SET ASSESS'
   V4774   = 'C19A.NAME2 GOVT ORG SET ASSESS'
   V4775   = 'C19A.NAME3 GOVT ORG SET ASSESS'
   V4776   = 'C21A.NAME1 AGRMT W ORG SET ASSESS'
   V4777   = 'C21A.NAME2 AGRMT W ORG SET ASSESS'
   V4778   = 'C21A.NAME3 AGRMT W ORG SET ASSESS'
   V4779   = 'C23A.NAME1 INCNTV ORG SET ASSESS'
   V4780   = 'C23A.NAME2 INCNTV ORG SET ASSESS'
   V4781   = 'C23A.NAME3 INCNTV ORG SET ASSESS'
   V4782   = 'C27A.NAME1 GOVT ORG SET TRTMNT'
   V4783   = 'C27A.NAME2 GOVT ORG SET TRTMNT'
   V4784   = 'C27A.NAME3 GOVT ORG SET TRTMNT'
   V4785   = 'C29A.NAME1 AGRMT W ORG SET TRTMNT'
   V4786   = 'C29A.NAME2 AGRMT W ORG SET TRTMNT'
   V4787   = 'C29A.NAME3 AGRMT W ORG SET TRTMNT'
   V4788   = 'C31A.NAME1 INCNTV ORG SET TRTMNT'
   V4789   = 'C31A.NAME2 INCNTV ORG SET TRTMNT'
   V4790   = 'C31A.NAME3 INCNTV ORG SET TRTMNT'
   V5004   = 'SFS INTERVIEWERS ID'
   V5005   = 'SFS MONTH BEGAN INTERVEW'
   V5006   = 'SFS DAY BEGAN INTERVIEW'
   V5007   = 'SFS YEAR BEGAN INTERVIEW'
   V5008   = 'SFS MONTH FINISH INTERVW'
   V5009   = 'SFS DAY FINISH INTERVIEW'
   V5010   = 'SFS YEAR FINISH INTERVEW'
   V5011   = 'SFS LENGTH OF INTERVIEW'
   V5012   = 'S INSERT PAGE 5 THIS IW?'
   V5013   = 'SA1A REFRL FRM VOC REHAB'
   V5014   = 'SA1B REFRL FROM COURTS'
   V5015   = 'SA1C REFRL FRM HOSPITALS'
   V5016   = 'SA1D REFRL FRM PR CLINIC'
   V5017   = 'SA1E REFRL FRM PHYSICIAN'
   V5018   = 'SA1F REFRL FROM DSS'
   V5019   = 'SA1G REFRL FRM MH AGENCY'
   V5020   = 'SA1H REFRL FROM EAP'
   V5021   = 'SA1I REFRL FROM POLICE'
   V5022   = 'SA1J REFRL FROM SCHOOLS'
   V5023   = 'SA1K REFRL FROM CHURCHES'
   V5024   = 'SA1L SELF_REFERRALS'
   V5025   = 'SA1M REFRL FRM CL FRIEND'
   V5026   = 'SA1N REFRL FRM CL FAMILY'
   V5027   = 'SA1O REFRL FROM OTHERS'
   V5028   = 'SA1OM1 OTHER REFRL FROM'
   V5029   = 'SA1OM2 OTHER REFRL FROM'
   V5030   = 'SA2 MOST IMP REF SOURCE'
   V5031   = 'SA3M1 Y MOST IMP REF SOU'
   V5032   = 'SA3M2 Y MOST IMP REF SOU'
   V5033   = 'SA4 ICSA2 SELF FRN FAM?'
   V5034   = 'SA5M1 REF FR A2_U REQ DO'
   V5035   = 'SA5M2 REF FR A2_U REQ DO'
   V5036   = 'SA6A REFER TO HOSPITALS'
   V5037   = 'SA6B REFER TO PR CLINICS'
   V5038   = 'SA6C REFER TO PHYSICIANS'
   V5039   = 'SA6D REFER TO VOC REHAB'
   V5040   = 'SA6E REFER TO DSS'
   V5041   = 'SA6F REFER TO MH AGENCY'
   V5042   = 'SA6G REFER TO OTHR OSATU'
   V5043   = 'SA6H REFER TO SCHOOLS'
   V5044   = 'SA6I REFER TO CHURCHES'
   V5045   = 'SA6J REFER TO AA NA'
   V5046   = 'SA6K REFER TO OTHERS'
   V5047   = 'SA6KM1 OTHER REFER TO'
   V5048   = 'SA6KM2 OTHER REFER TO'
   V5049   = 'SA7 MOST IMP ORG REFR TO'
   V5050   = 'SA8M1 Y MOST IMP REFR TO'
   V5051   = 'SA8M2 Y MOST IMP REFR TO'
   V5052   = 'SA9A REFER SEND WR SUMRY'
   V5053   = 'SA9B REFER SEND CHART'
   V5054   = 'SA9C REFR PHONE CASE SUM'
   V5055   = 'SA9D REFER MAKE APPT_CL'
   V5056   = 'SA9E REFER FOLOW_UP CALL'
   V5057   = 'SA9F REFR RECEIVE REPORT'
   V5058   = 'SA9G REFER OTHR PROCEDRS'
   V5059   = 'SA9GM1 OTHER REFER PROC'
   V5060   = 'SB1 US # F_T PAID STAFF'
   V5061   = 'SB2 US # P_T PAID STAFF'
   V5062   = 'SB3 F_T&P_T STAF # FTES'
   V5063   = 'SB3 P_T STAFFS HOURS/WK'
   V5064   = 'SB4 US # CONSULT''&''CONTCT'
   V5065   = 'SB4A CONSLT''&''CONT # FTES'
   V5066   = 'SB4A CONSLT''&''CONTXS HR/WK'
   V5067   = 'SB5A FTE # ADMINSTV WORK'
   V5068   = 'SB5B FTE # CLERICL&SUPRT'
   V5069   = 'SB5C FTE # COUNSEL''&''OTHER'
   V5070   = 'SB5A HR/WK ADMINSTV WORK'
   V5071   = 'SB5B HR/WK CLERICL''&''SUPRT'
   V5072   = 'SB5C HR/WK COUNSEL''&''OTHER'
   V5073   = 'SB6 US TOTAL # VOLUNTER'
   V5074   = 'SB7 CL TRMT # WITH PHD'
   V5075   = 'SB7AM1 PHD SPECIAL AREA'
   V5076   = 'SB7AM2 PHD SPECIAL AREA'
   V5077   = 'SB7B PHDXS HR/WK TO CL T'
   V5078   = 'SB8 CL TRMT # WITH MD DO'
   V5079   = 'SB8AM1 MD DO SPECIL AREA'
   V5080   = 'SB8AM2 MD DO SPECIL AREA'
   V5081   = 'SB8B MD DO HR/WK TO CL T'
   V5082   = 'SB9 CL TRMT # WI MASTERS'
   V5083   = 'SB9AM1 MAS SPECIAL AREA'
   V5084   = 'SB9AM2 MAS SPECIAL AREA'
   V5085   = 'SB9AM3 MAS SPECIAL AREA'
   V5086   = 'SB9AM4 MAS SPECIAL AREA'
   V5087   = 'SB9AM5 MAS SPECIAL AREA'
   V5088   = 'SB9B MAS HR/WK TO CL TX'
   V5089   = 'SB10 CL TRMT # WITH BAS'
   V5090   = 'SB10A BAS HR/WK TO CL T'
   V5091   = 'SB11 CL TRMT # WITH RNS'
   V5092   = 'SB11A RNS HR/WK TO CL T'
   V5093   = 'SB12 CL TRMT # WI ASSOC'
   V5094   = 'SB12A ASSOC HR/WK 2 CL T'
   V5095   = 'SB13 CL TRMT # W HS LESS'
   V5096   = 'SB13A HS less HR/WK TO CL T'
   V5097   = 'SB14 T STAF # EX-ADDICTS'
   V5098   = 'SB15 X_ADICT PUBLC IMAGE'
   V5099   = 'SB16 X_ADICT UP WI FIELD'
   V5100   = 'SB17 OT STAF # MO TRAING'
   V5101   = 'SB18 OT STAF # SAT TRAIN'
   V5102   = 'SB19 OT STAF # SAT CERTF'
   V5103   = 'SB20 STAF CERTF GOV REGS'
   V5104   = 'SB21 STAF CERTF AGREEMNT'
   V5105   = 'SB22 STAF CERTF INCENTIV'
   V5106   = 'SB23 STAF CERTF PUB IMAG'
   V5107   = 'SB24 STAF CERTF UP W FLD'
   V5108   = 'SB25 IC:TRMT STAF =,>MA?'
   V5109   = 'SB26 PRO:GOV AGENCY REGS'
   V5110   = 'SB26A PRO:GOV_AGY NAMES'
   V5111   = 'SB26B PRO:GOV_FUND AGY#1'
   V5112   = 'SB26B PRO:GOV_LICN AGY#1'
   V5113   = 'SB26B PRO:GOV_REFR AGY#1'
   V5114   = 'SB26C PRO:GOV_LEVL AGY#1'
   V5115   = 'SB26B PRO:GOV_FUND AGY#2'
   V5116   = 'SB26B PRO:GOV_LICN AGY#2'
   V5117   = 'SB26B PRO:GOV_REFR AGY#2'
   V5118   = 'SB26C PRO:GOV_LEVL AGY#2'
   V5119   = 'SB26B PRO:GOV_FUND AGY#3'
   V5120   = 'SB26B PRO:GOV_LICN AGY#3'
   V5121   = 'SB26B PRO:GOV-REFR AGY#3'
   V5122   = 'SB26C PRO:GOV-LEVL AGY#3'
   V5123   = 'SB27 PRO:GOV-CONFLCT REQ'
   V5124   = 'SB28 PRO:FORMAL AGREEMNT'
   V5125   = 'SB28A PRO:AGR-#ORG NAMES'
   V5126   = 'SB28B PRO:AGR-FUND AGY#1'
   V5127   = 'SB28B PRO:AGR-LICN AGY#1'
   V5128   = 'SB28B PRO:AGR-REFR AGY#1'
   V5129   = 'SB28B PRO:AGR-TRMT AGY#1'
   V5130   = 'SB28C PRO:AGR-LEVL AGY#1'
   V5131   = 'SB28B PRO:AGR-FUND AGY#2'
   V5132   = 'SB28B PRO:AGR-LICN AGY#2'
   V5133   = 'SB28B PRO:AGR-REFR AGY#2'
   V5134   = 'SB28B PRO:AGR-TRMT AGY#2'
   V5135   = 'SB28C PRO:AGR-LEVL AGY#2'
   V5136   = 'SB28B PRO:AGR-FUND AGY#3'
   V5137   = 'SB28B PRO:AGR-LICN AGY#3'
   V5138   = 'SB28B PRO:AGR-REFR AGY#3'
   V5139   = 'SB28B PRO:AGR-TRMT AGY#3'
   V5140   = 'SB28C PRO:AGR-LEVL AGY#3'
   V5141   = 'SB29 PRO:AGR-CONFLCT REQ'
   V5142   = 'SB30 PRO:ORG OFRD INCENT'
   V5143   = 'SB30A PRO:INC-#ORG NAMES'
   V5144   = 'SB30B PRO:INC-FUND AGY#1'
   V5145   = 'SB30B PRO:INC-LICN AGY#1'
   V5146   = 'SB30B PRO:INC-REFR AGY#1'
   V5147   = 'SB30B PRO:INC-TRMT AGY#1'
   V5148   = 'SB30C PRO:INC-LEVL AGY#1'
   V5149   = 'SB30B PRO:INC-FUND AGY#2'
   V5150   = 'SB30B PRO:INC-LICN AGY#2'
   V5151   = 'SB30B PRO:INC-REFR AGY#2'
   V5152   = 'SB30B PRO:INC-TRMT AGY#2'
   V5153   = 'SB30C PRO:INC-LEVL AGY#2'
   V5154   = 'SB30B PRO:INC-FUND AGY#3'
   V5155   = 'SB30B PRO:INC-LICN AGY#3'
   V5156   = 'SB30B PRO:INC-REFR AGY#3'
   V5157   = 'SB30B PRO:INC-TRMT AGY#3'
   V5158   = 'SB30C PRO:INC-LEVL AGY#3'
   V5159   = 'SB31 PRO:INC-CONFLCT REQ'
   V5160   = 'SB32 PRO:ENHANC PUB IMAG'
   V5161   = 'SB33 PRO:KEEP UP W FIELD'
   V5162   = 'SB34A APLCNT:PROF DEGREE'
   V5163   = 'SB34B APLCNT:WORK EXPER'
   V5164   = 'SB34C APLCNT:SPECL TRAIN'
   V5165   = 'SB34D APLCNT:HSTORY ABUS'
   V5166   = 'SB34E APLCNT:CERTFC CNSL'
   V5167   = 'SB34F APLCNT:CLINCAL EXP'
   V5168   = 'SB35A X-AD MORE EFFECTIV'
   V5169   = 'SB35B PROF DEG > EFFECTV'
   V5170   = 'SB35C X-AD > W CL DENIAL'
   V5171   = 'SB35D PROF DEG > OBJECTV'
   V5172   = 'SB36 T STAF PERFORM EVAL'
   V5173   = 'SB37 # CL/STAFF IN OSATU'
   V5174   = 'SB38A INOVAT-REWARD STAF'
   V5175   = 'SB38B LIMIT PROCDR CHANG'
   V5176   = 'SB38C STAF UNCMF W CHANG'
   V5177   = 'SB38D ENUF $-NEW PROCDRS'
   V5178   = 'SC1 ''%'' CL:EVAL SEVERITY'
   V5179   = 'SC2 ''%'' CL:DRUG HISTORY'
   V5180   = 'SC3 ''%'' CL:INFO-PERCEPTION'
   V5181   = 'SC4 ''%'' CL:TEST FOR AIDS'
   V5182   = 'SC5 ''%'' CL:ASSESS NETWORKS'
   V5183   = 'SC6 ''%'' CL:PHYSICAL EXAMS'
   V5184   = 'SC7 ''%'' CL:MEDICAL TESTS'
   V5185   = 'SC8 IC:EXAMS ''&'' MED TESTS'
   V5186   = 'SC9A CL-PHYSCAL:PSYCHIAT'
   V5187   = 'SC9B CL-PHYSCAL:PHYSICAN'
   V5188   = 'SC9C CL-PHYSCAL:PSYCHOLG'
   V5189   = 'SC9D CL-PHYSCAL:SOC WRKR'
   V5190   = 'SC9E CL-PHYSCAL: RN'
   V5191   = 'SC9F CL-PHYSCAL:DR. ASST'
   V5192   = 'SC9G CL-PHYSCAL: OTHER?'
   V5193   = 'SC9G CL-PHYSCL:OTHER-WHO'
   V5194   = 'SC10 ''%'' CL:ASSES MH PROBS'
   V5195   = 'SC11 PSYCH TESTS WI CL?'
   V5196   = 'SC11AM1 PSYCH TESTS USE'
   V5197   = 'SC11AM2 PSYCH TESTS USE'
   V5198   = 'SC11AM3 PSYCH TESTS USE'
   V5199   = 'SC12A CL-PSYCH:PSYCHIATR'
   V5200   = 'SC12B CL-PSYCH:PHYSICIAN'
   V5201   = 'SC12C CL-PSYCH:PSYCHOLOG'
   V5202   = 'SC12D CL-PSYCH:SOCL WRKR'
   V5203   = 'SC12E CL-PSYCH: RN'
   V5204   = 'SC12F CL-PSYCH:DR. ASST.'
   V5205   = 'SC12G CL-PSYCH: OTHER?'
   V5206   = 'SC12G CL-PSYCH:OTHER-WHO'
   V5207   = 'SC13 ''%'' CL:DSM3 DIAGNOSIS'
   V5208   = 'SC14A CL-DSM3:PSYCHIATRS'
   V5209   = 'SC14B CL-DSM3:PHYSICIAN'
   V5210   = 'SC14C CL-DSM3:PSYCHOLOGS'
   V5211   = 'SC14D CL-DSM3:SOCL WORKR'
   V5212   = 'SC14E CL-DSM3: RN'
   V5213   = 'SC14F CL-DSM3:DR. ASSIST'
   V5214   = 'SC14G CL-DSM3: OTHER?'
   V5215   = 'SC14G CL-DSM3: OTHER-WHO'
   V5216   = 'SC15A ASSESMT:WRITN PROC'
   V5217   = 'SC15B ASSESMT:STAF TRAIN'
   V5218   = 'SC15C ASSESMT:STAFF EVAL'
   V5219   = 'SC16 AA,NA MODEL EFFETV'
   V5220   = 'SC17 T EFFECTV-CL ORDERD'
   V5221   = 'SC18A CL SOBER IN TRTMNT'
   V5222   = 'SC18B CL KNOW IS ABUSER'
   V5223   = 'SC18C CL RESPONBL RECOVR'
   V5224   = 'SC18D CL LEARN NEW SKILS'
   V5225   = 'SC18E CL GAIN INSIGHT'
   V5226   = 'SC18F CL KNOW NEVR AGAIN'
   V5227   = 'SC18G CL HIT BOTTOM'
   V5228   = 'SC19 # WAITING OSA TRMT'
   V5229   = 'SC19A # DAYS WAIT 4 TRMT'
   V5230   = 'SC20 TYPE CL-QUICK OSAT?'
   V5231   = 'SC21M1 CL GET QUICK OSAT'
   V5232   = 'SC21M2 CL GET QUICK OSAT'
   V5233   = 'SC22M1 REASONS FOR ABUSE'
   V5234   = 'SC22M2 REASONS FOR ABUSE'
   V5235   = 'SC22M3 REASONS FOR ABUSE'
   V5236   = 'SC22M4 REASONS FOR ABUSE'
   V5237   = 'SC22M5 REASONS FOR ABUSE'
   V5238   = 'SC23M1 REASONS RECOVER'
   V5239   = 'SC23M2 REASONS RECOVER'
   V5240   = 'SC23M3 REASONS RECOVER'
   V5241   = 'SC23M4 REASONS RECOVER'
   V5242   = 'SC24M1 #1 EFFECTIVE OSAT'
   V5243   = 'SC24M2 #1 EFFECTIVE OSAT'
   V5244   = 'SC24M3 #1 EFFECTIVE OSAT'
   V5245   = 'SC25 CL:#MONTHS IN OSAT'
   V5246   = 'SC26A ''%''CL:EDUCATE-ADICTN'
   V5247   = 'SC26B ''%''CL:MEDICAL CARE'
   V5248   = 'SC26C ''%''CL:TRMT-MH PROBS'
   V5249   = 'SC26D ''%''CL:TRMT-MULT DRUG'
   V5250   = 'SC26E ''%''CL:EMPLOYMNT CNSL'
   V5251   = 'SC26F ''%''CL:FINANCIAL CNSL'
   V5252   = 'SC26G ''%''CL:LEGAL COUNSEL'
   V5253   = 'SC26H ''%''CL:DWI PROGRAMS'
   V5254   = 'SC26I ''%''CL:ANTABUSE'
   V5255   = 'SC26J ''%''CL:NALTREXONE'
   V5256   = 'SC26K ''%''CL:OTHER SERVICES'
   V5257   = 'SC26LM1 OTHER CL SERVICE'
   V5258   = 'SC26LM2 OTHER CL SERVICE'
   V5259   = 'SC26LM3 OTHER CL SERVICE'
   V5260   = 'SC27 IC: METHADONE CS?'
   V5261   = 'SC28A FYR:#METH DETOX CL'
   V5262   = 'SC28B FYR:#METH MAINT CL'
   V5263   = 'SC28C #CL NOW:METH MAINT'
   V5264   = 'SC29A #MM CL:<DOSES METH'
   V5265   = 'SC29A ''%''MM CL:<DOSES METH'
   V5266   = 'SC29B #MM CL:>DOSES METH'
   V5267   = 'SC29B ''%''MM CL:>DOSES METH'
   V5268   = 'SC29C #MM CL:=DOSES METH'
   V5269   = 'SC29C ''%''MM CL:=DOSES METH'
   V5270   = 'SC30A # CL=METH:< 20 MG'
   V5271   = 'SC30A ''%'' CL=METH:< 20 MG'
   V5272   = 'SC30B # CL=METH:20-39 MG'
   V5273   = 'SC30B ''%'' CL=METH:20-39 MG'
   V5274   = 'SC30C # CL=METH:40-59 MG'
   V5275   = 'SC30C ''%'' CL=METH:40-59 MG'
   V5276   = 'SC30D # CL=METH:60-79 MG'
   V5277   = 'SC30D ''%'' CL=METH:60-79 MG'
   V5278   = 'SC30E # CL=METH:80-99 MG'
   V5279   = 'SC30E ''%'' CL=METH:80-99 MG'
   V5280   = 'SC30F #CL=METH:100-119MG'
   V5281   = 'SC30F ''%''CL=METH:100-119MG'
   V5282   = 'SC30G #CL=METH:=OR>120MG'
   V5283   = 'SC30G ''%''CL=METH:=OR>120MG'
   V5284   = 'SC31A #CL:CONT METH <3MO'
   V5285   = 'SC31A ''%''CL:CONT METH <3MO'
   V5286   = 'SC31B #CL:METH @3MO&<1YR'
   V5287   = 'SC31B ''%''CL:METH @3MO&<1YR'
   V5288   = 'SC31C #CL:METH @1YR&<2YR'
   V5289   = 'SC31C ''%''CL:METH @1YR&<2YR'
   V5290   = 'SC31D #CL:METH @2YR&<3YR'
   V5291   = 'SC31D ''%''CL:METH @2YR&<3YR'
   V5292   = 'SC31E # CL:METH =OR>3YR'
   V5293   = 'SC31E ''%'' CL:METH =OR>3YR'
   V5294   = 'SC32A CL AWARE METH LEVL'
   V5295   = 'SC32B CL INFLU METH LEVL'
   V5296   = 'SC32C ALLOW TAKE-HM METH'
   V5297   = 'SC33 ENCOURGE METH DETOX'
   V5298   = 'SC33A WHEN URGE CL DETOX'
   V5299   = 'SC34 MAX TIME-MUST DTOX?'
   V5300   = 'SC34A WHEN REQUIRE DETOX'
   V5301   = 'SC35 SET UPPER METH LEVL'
   V5302   = 'SC35A #MG:UPPER METH LVL'
   V5303   = 'SC36 MDL:GOV AGENCY REGS'
   V5304   = 'SC36A MDL:GOV-#AGY NAMES'
   V5305   = 'SC36B MDL:GOV-FUND AGY#1'
   V5306   = 'SC36B MDL:GOV-LICN AGY#1'
   V5307   = 'SC36B MDL:GOV-REFR AGY#1'
   V5308   = 'SC36C MDL:GOV-LEVL AGY#1'
   V5309   = 'SC36B MDL:GOV-FUND AGY#2'
   V5310   = 'SC36B MDL:GOV-LICN AGY#2'
   V5311   = 'SC36B MDL:GOV-REFR AGY#2'
   V5312   = 'SC36C MDL:GOV-LEVL AGY#2'
   V5313   = 'SC36B MDL:GOV-FUND AGY#3'
   V5314   = 'SC36B MDL:GOV-LICN AGY#3'
   V5315   = 'SC36B MDL:GOV-REFR AGY#3'
   V5316   = 'SC36C MDL:GOV-LEVL AGY#3'
   V5317   = 'SC37 MDL:GOV-CONFLCT REQ'
   V5318   = 'SC38 MDL:FORMAL AGREEMNT'
   V5319   = 'SC38A MDL:AGR-#ORG NAMES'
   V5320   = 'SC38B MDL:AGR-FUND AGY#1'
   V5321   = 'SC38B MDL:AGY-LICN AGY#1'
   V5322   = 'SC38B MDL:AGR-REFR AGY#1'
   V5323   = 'SC38B MDL:AGR-TRMT AGY#1'
   V5324   = 'SC38C MDL:AGR-LEVL AGY#1'
   V5325   = 'SC38B MDL:AGR-FUND AGY#2'
   V5326   = 'SC38B MDL:AGR-LICN AGY#2'
   V5327   = 'SC38B MDL:AGR-REFR AGY#2'
   V5328   = 'SC38B MDL:AGR-TRMT AGY#2'
   V5329   = 'SC38C MDL:AGR-LEVL AGY#2'
   V5330   = 'SC38B MDL:AGR-FUND AGY#3'
   V5331   = 'SC38B MDL:AGR-LICN AGY#3'
   V5332   = 'SC38B MDL:AGR-REFR AGY#3'
   V5333   = 'SC38B MDL:AGR-TRMT AGY#3'
   V5334   = 'SC38C MDL:AGR-LEVL AGY#3'
   V5335   = 'SC39 MDL:AGR-CONFLCT REQ'
   V5336   = 'SC40 MDL:ORG OFRD INCENT'
   V5337   = 'SC40A MDL:INC-#ORG NAMES'
   V5338   = 'SC40B MDL:INC-FUND AGY#1'
   V5339   = 'SC40B MDL:INC-LICN AGY#1'
   V5340   = 'SC40B MDL:INC-REFR AGY#1'
   V5341   = 'SC40B MDL:INC-TRMT AGY#1'
   V5342   = 'SC40C MDL:INC-LEVL AGY#1'
   V5343   = 'SC40B MDL:INC-FUND AGY#2'
   V5344   = 'SC40B MDL:INC-LICN AGY#2'
   V5345   = 'SC40B MDL:INC-REFR AGY#2'
   V5346   = 'SC40B MDL:INC-TRMT AGY#2'
   V5347   = 'SC40C MDL:INC-LEVL AGY#2'
   V5348   = 'SC40B MDL:INC-FUND AGY#3'
   V5349   = 'SC40B MDL:INC-LICN AGY#3'
   V5350   = 'SC40B MDL:INC-REFR AGY#3'
   V5351   = 'SC40B MDL:INC-TRMT AGY#3'
   V5352   = 'SC40C MDL:INC-LEVL AGY#3'
   V5353   = 'SC41 MDL:INC-CONFLCT REQ'
   V5354   = 'SC42 MDL:ENHANC PUB IMAG'
   V5355   = 'SC43 MDL:KEEP UP W FIELD'
   V5356   = 'SC44 ENCOURAGE CL AA,NA'
   V5357   = 'SC45 US CL USE AA,NA'
   V5358   = 'SC46 URGE AA,NA:AGREEMNT'
   V5359   = 'SC47 URGE AA,NA:INCENTIV'
   V5360   = 'SC48 URGE AA,NA:PUB IMAG'
   V5361   = 'SC49 URGE AA,NA:UP W FLD'
   V5362   = 'SC50 U OFER SPECL OPROG?'
   V5363   = 'SC50AM1 SPECIAL PROGRAMS'
   V5364   = 'SC50AM2 SPECIAL PROGRAMS'
   V5365   = 'SC50AM3 SPECIAL PROGRAMS'
   V5366   = 'SC50AM4 SPECIAL PROGRAMS'
   V5367   = 'SC50BM1 CL TYPES-PROGRAM'
   V5368   = 'SC50BM2 CL TYPES-PROGRAM'
   V5369   = 'SC50BM3 CL TYPES-PROGRAM'
   V5370   = 'SC50BM4 CL TYPES-PROGRAM'
   V5371   = 'SC51 CL ESTAB TRMT GOALS'
   V5372   = 'SC52A TX GOAL:ABSTINENCE'
   V5373   = 'SC52B GOAL:RESPONSBL USE'
   V5374   = 'SC52C GOAL:STEADY EMPLOY'
   V5375   = 'SC52D GOAL:STABLE RELATE'
   V5376   = 'SC52E GOAL:+ PHYS HEALTH'
   V5377   = 'SC52F GOAL:+ EMOT WELLBE'
   V5378   = 'SC52G GOAL:SPIRIT STRNTH'
   V5379   = 'SC52H GOAL:MET LEGAL REQ'
   V5380   = 'SC53 ABSTINENCE:U T GOAL'
   V5381   = 'SC54 ABSTINENCE:GOV REGS'
   V5382   = 'SC55 ABSTINENCE:AGREEMNT'
   V5383   = 'SC56 ABSTINENCE:INCENTIV'
   V5384   = 'SC57 ABSTINENCE:PUB IMAG'
   V5385   = 'SC58 ABSTINENCE:UP W FLD'
   V5386   = 'SC59 U OFFR IND THERAPY?'
   V5387   = 'SC59A COMMON IND THERPY?'
   V5388   = 'SC59BM1 IND THERAPY USED'
   V5389   = 'SC59BM2 IND THERAPY USED'
   V5390   = 'SC59BM3 IND THERAPY USED'
   V5391   = 'SC59BM4 IND THERAPY USED'
   V5392   = 'SC59BM5 IND THERAPY USED'
   V5393   = 'SC60 U OFFR GRP THERAPY?'
   V5394   = 'SC60A COMMON GRP THERPY?'
   V5395   = 'SC60BM1 GRP THERAPY USED'
   V5396   = 'SC60BM2 GRP THERAPY USED'
   V5397   = 'SC60BM3 GRP THERAPY USED'
   V5398   = 'SC61 CONTACT AFTER HOURS'
   V5399   = 'SC62A MONITOR:CL RECORDS'
   V5400   = 'SC62B MONITOR:SLF-REPORT'
   V5401   = 'SC62C MONITOR:URINALYSIS'
   V5402   = 'SC62D MONTR:SIGO REPORTS'
   V5403   = 'SC62E MONTR:THERPST EVAL'
   V5404   = 'SC62F MONTR:EMPLYR REPRT'
   V5405   = 'SC62G MONTR:COURT OFICER'
   V5406   = 'SC62H MONTR: CL NO SHOWS'
   V5407   = 'SC62I MONTR:STAF NO SHOW'
   V5408   = 'SC62J MONTR:OTHR METHODS'
   V5409   = 'SC62JM1 OTHER MONITOR CL'
   V5410   = 'SC62JM2 OTHER MONITOR CL'
   V5411   = 'SC63 CONDTN:REMAIN IN TP'
   V5412   = 'SC63A CONDITION:SOBRIETY'
   V5413   = 'SC63B CONDTN:COMPLY-TRMT'
   V5414   = 'SC63C COND:COMPLY-COURTS'
   V5415   = 'SC63D CONDTN:GRP THERAPY'
   V5416   = 'SC63E CONDITIONS:OTHER'
   V5417   = 'SC63EM1 OTHER CONDITIONS'
   V5418   = 'SC63EM2 OTHER CONDITIONS'
   V5419   = 'SC64A CL END T:''%''CONT USE'
   V5420   = 'SC64B CL END TMT:''%''INCARC'
   V5421   = 'SC64C CL END TMT:''%''DIED'
   V5422   = 'SC64D CL END T:''%''NO CMPLY'
   V5423   = 'SC64E CL END T:''%''FAIL PAY'
   V5424   = 'SC64F CL END T:''%''INSR END'
   V5425   = 'SC64G CL END T:''%''DRUGFREE'
   V5426   = 'SC64H CL END T:''%''OTHER'
   V5427   = 'SC64H CL END T:OTHER-WHY'
   V5428   = 'SC65 CL END T:''%''INVOLUNT'
   V5429   = 'SC66 CL END T:''%''MET GOALS'
   V5430   = 'SC66AM1 CRITERIA CL SUCC'
   V5431   = 'SC66AM2 CRITERIA CL SUCC'
   V5432   = 'SC66AM3 CRITERIA CL SUCC'
   V5433   = 'SC66AM4 CRITERIA CL SUCC'
   V5434   = 'SC66AM5 CRITERIA CL SUCC'
   V5435   = 'SC67 ''%''CL:POST-TRMT PLAN'
   V5436   = 'SC68 U QUAL ASURNCE PLAN'
   V5437   = 'SC68A JCAHCO BASED Q.C.P'
   V5438   = 'SC69A REVIEW:T PLAN ADDR'
   V5439   = 'SC69B REVIEW:REFERS MADE'
   V5440   = 'SC69C REVIEW:CHANGE TRMT'
   V5441   = 'SC69D REVIEW:TRMT DURATN'
   V5442   = 'SC69E REVIEW:DOC T PROBS'
   V5443   = 'SC69F REVIEW:ALL PROB AD'
   V5444   = 'SC69G REVIEW:DISCHG PLAN'
   V5445   = 'SC69H REVIEW:COMP RESOLV'
   V5446   = 'SC70A AIDS:KNOWL-PREVENT'
   V5447   = 'SC70B AIDS:TEACH CL PREV'
   V5448   = 'SC70C AIDS:HOW WORK W CL'
   V5449   = 'SC70D AIDS:STAF RISKS-CL'
   V5450   = 'SC70E AIDS:STAFF FEAR CL'
   V5451   = 'SC71A AIDS:CLEAN NEEDLES'
   V5452   = 'SC71B AIDS:BLEACH SOLUTN'
   V5453   = 'SC71C AIDS:CONDOMS TO IV'
   V5454   = 'SC71D AIDS:EDUCATN TO IV'
   V5455   = 'SC72A AIDS:U ADEQUATE $'
   V5456   = 'SC72B AIDS:U ENOUGH STAF'
   V5457   = 'SC72C AIDS:TALK CL-SEX'
   V5458   = 'SC72D AIDS:TALK CL-IV'
   V5459   = 'SC72E AIDS:TALK CL-FETUS'
   V5460   = 'SC72F AIDS:GIV CL READNG'
   V5461   = 'SC72G AIDS:USE MAS MEDIA'
   V5462   = 'SC72H AIDS:SPECIAL STAFF'
   V5463   = 'SC73 AIDS:WORK W OTH ORG'
   V5464   = 'SC73A AIDS:GIV ORG NAMES'
   V5465   = 'SC74 AIDS:COMMUNITY WORK'
   V5466   = 'SC75 AIDS:HR/WK-COMMUNTY'
   V5467   = 'SC76 AIDS:SPECL TRAINING'
   V5468   = 'SC76AM1 AIDS TRAINING'
   V5469   = 'SC76AM2 AIDS TRAINING'
   V5470   = 'SC76AM3 AIDS TRAINING'
   V5471   = 'SC77A AIDS:INFO-CLEAN IV'
   V5472   = 'SC77B AIDS:INFO-CONDOMS'
   V5473   = 'SC77C AIDS:INFO-PREVENTN'
   V5474   = 'SC77D AIDS:GIVE CONDOMS'
   V5475   = 'SC77E AIDS:GIVE CLEAN IV'
   V5476   = 'SC77F AIDS:GIVE BLEACH'
   V5477   = 'SC77G AIDS:TALK-IV USERS'
   V5478   = 'SC77H AIDS:TALK-IV FAMLY'
   V5479   = 'SC78M1 AIDS:HOW PREV-IV'
   V5480   = 'SC78M2 AIDS:HOW PREV-IV'
   V5481   = 'SC78M3 AIDS:HOW PREV-IV'
   V5482   = 'SD1 #CL:ANY OUTP TMT-FYR'
   V5483   = 'SD1A #CL:OSAT-FISCAL YR'
   V5484   = 'SD1B #CL:NEW OSAT CL-FYR'
   V5485   = 'SD1B ''%''CL:NEW OSAT CL-FYR'
   V5486   = 'SD2 #CL:END OSAT-FISC YR'
   V5487   = 'SD2A #CL:OSAT-LAST 30DAY'
   V5488   = 'SD3A #CL:#1 PROB ALCOHOL'
   V5489   = 'SD3A ''%''CL:#1 PROB ALCOHOL'
   V5490   = 'SD3B #CL:ALCH T-REQUIRED'
   V5491   = 'SD3B ''%''CL:ALCH T-REQUIRED'
   V5492   = 'SD3C #CL:#1 PROBLEM DRUG'
   V5493   = 'SD3C ''%''CL:#1 PROBLEM DRUG'
   V5494   = 'SD3D #CL:DRUG T-REQUIRED'
   V5495   = 'SD3D ''%''CL:DRUG T-REQUIRED'
   V5496   = 'SD4A #CL:HEROIN ABUSE'
   V5497   = 'SD4A ''%''CL:HEROIN ABUSE'
   V5498   = 'SD4B #CL:NONPRESCRP METH'
   V5499   = 'SD4B ''%''CL:NONPRESCRP METH'
   V5500   = 'SD4C #CL:OPIATE/SYNTHETC'
   V5501   = 'SD4C ''%''CL:OPIATE/SYNTHETC'
   V5502   = 'SD4D #CL:BARBITURATES'
   V5503   = 'SD4D ''%''CL:BARBITURATES'
   V5504   = 'SD4E #CL:OTHER SEDATIVES'
   V5505   = 'SD4E ''%''CL:OTHER SEDATIVES'
   V5506   = 'SD4F #CL:COCAINE(~CRACK)'
   V5507   = 'SD4F ''%''CL:COCAINE(~CRACK)'
   V5508   = 'SD4G #CL:CRACK ABUSE'
   V5509   = 'SD4G ''%''CL:CRACK ABUSE'
   V5510   = 'SD4H #CL:AMPHETAMINES'
   V5511   = 'SD4H ''%''CL:AMPHETAMINES'
   V5512   = 'SD4I #CL:QUAALUDE ABUSE'
   V5513   = 'SD4I ''%''CL:QUAALUDE ABUSE'
   V5514   = 'SD4J #CL:OVER-THE-COUNTR'
   V5515   = 'SD4J ''%''CL:OVER-THE-COUNTR'
   V5516   = 'SD4K #CL:INHALANT ABUSE'
   V5517   = 'SD4K ''%''CL:INHALANT ABUSE'
   V5518   = 'SD4L #CL:TRANQUILIZERS'
   V5519   = 'SD4L ''%''CL:TRANQUILIZERS'
   V5520   = 'SD4M #CL:PCP ABUSE'
   V5521   = 'SD4M ''%''CL:PCP ABUSE'
   V5522   = 'SD4N #CL:MARIJUANA/HASH'
   V5523   = 'SD4N ''%''CL:MARIJUANA/HASH'
   V5524   = 'SD4O #CL:LSD ABUSE'
   V5525   = 'SD4O ''%''CL:LSD ABUSE'
   V5526   = 'SD4P #CL:HALLUCINOGENS'
   V5527   = 'SD4P ''%''CL:HALLUCINOGENS'
   V5528   = 'SD4Q #CL:MULTIPLE DRUGS'
   V5529   = 'SD4Q ''%''CL:MULTIPLE DRUGS'
   V5530   = 'SD4RM1 OTHER ABUSED DRUG'
   V5531   = 'SD4R #CL:ABUSED DRUG #1'
   V5532   = 'SD4R ''%''CL:ABUSED DRUG #1'
   V5533   = 'SD4RM2 OTHER ABUSED DRUG'
   V5534   = 'SD4R #CL:ABUSED DRUG #2'
   V5535   = 'SD4R ''%''CL:ABUSED DRUG #2'
   V5536   = 'SD4RM3 OTHER ABUSED DRUG'
   V5537   = 'SD4R #CL:ABUSED DRUG #3'
   V5538   = 'SD4R ''%''CL:ABUSED DRUG #3'
   V5539   = 'SD4RM4 OTHER ABUSED DRUG'
   V5540   = 'SD4R #CL:ABUSED DRUG #4'
   V5541   = 'SD4R ''%''CL:ABUSED DRUG #4'
   V5542   = 'SD5 #CL:IV DRUG USER-FYR'
   V5543   = 'SD5 ''%''CL:IV DRUG USER-FYR'
   V5544   = 'SD6 #CL:IV DRUG USE-30DY'
   V5545   = 'SD6 ''%''CL:IV DRUG USE-30DY'
   V5546   = 'SD7 # OSAT CL:MALES-FYR'
   V5547   = 'SD7 ''%'' OSAT CL:MALES-FYR'
   V5548   = 'SD8A #CL:AMERIND/ALASKAN'
   V5549   = 'SD8A ''%''CL:AMERIND/ALASKAN'
   V5550   = 'SD8B #CL:ASIAN/PACIFC IS'
   V5551   = 'SD8B ''%''CL:ASIAN/PACIFC IS'
   V5552   = 'SD8C #CL:HISPANIC'
   V5553   = 'SD8C ''%''CL:HISPANIC'
   V5554   = 'SD8D #CL:BLACK NOT HISP'
   V5555   = 'SD8D ''%''CL:BLACK NOT HISP'
   V5556   = 'SD8E #CL:WHITE NOT HISP'
   V5557   = 'SD8E ''%''CL:WHITE NOT HISP'
   V5558   = 'SD9A # CL: < 20 YRS OLD'
   V5559   = 'SD9A ''%'' CL: < 20 YRS OLD'
   V5560   = 'SD9B # CL: 20-29 YRS OLD'
   V5561   = 'SD9B ''%'' CL: 20-29 YRS OLD'
   V5562   = 'SD9C # CL: 30-39 YRS OLD'
   V5563   = 'SD9C ''%'' CL: 30-39 YRS OLD'
   V5564   = 'SD9D # CL: 40-49 YRS OLD'
   V5565   = 'SD9D ''%'' CL: 40-49 YRS OLD'
   V5566   = 'SD9E # CL: 50-64 YRS OLD'
   V5567   = 'SD9E ''%'' CL: 50-64 YRS OLD'
   V5568   = 'SD9F # CL: > 64 YRS OLD'
   V5569   = 'SD9F ''%'' CL: > 64 YRS OLD'
   V5570   = 'SD10A #CL: + AIDS VIRUS'
   V5571   = 'SD10A ''%''CL: + AIDS VIRUS'
   V5572   = 'SD10B #CL:DIAGNOSED-AIDS'
   V5573   = 'SD10B ''%''CL:DIAGNOSED-AIDS'
   V5574   = 'SD10C #CL:DIED FROM AIDS'
   V5575   = 'SD10C ''%''CL:DIED FROM AIDS'
   V5576   = 'SD11A # CL:PROSTITUTION'
   V5577   = 'SD11A ''%'' CL:PROSTITUTION'
   V5578   = 'SD11B # CL:THEFT/BURGLAR'
   V5579   = 'SD11B ''%'' CL:THEFT/BURGLAR'
   V5580   = 'SD11C # CL:DEALT DRUGS'
   V5581   = 'SD11C ''%'' CL:DEALT DRUGS'
   V5582   = 'SD11D # CL:VIOLENT CRIME'
   V5583   = 'SD11D ''%'' CL:VIOLENT CRIME'
   V5584   = 'SD11FM1 OTHR ILLEGAL ACT'
   V5585   = 'SD11F #CL:ILLEGAL ACT #1'
   V5586   = 'SD11F ''%''CL:ILLEGAL ACT #1'
   V5587   = 'SD11FM2 OTHR ILLEGAL ACT'
   V5588   = 'SD11F #CL:ILLEGAL ACT #2'
   V5589   = 'SD11F ''%''CL:ILLEGAL ACT #2'
   V5590   = 'SD11FM3 OTHR ILLEGAL ACT'
   V5591   = 'SD11F #CL:ILLEGAL ACT #3'
   V5592   = 'SD11F ''%''CL:ILLEGAL ACT #3'
   V5593   = 'SD11FM4 OTHR ILLEGAL ACT'
   V5594   = 'SD11F #CL:ILLEGAL ACT #4'
   V5595   = 'SD11F ''%''CL:ILLEGAL ACT #4'
   V5596   = 'SD11FM5 OTHR ILLEGAL ACT'
   V5597   = 'SD11F #CL:ILLEGAL ACT #5'
   V5598   = 'SD11F ''%''CL:ILLEGAL ACT #5'
   V5599   = 'SE1 # YRS:EMPLOYED BY U'
   V5600   = 'SE1 # MOS:EMPLOYED BY U'
   V5601   = 'SE2 # YRS:WORK IN FIELD'
   V5602   = 'SE2 # MOS:WORK IN FIELD'
   V5603   = 'SE2A #YRS:MAINLY THERAPY'
   V5604   = 'SE2A #MOS:MAINLY THERAPY'
   V5605   = 'SE2B #YRS:MAINLY SUPERVS'
   V5606   = 'SE2B #MOS:MAINLY SUPERVS'
   V5607   = 'SE3 PRESENT POSITION,JOB'
   V5608   = 'SE3A #YR:PRESNT POSITION'
   V5609   = 'SE3A #MO:PRESNT POSITION'
   V5610   = 'SE4 POSITION BEFORE NOW'
   V5611   = 'SE4A PREV POSITION IN U?'
   V5612   = 'SE4B # YRS:PREV POSITION'
   V5613   = 'SE4B # MOS:PREV POSITION'
   V5614   = 'SUPERVISOR OR RESP AGE - CATEGORIZED'
   V5615   = 'SE6 ARE YOU MALE/FEMALE?'
   V5616   = 'IS SUPERVISOR HISPANIC - RECODED'
   V5617   = 'SE7A R:WHT?BLACK?AMERIN?'
   V5618   = 'SE8 R:MARITAL STATUS'
   V5619   = 'SE9 R:HR/WK WORK-OSATU'
   V5620   = 'SE10A R:HR/WK-THERAPY'
   V5621   = 'SE10B R:HR/WK-SUPERVISNG'
   V5622   = 'SE10C R:HR/WK-REV RECORD'
   V5623   = 'SE11 R:HI GRADE,YR SCHOL'
   V5624   = 'SE11A R:PASS HI SCHOOL?'
   V5625   = 'SE11B R:COLLEGE DEGREE?'
   V5626   = 'SE11CM1 R:WHAT DEGREE'
   V5627   = 'SE11DM1 R:DEGREE FIELD'
   V5628   = 'SE11CM2 R:WHAT DEGREE'
   V5629   = 'SE11DM2 R:DEGREE FIELD'
   V5630   = 'SE11CM3 R:WHAT DEGREE'
   V5631   = 'SE11DM3 R:DEGREE FIELD'
   V5632   = 'SE12 R:CERTF SA COUNSEL?'
   V5665   = 'SB26A NAME1GOVORG PRO ST'
   V5666   = 'SB26A NAME2GOVORG PRO ST'
   V5667   = 'SB26A NAME3GOVORG PRO ST'
   V5668   = 'SB28A NAME1AGRORG PRO ST'
   V5669   = 'SB28A NAME2AGRORG PRO ST'
   V5670   = 'SB28A NAME3AGRORG PRO ST'
   V5671   = 'SB30A NAME1INCORG PRO ST'
   V5672   = 'SB30A NAME2INCORG PRO ST'
   V5673   = 'SB30A NAME3INCORG PRO ST'
   V5674   = 'SC36A NAME1GOVORG METH'
   V5675   = 'SC36A NAME2GOVORG METH'
   V5676   = 'SC36A NAME3GOVORG METH'
   V5677   = 'SC38A NAME1AGRORG METH'
   V5678   = 'SC38A NAME2AGRORG METH'
   V5679   = 'SC38A NAME3AGRORG METH'
   V5680   = 'SC40A NAME1INCORG METH'
   V5681   = 'SC40A NAME2INCORG METH'
   V5682   = 'SC40A NAME3INCORG METH'
   V6998   = 'SMP:ODA2 CENT WEIGHTS'
   V7000   = 'SMP:TRIMMED.WEIGHTS'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (V4004 >= -5 AND V4004 <= -1) THEN V4004 = .;
   IF (V4005 >= -5 AND V4005 <= -1) THEN V4005 = .;
   IF (V4006 >= -5 AND V4006 <= -1) THEN V4006 = .;
   IF (V4007 >= -5 AND V4007 <= -1) THEN V4007 = .;
   IF (V4008 >= -5 AND V4008 <= -1) THEN V4008 = .;
   IF (V4009 >= -5 AND V4009 <= -1) THEN V4009 = .;
   IF (V4010 >= -5 AND V4010 <= -1) THEN V4010 = .;
   IF (V4011 >= -5 AND V4011 <= -1) THEN V4011 = .;
   IF (V4012 >= -5 AND V4012 <= -1) THEN V4012 = .;
   IF (V4013 >= -5 AND V4013 <= -1) THEN V4013 = .;
   IF (V4014 >= -5 AND V4014 <= -1) THEN V4014 = .;
   IF (V4015 >= -5 AND V4015 <= -1) THEN V4015 = .;
   IF (V4016 >= -5 AND V4016 <= -1) THEN V4016 = .;
   IF (V4017 >= -5 AND V4017 <= -1) THEN V4017 = .;
   IF (V4018 >= -5 AND V4018 <= -1) THEN V4018 = .;
   IF (V4019 >= -5 AND V4019 <= -1) THEN V4019 = .;
   IF (V4020 >= -5 AND V4020 <= -1) THEN V4020 = .;
   IF (V4021 >= -5 AND V4021 <= -1) THEN V4021 = .;
   IF (V4022 >= -5 AND V4022 <= -1) THEN V4022 = .;
   IF (V4023 >= -5 AND V4023 <= -1) THEN V4023 = .;
   IF (V4024 >= -5 AND V4024 <= -1) THEN V4024 = .;
   IF (V4025 >= -5 AND V4025 <= -1) THEN V4025 = .;
   IF (V4026 >= -5 AND V4026 <= -1) THEN V4026 = .;
   IF (V4027 >= -5 AND V4027 <= -1) THEN V4027 = .;
   IF (V4028 >= -5 AND V4028 <= -1) THEN V4028 = .;
   IF (V4029 >= -5 AND V4029 <= -1) THEN V4029 = .;
   IF (V4030 >= -5 AND V4030 <= -1) THEN V4030 = .;
   IF (V4031 >= -5 AND V4031 <= -1) THEN V4031 = .;
   IF (V4032 >= -5 AND V4032 <= -1) THEN V4032 = .;
   IF (V4033 >= -5 AND V4033 <= -1) THEN V4033 = .;
   IF (V4034 >= -5 AND V4034 <= -1) THEN V4034 = .;
   IF (V4035 >= -5 AND V4035 <= -1) THEN V4035 = .;
   IF (V4036 >= -5 AND V4036 <= -1) THEN V4036 = .;
   IF (V4037 >= -5 AND V4037 <= -1) THEN V4037 = .;
   IF (V4038 >= -5 AND V4038 <= -1) THEN V4038 = .;
   IF (V4039 >= -5 AND V4039 <= -1) THEN V4039 = .;
   IF (V4040 >= -5 AND V4040 <= -1) THEN V4040 = .;
   IF (V4041 >= -5 AND V4041 <= -1) THEN V4041 = .;
   IF (V4042 >= -5 AND V4042 <= -1) THEN V4042 = .;
   IF (V4043 >= -5 AND V4043 <= -1) THEN V4043 = .;
   IF (V4044 >= -5 AND V4044 <= -1) THEN V4044 = .;
   IF (V4045 >= -5 AND V4045 <= -1) THEN V4045 = .;
   IF (V4046 >= -5 AND V4046 <= -1) THEN V4046 = .;
   IF (V4047 >= -5 AND V4047 <= -1) THEN V4047 = .;
   IF (V4048 >= -5 AND V4048 <= -1) THEN V4048 = .;
   IF (V4049 >= -5 AND V4049 <= -1) THEN V4049 = .;
   IF (V4050 >= -5 AND V4050 <= -1) THEN V4050 = .;
   IF (V4051 >= -5 AND V4051 <= -1) THEN V4051 = .;
   IF (V4052 >= -5 AND V4052 <= -1) THEN V4052 = .;
   IF (V4053 >= -5 AND V4053 <= -1) THEN V4053 = .;
   IF (V4054 >= -5 AND V4054 <= -1) THEN V4054 = .;
   IF (V4055 >= -5 AND V4055 <= -1) THEN V4055 = .;
   IF (V4056 >= -5 AND V4056 <= -1) THEN V4056 = .;
   IF (V4057 >= -5 AND V4057 <= -1) THEN V4057 = .;
   IF (V4058 >= -5 AND V4058 <= -1) THEN V4058 = .;
   IF (V4059 >= -5 AND V4059 <= -1) THEN V4059 = .;
   IF (V4060 >= -5 AND V4060 <= -1) THEN V4060 = .;
   IF (V4061 >= -5 AND V4061 <= -1) THEN V4061 = .;
   IF (V4062 >= -5 AND V4062 <= -1) THEN V4062 = .;
   IF (V4063 >= -5 AND V4063 <= -1) THEN V4063 = .;
   IF (V4064 >= -5 AND V4064 <= -1) THEN V4064 = .;
   IF (V4065 >= -5 AND V4065 <= -1) THEN V4065 = .;
   IF (V4066 >= -5 AND V4066 <= -1) THEN V4066 = .;
   IF (V4067 >= -5 AND V4067 <= -1) THEN V4067 = .;
   IF (V4068 >= -5 AND V4068 <= -1) THEN V4068 = .;
   IF (V4069 >= -5 AND V4069 <= -1) THEN V4069 = .;
   IF (V4070 >= -5 AND V4070 <= -1) THEN V4070 = .;
   IF (V4071 >= -5 AND V4071 <= -1) THEN V4071 = .;
   IF (V4072 >= -5 AND V4072 <= -1) THEN V4072 = .;
   IF (V4073 >= -5 AND V4073 <= -1) THEN V4073 = .;
   IF (V4074 >= -5 AND V4074 <= -1) THEN V4074 = .;
   IF (V4075 >= -5 AND V4075 <= -1) THEN V4075 = .;
   IF (V4076 >= -5 AND V4076 <= -1) THEN V4076 = .;
   IF (V4077 >= -5 AND V4077 <= -1) THEN V4077 = .;
   IF (V4078 >= -5 AND V4078 <= -1) THEN V4078 = .;
   IF (V4079 >= -5 AND V4079 <= -1) THEN V4079 = .;
   IF (V4080 >= -5 AND V4080 <= -1) THEN V4080 = .;
   IF (V4081 >= -5 AND V4081 <= -1) THEN V4081 = .;
   IF (V4082 >= -5 AND V4082 <= -1) THEN V4082 = .;
   IF (V4083 >= -5 AND V4083 <= -1) THEN V4083 = .;
   IF (V4084 >= -5 AND V4084 <= -1) THEN V4084 = .;
   IF (V4085 >= -5 AND V4085 <= -1) THEN V4085 = .;
   IF (V4086 >= -5 AND V4086 <= -1) THEN V4086 = .;
   IF (V4087 >= -5 AND V4087 <= -1) THEN V4087 = .;
   IF (V4088 >= -5 AND V4088 <= -1) THEN V4088 = .;
   IF (V4089 >= -5 AND V4089 <= -1) THEN V4089 = .;
   IF (V4090 >= -5 AND V4090 <= -1) THEN V4090 = .;
   IF (V4091 >= -5 AND V4091 <= -1) THEN V4091 = .;
   IF (V4092 >= -5 AND V4092 <= -1) THEN V4092 = .;
   IF (V4093 >= -5 AND V4093 <= -1) THEN V4093 = .;
   IF (V4094 >= -5 AND V4094 <= -1) THEN V4094 = .;
   IF (V4095 >= -5 AND V4095 <= -1) THEN V4095 = .;
   IF (V4096 >= -5 AND V4096 <= -1) THEN V4096 = .;
   IF (V4097 >= -5 AND V4097 <= -1) THEN V4097 = .;
   IF (V4098 >= -5 AND V4098 <= -1) THEN V4098 = .;
   IF (V4099 >= -5 AND V4099 <= -1) THEN V4099 = .;
   IF (V4100 >= -5 AND V4100 <= -1) THEN V4100 = .;
   IF (V4101 >= -5 AND V4101 <= -1) THEN V4101 = .;
   IF (V4102 >= -5 AND V4102 <= -1) THEN V4102 = .;
   IF (V4103 >= -5 AND V4103 <= -1) THEN V4103 = .;
   IF (V4104 >= -5 AND V4104 <= -1) THEN V4104 = .;
   IF (V4105 >= -5 AND V4105 <= -1) THEN V4105 = .;
   IF (V4106 >= -5 AND V4106 <= -1) THEN V4106 = .;
   IF (V4107 >= -5 AND V4107 <= -1) THEN V4107 = .;
   IF (V4108 >= -5 AND V4108 <= -1) THEN V4108 = .;
   IF (V4109 >= -5 AND V4109 <= -1) THEN V4109 = .;
   IF (V4110 >= -5 AND V4110 <= -1) THEN V4110 = .;
   IF (V4111 >= -5 AND V4111 <= -1) THEN V4111 = .;
   IF (V4112 >= -5 AND V4112 <= -1) THEN V4112 = .;
   IF (V4113 >= -5 AND V4113 <= -1) THEN V4113 = .;
   IF (V4114 >= -5 AND V4114 <= -1) THEN V4114 = .;
   IF (V4115 >= -5 AND V4115 <= -1) THEN V4115 = .;
   IF (V4116 >= -5 AND V4116 <= -1) THEN V4116 = .;
   IF (V4117 >= -5 AND V4117 <= -1) THEN V4117 = .;
   IF (V4118 >= -5 AND V4118 <= -1) THEN V4118 = .;
   IF (V4119 >= -5 AND V4119 <= -1) THEN V4119 = .;
   IF (V4120 >= -5 AND V4120 <= -1) THEN V4120 = .;
   IF (V4121 >= -5 AND V4121 <= -1) THEN V4121 = .;
   IF (V4122 >= -5 AND V4122 <= -1) THEN V4122 = .;
   IF (V4123 >= -5 AND V4123 <= -1) THEN V4123 = .;
   IF (V4124 >= -5 AND V4124 <= -1) THEN V4124 = .;
   IF (V4125 >= -5 AND V4125 <= -1) THEN V4125 = .;
   IF (V4126 >= -5 AND V4126 <= -1) THEN V4126 = .;
   IF (V4127 >= -5 AND V4127 <= -1) THEN V4127 = .;
   IF (V4128 >= -5 AND V4128 <= -1) THEN V4128 = .;
   IF (V4129 >= -5 AND V4129 <= -1) THEN V4129 = .;
   IF (V4130 >= -5 AND V4130 <= -1) THEN V4130 = .;
   IF (V4131 >= -5 AND V4131 <= -1) THEN V4131 = .;
   IF (V4132 >= -5 AND V4132 <= -1) THEN V4132 = .;
   IF (V4133 >= -5 AND V4133 <= -1) THEN V4133 = .;
   IF (V4134 >= -5 AND V4134 <= -1) THEN V4134 = .;
   IF (V4135 >= -5 AND V4135 <= -1) THEN V4135 = .;
   IF (V4136 >= -5 AND V4136 <= -1) THEN V4136 = .;
   IF (V4137 >= -5 AND V4137 <= -1) THEN V4137 = .;
   IF (V4138 >= -5 AND V4138 <= -1) THEN V4138 = .;
   IF (V4139 >= -5 AND V4139 <= -1) THEN V4139 = .;
   IF (V4140 >= -5 AND V4140 <= -1) THEN V4140 = .;
   IF (V4141 >= -5 AND V4141 <= -1) THEN V4141 = .;
   IF (V4142 >= -5 AND V4142 <= -1) THEN V4142 = .;
   IF (V4143 >= -5 AND V4143 <= -1) THEN V4143 = .;
   IF (V4144 >= -5 AND V4144 <= -1) THEN V4144 = .;
   IF (V4145 >= -5 AND V4145 <= -1) THEN V4145 = .;
   IF (V4146 >= -5 AND V4146 <= -1) THEN V4146 = .;
   IF (V4147 >= -5 AND V4147 <= -1) THEN V4147 = .;
   IF (V4148 >= -5 AND V4148 <= -1) THEN V4148 = .;
   IF (V4149 >= -5 AND V4149 <= -1) THEN V4149 = .;
   IF (V4150 >= -5 AND V4150 <= -1) THEN V4150 = .;
   IF (V4151 >= -5 AND V4151 <= -1) THEN V4151 = .;
   IF (V4152 >= -5 AND V4152 <= -1) THEN V4152 = .;
   IF (V4153 >= -5 AND V4153 <= -1) THEN V4153 = .;
   IF (V4154 >= -5 AND V4154 <= -1) THEN V4154 = .;
   IF (V4155 >= -5 AND V4155 <= -1) THEN V4155 = .;
   IF (V4156 >= -5 AND V4156 <= -1) THEN V4156 = .;
   IF (V4157 >= -5 AND V4157 <= -1) THEN V4157 = .;
   IF (V4158 >= -5 AND V4158 <= -1) THEN V4158 = .;
   IF (V4159 >= -5 AND V4159 <= -1) THEN V4159 = .;
   IF (V4160 >= -5 AND V4160 <= -1) THEN V4160 = .;
   IF (V4161 >= -5 AND V4161 <= -1) THEN V4161 = .;
   IF (V4162 >= -5 AND V4162 <= -1) THEN V4162 = .;
   IF (V4163 >= -5 AND V4163 <= -1) THEN V4163 = .;
   IF (V4164 >= -5 AND V4164 <= -1) THEN V4164 = .;
   IF (V4165 >= -5 AND V4165 <= -1) THEN V4165 = .;
   IF (V4166 >= -5 AND V4166 <= -1) THEN V4166 = .;
   IF (V4167 >= -5 AND V4167 <= -1) THEN V4167 = .;
   IF (V4168 >= -5 AND V4168 <= -1) THEN V4168 = .;
   IF (V4169 >= -5 AND V4169 <= -1) THEN V4169 = .;
   IF (V4170 >= -5 AND V4170 <= -1) THEN V4170 = .;
   IF (V4171 >= -5 AND V4171 <= -1) THEN V4171 = .;
   IF (V4172 >= -5 AND V4172 <= -1) THEN V4172 = .;
   IF (V4173 >= -5 AND V4173 <= -1) THEN V4173 = .;
   IF (V4174 >= -5 AND V4174 <= -1) THEN V4174 = .;
   IF (V4175 >= -5 AND V4175 <= -1) THEN V4175 = .;
   IF (V4176 >= -5 AND V4176 <= -1) THEN V4176 = .;
   IF (V4177 >= -5 AND V4177 <= -1) THEN V4177 = .;
   IF (V4178 >= -5 AND V4178 <= -1) THEN V4178 = .;
   IF (V4179 >= -5 AND V4179 <= -1) THEN V4179 = .;
   IF (V4180 >= -5 AND V4180 <= -1) THEN V4180 = .;
   IF (V4181 >= -5 AND V4181 <= -1) THEN V4181 = .;
   IF (V4182 >= -5 AND V4182 <= -1) THEN V4182 = .;
   IF (V4183 >= -5 AND V4183 <= -1) THEN V4183 = .;
   IF (V4184 >= -5 AND V4184 <= -1) THEN V4184 = .;
   IF (V4185 >= -5 AND V4185 <= -1) THEN V4185 = .;
   IF (V4186 >= -5 AND V4186 <= -1) THEN V4186 = .;
   IF (V4187 >= -5 AND V4187 <= -1) THEN V4187 = .;
   IF (V4188 >= -5 AND V4188 <= -1) THEN V4188 = .;
   IF (V4189 >= -5 AND V4189 <= -1) THEN V4189 = .;
   IF (V4190 >= -5 AND V4190 <= -1) THEN V4190 = .;
   IF (V4191 >= -5 AND V4191 <= -1) THEN V4191 = .;
   IF (V4192 >= -5.00 AND V4192 <= -1.00) THEN V4192 = .;
   IF (V4193 >= -5 AND V4193 <= -1) THEN V4193 = .;
   IF (V4194 >= -5 AND V4194 <= -1) THEN V4194 = .;
   IF (V4195 >= -5 AND V4195 <= -1) THEN V4195 = .;
   IF (V4196 >= -5 AND V4196 <= -1) THEN V4196 = .;
   IF (V4197 >= -5 AND V4197 <= -1) THEN V4197 = .;
   IF (V4198 >= -5.00 AND V4198 <= -1.00) THEN V4198 = .;
   IF (V4199 >= -5 AND V4199 <= -1) THEN V4199 = .;
   IF (V4200 >= -5.00 AND V4200 <= -1.00) THEN V4200 = .;
   IF (V4201 >= -5 AND V4201 <= -1) THEN V4201 = .;
   IF (V4202 >= -5 AND V4202 <= -1) THEN V4202 = .;
   IF (V4203 >= -5 AND V4203 <= -1) THEN V4203 = .;
   IF (V4204 >= -5 AND V4204 <= -1) THEN V4204 = .;
   IF (V4205 >= -5 AND V4205 <= -1) THEN V4205 = .;
   IF (V4206 >= -5 AND V4206 <= -1) THEN V4206 = .;
   IF (V4207 >= -5 AND V4207 <= -1) THEN V4207 = .;
   IF (V4208 >= -5 AND V4208 <= -1) THEN V4208 = .;
   IF (V4209 >= -5.00 AND V4209 <= -1.00) THEN V4209 = .;
   IF (V4210 >= -5 AND V4210 <= -1) THEN V4210 = .;
   IF (V4211 >= -5 AND V4211 <= -1) THEN V4211 = .;
   IF (V4212 >= -5 AND V4212 <= -1) THEN V4212 = .;
   IF (V4213 >= -5 AND V4213 <= -1) THEN V4213 = .;
   IF (V4214 >= -5 AND V4214 <= -1) THEN V4214 = .;
   IF (V4215 >= -5 AND V4215 <= -1) THEN V4215 = .;
   IF (V4216 >= -5 AND V4216 <= -1) THEN V4216 = .;
   IF (V4217 >= -5 AND V4217 <= -1) THEN V4217 = .;
   IF (V4218 >= -5 AND V4218 <= -1) THEN V4218 = .;
   IF (V4219 >= -5 AND V4219 <= -1) THEN V4219 = .;
   IF (V4220 >= -5 AND V4220 <= -1) THEN V4220 = .;
   IF (V4221 >= -5 AND V4221 <= -1) THEN V4221 = .;
   IF (V4222 >= -5 AND V4222 <= -1) THEN V4222 = .;
   IF (V4223 >= -5 AND V4223 <= -1) THEN V4223 = .;
   IF (V4224 >= -5 AND V4224 <= -1) THEN V4224 = .;
   IF (V4225 >= -5 AND V4225 <= -1) THEN V4225 = .;
   IF (V4226 >= -5 AND V4226 <= -1) THEN V4226 = .;
   IF (V4227 >= -5 AND V4227 <= -1) THEN V4227 = .;
   IF (V4228 >= -5 AND V4228 <= -1) THEN V4228 = .;
   IF (V4229 >= -5 AND V4229 <= -1) THEN V4229 = .;
   IF (V4230 >= -5 AND V4230 <= -1) THEN V4230 = .;
   IF (V4231 >= -5 AND V4231 <= -1) THEN V4231 = .;
   IF (V4232 >= -5 AND V4232 <= -1) THEN V4232 = .;
   IF (V4233 >= -5 AND V4233 <= -1) THEN V4233 = .;
   IF (V4234 >= -5 AND V4234 <= -1) THEN V4234 = .;
   IF (V4235 >= -5 AND V4235 <= -1) THEN V4235 = .;
   IF (V4236 >= -5 AND V4236 <= -1) THEN V4236 = .;
   IF (V4237 >= -5 AND V4237 <= -1) THEN V4237 = .;
   IF (V4238 >= -5 AND V4238 <= -1) THEN V4238 = .;
   IF (V4239 >= -5 AND V4239 <= -1) THEN V4239 = .;
   IF (V4240 >= -5 AND V4240 <= -1) THEN V4240 = .;
   IF (V4241 >= -5 AND V4241 <= -1) THEN V4241 = .;
   IF (V4242 >= -5 AND V4242 <= -1) THEN V4242 = .;
   IF (V4243 >= -5 AND V4243 <= -1) THEN V4243 = .;
   IF (V4244 >= -5 AND V4244 <= -1) THEN V4244 = .;
   IF (V4245 >= -5 AND V4245 <= -1) THEN V4245 = .;
   IF (V4246 >= -5 AND V4246 <= -1) THEN V4246 = .;
   IF (V4247 >= -5 AND V4247 <= -1) THEN V4247 = .;
   IF (V4248 >= -5 AND V4248 <= -1) THEN V4248 = .;
   IF (V4249 >= -5 AND V4249 <= -1) THEN V4249 = .;
   IF (V4250 >= -5 AND V4250 <= -1) THEN V4250 = .;
   IF (V4251 >= -5 AND V4251 <= -1) THEN V4251 = .;
   IF (V4252 >= -5 AND V4252 <= -1) THEN V4252 = .;
   IF (V4253 >= -5 AND V4253 <= -1) THEN V4253 = .;
   IF (V4254 >= -5 AND V4254 <= -1) THEN V4254 = .;
   IF (V4255 >= -5 AND V4255 <= -1) THEN V4255 = .;
   IF (V4256 >= -5 AND V4256 <= -1) THEN V4256 = .;
   IF (V4257 >= -5 AND V4257 <= -1) THEN V4257 = .;
   IF (V4258 >= -5 AND V4258 <= -1) THEN V4258 = .;
   IF (V4259 >= -5 AND V4259 <= -1) THEN V4259 = .;
   IF (V4260 >= -5 AND V4260 <= -1) THEN V4260 = .;
   IF (V4261 >= -5 AND V4261 <= -1) THEN V4261 = .;
   IF (V4262 >= -5 AND V4262 <= -1) THEN V4262 = .;
   IF (V4263 >= -5 AND V4263 <= -1) THEN V4263 = .;
   IF (V4264 >= -5 AND V4264 <= -1) THEN V4264 = .;
   IF (V4265 >= -5 AND V4265 <= -1) THEN V4265 = .;
   IF (V4266 >= -5 AND V4266 <= -1) THEN V4266 = .;
   IF (V4267 >= -5 AND V4267 <= -1) THEN V4267 = .;
   IF (V4268 >= -5 AND V4268 <= -1) THEN V4268 = .;
   IF (V4269 >= -5 AND V4269 <= -1) THEN V4269 = .;
   IF (V4270 >= -5 AND V4270 <= -1) THEN V4270 = .;
   IF (V4271 >= -5 AND V4271 <= -1) THEN V4271 = .;
   IF (V4272 >= -5 AND V4272 <= -1) THEN V4272 = .;
   IF (V4273 >= -5 AND V4273 <= -1) THEN V4273 = .;
   IF (V4274 >= -5 AND V4274 <= -1) THEN V4274 = .;
   IF (V4275 >= -5 AND V4275 <= -1) THEN V4275 = .;
   IF (V4276 >= -5 AND V4276 <= -1) THEN V4276 = .;
   IF (V4277 >= -5 AND V4277 <= -1) THEN V4277 = .;
   IF (V4278 >= -5 AND V4278 <= -1) THEN V4278 = .;
   IF (V4279 >= -5 AND V4279 <= -1) THEN V4279 = .;
   IF (V4280 >= -5 AND V4280 <= -1) THEN V4280 = .;
   IF (V4281 >= -5 AND V4281 <= -1) THEN V4281 = .;
   IF (V4282 >= -5 AND V4282 <= -1) THEN V4282 = .;
   IF (V4283 >= -5 AND V4283 <= -1) THEN V4283 = .;
   IF (V4284 >= -5 AND V4284 <= -1) THEN V4284 = .;
   IF (V4285 >= -5 AND V4285 <= -1) THEN V4285 = .;
   IF (V4286 >= -5 AND V4286 <= -1) THEN V4286 = .;
   IF (V4287 >= -5 AND V4287 <= -1) THEN V4287 = .;
   IF (V4288 >= -5 AND V4288 <= -1) THEN V4288 = .;
   IF (V4289 >= -5 AND V4289 <= -1) THEN V4289 = .;
   IF (V4290 >= -5 AND V4290 <= -1) THEN V4290 = .;
   IF (V4291 >= -5 AND V4291 <= -1) THEN V4291 = .;
   IF (V4292 >= -5 AND V4292 <= -1) THEN V4292 = .;
   IF (V4293 >= -5 AND V4293 <= -1) THEN V4293 = .;
   IF (V4294 >= -5 AND V4294 <= -1) THEN V4294 = .;
   IF (V4295 >= -5 AND V4295 <= -1) THEN V4295 = .;
   IF (V4296 >= -5 AND V4296 <= -1) THEN V4296 = .;
   IF (V4297 >= -5 AND V4297 <= -1) THEN V4297 = .;
   IF (V4298 >= -5 AND V4298 <= -1) THEN V4298 = .;
   IF (V4299 >= -5 AND V4299 <= -1) THEN V4299 = .;
   IF (V4300 >= -5 AND V4300 <= -1) THEN V4300 = .;
   IF (V4301 >= -5 AND V4301 <= -1) THEN V4301 = .;
   IF (V4302 >= -5 AND V4302 <= -1) THEN V4302 = .;
   IF (V4303 >= -5 AND V4303 <= -1) THEN V4303 = .;
   IF (V4304 >= -5 AND V4304 <= -1) THEN V4304 = .;
   IF (V4305 >= -5 AND V4305 <= -1) THEN V4305 = .;
   IF (V4306 >= -5 AND V4306 <= -1) THEN V4306 = .;
   IF (V4307 >= -5 AND V4307 <= -1) THEN V4307 = .;
   IF (V4308 >= -5 AND V4308 <= -1) THEN V4308 = .;
   IF (V4309 >= -5 AND V4309 <= -1) THEN V4309 = .;
   IF (V4310 >= -5 AND V4310 <= -1) THEN V4310 = .;
   IF (V4311 >= -5 AND V4311 <= -1) THEN V4311 = .;
   IF (V4312 >= -5 AND V4312 <= -1) THEN V4312 = .;
   IF (V4313 >= -5 AND V4313 <= -1) THEN V4313 = .;
   IF (V4314 >= -5 AND V4314 <= -1) THEN V4314 = .;
   IF (V4315 >= -5 AND V4315 <= -1) THEN V4315 = .;
   IF (V4316 >= -5 AND V4316 <= -1) THEN V4316 = .;
   IF (V4317 >= -5 AND V4317 <= -1) THEN V4317 = .;
   IF (V4318 >= -5 AND V4318 <= -1) THEN V4318 = .;
   IF (V4319 >= -5 AND V4319 <= -1) THEN V4319 = .;
   IF (V4320 >= -5 AND V4320 <= -1) THEN V4320 = .;
   IF (V4321 >= -5 AND V4321 <= -1) THEN V4321 = .;
   IF (V4322 >= -5 AND V4322 <= -1) THEN V4322 = .;
   IF (V4323 >= -5 AND V4323 <= -1) THEN V4323 = .;
   IF (V4324 >= -5 AND V4324 <= -1) THEN V4324 = .;
   IF (V4325 >= -5 AND V4325 <= -1) THEN V4325 = .;
   IF (V4326 >= -5 AND V4326 <= -1) THEN V4326 = .;
   IF (V4327 >= -5 AND V4327 <= -1) THEN V4327 = .;
   IF (V4328 >= -5 AND V4328 <= -1) THEN V4328 = .;
   IF (V4329 >= -5 AND V4329 <= -1) THEN V4329 = .;
   IF (V4330 >= -5 AND V4330 <= -1) THEN V4330 = .;
   IF (V4331 >= -5 AND V4331 <= -1) THEN V4331 = .;
   IF (V4332 >= -5 AND V4332 <= -1) THEN V4332 = .;
   IF (V4333 >= -5 AND V4333 <= -1) THEN V4333 = .;
   IF (V4334 >= -5 AND V4334 <= -1) THEN V4334 = .;
   IF (V4335 >= -5 AND V4335 <= -1) THEN V4335 = .;
   IF (V4336 >= -5 AND V4336 <= -1) THEN V4336 = .;
   IF (V4337 >= -5 AND V4337 <= -1) THEN V4337 = .;
   IF (V4338 >= -5 AND V4338 <= -1) THEN V4338 = .;
   IF (V4339 >= -5 AND V4339 <= -1) THEN V4339 = .;
   IF (V4340 >= -5 AND V4340 <= -1) THEN V4340 = .;
   IF (V4341 >= -5 AND V4341 <= -1) THEN V4341 = .;
   IF (V4342 >= -5 AND V4342 <= -1) THEN V4342 = .;
   IF (V4343 >= -5 AND V4343 <= -1) THEN V4343 = .;
   IF (V4344 >= -5 AND V4344 <= -1) THEN V4344 = .;
   IF (V4345 >= -5 AND V4345 <= -1) THEN V4345 = .;
   IF (V4346 >= -5 AND V4346 <= -1) THEN V4346 = .;
   IF (V4347 >= -5 AND V4347 <= -1) THEN V4347 = .;
   IF (V4348 >= -5 AND V4348 <= -1) THEN V4348 = .;
   IF (V4349 >= -5 AND V4349 <= -1) THEN V4349 = .;
   IF (V4350 >= -5 AND V4350 <= -1) THEN V4350 = .;
   IF (V4351 >= -5 AND V4351 <= -1) THEN V4351 = .;
   IF (V4352 >= -5 AND V4352 <= -1) THEN V4352 = .;
   IF (V4353 >= -5 AND V4353 <= -1) THEN V4353 = .;
   IF (V4354 >= -5 AND V4354 <= -1) THEN V4354 = .;
   IF (V4355 >= -5 AND V4355 <= -1) THEN V4355 = .;
   IF (V4356 >= -5 AND V4356 <= -1) THEN V4356 = .;
   IF (V4357 >= -5 AND V4357 <= -1) THEN V4357 = .;
   IF (V4358 >= -5 AND V4358 <= -1) THEN V4358 = .;
   IF (V4359 >= -5 AND V4359 <= -1) THEN V4359 = .;
   IF (V4360 >= -5 AND V4360 <= -1) THEN V4360 = .;
   IF (V4361 >= -5 AND V4361 <= -1) THEN V4361 = .;
   IF (V4362 >= -5 AND V4362 <= -1) THEN V4362 = .;
   IF (V4363 >= -5 AND V4363 <= -1) THEN V4363 = .;
   IF (V4364 >= -5 AND V4364 <= -1) THEN V4364 = .;
   IF (V4365 >= -5 AND V4365 <= -1) THEN V4365 = .;
   IF (V4366 >= -5 AND V4366 <= -1) THEN V4366 = .;
   IF (V4367 >= -5 AND V4367 <= -1) THEN V4367 = .;
   IF (V4368 >= -5 AND V4368 <= -1) THEN V4368 = .;
   IF (V4369 >= -5 AND V4369 <= -1) THEN V4369 = .;
   IF (V4370 >= -5 AND V4370 <= -1) THEN V4370 = .;
   IF (V4371 >= -5 AND V4371 <= -1) THEN V4371 = .;
   IF (V4372 >= -5 AND V4372 <= -1) THEN V4372 = .;
   IF (V4373 >= -5 AND V4373 <= -1) THEN V4373 = .;
   IF (V4374 >= -5 AND V4374 <= -1) THEN V4374 = .;
   IF (V4375 >= -5 AND V4375 <= -1) THEN V4375 = .;
   IF (V4376 >= -5 AND V4376 <= -1) THEN V4376 = .;
   IF (V4377 >= -5 AND V4377 <= -1) THEN V4377 = .;
   IF (V4378 >= -5 AND V4378 <= -1) THEN V4378 = .;
   IF (V4379 >= -5 AND V4379 <= -1) THEN V4379 = .;
   IF (V4380 >= -5 AND V4380 <= -1) THEN V4380 = .;
   IF (V4381 >= -5 AND V4381 <= -1) THEN V4381 = .;
   IF (V4382 >= -5 AND V4382 <= -1) THEN V4382 = .;
   IF (V4383 >= -5 AND V4383 <= -1) THEN V4383 = .;
   IF (V4384 >= -5 AND V4384 <= -1) THEN V4384 = .;
   IF (V4385 >= -5 AND V4385 <= -1) THEN V4385 = .;
   IF (V4386 >= -5 AND V4386 <= -1) THEN V4386 = .;
   IF (V4387 >= -5 AND V4387 <= -1) THEN V4387 = .;
   IF (V4388 >= -5 AND V4388 <= -1) THEN V4388 = .;
   IF (V4389 >= -5 AND V4389 <= -1) THEN V4389 = .;
   IF (V4390 >= -5 AND V4390 <= -1) THEN V4390 = .;
   IF (V4391 >= -5 AND V4391 <= -1) THEN V4391 = .;
   IF (V4392 >= -5 AND V4392 <= -1) THEN V4392 = .;
   IF (V4393 >= -5 AND V4393 <= -1) THEN V4393 = .;
   IF (V4394 >= -5 AND V4394 <= -1) THEN V4394 = .;
   IF (V4395 >= -5 AND V4395 <= -1) THEN V4395 = .;
   IF (V4396 >= -5 AND V4396 <= -1) THEN V4396 = .;
   IF (V4397 >= -5 AND V4397 <= -1) THEN V4397 = .;
   IF (V4398 >= -5 AND V4398 <= -1) THEN V4398 = .;
   IF (V4399 >= -5 AND V4399 <= -1) THEN V4399 = .;
   IF (V4400 >= -5 AND V4400 <= -1) THEN V4400 = .;
   IF (V4401 >= -5 AND V4401 <= -1) THEN V4401 = .;
   IF (V4402 >= -5 AND V4402 <= -1) THEN V4402 = .;
   IF (V4403 >= -5 AND V4403 <= -1) THEN V4403 = .;
   IF (V4404 >= -5 AND V4404 <= -1) THEN V4404 = .;
   IF (V4405 >= -5 AND V4405 <= -1) THEN V4405 = .;
   IF (V4406 >= -5 AND V4406 <= -1) THEN V4406 = .;
   IF (V4407 >= -5 AND V4407 <= -1) THEN V4407 = .;
   IF (V4408 >= -5 AND V4408 <= -1) THEN V4408 = .;
   IF (V4409 >= -5 AND V4409 <= -1) THEN V4409 = .;
   IF (V4410 >= -5 AND V4410 <= -1) THEN V4410 = .;
   IF (V4411 >= -5 AND V4411 <= -1) THEN V4411 = .;
   IF (V4412 >= -5 AND V4412 <= -1) THEN V4412 = .;
   IF (V4413 >= -5 AND V4413 <= -1) THEN V4413 = .;
   IF (V4414 >= -5 AND V4414 <= -1) THEN V4414 = .;
   IF (V4415 >= -5 AND V4415 <= -1) THEN V4415 = .;
   IF (V4416 >= -5 AND V4416 <= -1) THEN V4416 = .;
   IF (V4417 >= -5 AND V4417 <= -1) THEN V4417 = .;
   IF (V4418 >= -5 AND V4418 <= -1) THEN V4418 = .;
   IF (V4419 >= -5 AND V4419 <= -1) THEN V4419 = .;
   IF (V4420 >= -5 AND V4420 <= -1) THEN V4420 = .;
   IF (V4421 >= -5 AND V4421 <= -1) THEN V4421 = .;
   IF (V4422 >= -5 AND V4422 <= -1) THEN V4422 = .;
   IF (V4423 >= -5 AND V4423 <= -1) THEN V4423 = .;
   IF (V4424 >= -5 AND V4424 <= -1) THEN V4424 = .;
   IF (V4425 >= -5 AND V4425 <= -1) THEN V4425 = .;
   IF (V4426 >= -5 AND V4426 <= -1) THEN V4426 = .;
   IF (V4427 >= -5 AND V4427 <= -1) THEN V4427 = .;
   IF (V4428 >= -5 AND V4428 <= -1) THEN V4428 = .;
   IF (V4429 >= -5 AND V4429 <= -1) THEN V4429 = .;
   IF (V4430 >= -5 AND V4430 <= -1) THEN V4430 = .;
   IF (V4431 >= -5 AND V4431 <= -1) THEN V4431 = .;
   IF (V4432 >= -5 AND V4432 <= -1) THEN V4432 = .;
   IF (V4433 >= -5 AND V4433 <= -1) THEN V4433 = .;
   IF (V4434 >= -5 AND V4434 <= -1) THEN V4434 = .;
   IF (V4435 >= -5 AND V4435 <= -1) THEN V4435 = .;
   IF (V4436 >= -5 AND V4436 <= -1) THEN V4436 = .;
   IF (V4437 >= -5 AND V4437 <= -1) THEN V4437 = .;
   IF (V4438 >= -5 AND V4438 <= -1) THEN V4438 = .;
   IF (V4439 >= -5 AND V4439 <= -1) THEN V4439 = .;
   IF (V4440 >= -5 AND V4440 <= -1) THEN V4440 = .;
   IF (V4441 >= -5 AND V4441 <= -1) THEN V4441 = .;
   IF (V4442 >= -5 AND V4442 <= -1) THEN V4442 = .;
   IF (V4443 >= -5 AND V4443 <= -1) THEN V4443 = .;
   IF (V4444 >= -5 AND V4444 <= -1) THEN V4444 = .;
   IF (V4445 >= -5 AND V4445 <= -1) THEN V4445 = .;
   IF (V4446 >= -5 AND V4446 <= -1) THEN V4446 = .;
   IF (V4447 >= -5 AND V4447 <= -1) THEN V4447 = .;
   IF (V4448 >= -5 AND V4448 <= -1) THEN V4448 = .;
   IF (V4449 >= -5 AND V4449 <= -1) THEN V4449 = .;
   IF (V4450 >= -5 AND V4450 <= -1) THEN V4450 = .;
   IF (V4451 >= -5 AND V4451 <= -1) THEN V4451 = .;
   IF (V4452 >= -5 AND V4452 <= -1) THEN V4452 = .;
   IF (V4453 >= -5 AND V4453 <= -1) THEN V4453 = .;
   IF (V4454 >= -5 AND V4454 <= -1) THEN V4454 = .;
   IF (V4455 >= -5 AND V4455 <= -1) THEN V4455 = .;
   IF (V4456 >= -5 AND V4456 <= -1) THEN V4456 = .;
   IF (V4457 >= -5 AND V4457 <= -1) THEN V4457 = .;
   IF (V4458 >= -5 AND V4458 <= -1) THEN V4458 = .;
   IF (V4459 >= -5 AND V4459 <= -1) THEN V4459 = .;
   IF (V4460 >= -5 AND V4460 <= -1) THEN V4460 = .;
   IF (V4461 >= -5 AND V4461 <= -1) THEN V4461 = .;
   IF (V4462 >= -5 AND V4462 <= -1) THEN V4462 = .;
   IF (V4463 >= -5 AND V4463 <= -1) THEN V4463 = .;
   IF (V4464 >= -5 AND V4464 <= -1) THEN V4464 = .;
   IF (V4465 >= -5 AND V4465 <= -1) THEN V4465 = .;
   IF (V4466 >= -5 AND V4466 <= -1) THEN V4466 = .;
   IF (V4467 >= -5 AND V4467 <= -1) THEN V4467 = .;
   IF (V4468 >= -5 AND V4468 <= -1) THEN V4468 = .;
   IF (V4469 >= -5 AND V4469 <= -1) THEN V4469 = .;
   IF (V4470 >= -5 AND V4470 <= -1) THEN V4470 = .;
   IF (V4471 >= -5 AND V4471 <= -1) THEN V4471 = .;
   IF (V4472 >= -5 AND V4472 <= -1) THEN V4472 = .;
   IF (V4473 >= -5 AND V4473 <= -1) THEN V4473 = .;
   IF (V4474 >= -5 AND V4474 <= -1) THEN V4474 = .;
   IF (V4475 >= -5 AND V4475 <= -1) THEN V4475 = .;
   IF (V4476 >= -5 AND V4476 <= -1) THEN V4476 = .;
   IF (V4477 >= -5 AND V4477 <= -1) THEN V4477 = .;
   IF (V4478 >= -5 AND V4478 <= -1) THEN V4478 = .;
   IF (V4479 >= -5 AND V4479 <= -1) THEN V4479 = .;
   IF (V4480 >= -5 AND V4480 <= -1) THEN V4480 = .;
   IF (V4481 >= -5 AND V4481 <= -1) THEN V4481 = .;
   IF (V4482 >= -5 AND V4482 <= -1) THEN V4482 = .;
   IF (V4483 >= -5 AND V4483 <= -1) THEN V4483 = .;
   IF (V4484 >= -5 AND V4484 <= -1) THEN V4484 = .;
   IF (V4485 >= -5 AND V4485 <= -1) THEN V4485 = .;
   IF (V4486 >= -5 AND V4486 <= -1) THEN V4486 = .;
   IF (V4487 >= -5 AND V4487 <= -1) THEN V4487 = .;
   IF (V4488 >= -5 AND V4488 <= -1) THEN V4488 = .;
   IF (V4489 >= -5 AND V4489 <= -1) THEN V4489 = .;
   IF (V4490 >= -5 AND V4490 <= -1) THEN V4490 = .;
   IF (V4491 >= -5 AND V4491 <= -1) THEN V4491 = .;
   IF (V4492 >= -5 AND V4492 <= -1) THEN V4492 = .;
   IF (V4493 >= -5 AND V4493 <= -1) THEN V4493 = .;
   IF (V4494 >= -5 AND V4494 <= -1) THEN V4494 = .;
   IF (V4495 >= -5 AND V4495 <= -1) THEN V4495 = .;
   IF (V4496 >= -5 AND V4496 <= -1) THEN V4496 = .;
   IF (V4497 >= -5 AND V4497 <= -1) THEN V4497 = .;
   IF (V4498 >= -5 AND V4498 <= -1) THEN V4498 = .;
   IF (V4499 >= -5 AND V4499 <= -1) THEN V4499 = .;
   IF (V4500 >= -5 AND V4500 <= -1) THEN V4500 = .;
   IF (V4501 >= -5 AND V4501 <= -1) THEN V4501 = .;
   IF (V4502 >= -5 AND V4502 <= -1) THEN V4502 = .;
   IF (V4503 >= -5 AND V4503 <= -1) THEN V4503 = .;
   IF (V4504 >= -5 AND V4504 <= -1) THEN V4504 = .;
   IF (V4505 >= -5 AND V4505 <= -1) THEN V4505 = .;
   IF (V4506 >= -5 AND V4506 <= -1) THEN V4506 = .;
   IF (V4507 >= -5 AND V4507 <= -1) THEN V4507 = .;
   IF (V4508 >= -5 AND V4508 <= -1) THEN V4508 = .;
   IF (V4509 >= -5 AND V4509 <= -1) THEN V4509 = .;
   IF (V4510 >= -5 AND V4510 <= -1) THEN V4510 = .;
   IF (V4511 >= -5 AND V4511 <= -1) THEN V4511 = .;
   IF (V4512 >= -5 AND V4512 <= -1) THEN V4512 = .;
   IF (V4513 >= -5 AND V4513 <= -1) THEN V4513 = .;
   IF (V4514 >= -5 AND V4514 <= -1) THEN V4514 = .;
   IF (V4515 >= -5 AND V4515 <= -1) THEN V4515 = .;
   IF (V4516 >= -5 AND V4516 <= -1) THEN V4516 = .;
   IF (V4517 >= -5 AND V4517 <= -1) THEN V4517 = .;
   IF (V4518 >= -5 AND V4518 <= -1) THEN V4518 = .;
   IF (V4519 >= -5 AND V4519 <= -1) THEN V4519 = .;
   IF (V4520 >= -5 AND V4520 <= -1) THEN V4520 = .;
   IF (V4521 >= -5 AND V4521 <= -1) THEN V4521 = .;
   IF (V4522 >= -5 AND V4522 <= -1) THEN V4522 = .;
   IF (V4523 >= -5 AND V4523 <= -1) THEN V4523 = .;
   IF (V4524 >= -5 AND V4524 <= -1) THEN V4524 = .;
   IF (V4525 >= -5 AND V4525 <= -1) THEN V4525 = .;
   IF (V4526 >= -5 AND V4526 <= -1) THEN V4526 = .;
   IF (V4527 >= -5 AND V4527 <= -1) THEN V4527 = .;
   IF (V4528 >= -5 AND V4528 <= -1) THEN V4528 = .;
   IF (V4529 >= -5 AND V4529 <= -1) THEN V4529 = .;
   IF (V4530 >= -5 AND V4530 <= -1) THEN V4530 = .;
   IF (V4531 >= -5 AND V4531 <= -1) THEN V4531 = .;
   IF (V4532 >= -5 AND V4532 <= -1) THEN V4532 = .;
   IF (V4533 >= -5 AND V4533 <= -1) THEN V4533 = .;
   IF (V4534 >= -5 AND V4534 <= -1) THEN V4534 = .;
   IF (V4535 >= -5 AND V4535 <= -1) THEN V4535 = .;
   IF (V4536 >= -5 AND V4536 <= -1) THEN V4536 = .;
   IF (V4537 >= -5 AND V4537 <= -1) THEN V4537 = .;
   IF (V4538 >= -5 AND V4538 <= -1) THEN V4538 = .;
   IF (V4539 >= -5 AND V4539 <= -1) THEN V4539 = .;
   IF (V4540 >= -5 AND V4540 <= -1) THEN V4540 = .;
   IF (V4541 >= -5 AND V4541 <= -1) THEN V4541 = .;
   IF (V4542 >= -5 AND V4542 <= -1) THEN V4542 = .;
   IF (V4543 >= -5 AND V4543 <= -1) THEN V4543 = .;
   IF (V4544 >= -5 AND V4544 <= -1) THEN V4544 = .;
   IF (V4545 >= -5 AND V4545 <= -1) THEN V4545 = .;
   IF (V4546 >= -5 AND V4546 <= -1) THEN V4546 = .;
   IF (V4547 >= -5 AND V4547 <= -1) THEN V4547 = .;
   IF (V4548 >= -5 AND V4548 <= -1) THEN V4548 = .;
   IF (V4549 >= -5 AND V4549 <= -1) THEN V4549 = .;
   IF (V4550 >= -5 AND V4550 <= -1) THEN V4550 = .;
   IF (V4551 >= -5 AND V4551 <= -1) THEN V4551 = .;
   IF (V4552 >= -5 AND V4552 <= -1) THEN V4552 = .;
   IF (V4553 >= -5 AND V4553 <= -1) THEN V4553 = .;
   IF (V4554 >= -5 AND V4554 <= -1) THEN V4554 = .;
   IF (V4555 >= -5 AND V4555 <= -1) THEN V4555 = .;
   IF (V4556 >= -5 AND V4556 <= -1) THEN V4556 = .;
   IF (V4557 >= -5 AND V4557 <= -1) THEN V4557 = .;
   IF (V4558 >= -5 AND V4558 <= -1) THEN V4558 = .;
   IF (V4559 >= -5 AND V4559 <= -1) THEN V4559 = .;
   IF (V4560 >= -5 AND V4560 <= -1) THEN V4560 = .;
   IF (V4561 >= -5 AND V4561 <= -1) THEN V4561 = .;
   IF (V4562 >= -5 AND V4562 <= -1) THEN V4562 = .;
   IF (V4563 >= -5 AND V4563 <= -1) THEN V4563 = .;
   IF (V4564 >= -5 AND V4564 <= -1) THEN V4564 = .;
   IF (V4565 >= -5 AND V4565 <= -1) THEN V4565 = .;
   IF (V4566 >= -5 AND V4566 <= -1) THEN V4566 = .;
   IF (V4567 >= -5 AND V4567 <= -1) THEN V4567 = .;
   IF (V4568 >= -5 AND V4568 <= -1) THEN V4568 = .;
   IF (V4569 >= -5 AND V4569 <= -1) THEN V4569 = .;
   IF (V4570 >= -5 AND V4570 <= -1) THEN V4570 = .;
   IF (V4571 >= -5 AND V4571 <= -1) THEN V4571 = .;
   IF (V4572 >= -5 AND V4572 <= -1) THEN V4572 = .;
   IF (V4573 >= -5 AND V4573 <= -1) THEN V4573 = .;
   IF (V4574 >= -5 AND V4574 <= -1) THEN V4574 = .;
   IF (V4575 >= -5 AND V4575 <= -1) THEN V4575 = .;
   IF (V4576 >= -5 AND V4576 <= -1) THEN V4576 = .;
   IF (V4577 >= -5 AND V4577 <= -1) THEN V4577 = .;
   IF (V4578 >= -5 AND V4578 <= -1) THEN V4578 = .;
   IF (V4579 >= -5 AND V4579 <= -1) THEN V4579 = .;
   IF (V4580 >= -5 AND V4580 <= -1) THEN V4580 = .;
   IF (V4581 >= -5 AND V4581 <= -1) THEN V4581 = .;
   IF (V4582 >= -5 AND V4582 <= -1) THEN V4582 = .;
   IF (V4583 >= -5 AND V4583 <= -1) THEN V4583 = .;
   IF (V4584 >= -5 AND V4584 <= -1) THEN V4584 = .;
   IF (V4585 >= -5 AND V4585 <= -1) THEN V4585 = .;
   IF (V4586 >= -5 AND V4586 <= -1) THEN V4586 = .;
   IF (V4587 >= -5 AND V4587 <= -1) THEN V4587 = .;
   IF (V4588 >= -5 AND V4588 <= -1) THEN V4588 = .;
   IF (V4589 >= -5 AND V4589 <= -1) THEN V4589 = .;
   IF (V4590 >= -5 AND V4590 <= -1) THEN V4590 = .;
   IF (V4591 >= -5 AND V4591 <= -1) THEN V4591 = .;
   IF (V4592 >= -5 AND V4592 <= -1) THEN V4592 = .;
   IF (V4593 >= -5 AND V4593 <= -1) THEN V4593 = .;
   IF (V4594 >= -5 AND V4594 <= -1) THEN V4594 = .;
   IF (V4595 >= -5 AND V4595 <= -1) THEN V4595 = .;
   IF (V4596 >= -5 AND V4596 <= -1) THEN V4596 = .;
   IF (V4597 >= -5 AND V4597 <= -1) THEN V4597 = .;
   IF (V4598 >= -5 AND V4598 <= -1) THEN V4598 = .;
   IF (V4599 >= -5 AND V4599 <= -1) THEN V4599 = .;
   IF (V4600 >= -5 AND V4600 <= -1) THEN V4600 = .;
   IF (V4601 >= -5 AND V4601 <= -1) THEN V4601 = .;
   IF (V4602 >= -5 AND V4602 <= -1) THEN V4602 = .;
   IF (V4603 >= -5 AND V4603 <= -1) THEN V4603 = .;
   IF (V4604 >= -5 AND V4604 <= -1) THEN V4604 = .;
   IF (V4605 >= -5 AND V4605 <= -1) THEN V4605 = .;
   IF (V4606 >= -5 AND V4606 <= -1) THEN V4606 = .;
   IF (V4607 >= -5 AND V4607 <= -1) THEN V4607 = .;
   IF (V4608 >= -5 AND V4608 <= -1) THEN V4608 = .;
   IF (V4609 >= -5 AND V4609 <= -1) THEN V4609 = .;
   IF (V4610 >= -5 AND V4610 <= -1) THEN V4610 = .;
   IF (V4611 >= -5 AND V4611 <= -1) THEN V4611 = .;
   IF (V4612 >= -5 AND V4612 <= -1) THEN V4612 = .;
   IF (V4613 >= -5 AND V4613 <= -1) THEN V4613 = .;
   IF (V4614 >= -5 AND V4614 <= -1) THEN V4614 = .;
   IF (V4615 >= -5 AND V4615 <= -1) THEN V4615 = .;
   IF (V4616 >= -5 AND V4616 <= -1) THEN V4616 = .;
   IF (V4617 >= -5 AND V4617 <= -1) THEN V4617 = .;
   IF (V4618 >= -5 AND V4618 <= -1) THEN V4618 = .;
   IF (V4619 >= -5 AND V4619 <= -1) THEN V4619 = .;
   IF (V4620 >= -5 AND V4620 <= -1) THEN V4620 = .;
   IF (V4621 >= -5 AND V4621 <= -1) THEN V4621 = .;
   IF (V4622 >= -5 AND V4622 <= -1) THEN V4622 = .;
   IF (V4623 >= -5 AND V4623 <= -1) THEN V4623 = .;
   IF (V4624 >= -5 AND V4624 <= -1) THEN V4624 = .;
   IF (V4625 >= -5 AND V4625 <= -1) THEN V4625 = .;
   IF (V4626 >= -5 AND V4626 <= -1) THEN V4626 = .;
   IF (V4627 >= -5 AND V4627 <= -1) THEN V4627 = .;
   IF (V4628 >= -5 AND V4628 <= -1) THEN V4628 = .;
   IF (V4629 >= -5 AND V4629 <= -1) THEN V4629 = .;
   IF (V4630 >= -5 AND V4630 <= -1) THEN V4630 = .;
   IF (V4631 >= -5 AND V4631 <= -1) THEN V4631 = .;
   IF (V4632 >= -5 AND V4632 <= -1) THEN V4632 = .;
   IF (V4633 >= -5 AND V4633 <= -1) THEN V4633 = .;
   IF (V4634 >= -5 AND V4634 <= -1) THEN V4634 = .;
   IF (V4635 >= -5 AND V4635 <= -1) THEN V4635 = .;
   IF (V4636 >= -5 AND V4636 <= -1) THEN V4636 = .;
   IF (V4637 >= -5 AND V4637 <= -1) THEN V4637 = .;
   IF (V4638 >= -5 AND V4638 <= -1) THEN V4638 = .;
   IF (V4639 >= -5 AND V4639 <= -1) THEN V4639 = .;
   IF (V4640 >= -5 AND V4640 <= -1) THEN V4640 = .;
   IF (V4641 >= -5 AND V4641 <= -1) THEN V4641 = .;
   IF (V4642 >= -5 AND V4642 <= -1) THEN V4642 = .;
   IF (V4643 >= -5 AND V4643 <= -1) THEN V4643 = .;
   IF (V4644 >= -5 AND V4644 <= -1) THEN V4644 = .;
   IF (V4645 >= -5 AND V4645 <= -1) THEN V4645 = .;
   IF (V4646 >= -5 AND V4646 <= -1) THEN V4646 = .;
   IF (V4647 >= -5 AND V4647 <= -1) THEN V4647 = .;
   IF (V4648 >= -5 AND V4648 <= -1) THEN V4648 = .;
   IF (V4649 >= -5 AND V4649 <= -1) THEN V4649 = .;
   IF (V4650 >= -5 AND V4650 <= -1) THEN V4650 = .;
   IF (V4651 >= -5 AND V4651 <= -1) THEN V4651 = .;
   IF (V4652 >= -5 AND V4652 <= -1) THEN V4652 = .;
   IF (V4653 >= -5 AND V4653 <= -1) THEN V4653 = .;
   IF (V4654 >= -5 AND V4654 <= -1) THEN V4654 = .;
   IF (V4655 >= -5 AND V4655 <= -1) THEN V4655 = .;
   IF (V4656 >= -5 AND V4656 <= -1) THEN V4656 = .;
   IF (V4657 >= -5 AND V4657 <= -1) THEN V4657 = .;
   IF (V4658 >= -5 AND V4658 <= -1) THEN V4658 = .;
   IF (V4659 >= -5 AND V4659 <= -1) THEN V4659 = .;
   IF (V4660 >= -5 AND V4660 <= -1) THEN V4660 = .;
   IF (V4661 >= -5 AND V4661 <= -1) THEN V4661 = .;
   IF (V4662 >= -5 AND V4662 <= -1) THEN V4662 = .;
   IF (V4663 >= -5 AND V4663 <= -1) THEN V4663 = .;
   IF (V4664 >= -5 AND V4664 <= -1) THEN V4664 = .;
   IF (V4665 >= -5 AND V4665 <= -1) THEN V4665 = .;
   IF (V4666 >= -5 AND V4666 <= -1) THEN V4666 = .;
   IF (V4667 >= -5 AND V4667 <= -1) THEN V4667 = .;
   IF (V4668 >= -5 AND V4668 <= -1) THEN V4668 = .;
   IF (V4669 >= -5 AND V4669 <= -1) THEN V4669 = .;
   IF (V4670 >= -5 AND V4670 <= -1) THEN V4670 = .;
   IF (V4671 >= -5 AND V4671 <= -1) THEN V4671 = .;
   IF (V4672 >= -5 AND V4672 <= -1) THEN V4672 = .;
   IF (V4673 >= -5 AND V4673 <= -1) THEN V4673 = .;
   IF (V4674 >= -5 AND V4674 <= -1) THEN V4674 = .;
   IF (V4675 >= -5 AND V4675 <= -1) THEN V4675 = .;
   IF (V4676 >= -5 AND V4676 <= -1) THEN V4676 = .;
   IF (V4677 >= -5 AND V4677 <= -1) THEN V4677 = .;
   IF (V4678 >= -5 AND V4678 <= -1) THEN V4678 = .;
   IF (V4679 >= -5 AND V4679 <= -1) THEN V4679 = .;
   IF (V4680 >= -5 AND V4680 <= -1) THEN V4680 = .;
   IF (V4681 >= -5 AND V4681 <= -1) THEN V4681 = .;
   IF (V4682 >= -5 AND V4682 <= -1) THEN V4682 = .;
   IF (V4683 >= -5 AND V4683 <= -1) THEN V4683 = .;
   IF (V4684 >= -5 AND V4684 <= -1) THEN V4684 = .;
   IF (V4685 >= -5 AND V4685 <= -1) THEN V4685 = .;
   IF (V4686 >= -5 AND V4686 <= -1) THEN V4686 = .;
   IF (V4687 >= -5 AND V4687 <= -1) THEN V4687 = .;
   IF (V4688 >= -5 AND V4688 <= -1) THEN V4688 = .;
   IF (V4689 >= -5 AND V4689 <= -1) THEN V4689 = .;
   IF (V4690 >= -5 AND V4690 <= -1) THEN V4690 = .;
   IF (V4691 >= -5 AND V4691 <= -1) THEN V4691 = .;
   IF (V4692 >= -5 AND V4692 <= -1) THEN V4692 = .;
   IF (V4693 >= -5 AND V4693 <= -1) THEN V4693 = .;
   IF (V4694 >= -5 AND V4694 <= -1) THEN V4694 = .;
   IF (V4695 >= -5 AND V4695 <= -1) THEN V4695 = .;
   IF (V4696 >= -5 AND V4696 <= -1) THEN V4696 = .;
   IF (V4697 >= -5 AND V4697 <= -1) THEN V4697 = .;
   IF (V4698 >= -5 AND V4698 <= -1) THEN V4698 = .;
   IF (V4699 >= -5 AND V4699 <= -1) THEN V4699 = .;
   IF (V4700 >= -5 AND V4700 <= -1) THEN V4700 = .;
   IF (V4701 >= -5 AND V4701 <= -1) THEN V4701 = .;
   IF (V4702 >= -5 AND V4702 <= -1) THEN V4702 = .;
   IF (V4703 >= -5 AND V4703 <= -1) THEN V4703 = .;
   IF (V4704 >= -5 AND V4704 <= -1) THEN V4704 = .;
   IF (V4705 >= -5 AND V4705 <= -1) THEN V4705 = .;
   IF (V4706 >= -5 AND V4706 <= -1) THEN V4706 = .;
   IF (V4707 >= -5 AND V4707 <= -1) THEN V4707 = .;
   IF (V4708 >= -5 AND V4708 <= -1) THEN V4708 = .;
   IF (V4709 >= -5 AND V4709 <= -1) THEN V4709 = .;
   IF (V4710 >= -5 AND V4710 <= -1) THEN V4710 = .;
   IF (V4711 >= -5 AND V4711 <= -1) THEN V4711 = .;
   IF (V4712 >= -5 AND V4712 <= -1) THEN V4712 = .;
   IF (V4713 >= -5 AND V4713 <= -1) THEN V4713 = .;
   IF (V4714 >= -5 AND V4714 <= -1) THEN V4714 = .;
   IF (V4715 >= -5 AND V4715 <= -1) THEN V4715 = .;
   IF (V4716 >= -5 AND V4716 <= -1) THEN V4716 = .;
   IF (V4717 >= -5 AND V4717 <= -1) THEN V4717 = .;
   IF (V4718 >= -5 AND V4718 <= -1) THEN V4718 = .;
   IF (V4719 >= -5 AND V4719 <= -1) THEN V4719 = .;
   IF (V4720 >= -5 AND V4720 <= -1) THEN V4720 = .;
   IF (V4721 >= -5 AND V4721 <= -1) THEN V4721 = .;
   IF (V4722 >= -5 AND V4722 <= -1) THEN V4722 = .;
   IF (V4723 >= -5 AND V4723 <= -1) THEN V4723 = .;
   IF (V4724 >= -5 AND V4724 <= -1) THEN V4724 = .;
   IF (V4725 >= -5 AND V4725 <= -1) THEN V4725 = .;
   IF (V4726 >= -5 AND V4726 <= -1) THEN V4726 = .;
   IF (V4727 >= -5 AND V4727 <= -1) THEN V4727 = .;
   IF (V4728 >= -5 AND V4728 <= -1) THEN V4728 = .;
   IF (V4729 >= -5 AND V4729 <= -1) THEN V4729 = .;
   IF (V4730 >= -5 AND V4730 <= -1) THEN V4730 = .;
   IF (V4731 >= -5 AND V4731 <= -1) THEN V4731 = .;
   IF (V4732 >= -5 AND V4732 <= -1) THEN V4732 = .;
   IF (V4733 >= -5 AND V4733 <= -1) THEN V4733 = .;
   IF (V4734 >= -5 AND V4734 <= -1) THEN V4734 = .;
   IF (V4735 >= -5 AND V4735 <= -1) THEN V4735 = .;
   IF (V4736 >= -5 AND V4736 <= -1) THEN V4736 = .;
   IF (V4737 >= -5 AND V4737 <= -1) THEN V4737 = .;
   IF (V4738 >= -5 AND V4738 <= -1) THEN V4738 = .;
   IF (V4739 >= -5 AND V4739 <= -1) THEN V4739 = .;
   IF (V4740 >= -5 AND V4740 <= -1) THEN V4740 = .;
   IF (V4741 >= -5 AND V4741 <= -1) THEN V4741 = .;
   IF (V4742 >= -5 AND V4742 <= -1) THEN V4742 = .;
   IF (V4743 >= -5 AND V4743 <= -1) THEN V4743 = .;
   IF (V4744 >= -5 AND V4744 <= -1) THEN V4744 = .;
   IF (V4745 >= -5 AND V4745 <= -1) THEN V4745 = .;
   IF (V4746 >= -5 AND V4746 <= -1) THEN V4746 = .;
   IF (V4747 >= -5 AND V4747 <= -1) THEN V4747 = .;
   IF (V4748 >= -5 AND V4748 <= -1) THEN V4748 = .;
   IF (V4749 >= -5 AND V4749 <= -1) THEN V4749 = .;
   IF (V4750 >= -5 AND V4750 <= -1) THEN V4750 = .;
   IF (V4751 >= -5 AND V4751 <= -1) THEN V4751 = .;
   IF (V4752 >= -5 AND V4752 <= -1) THEN V4752 = .;
   IF (V4753 >= -5 AND V4753 <= -1) THEN V4753 = .;
   IF (V4754 >= -5 AND V4754 <= -1) THEN V4754 = .;
   IF (V4755 >= -5 AND V4755 <= -1) THEN V4755 = .;
   IF (V4756 >= -5 AND V4756 <= -1) THEN V4756 = .;
   IF (V4757 >= -5 AND V4757 <= -1) THEN V4757 = .;
   IF (V4758 >= -5 AND V4758 <= -1) THEN V4758 = .;
   IF (V4759 >= -5 AND V4759 <= -1) THEN V4759 = .;
   IF (V4764 >= -5 AND V4764 <= -1) THEN V4764 = .;
   IF (V4765 >= -5 AND V4765 <= -1) THEN V4765 = .;
   IF (V4766 >= -5 AND V4766 <= -1) THEN V4766 = .;
   IF (V4767 >= -5 AND V4767 <= -1) THEN V4767 = .;
   IF (V4768 >= -5 AND V4768 <= -1) THEN V4768 = .;
   IF (V4769 >= -5 AND V4769 <= -1) THEN V4769 = .;
   IF (V4770 >= -5 AND V4770 <= -1) THEN V4770 = .;
   IF (V4771 >= -5 AND V4771 <= -1) THEN V4771 = .;
   IF (V4772 >= -5 AND V4772 <= -1) THEN V4772 = .;
   IF (V4773 >= -5 AND V4773 <= -1) THEN V4773 = .;
   IF (V4774 >= -5 AND V4774 <= -1) THEN V4774 = .;
   IF (V4775 >= -5 AND V4775 <= -1) THEN V4775 = .;
   IF (V4776 >= -5 AND V4776 <= -1) THEN V4776 = .;
   IF (V4777 >= -5 AND V4777 <= -1) THEN V4777 = .;
   IF (V4778 >= -5 AND V4778 <= -1) THEN V4778 = .;
   IF (V4779 >= -5 AND V4779 <= -1) THEN V4779 = .;
   IF (V4780 >= -5 AND V4780 <= -1) THEN V4780 = .;
   IF (V4781 >= -5 AND V4781 <= -1) THEN V4781 = .;
   IF (V4782 >= -5 AND V4782 <= -1) THEN V4782 = .;
   IF (V4783 >= -5 AND V4783 <= -1) THEN V4783 = .;
   IF (V4784 >= -5 AND V4784 <= -1) THEN V4784 = .;
   IF (V4785 >= -5 AND V4785 <= -1) THEN V4785 = .;
   IF (V4786 >= -5 AND V4786 <= -1) THEN V4786 = .;
   IF (V4787 >= -5 AND V4787 <= -1) THEN V4787 = .;
   IF (V4788 >= -5 AND V4788 <= -1) THEN V4788 = .;
   IF (V4789 >= -5 AND V4789 <= -1) THEN V4789 = .;
   IF (V4790 >= -5 AND V4790 <= -1) THEN V4790 = .;
   IF (V5004 >= -5 AND V5004 <= -1) THEN V5004 = .;
   IF (V5005 >= -5 AND V5005 <= -1) THEN V5005 = .;
   IF (V5006 >= -5 AND V5006 <= -1) THEN V5006 = .;
   IF (V5007 >= -5 AND V5007 <= -1) THEN V5007 = .;
   IF (V5008 >= -5 AND V5008 <= -1) THEN V5008 = .;
   IF (V5009 >= -5 AND V5009 <= -1) THEN V5009 = .;
   IF (V5010 >= -5 AND V5010 <= -1) THEN V5010 = .;
   IF (V5011 >= -5 AND V5011 <= -1) THEN V5011 = .;
   IF (V5012 >= -5 AND V5012 <= -1) THEN V5012 = .;
   IF (V5013 >= -5 AND V5013 <= -1) THEN V5013 = .;
   IF (V5014 >= -5 AND V5014 <= -1) THEN V5014 = .;
   IF (V5015 >= -5 AND V5015 <= -1) THEN V5015 = .;
   IF (V5016 >= -5 AND V5016 <= -1) THEN V5016 = .;
   IF (V5017 >= -5 AND V5017 <= -1) THEN V5017 = .;
   IF (V5018 >= -5 AND V5018 <= -1) THEN V5018 = .;
   IF (V5019 >= -5 AND V5019 <= -1) THEN V5019 = .;
   IF (V5020 >= -5 AND V5020 <= -1) THEN V5020 = .;
   IF (V5021 >= -5 AND V5021 <= -1) THEN V5021 = .;
   IF (V5022 >= -5 AND V5022 <= -1) THEN V5022 = .;
   IF (V5023 >= -5 AND V5023 <= -1) THEN V5023 = .;
   IF (V5024 >= -5 AND V5024 <= -1) THEN V5024 = .;
   IF (V5025 >= -5 AND V5025 <= -1) THEN V5025 = .;
   IF (V5026 >= -5 AND V5026 <= -1) THEN V5026 = .;
   IF (V5027 >= -5 AND V5027 <= -1) THEN V5027 = .;
   IF (V5028 >= -5 AND V5028 <= -1) THEN V5028 = .;
   IF (V5029 >= -5 AND V5029 <= -1) THEN V5029 = .;
   IF (V5030 >= -5 AND V5030 <= -1) THEN V5030 = .;
   IF (V5031 >= -5 AND V5031 <= -1) THEN V5031 = .;
   IF (V5032 >= -5 AND V5032 <= -1) THEN V5032 = .;
   IF (V5033 >= -5 AND V5033 <= -1) THEN V5033 = .;
   IF (V5034 >= -5 AND V5034 <= -1) THEN V5034 = .;
   IF (V5035 >= -5 AND V5035 <= -1) THEN V5035 = .;
   IF (V5036 >= -5 AND V5036 <= -1) THEN V5036 = .;
   IF (V5037 >= -5 AND V5037 <= -1) THEN V5037 = .;
   IF (V5038 >= -5 AND V5038 <= -1) THEN V5038 = .;
   IF (V5039 >= -5 AND V5039 <= -1) THEN V5039 = .;
   IF (V5040 >= -5 AND V5040 <= -1) THEN V5040 = .;
   IF (V5041 >= -5 AND V5041 <= -1) THEN V5041 = .;
   IF (V5042 >= -5 AND V5042 <= -1) THEN V5042 = .;
   IF (V5043 >= -5 AND V5043 <= -1) THEN V5043 = .;
   IF (V5044 >= -5 AND V5044 <= -1) THEN V5044 = .;
   IF (V5045 >= -5 AND V5045 <= -1) THEN V5045 = .;
   IF (V5046 >= -5 AND V5046 <= -1) THEN V5046 = .;
   IF (V5047 >= -5 AND V5047 <= -1) THEN V5047 = .;
   IF (V5048 >= -5 AND V5048 <= -1) THEN V5048 = .;
   IF (V5049 >= -5 AND V5049 <= -1) THEN V5049 = .;
   IF (V5050 >= -5 AND V5050 <= -1) THEN V5050 = .;
   IF (V5051 >= -5 AND V5051 <= -1) THEN V5051 = .;
   IF (V5052 >= -5 AND V5052 <= -1) THEN V5052 = .;
   IF (V5053 >= -5 AND V5053 <= -1) THEN V5053 = .;
   IF (V5054 >= -5 AND V5054 <= -1) THEN V5054 = .;
   IF (V5055 >= -5 AND V5055 <= -1) THEN V5055 = .;
   IF (V5056 >= -5 AND V5056 <= -1) THEN V5056 = .;
   IF (V5057 >= -5 AND V5057 <= -1) THEN V5057 = .;
   IF (V5058 >= -5 AND V5058 <= -1) THEN V5058 = .;
   IF (V5059 >= -5 AND V5059 <= -1) THEN V5059 = .;
   IF (V5060 >= -5 AND V5060 <= -1) THEN V5060 = .;
   IF (V5061 >= -5 AND V5061 <= -1) THEN V5061 = .;
   IF (V5062 >= -5.00 AND V5062 <= -1.00) THEN V5062 = .;
   IF (V5063 >= -5 AND V5063 <= -1) THEN V5063 = .;
   IF (V5064 >= -5 AND V5064 <= -1) THEN V5064 = .;
   IF (V5065 >= -5.00 AND V5065 <= -1.00) THEN V5065 = .;
   IF (V5066 >= -5 AND V5066 <= -1) THEN V5066 = .;
   IF (V5067 >= -5.00 AND V5067 <= -1.00) THEN V5067 = .;
   IF (V5068 >= -5.00 AND V5068 <= -1.00) THEN V5068 = .;
   IF (V5069 >= -5.00 AND V5069 <= -1.00) THEN V5069 = .;
   IF (V5070 >= -5 AND V5070 <= -1) THEN V5070 = .;
   IF (V5071 >= -5 AND V5071 <= -1) THEN V5071 = .;
   IF (V5072 >= -5 AND V5072 <= -1) THEN V5072 = .;
   IF (V5073 >= -5 AND V5073 <= -1) THEN V5073 = .;
   IF (V5074 >= -5 AND V5074 <= -1) THEN V5074 = .;
   IF (V5075 >= -5 AND V5075 <= -1) THEN V5075 = .;
   IF (V5076 >= -5 AND V5076 <= -1) THEN V5076 = .;
   IF (V5077 >= -5 AND V5077 <= -1) THEN V5077 = .;
   IF (V5078 >= -5 AND V5078 <= -1) THEN V5078 = .;
   IF (V5079 >= -5 AND V5079 <= -1) THEN V5079 = .;
   IF (V5080 >= -5 AND V5080 <= -1) THEN V5080 = .;
   IF (V5081 >= -5 AND V5081 <= -1) THEN V5081 = .;
   IF (V5082 >= -5 AND V5082 <= -1) THEN V5082 = .;
   IF (V5083 >= -5 AND V5083 <= -1) THEN V5083 = .;
   IF (V5084 >= -5 AND V5084 <= -1) THEN V5084 = .;
   IF (V5085 >= -5 AND V5085 <= -1) THEN V5085 = .;
   IF (V5086 >= -5 AND V5086 <= -1) THEN V5086 = .;
   IF (V5087 >= -5 AND V5087 <= -1) THEN V5087 = .;
   IF (V5088 >= -5 AND V5088 <= -1) THEN V5088 = .;
   IF (V5089 >= -5 AND V5089 <= -1) THEN V5089 = .;
   IF (V5090 >= -5 AND V5090 <= -1) THEN V5090 = .;
   IF (V5091 >= -5 AND V5091 <= -1) THEN V5091 = .;
   IF (V5092 >= -5 AND V5092 <= -1) THEN V5092 = .;
   IF (V5093 >= -5 AND V5093 <= -1) THEN V5093 = .;
   IF (V5094 >= -5 AND V5094 <= -1) THEN V5094 = .;
   IF (V5095 >= -5 AND V5095 <= -1) THEN V5095 = .;
   IF (V5096 >= -5 AND V5096 <= -1) THEN V5096 = .;
   IF (V5097 >= -5 AND V5097 <= -1) THEN V5097 = .;
   IF (V5098 >= -5 AND V5098 <= -1) THEN V5098 = .;
   IF (V5099 >= -5 AND V5099 <= -1) THEN V5099 = .;
   IF (V5100 >= -5 AND V5100 <= -1) THEN V5100 = .;
   IF (V5101 >= -5 AND V5101 <= -1) THEN V5101 = .;
   IF (V5102 >= -5 AND V5102 <= -1) THEN V5102 = .;
   IF (V5103 >= -5 AND V5103 <= -1) THEN V5103 = .;
   IF (V5104 >= -5 AND V5104 <= -1) THEN V5104 = .;
   IF (V5105 >= -5 AND V5105 <= -1) THEN V5105 = .;
   IF (V5106 >= -5 AND V5106 <= -1) THEN V5106 = .;
   IF (V5107 >= -5 AND V5107 <= -1) THEN V5107 = .;
   IF (V5108 >= -5 AND V5108 <= -1) THEN V5108 = .;
   IF (V5109 >= -5 AND V5109 <= -1) THEN V5109 = .;
   IF (V5110 >= -5 AND V5110 <= -1) THEN V5110 = .;
   IF (V5111 >= -5 AND V5111 <= -1) THEN V5111 = .;
   IF (V5112 >= -5 AND V5112 <= -1) THEN V5112 = .;
   IF (V5113 >= -5 AND V5113 <= -1) THEN V5113 = .;
   IF (V5114 >= -5 AND V5114 <= -1) THEN V5114 = .;
   IF (V5115 >= -5 AND V5115 <= -1) THEN V5115 = .;
   IF (V5116 >= -5 AND V5116 <= -1) THEN V5116 = .;
   IF (V5117 >= -5 AND V5117 <= -1) THEN V5117 = .;
   IF (V5118 >= -5 AND V5118 <= -1) THEN V5118 = .;
   IF (V5119 >= -5 AND V5119 <= -1) THEN V5119 = .;
   IF (V5120 >= -5 AND V5120 <= -1) THEN V5120 = .;
   IF (V5121 >= -5 AND V5121 <= -1) THEN V5121 = .;
   IF (V5122 >= -5 AND V5122 <= -1) THEN V5122 = .;
   IF (V5123 >= -5 AND V5123 <= -1) THEN V5123 = .;
   IF (V5124 >= -5 AND V5124 <= -1) THEN V5124 = .;
   IF (V5125 >= -5 AND V5125 <= -1) THEN V5125 = .;
   IF (V5126 >= -5 AND V5126 <= -1) THEN V5126 = .;
   IF (V5127 >= -5 AND V5127 <= -1) THEN V5127 = .;
   IF (V5128 >= -5 AND V5128 <= -1) THEN V5128 = .;
   IF (V5129 >= -5 AND V5129 <= -1) THEN V5129 = .;
   IF (V5130 >= -5 AND V5130 <= -1) THEN V5130 = .;
   IF (V5131 >= -5 AND V5131 <= -1) THEN V5131 = .;
   IF (V5132 >= -5 AND V5132 <= -1) THEN V5132 = .;
   IF (V5133 >= -5 AND V5133 <= -1) THEN V5133 = .;
   IF (V5134 >= -5 AND V5134 <= -1) THEN V5134 = .;
   IF (V5135 >= -5 AND V5135 <= -1) THEN V5135 = .;
   IF (V5136 >= -5 AND V5136 <= -1) THEN V5136 = .;
   IF (V5137 >= -5 AND V5137 <= -1) THEN V5137 = .;
   IF (V5138 >= -5 AND V5138 <= -1) THEN V5138 = .;
   IF (V5139 >= -5 AND V5139 <= -1) THEN V5139 = .;
   IF (V5140 >= -5 AND V5140 <= -1) THEN V5140 = .;
   IF (V5141 >= -5 AND V5141 <= -1) THEN V5141 = .;
   IF (V5142 >= -5 AND V5142 <= -1) THEN V5142 = .;
   IF (V5143 >= -5 AND V5143 <= -1) THEN V5143 = .;
   IF (V5144 >= -5 AND V5144 <= -1) THEN V5144 = .;
   IF (V5145 >= -5 AND V5145 <= -1) THEN V5145 = .;
   IF (V5146 >= -5 AND V5146 <= -1) THEN V5146 = .;
   IF (V5147 >= -5 AND V5147 <= -1) THEN V5147 = .;
   IF (V5148 >= -5 AND V5148 <= -1) THEN V5148 = .;
   IF (V5149 >= -5 AND V5149 <= -1) THEN V5149 = .;
   IF (V5150 >= -5 AND V5150 <= -1) THEN V5150 = .;
   IF (V5151 >= -5 AND V5151 <= -1) THEN V5151 = .;
   IF (V5152 >= -5 AND V5152 <= -1) THEN V5152 = .;
   IF (V5153 >= -5 AND V5153 <= -1) THEN V5153 = .;
   IF (V5154 >= -5 AND V5154 <= -1) THEN V5154 = .;
   IF (V5155 >= -5 AND V5155 <= -1) THEN V5155 = .;
   IF (V5156 >= -5 AND V5156 <= -1) THEN V5156 = .;
   IF (V5157 >= -5 AND V5157 <= -1) THEN V5157 = .;
   IF (V5158 >= -5 AND V5158 <= -1) THEN V5158 = .;
   IF (V5159 >= -5 AND V5159 <= -1) THEN V5159 = .;
   IF (V5160 >= -5 AND V5160 <= -1) THEN V5160 = .;
   IF (V5161 >= -5 AND V5161 <= -1) THEN V5161 = .;
   IF (V5162 >= -5 AND V5162 <= -1) THEN V5162 = .;
   IF (V5163 >= -5 AND V5163 <= -1) THEN V5163 = .;
   IF (V5164 >= -5 AND V5164 <= -1) THEN V5164 = .;
   IF (V5165 >= -5 AND V5165 <= -1) THEN V5165 = .;
   IF (V5166 >= -5 AND V5166 <= -1) THEN V5166 = .;
   IF (V5167 >= -5 AND V5167 <= -1) THEN V5167 = .;
   IF (V5168 >= -5 AND V5168 <= -1) THEN V5168 = .;
   IF (V5169 >= -5 AND V5169 <= -1) THEN V5169 = .;
   IF (V5170 >= -5 AND V5170 <= -1) THEN V5170 = .;
   IF (V5171 >= -5 AND V5171 <= -1) THEN V5171 = .;
   IF (V5172 >= -5 AND V5172 <= -1) THEN V5172 = .;
   IF (V5173 >= -5 AND V5173 <= -1) THEN V5173 = .;
   IF (V5174 >= -5 AND V5174 <= -1) THEN V5174 = .;
   IF (V5175 >= -5 AND V5175 <= -1) THEN V5175 = .;
   IF (V5176 >= -5 AND V5176 <= -1) THEN V5176 = .;
   IF (V5177 >= -5 AND V5177 <= -1) THEN V5177 = .;
   IF (V5178 >= -5 AND V5178 <= -1) THEN V5178 = .;
   IF (V5179 >= -5 AND V5179 <= -1) THEN V5179 = .;
   IF (V5180 >= -5 AND V5180 <= -1) THEN V5180 = .;
   IF (V5181 >= -5 AND V5181 <= -1) THEN V5181 = .;
   IF (V5182 >= -5 AND V5182 <= -1) THEN V5182 = .;
   IF (V5183 >= -5 AND V5183 <= -1) THEN V5183 = .;
   IF (V5184 >= -5 AND V5184 <= -1) THEN V5184 = .;
   IF (V5185 >= -5 AND V5185 <= -1) THEN V5185 = .;
   IF (V5186 >= -5 AND V5186 <= -1) THEN V5186 = .;
   IF (V5187 >= -5 AND V5187 <= -1) THEN V5187 = .;
   IF (V5188 >= -5 AND V5188 <= -1) THEN V5188 = .;
   IF (V5189 >= -5 AND V5189 <= -1) THEN V5189 = .;
   IF (V5190 >= -5 AND V5190 <= -1) THEN V5190 = .;
   IF (V5191 >= -5 AND V5191 <= -1) THEN V5191 = .;
   IF (V5192 >= -5 AND V5192 <= -1) THEN V5192 = .;
   IF (V5193 >= -5 AND V5193 <= -1) THEN V5193 = .;
   IF (V5194 >= -5 AND V5194 <= -1) THEN V5194 = .;
   IF (V5195 >= -5 AND V5195 <= -1) THEN V5195 = .;
   IF (V5196 >= -5 AND V5196 <= -1) THEN V5196 = .;
   IF (V5197 >= -5 AND V5197 <= -1) THEN V5197 = .;
   IF (V5198 >= -5 AND V5198 <= -1) THEN V5198 = .;
   IF (V5199 >= -5 AND V5199 <= -1) THEN V5199 = .;
   IF (V5200 >= -5 AND V5200 <= -1) THEN V5200 = .;
   IF (V5201 >= -5 AND V5201 <= -1) THEN V5201 = .;
   IF (V5202 >= -5 AND V5202 <= -1) THEN V5202 = .;
   IF (V5203 >= -5 AND V5203 <= -1) THEN V5203 = .;
   IF (V5204 >= -5 AND V5204 <= -1) THEN V5204 = .;
   IF (V5205 >= -5 AND V5205 <= -1) THEN V5205 = .;
   IF (V5206 >= -5 AND V5206 <= -1) THEN V5206 = .;
   IF (V5207 >= -5 AND V5207 <= -1) THEN V5207 = .;
   IF (V5208 >= -5 AND V5208 <= -1) THEN V5208 = .;
   IF (V5209 >= -5 AND V5209 <= -1) THEN V5209 = .;
   IF (V5210 >= -5 AND V5210 <= -1) THEN V5210 = .;
   IF (V5211 >= -5 AND V5211 <= -1) THEN V5211 = .;
   IF (V5212 >= -5 AND V5212 <= -1) THEN V5212 = .;
   IF (V5213 >= -5 AND V5213 <= -1) THEN V5213 = .;
   IF (V5214 >= -5 AND V5214 <= -1) THEN V5214 = .;
   IF (V5215 >= -5 AND V5215 <= -1) THEN V5215 = .;
   IF (V5216 >= -5 AND V5216 <= -1) THEN V5216 = .;
   IF (V5217 >= -5 AND V5217 <= -1) THEN V5217 = .;
   IF (V5218 >= -5 AND V5218 <= -1) THEN V5218 = .;
   IF (V5219 >= -5 AND V5219 <= -1) THEN V5219 = .;
   IF (V5220 >= -5 AND V5220 <= -1) THEN V5220 = .;
   IF (V5221 >= -5 AND V5221 <= -1) THEN V5221 = .;
   IF (V5222 >= -5 AND V5222 <= -1) THEN V5222 = .;
   IF (V5223 >= -5 AND V5223 <= -1) THEN V5223 = .;
   IF (V5224 >= -5 AND V5224 <= -1) THEN V5224 = .;
   IF (V5225 >= -5 AND V5225 <= -1) THEN V5225 = .;
   IF (V5226 >= -5 AND V5226 <= -1) THEN V5226 = .;
   IF (V5227 >= -5 AND V5227 <= -1) THEN V5227 = .;
   IF (V5228 >= -5 AND V5228 <= -1) THEN V5228 = .;
   IF (V5229 >= -5 AND V5229 <= -1) THEN V5229 = .;
   IF (V5230 >= -5 AND V5230 <= -1) THEN V5230 = .;
   IF (V5231 >= -5 AND V5231 <= -1) THEN V5231 = .;
   IF (V5232 >= -5 AND V5232 <= -1) THEN V5232 = .;
   IF (V5233 >= -5 AND V5233 <= -1) THEN V5233 = .;
   IF (V5234 >= -5 AND V5234 <= -1) THEN V5234 = .;
   IF (V5235 >= -5 AND V5235 <= -1) THEN V5235 = .;
   IF (V5236 >= -5 AND V5236 <= -1) THEN V5236 = .;
   IF (V5237 >= -5 AND V5237 <= -1) THEN V5237 = .;
   IF (V5238 >= -5 AND V5238 <= -1) THEN V5238 = .;
   IF (V5239 >= -5 AND V5239 <= -1) THEN V5239 = .;
   IF (V5240 >= -5 AND V5240 <= -1) THEN V5240 = .;
   IF (V5241 >= -5 AND V5241 <= -1) THEN V5241 = .;
   IF (V5242 >= -5 AND V5242 <= -1) THEN V5242 = .;
   IF (V5243 >= -5 AND V5243 <= -1) THEN V5243 = .;
   IF (V5244 >= -5 AND V5244 <= -1) THEN V5244 = .;
   IF (V5245 >= -5 AND V5245 <= -1) THEN V5245 = .;
   IF (V5246 >= -5 AND V5246 <= -1) THEN V5246 = .;
   IF (V5247 >= -5 AND V5247 <= -1) THEN V5247 = .;
   IF (V5248 >= -5 AND V5248 <= -1) THEN V5248 = .;
   IF (V5249 >= -5 AND V5249 <= -1) THEN V5249 = .;
   IF (V5250 >= -5 AND V5250 <= -1) THEN V5250 = .;
   IF (V5251 >= -5 AND V5251 <= -1) THEN V5251 = .;
   IF (V5252 >= -5 AND V5252 <= -1) THEN V5252 = .;
   IF (V5253 >= -5 AND V5253 <= -1) THEN V5253 = .;
   IF (V5254 >= -5 AND V5254 <= -1) THEN V5254 = .;
   IF (V5255 >= -5 AND V5255 <= -1) THEN V5255 = .;
   IF (V5256 >= -5 AND V5256 <= -1) THEN V5256 = .;
   IF (V5257 >= -5 AND V5257 <= -1) THEN V5257 = .;
   IF (V5258 >= -5 AND V5258 <= -1) THEN V5258 = .;
   IF (V5259 >= -5 AND V5259 <= -1) THEN V5259 = .;
   IF (V5260 >= -5 AND V5260 <= -1) THEN V5260 = .;
   IF (V5261 >= -5 AND V5261 <= -1) THEN V5261 = .;
   IF (V5262 >= -5 AND V5262 <= -1) THEN V5262 = .;
   IF (V5263 >= -5 AND V5263 <= -1) THEN V5263 = .;
   IF (V5264 >= -5 AND V5264 <= -1) THEN V5264 = .;
   IF (V5265 >= -5 AND V5265 <= -1) THEN V5265 = .;
   IF (V5266 >= -5 AND V5266 <= -1) THEN V5266 = .;
   IF (V5267 >= -5 AND V5267 <= -1) THEN V5267 = .;
   IF (V5268 >= -5 AND V5268 <= -1) THEN V5268 = .;
   IF (V5269 >= -5 AND V5269 <= -1) THEN V5269 = .;
   IF (V5270 >= -5 AND V5270 <= -1) THEN V5270 = .;
   IF (V5271 >= -5 AND V5271 <= -1) THEN V5271 = .;
   IF (V5272 >= -5 AND V5272 <= -1) THEN V5272 = .;
   IF (V5273 >= -5 AND V5273 <= -1) THEN V5273 = .;
   IF (V5274 >= -5 AND V5274 <= -1) THEN V5274 = .;
   IF (V5275 >= -5 AND V5275 <= -1) THEN V5275 = .;
   IF (V5276 >= -5 AND V5276 <= -1) THEN V5276 = .;
   IF (V5277 >= -5 AND V5277 <= -1) THEN V5277 = .;
   IF (V5278 >= -5 AND V5278 <= -1) THEN V5278 = .;
   IF (V5279 >= -5 AND V5279 <= -1) THEN V5279 = .;
   IF (V5280 >= -5 AND V5280 <= -1) THEN V5280 = .;
   IF (V5281 >= -5 AND V5281 <= -1) THEN V5281 = .;
   IF (V5282 >= -5 AND V5282 <= -1) THEN V5282 = .;
   IF (V5283 >= -5 AND V5283 <= -1) THEN V5283 = .;
   IF (V5284 >= -5 AND V5284 <= -1) THEN V5284 = .;
   IF (V5285 >= -5 AND V5285 <= -1) THEN V5285 = .;
   IF (V5286 >= -5 AND V5286 <= -1) THEN V5286 = .;
   IF (V5287 >= -5 AND V5287 <= -1) THEN V5287 = .;
   IF (V5288 >= -5 AND V5288 <= -1) THEN V5288 = .;
   IF (V5289 >= -5 AND V5289 <= -1) THEN V5289 = .;
   IF (V5290 >= -5 AND V5290 <= -1) THEN V5290 = .;
   IF (V5291 >= -5 AND V5291 <= -1) THEN V5291 = .;
   IF (V5292 >= -5 AND V5292 <= -1) THEN V5292 = .;
   IF (V5293 >= -5 AND V5293 <= -1) THEN V5293 = .;
   IF (V5294 >= -5 AND V5294 <= -1) THEN V5294 = .;
   IF (V5295 >= -5 AND V5295 <= -1) THEN V5295 = .;
   IF (V5296 >= -5 AND V5296 <= -1) THEN V5296 = .;
   IF (V5297 >= -5 AND V5297 <= -1) THEN V5297 = .;
   IF (V5298 >= -5 AND V5298 <= -1) THEN V5298 = .;
   IF (V5299 >= -5 AND V5299 <= -1) THEN V5299 = .;
   IF (V5300 >= -5 AND V5300 <= -1) THEN V5300 = .;
   IF (V5301 >= -5 AND V5301 <= -1) THEN V5301 = .;
   IF (V5302 >= -5 AND V5302 <= -1) THEN V5302 = .;
   IF (V5303 >= -5 AND V5303 <= -1) THEN V5303 = .;
   IF (V5304 >= -5 AND V5304 <= -1) THEN V5304 = .;
   IF (V5305 >= -5 AND V5305 <= -1) THEN V5305 = .;
   IF (V5306 >= -5 AND V5306 <= -1) THEN V5306 = .;
   IF (V5307 >= -5 AND V5307 <= -1) THEN V5307 = .;
   IF (V5308 >= -5 AND V5308 <= -1) THEN V5308 = .;
   IF (V5309 >= -5 AND V5309 <= -1) THEN V5309 = .;
   IF (V5310 >= -5 AND V5310 <= -1) THEN V5310 = .;
   IF (V5311 >= -5 AND V5311 <= -1) THEN V5311 = .;
   IF (V5312 >= -5 AND V5312 <= -1) THEN V5312 = .;
   IF (V5313 >= -5 AND V5313 <= -1) THEN V5313 = .;
   IF (V5314 >= -5 AND V5314 <= -1) THEN V5314 = .;
   IF (V5315 >= -5 AND V5315 <= -1) THEN V5315 = .;
   IF (V5316 >= -5 AND V5316 <= -1) THEN V5316 = .;
   IF (V5317 >= -5 AND V5317 <= -1) THEN V5317 = .;
   IF (V5318 >= -5 AND V5318 <= -1) THEN V5318 = .;
   IF (V5319 >= -5 AND V5319 <= -1) THEN V5319 = .;
   IF (V5320 >= -5 AND V5320 <= -1) THEN V5320 = .;
   IF (V5321 >= -5 AND V5321 <= -1) THEN V5321 = .;
   IF (V5322 >= -5 AND V5322 <= -1) THEN V5322 = .;
   IF (V5323 >= -5 AND V5323 <= -1) THEN V5323 = .;
   IF (V5324 >= -5 AND V5324 <= -1) THEN V5324 = .;
   IF (V5325 >= -5 AND V5325 <= -1) THEN V5325 = .;
   IF (V5326 >= -5 AND V5326 <= -1) THEN V5326 = .;
   IF (V5327 >= -5 AND V5327 <= -1) THEN V5327 = .;
   IF (V5328 >= -5 AND V5328 <= -1) THEN V5328 = .;
   IF (V5329 >= -5 AND V5329 <= -1) THEN V5329 = .;
   IF (V5330 >= -5 AND V5330 <= -1) THEN V5330 = .;
   IF (V5331 >= -5 AND V5331 <= -1) THEN V5331 = .;
   IF (V5332 >= -5 AND V5332 <= -1) THEN V5332 = .;
   IF (V5333 >= -5 AND V5333 <= -1) THEN V5333 = .;
   IF (V5334 >= -5 AND V5334 <= -1) THEN V5334 = .;
   IF (V5335 >= -5 AND V5335 <= -1) THEN V5335 = .;
   IF (V5336 >= -5 AND V5336 <= -1) THEN V5336 = .;
   IF (V5337 >= -5 AND V5337 <= -1) THEN V5337 = .;
   IF (V5338 >= -5 AND V5338 <= -1) THEN V5338 = .;
   IF (V5339 >= -5 AND V5339 <= -1) THEN V5339 = .;
   IF (V5340 >= -5 AND V5340 <= -1) THEN V5340 = .;
   IF (V5341 >= -5 AND V5341 <= -1) THEN V5341 = .;
   IF (V5342 >= -5 AND V5342 <= -1) THEN V5342 = .;
   IF (V5343 >= -5 AND V5343 <= -1) THEN V5343 = .;
   IF (V5344 >= -5 AND V5344 <= -1) THEN V5344 = .;
   IF (V5345 >= -5 AND V5345 <= -1) THEN V5345 = .;
   IF (V5346 >= -5 AND V5346 <= -1) THEN V5346 = .;
   IF (V5347 >= -5 AND V5347 <= -1) THEN V5347 = .;
   IF (V5348 >= -5 AND V5348 <= -1) THEN V5348 = .;
   IF (V5349 >= -5 AND V5349 <= -1) THEN V5349 = .;
   IF (V5350 >= -5 AND V5350 <= -1) THEN V5350 = .;
   IF (V5351 >= -5 AND V5351 <= -1) THEN V5351 = .;
   IF (V5352 >= -5 AND V5352 <= -1) THEN V5352 = .;
   IF (V5353 >= -5 AND V5353 <= -1) THEN V5353 = .;
   IF (V5354 >= -5 AND V5354 <= -1) THEN V5354 = .;
   IF (V5355 >= -5 AND V5355 <= -1) THEN V5355 = .;
   IF (V5356 >= -5 AND V5356 <= -1) THEN V5356 = .;
   IF (V5357 >= -5 AND V5357 <= -1) THEN V5357 = .;
   IF (V5358 >= -5 AND V5358 <= -1) THEN V5358 = .;
   IF (V5359 >= -5 AND V5359 <= -1) THEN V5359 = .;
   IF (V5360 >= -5 AND V5360 <= -1) THEN V5360 = .;
   IF (V5361 >= -5 AND V5361 <= -1) THEN V5361 = .;
   IF (V5362 >= -5 AND V5362 <= -1) THEN V5362 = .;
   IF (V5363 >= -5 AND V5363 <= -1) THEN V5363 = .;
   IF (V5364 >= -5 AND V5364 <= -1) THEN V5364 = .;
   IF (V5365 >= -5 AND V5365 <= -1) THEN V5365 = .;
   IF (V5366 >= -5 AND V5366 <= -1) THEN V5366 = .;
   IF (V5367 >= -5 AND V5367 <= -1) THEN V5367 = .;
   IF (V5368 >= -5 AND V5368 <= -1) THEN V5368 = .;
   IF (V5369 >= -5 AND V5369 <= -1) THEN V5369 = .;
   IF (V5370 >= -5 AND V5370 <= -1) THEN V5370 = .;
   IF (V5371 >= -5 AND V5371 <= -1) THEN V5371 = .;
   IF (V5372 >= -5 AND V5372 <= -1) THEN V5372 = .;
   IF (V5373 >= -5 AND V5373 <= -1) THEN V5373 = .;
   IF (V5374 >= -5 AND V5374 <= -1) THEN V5374 = .;
   IF (V5375 >= -5 AND V5375 <= -1) THEN V5375 = .;
   IF (V5376 >= -5 AND V5376 <= -1) THEN V5376 = .;
   IF (V5377 >= -5 AND V5377 <= -1) THEN V5377 = .;
   IF (V5378 >= -5 AND V5378 <= -1) THEN V5378 = .;
   IF (V5379 >= -5 AND V5379 <= -1) THEN V5379 = .;
   IF (V5380 >= -5 AND V5380 <= -1) THEN V5380 = .;
   IF (V5381 >= -5 AND V5381 <= -1) THEN V5381 = .;
   IF (V5382 >= -5 AND V5382 <= -1) THEN V5382 = .;
   IF (V5383 >= -5 AND V5383 <= -1) THEN V5383 = .;
   IF (V5384 >= -5 AND V5384 <= -1) THEN V5384 = .;
   IF (V5385 >= -5 AND V5385 <= -1) THEN V5385 = .;
   IF (V5386 >= -5 AND V5386 <= -1) THEN V5386 = .;
   IF (V5387 >= -5 AND V5387 <= -1) THEN V5387 = .;
   IF (V5388 >= -5 AND V5388 <= -1) THEN V5388 = .;
   IF (V5389 >= -5 AND V5389 <= -1) THEN V5389 = .;
   IF (V5390 >= -5 AND V5390 <= -1) THEN V5390 = .;
   IF (V5391 >= -5 AND V5391 <= -1) THEN V5391 = .;
   IF (V5392 >= -5 AND V5392 <= -1) THEN V5392 = .;
   IF (V5393 >= -5 AND V5393 <= -1) THEN V5393 = .;
   IF (V5394 >= -5 AND V5394 <= -1) THEN V5394 = .;
   IF (V5395 >= -5 AND V5395 <= -1) THEN V5395 = .;
   IF (V5396 >= -5 AND V5396 <= -1) THEN V5396 = .;
   IF (V5397 >= -5 AND V5397 <= -1) THEN V5397 = .;
   IF (V5398 >= -5 AND V5398 <= -1) THEN V5398 = .;
   IF (V5399 >= -5 AND V5399 <= -1) THEN V5399 = .;
   IF (V5400 >= -5 AND V5400 <= -1) THEN V5400 = .;
   IF (V5401 >= -5 AND V5401 <= -1) THEN V5401 = .;
   IF (V5402 >= -5 AND V5402 <= -1) THEN V5402 = .;
   IF (V5403 >= -5 AND V5403 <= -1) THEN V5403 = .;
   IF (V5404 >= -5 AND V5404 <= -1) THEN V5404 = .;
   IF (V5405 >= -5 AND V5405 <= -1) THEN V5405 = .;
   IF (V5406 >= -5 AND V5406 <= -1) THEN V5406 = .;
   IF (V5407 >= -5 AND V5407 <= -1) THEN V5407 = .;
   IF (V5408 >= -5 AND V5408 <= -1) THEN V5408 = .;
   IF (V5409 >= -5 AND V5409 <= -1) THEN V5409 = .;
   IF (V5410 >= -5 AND V5410 <= -1) THEN V5410 = .;
   IF (V5411 >= -5 AND V5411 <= -1) THEN V5411 = .;
   IF (V5412 >= -5 AND V5412 <= -1) THEN V5412 = .;
   IF (V5413 >= -5 AND V5413 <= -1) THEN V5413 = .;
   IF (V5414 >= -5 AND V5414 <= -1) THEN V5414 = .;
   IF (V5415 >= -5 AND V5415 <= -1) THEN V5415 = .;
   IF (V5416 >= -5 AND V5416 <= -1) THEN V5416 = .;
   IF (V5417 >= -5 AND V5417 <= -1) THEN V5417 = .;
   IF (V5418 >= -5 AND V5418 <= -1) THEN V5418 = .;
   IF (V5419 >= -5 AND V5419 <= -1) THEN V5419 = .;
   IF (V5420 >= -5 AND V5420 <= -1) THEN V5420 = .;
   IF (V5421 >= -5 AND V5421 <= -1) THEN V5421 = .;
   IF (V5422 >= -5 AND V5422 <= -1) THEN V5422 = .;
   IF (V5423 >= -5 AND V5423 <= -1) THEN V5423 = .;
   IF (V5424 >= -5 AND V5424 <= -1) THEN V5424 = .;
   IF (V5425 >= -5 AND V5425 <= -1) THEN V5425 = .;
   IF (V5426 >= -5 AND V5426 <= -1) THEN V5426 = .;
   IF (V5427 >= -5 AND V5427 <= -1) THEN V5427 = .;
   IF (V5428 >= -5 AND V5428 <= -1) THEN V5428 = .;
   IF (V5429 >= -5 AND V5429 <= -1) THEN V5429 = .;
   IF (V5430 >= -5 AND V5430 <= -1) THEN V5430 = .;
   IF (V5431 >= -5 AND V5431 <= -1) THEN V5431 = .;
   IF (V5432 >= -5 AND V5432 <= -1) THEN V5432 = .;
   IF (V5433 >= -5 AND V5433 <= -1) THEN V5433 = .;
   IF (V5434 >= -5 AND V5434 <= -1) THEN V5434 = .;
   IF (V5435 >= -5 AND V5435 <= -1) THEN V5435 = .;
   IF (V5436 >= -5 AND V5436 <= -1) THEN V5436 = .;
   IF (V5437 >= -5 AND V5437 <= -1) THEN V5437 = .;
   IF (V5438 >= -5 AND V5438 <= -1) THEN V5438 = .;
   IF (V5439 >= -5 AND V5439 <= -1) THEN V5439 = .;
   IF (V5440 >= -5 AND V5440 <= -1) THEN V5440 = .;
   IF (V5441 >= -5 AND V5441 <= -1) THEN V5441 = .;
   IF (V5442 >= -5 AND V5442 <= -1) THEN V5442 = .;
   IF (V5443 >= -5 AND V5443 <= -1) THEN V5443 = .;
   IF (V5444 >= -5 AND V5444 <= -1) THEN V5444 = .;
   IF (V5445 >= -5 AND V5445 <= -1) THEN V5445 = .;
   IF (V5446 >= -5 AND V5446 <= -1) THEN V5446 = .;
   IF (V5447 >= -5 AND V5447 <= -1) THEN V5447 = .;
   IF (V5448 >= -5 AND V5448 <= -1) THEN V5448 = .;
   IF (V5449 >= -5 AND V5449 <= -1) THEN V5449 = .;
   IF (V5450 >= -5 AND V5450 <= -1) THEN V5450 = .;
   IF (V5451 >= -5 AND V5451 <= -1) THEN V5451 = .;
   IF (V5452 >= -5 AND V5452 <= -1) THEN V5452 = .;
   IF (V5453 >= -5 AND V5453 <= -1) THEN V5453 = .;
   IF (V5454 >= -5 AND V5454 <= -1) THEN V5454 = .;
   IF (V5455 >= -5 AND V5455 <= -1) THEN V5455 = .;
   IF (V5456 >= -5 AND V5456 <= -1) THEN V5456 = .;
   IF (V5457 >= -5 AND V5457 <= -1) THEN V5457 = .;
   IF (V5458 >= -5 AND V5458 <= -1) THEN V5458 = .;
   IF (V5459 >= -5 AND V5459 <= -1) THEN V5459 = .;
   IF (V5460 >= -5 AND V5460 <= -1) THEN V5460 = .;
   IF (V5461 >= -5 AND V5461 <= -1) THEN V5461 = .;
   IF (V5462 >= -5 AND V5462 <= -1) THEN V5462 = .;
   IF (V5463 >= -5 AND V5463 <= -1) THEN V5463 = .;
   IF (V5464 >= -5 AND V5464 <= -1) THEN V5464 = .;
   IF (V5465 >= -5 AND V5465 <= -1) THEN V5465 = .;
   IF (V5466 >= -5 AND V5466 <= -1) THEN V5466 = .;
   IF (V5467 >= -5 AND V5467 <= -1) THEN V5467 = .;
   IF (V5468 >= -5 AND V5468 <= -1) THEN V5468 = .;
   IF (V5469 >= -5 AND V5469 <= -1) THEN V5469 = .;
   IF (V5470 >= -5 AND V5470 <= -1) THEN V5470 = .;
   IF (V5471 >= -5 AND V5471 <= -1) THEN V5471 = .;
   IF (V5472 >= -5 AND V5472 <= -1) THEN V5472 = .;
   IF (V5473 >= -5 AND V5473 <= -1) THEN V5473 = .;
   IF (V5474 >= -5 AND V5474 <= -1) THEN V5474 = .;
   IF (V5475 >= -5 AND V5475 <= -1) THEN V5475 = .;
   IF (V5476 >= -5 AND V5476 <= -1) THEN V5476 = .;
   IF (V5477 >= -5 AND V5477 <= -1) THEN V5477 = .;
   IF (V5478 >= -5 AND V5478 <= -1) THEN V5478 = .;
   IF (V5479 >= -5 AND V5479 <= -1) THEN V5479 = .;
   IF (V5480 >= -5 AND V5480 <= -1) THEN V5480 = .;
   IF (V5481 >= -5 AND V5481 <= -1) THEN V5481 = .;
   IF (V5482 >= -5 AND V5482 <= -1) THEN V5482 = .;
   IF (V5483 >= -5 AND V5483 <= -1) THEN V5483 = .;
   IF (V5484 >= -5 AND V5484 <= -1) THEN V5484 = .;
   IF (V5485 >= -5 AND V5485 <= -1) THEN V5485 = .;
   IF (V5486 >= -5 AND V5486 <= -1) THEN V5486 = .;
   IF (V5487 >= -5 AND V5487 <= -1) THEN V5487 = .;
   IF (V5488 >= -5 AND V5488 <= -1) THEN V5488 = .;
   IF (V5489 >= -5 AND V5489 <= -1) THEN V5489 = .;
   IF (V5490 >= -5 AND V5490 <= -1) THEN V5490 = .;
   IF (V5491 >= -5 AND V5491 <= -1) THEN V5491 = .;
   IF (V5492 >= -5 AND V5492 <= -1) THEN V5492 = .;
   IF (V5493 >= -5 AND V5493 <= -1) THEN V5493 = .;
   IF (V5494 >= -5 AND V5494 <= -1) THEN V5494 = .;
   IF (V5495 >= -5 AND V5495 <= -1) THEN V5495 = .;
   IF (V5496 >= -5 AND V5496 <= -1) THEN V5496 = .;
   IF (V5497 >= -5 AND V5497 <= -1) THEN V5497 = .;
   IF (V5498 >= -5 AND V5498 <= -1) THEN V5498 = .;
   IF (V5499 >= -5 AND V5499 <= -1) THEN V5499 = .;
   IF (V5500 >= -5 AND V5500 <= -1) THEN V5500 = .;
   IF (V5501 >= -5 AND V5501 <= -1) THEN V5501 = .;
   IF (V5502 >= -5 AND V5502 <= -1) THEN V5502 = .;
   IF (V5503 >= -5 AND V5503 <= -1) THEN V5503 = .;
   IF (V5504 >= -5 AND V5504 <= -1) THEN V5504 = .;
   IF (V5505 >= -5 AND V5505 <= -1) THEN V5505 = .;
   IF (V5506 >= -5 AND V5506 <= -1) THEN V5506 = .;
   IF (V5507 >= -5 AND V5507 <= -1) THEN V5507 = .;
   IF (V5508 >= -5 AND V5508 <= -1) THEN V5508 = .;
   IF (V5509 >= -5 AND V5509 <= -1) THEN V5509 = .;
   IF (V5510 >= -5 AND V5510 <= -1) THEN V5510 = .;
   IF (V5511 >= -5 AND V5511 <= -1) THEN V5511 = .;
   IF (V5512 >= -5 AND V5512 <= -1) THEN V5512 = .;
   IF (V5513 >= -5 AND V5513 <= -1) THEN V5513 = .;
   IF (V5514 >= -5 AND V5514 <= -1) THEN V5514 = .;
   IF (V5515 >= -5 AND V5515 <= -1) THEN V5515 = .;
   IF (V5516 >= -5 AND V5516 <= -1) THEN V5516 = .;
   IF (V5517 >= -5 AND V5517 <= -1) THEN V5517 = .;
   IF (V5518 >= -5 AND V5518 <= -1) THEN V5518 = .;
   IF (V5519 >= -5 AND V5519 <= -1) THEN V5519 = .;
   IF (V5520 >= -5 AND V5520 <= -1) THEN V5520 = .;
   IF (V5521 >= -5 AND V5521 <= -1) THEN V5521 = .;
   IF (V5522 >= -5 AND V5522 <= -1) THEN V5522 = .;
   IF (V5523 >= -5 AND V5523 <= -1) THEN V5523 = .;
   IF (V5524 >= -5 AND V5524 <= -1) THEN V5524 = .;
   IF (V5525 >= -5 AND V5525 <= -1) THEN V5525 = .;
   IF (V5526 >= -5 AND V5526 <= -1) THEN V5526 = .;
   IF (V5527 >= -5 AND V5527 <= -1) THEN V5527 = .;
   IF (V5528 >= -5 AND V5528 <= -1) THEN V5528 = .;
   IF (V5529 >= -5 AND V5529 <= -1) THEN V5529 = .;
   IF (V5530 >= -5 AND V5530 <= -1) THEN V5530 = .;
   IF (V5531 >= -5 AND V5531 <= -1) THEN V5531 = .;
   IF (V5532 >= -5 AND V5532 <= -1) THEN V5532 = .;
   IF (V5533 >= -5 AND V5533 <= -1) THEN V5533 = .;
   IF (V5534 >= -5 AND V5534 <= -1) THEN V5534 = .;
   IF (V5535 >= -5 AND V5535 <= -1) THEN V5535 = .;
   IF (V5536 >= -5 AND V5536 <= -1) THEN V5536 = .;
   IF (V5537 >= -5 AND V5537 <= -1) THEN V5537 = .;
   IF (V5538 >= -5 AND V5538 <= -1) THEN V5538 = .;
   IF (V5539 >= -5 AND V5539 <= -1) THEN V5539 = .;
   IF (V5540 >= -5 AND V5540 <= -1) THEN V5540 = .;
   IF (V5541 >= -5 AND V5541 <= -1) THEN V5541 = .;
   IF (V5542 >= -5 AND V5542 <= -1) THEN V5542 = .;
   IF (V5543 >= -5 AND V5543 <= -1) THEN V5543 = .;
   IF (V5544 >= -5 AND V5544 <= -1) THEN V5544 = .;
   IF (V5545 >= -5 AND V5545 <= -1) THEN V5545 = .;
   IF (V5546 >= -5 AND V5546 <= -1) THEN V5546 = .;
   IF (V5547 >= -5 AND V5547 <= -1) THEN V5547 = .;
   IF (V5548 >= -5 AND V5548 <= -1) THEN V5548 = .;
   IF (V5549 >= -5 AND V5549 <= -1) THEN V5549 = .;
   IF (V5550 >= -5 AND V5550 <= -1) THEN V5550 = .;
   IF (V5551 >= -5 AND V5551 <= -1) THEN V5551 = .;
   IF (V5552 >= -5 AND V5552 <= -1) THEN V5552 = .;
   IF (V5553 >= -5 AND V5553 <= -1) THEN V5553 = .;
   IF (V5554 >= -5 AND V5554 <= -1) THEN V5554 = .;
   IF (V5555 >= -5 AND V5555 <= -1) THEN V5555 = .;
   IF (V5556 >= -5 AND V5556 <= -1) THEN V5556 = .;
   IF (V5557 >= -5 AND V5557 <= -1) THEN V5557 = .;
   IF (V5558 >= -5 AND V5558 <= -1) THEN V5558 = .;
   IF (V5559 >= -5 AND V5559 <= -1) THEN V5559 = .;
   IF (V5560 >= -5 AND V5560 <= -1) THEN V5560 = .;
   IF (V5561 >= -5 AND V5561 <= -1) THEN V5561 = .;
   IF (V5562 >= -5 AND V5562 <= -1) THEN V5562 = .;
   IF (V5563 >= -5 AND V5563 <= -1) THEN V5563 = .;
   IF (V5564 >= -5 AND V5564 <= -1) THEN V5564 = .;
   IF (V5565 >= -5 AND V5565 <= -1) THEN V5565 = .;
   IF (V5566 >= -5 AND V5566 <= -1) THEN V5566 = .;
   IF (V5567 >= -5 AND V5567 <= -1) THEN V5567 = .;
   IF (V5568 >= -5 AND V5568 <= -1) THEN V5568 = .;
   IF (V5569 >= -5 AND V5569 <= -1) THEN V5569 = .;
   IF (V5570 >= -5 AND V5570 <= -1) THEN V5570 = .;
   IF (V5571 >= -5 AND V5571 <= -1) THEN V5571 = .;
   IF (V5572 >= -5 AND V5572 <= -1) THEN V5572 = .;
   IF (V5573 >= -5 AND V5573 <= -1) THEN V5573 = .;
   IF (V5574 >= -5 AND V5574 <= -1) THEN V5574 = .;
   IF (V5575 >= -5 AND V5575 <= -1) THEN V5575 = .;
   IF (V5576 >= -5 AND V5576 <= -1) THEN V5576 = .;
   IF (V5577 >= -5 AND V5577 <= -1) THEN V5577 = .;
   IF (V5578 >= -5 AND V5578 <= -1) THEN V5578 = .;
   IF (V5579 >= -5 AND V5579 <= -1) THEN V5579 = .;
   IF (V5580 >= -5 AND V5580 <= -1) THEN V5580 = .;
   IF (V5581 >= -5 AND V5581 <= -1) THEN V5581 = .;
   IF (V5582 >= -5 AND V5582 <= -1) THEN V5582 = .;
   IF (V5583 >= -5 AND V5583 <= -1) THEN V5583 = .;
   IF (V5584 >= -5 AND V5584 <= -1) THEN V5584 = .;
   IF (V5585 >= -5 AND V5585 <= -1) THEN V5585 = .;
   IF (V5586 >= -5 AND V5586 <= -1) THEN V5586 = .;
   IF (V5587 >= -5 AND V5587 <= -1) THEN V5587 = .;
   IF (V5588 >= -5 AND V5588 <= -1) THEN V5588 = .;
   IF (V5589 >= -5 AND V5589 <= -1) THEN V5589 = .;
   IF (V5590 >= -5 AND V5590 <= -1) THEN V5590 = .;
   IF (V5591 >= -5 AND V5591 <= -1) THEN V5591 = .;
   IF (V5592 >= -5 AND V5592 <= -1) THEN V5592 = .;
   IF (V5593 >= -5 AND V5593 <= -1) THEN V5593 = .;
   IF (V5594 >= -5 AND V5594 <= -1) THEN V5594 = .;
   IF (V5595 >= -5 AND V5595 <= -1) THEN V5595 = .;
   IF (V5596 >= -5 AND V5596 <= -1) THEN V5596 = .;
   IF (V5597 >= -5 AND V5597 <= -1) THEN V5597 = .;
   IF (V5598 >= -5 AND V5598 <= -1) THEN V5598 = .;
   IF (V5599 >= -5 AND V5599 <= -1) THEN V5599 = .;
   IF (V5600 >= -5 AND V5600 <= -1) THEN V5600 = .;
   IF (V5601 >= -5 AND V5601 <= -1) THEN V5601 = .;
   IF (V5602 >= -5 AND V5602 <= -1) THEN V5602 = .;
   IF (V5603 >= -5 AND V5603 <= -1) THEN V5603 = .;
   IF (V5604 >= -5 AND V5604 <= -1) THEN V5604 = .;
   IF (V5605 >= -5 AND V5605 <= -1) THEN V5605 = .;
   IF (V5606 >= -5 AND V5606 <= -1) THEN V5606 = .;
   IF (V5607 >= -5 AND V5607 <= -1) THEN V5607 = .;
   IF (V5608 >= -5 AND V5608 <= -1) THEN V5608 = .;
   IF (V5609 >= -5 AND V5609 <= -1) THEN V5609 = .;
   IF (V5610 >= -5 AND V5610 <= -1) THEN V5610 = .;
   IF (V5611 >= -5 AND V5611 <= -1) THEN V5611 = .;
   IF (V5612 >= -5 AND V5612 <= -1) THEN V5612 = .;
   IF (V5613 >= -5 AND V5613 <= -1) THEN V5613 = .;
   IF (V5614 >= -5 AND V5614 <= -1) THEN V5614 = .;
   IF (V5615 >= -5 AND V5615 <= -1) THEN V5615 = .;
   IF (V5616 >= -5 AND V5616 <= -1) THEN V5616 = .;
   IF (V5617 >= -5 AND V5617 <= -1) THEN V5617 = .;
   IF (V5618 >= -5 AND V5618 <= -1) THEN V5618 = .;
   IF (V5619 >= -5 AND V5619 <= -1) THEN V5619 = .;
   IF (V5620 >= -5 AND V5620 <= -1) THEN V5620 = .;
   IF (V5621 >= -5 AND V5621 <= -1) THEN V5621 = .;
   IF (V5622 >= -5 AND V5622 <= -1) THEN V5622 = .;
   IF (V5623 >= -5 AND V5623 <= -1) THEN V5623 = .;
   IF (V5624 >= -5 AND V5624 <= -1) THEN V5624 = .;
   IF (V5625 >= -5 AND V5625 <= -1) THEN V5625 = .;
   IF (V5626 >= -5 AND V5626 <= -1) THEN V5626 = .;
   IF (V5627 >= -5 AND V5627 <= -1) THEN V5627 = .;
   IF (V5628 >= -5 AND V5628 <= -1) THEN V5628 = .;
   IF (V5629 >= -5 AND V5629 <= -1) THEN V5629 = .;
   IF (V5630 >= -5 AND V5630 <= -1) THEN V5630 = .;
   IF (V5631 >= -5 AND V5631 <= -1) THEN V5631 = .;
   IF (V5632 >= -5 AND V5632 <= -1) THEN V5632 = .;
   IF (V5665 >= -5 AND V5665 <= -1) THEN V5665 = .;
   IF (V5666 >= -5 AND V5666 <= -1) THEN V5666 = .;
   IF (V5667 >= -5 AND V5667 <= -1) THEN V5667 = .;
   IF (V5668 >= -5 AND V5668 <= -1) THEN V5668 = .;
   IF (V5669 >= -5 AND V5669 <= -1) THEN V5669 = .;
   IF (V5670 >= -5 AND V5670 <= -1) THEN V5670 = .;
   IF (V5671 >= -5 AND V5671 <= -1) THEN V5671 = .;
   IF (V5672 >= -5 AND V5672 <= -1) THEN V5672 = .;
   IF (V5673 >= -5 AND V5673 <= -1) THEN V5673 = .;
   IF (V5674 >= -5 AND V5674 <= -1) THEN V5674 = .;
   IF (V5675 >= -5 AND V5675 <= -1) THEN V5675 = .;
   IF (V5676 >= -5 AND V5676 <= -1) THEN V5676 = .;
   IF (V5677 >= -5 AND V5677 <= -1) THEN V5677 = .;
   IF (V5678 >= -5 AND V5678 <= -1) THEN V5678 = .;
   IF (V5679 >= -5 AND V5679 <= -1) THEN V5679 = .;
   IF (V5680 >= -5 AND V5680 <= -1) THEN V5680 = .;
   IF (V5681 >= -5 AND V5681 <= -1) THEN V5681 = .;
   IF (V5682 >= -5 AND V5682 <= -1) THEN V5682 = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT V4004 v4004fff. V4005 v4005fff. V4006 v4006fff.
         V4007 v4007fff. V4008 v4008fff. V4009 v4009fff.
         V4010 v4010fff. V4011 v4011fff. V4012 v4012fff.
         V4013 v4013fff. V4014 v4014fff. V4015 v4015fff.
         V4016 v4016fff. V4017 v4017fff. V4018 v4018fff.
         V4019 v4019fff. V4020 v4020fff. V4021 v4021fff.
         V4022 v4022fff. V4023 v4023fff. V4024 v4024fff.
         V4025 v4025fff. V4026 v4026fff. V4027 v4027fff.
         V4028 v4028fff. V4029 v4029fff. V4030 v4030fff.
         V4031 v4031fff. V4032 v4032fff. V4033 v4033fff.
         V4034 v4034fff. V4035 v4035fff. V4036 v4036fff.
         V4037 v4037fff. V4038 v4038fff. V4039 v4039fff.
         V4040 v4040fff. V4041 v4041fff. V4042 v4042fff.
         V4043 v4043fff. V4044 v4044fff. V4045 v4045fff.
         V4046 v4046fff. V4047 v4047fff. V4048 v4048fff.
         V4049 v4049fff. V4050 v4050fff. V4051 v4051fff.
         V4052 v4052fff. V4053 v4053fff. V4054 v4054fff.
         V4055 v4055fff. V4056 v4056fff. V4057 v4057fff.
         V4058 v4058fff. V4059 v4059fff. V4060 v4060fff.
         V4061 v4061fff. V4062 v4062fff. V4063 v4063fff.
         V4064 v4064fff. V4065 v4065fff. V4066 v4066fff.
         V4067 v4067fff. V4068 v4068fff. V4069 v4069fff.
         V4070 v4070fff. V4071 v4071fff. V4072 v4072fff.
         V4073 v4073fff. V4074 v4074fff. V4075 v4075fff.
         V4076 v4076fff. V4077 v4077fff. V4078 v4078fff.
         V4079 v4079fff. V4080 v4080fff. V4081 v4081fff.
         V4082 v4082fff. V4083 v4083fff. V4084 v4084fff.
         V4085 v4085fff. V4086 v4086fff. V4087 v4087fff.
         V4088 v4088fff. V4089 v4089fff. V4090 v4090fff.
         V4091 v4091fff. V4092 v4092fff. V4093 v4093fff.
         V4094 v4094fff. V4095 v4095fff. V4096 v4096fff.
         V4097 v4097fff. V4098 v4098fff. V4099 v4099fff.
         V4100 v4100fff. V4101 v4101fff. V4102 v4102fff.
         V4103 v4103fff. V4104 v4104fff. V4105 v4105fff.
         V4106 v4106fff. V4107 v4107fff. V4108 v4108fff.
         V4109 v4109fff. V4110 v4110fff. V4111 v4111fff.
         V4112 v4112fff. V4113 v4113fff. V4114 v4114fff.
         V4115 v4115fff. V4116 v4116fff. V4117 v4117fff.
         V4118 v4118fff. V4119 v4119fff. V4120 v4120fff.
         V4121 v4121fff. V4122 v4122fff. V4123 v4123fff.
         V4124 v4124fff. V4125 v4125fff. V4126 v4126fff.
         V4127 v4127fff. V4128 v4128fff. V4129 v4129fff.
         V4130 v4130fff. V4131 v4131fff. V4132 v4132fff.
         V4133 v4133fff. V4134 v4134fff. V4135 v4135fff.
         V4136 v4136fff. V4137 v4137fff. V4138 v4138fff.
         V4139 v4139fff. V4140 v4140fff. V4141 v4141fff.
         V4142 v4142fff. V4143 v4143fff. V4144 v4144fff.
         V4145 v4145fff. V4146 v4146fff. V4147 v4147fff.
         V4148 v4148fff. V4149 v4149fff. V4150 v4150fff.
         V4151 v4151fff. V4152 v4152fff. V4153 v4153fff.
         V4154 v4154fff. V4155 v4155fff. V4156 v4156fff.
         V4157 v4157fff. V4158 v4158fff. V4159 v4159fff.
         V4160 v4160fff. V4161 v4161fff. V4162 v4162fff.
         V4163 v4163fff. V4164 v4164fff. V4165 v4165fff.
         V4166 v4166fff. V4167 v4167fff. V4168 v4168fff.
         V4169 v4169fff. V4170 v4170fff. V4171 v4171fff.
         V4172 v4172fff. V4173 v4173fff. V4174 v4174fff.
         V4175 v4175fff. V4176 v4176fff. V4177 v4177fff.
         V4178 v4178fff. V4179 v4179fff. V4180 v4180fff.
         V4181 v4181fff. V4182 v4182fff. V4183 v4183fff.
         V4184 v4184fff. V4185 v4185fff. V4186 v4186fff.
         V4187 v4187fff. V4188 v4188fff. V4189 v4189fff.
         V4190 v4190fff. V4191 v4191fff. V4192 v4192fff.
         V4193 v4193fff. V4194 v4194fff. V4195 v4195fff.
         V4196 v4196fff. V4197 v4197fff. V4198 v4198fff.
         V4199 v4199fff. V4200 v4200fff. V4201 v4201fff.
         V4202 v4202fff. V4203 v4203fff. V4204 v4204fff.
         V4205 v4205fff. V4206 v4206fff. V4207 v4207fff.
         V4208 v4208fff. V4209 v4209fff. V4210 v4210fff.
         V4211 v4211fff. V4212 v4212fff. V4213 v4213fff.
         V4214 v4214fff. V4215 v4215fff. V4216 v4216fff.
         V4217 v4217fff. V4218 v4218fff. V4219 v4219fff.
         V4220 v4220fff. V4221 v4221fff. V4222 v4222fff.
         V4223 v4223fff. V4224 v4224fff. V4225 v4225fff.
         V4226 v4226fff. V4227 v4227fff. V4228 v4228fff.
         V4229 v4229fff. V4230 v4230fff. V4231 v4231fff.
         V4232 v4232fff. V4233 v4233fff. V4234 v4234fff.
         V4235 v4235fff. V4236 v4236fff. V4237 v4237fff.
         V4238 v4238fff. V4239 v4239fff. V4240 v4240fff.
         V4241 v4241fff. V4242 v4242fff. V4243 v4243fff.
         V4244 v4244fff. V4245 v4245fff. V4246 v4246fff.
         V4247 v4247fff. V4248 v4248fff. V4249 v4249fff.
         V4250 v4250fff. V4251 v4251fff. V4252 v4252fff.
         V4253 v4253fff. V4254 v4254fff. V4255 v4255fff.
         V4256 v4256fff. V4257 v4257fff. V4258 v4258fff.
         V4259 v4259fff. V4260 v4260fff. V4261 v4261fff.
         V4262 v4262fff. V4263 v4263fff. V4264 v4264fff.
         V4265 v4265fff. V4266 v4266fff. V4267 v4267fff.
         V4268 v4268fff. V4269 v4269fff. V4270 v4270fff.
         V4271 v4271fff. V4272 v4272fff. V4273 v4273fff.
         V4274 v4274fff. V4275 v4275fff. V4276 v4276fff.
         V4277 v4277fff. V4278 v4278fff. V4279 v4279fff.
         V4280 v4280fff. V4281 v4281fff. V4282 v4282fff.
         V4283 v4283fff. V4284 v4284fff. V4285 v4285fff.
         V4286 v4286fff. V4287 v4287fff. V4288 v4288fff.
         V4289 v4289fff. V4290 v4290fff. V4291 v4291fff.
         V4292 v4292fff. V4293 v4293fff. V4294 v4294fff.
         V4295 v4295fff. V4296 v4296fff. V4297 v4297fff.
         V4298 v4298fff. V4299 v4299fff. V4300 v4300fff.
         V4301 v4301fff. V4302 v4302fff. V4303 v4303fff.
         V4304 v4304fff. V4305 v4305fff. V4306 v4306fff.
         V4307 v4307fff. V4308 v4308fff. V4309 v4309fff.
         V4310 v4310fff. V4311 v4311fff. V4312 v4312fff.
         V4313 v4313fff. V4314 v4314fff. V4315 v4315fff.
         V4316 v4316fff. V4317 v4317fff. V4318 v4318fff.
         V4319 v4319fff. V4320 v4320fff. V4321 v4321fff.
         V4322 v4322fff. V4323 v4323fff. V4324 v4324fff.
         V4325 v4325fff. V4326 v4326fff. V4327 v4327fff.
         V4328 v4328fff. V4329 v4329fff. V4330 v4330fff.
         V4331 v4331fff. V4332 v4332fff. V4333 v4333fff.
         V4334 v4334fff. V4335 v4335fff. V4336 v4336fff.
         V4337 v4337fff. V4338 v4338fff. V4339 v4339fff.
         V4340 v4340fff. V4341 v4341fff. V4342 v4342fff.
         V4343 v4343fff. V4344 v4344fff. V4345 v4345fff.
         V4346 v4346fff. V4347 v4347fff. V4348 v4348fff.
         V4349 v4349fff. V4350 v4350fff. V4351 v4351fff.
         V4352 v4352fff. V4353 v4353fff. V4354 v4354fff.
         V4355 v4355fff. V4356 v4356fff. V4357 v4357fff.
         V4358 v4358fff. V4359 v4359fff. V4360 v4360fff.
         V4361 v4361fff. V4362 v4362fff. V4363 v4363fff.
         V4364 v4364fff. V4365 v4365fff. V4366 v4366fff.
         V4367 v4367fff. V4368 v4368fff. V4369 v4369fff.
         V4370 v4370fff. V4371 v4371fff. V4372 v4372fff.
         V4373 v4373fff. V4374 v4374fff. V4375 v4375fff.
         V4376 v4376fff. V4377 v4377fff. V4378 v4378fff.
         V4379 v4379fff. V4380 v4380fff. V4381 v4381fff.
         V4382 v4382fff. V4383 v4383fff. V4384 v4384fff.
         V4385 v4385fff. V4386 v4386fff. V4387 v4387fff.
         V4388 v4388fff. V4389 v4389fff. V4390 v4390fff.
         V4391 v4391fff. V4392 v4392fff. V4393 v4393fff.
         V4394 v4394fff. V4395 v4395fff. V4396 v4396fff.
         V4397 v4397fff. V4398 v4398fff. V4399 v4399fff.
         V4400 v4400fff. V4401 v4401fff. V4402 v4402fff.
         V4403 v4403fff. V4404 v4404fff. V4405 v4405fff.
         V4406 v4406fff. V4407 v4407fff. V4408 v4408fff.
         V4409 v4409fff. V4410 v4410fff. V4411 v4411fff.
         V4412 v4412fff. V4413 v4413fff. V4414 v4414fff.
         V4415 v4415fff. V4416 v4416fff. V4417 v4417fff.
         V4418 v4418fff. V4419 v4419fff. V4420 v4420fff.
         V4421 v4421fff. V4422 v4422fff. V4423 v4423fff.
         V4424 v4424fff. V4425 v4425fff. V4426 v4426fff.
         V4427 v4427fff. V4428 v4428fff. V4429 v4429fff.
         V4430 v4430fff. V4431 v4431fff. V4432 v4432fff.
         V4433 v4433fff. V4434 v4434fff. V4435 v4435fff.
         V4436 v4436fff. V4437 v4437fff. V4438 v4438fff.
         V4439 v4439fff. V4440 v4440fff. V4441 v4441fff.
         V4442 v4442fff. V4443 v4443fff. V4444 v4444fff.
         V4445 v4445fff. V4446 v4446fff. V4447 v4447fff.
         V4448 v4448fff. V4449 v4449fff. V4450 v4450fff.
         V4451 v4451fff. V4452 v4452fff. V4453 v4453fff.
         V4454 v4454fff. V4455 v4455fff. V4456 v4456fff.
         V4457 v4457fff. V4458 v4458fff. V4459 v4459fff.
         V4460 v4460fff. V4461 v4461fff. V4462 v4462fff.
         V4463 v4463fff. V4464 v4464fff. V4465 v4465fff.
         V4466 v4466fff. V4467 v4467fff. V4468 v4468fff.
         V4469 v4469fff. V4470 v4470fff. V4471 v4471fff.
         V4472 v4472fff. V4473 v4473fff. V4474 v4474fff.
         V4475 v4475fff. V4476 v4476fff. V4477 v4477fff.
         V4478 v4478fff. V4479 v4479fff. V4480 v4480fff.
         V4481 v4481fff. V4482 v4482fff. V4483 v4483fff.
         V4484 v4484fff. V4485 v4485fff. V4486 v4486fff.
         V4487 v4487fff. V4488 v4488fff. V4489 v4489fff.
         V4490 v4490fff. V4491 v4491fff. V4492 v4492fff.
         V4493 v4493fff. V4494 v4494fff. V4495 v4495fff.
         V4496 v4496fff. V4497 v4497fff. V4498 v4498fff.
         V4499 v4499fff. V4500 v4500fff. V4501 v4501fff.
         V4502 v4502fff. V4503 v4503fff. V4504 v4504fff.
         V4505 v4505fff. V4506 v4506fff. V4507 v4507fff.
         V4508 v4508fff. V4509 v4509fff. V4510 v4510fff.
         V4511 v4511fff. V4512 v4512fff. V4513 v4513fff.
         V4514 v4514fff. V4515 v4515fff. V4516 v4516fff.
         V4517 v4517fff. V4518 v4518fff. V4519 v4519fff.
         V4520 v4520fff. V4521 v4521fff. V4522 v4522fff.
         V4523 v4523fff. V4524 v4524fff. V4525 v4525fff.
         V4526 v4526fff. V4527 v4527fff. V4528 v4528fff.
         V4529 v4529fff. V4530 v4530fff. V4531 v4531fff.
         V4532 v4532fff. V4533 v4533fff. V4534 v4534fff.
         V4535 v4535fff. V4536 v4536fff. V4537 v4537fff.
         V4538 v4538fff. V4539 v4539fff. V4540 v4540fff.
         V4541 v4541fff. V4542 v4542fff. V4543 v4543fff.
         V4544 v4544fff. V4545 v4545fff. V4546 v4546fff.
         V4547 v4547fff. V4548 v4548fff. V4549 v4549fff.
         V4550 v4550fff. V4551 v4551fff. V4552 v4552fff.
         V4553 v4553fff. V4554 v4554fff. V4555 v4555fff.
         V4556 v4556fff. V4557 v4557fff. V4558 v4558fff.
         V4559 v4559fff. V4560 v4560fff. V4561 v4561fff.
         V4562 v4562fff. V4563 v4563fff. V4564 v4564fff.
         V4565 v4565fff. V4566 v4566fff. V4567 v4567fff.
         V4568 v4568fff. V4569 v4569fff. V4570 v4570fff.
         V4571 v4571fff. V4572 v4572fff. V4573 v4573fff.
         V4574 v4574fff. V4575 v4575fff. V4576 v4576fff.
         V4577 v4577fff. V4578 v4578fff. V4579 v4579fff.
         V4580 v4580fff. V4581 v4581fff. V4582 v4582fff.
         V4583 v4583fff. V4584 v4584fff. V4585 v4585fff.
         V4586 v4586fff. V4587 v4587fff. V4588 v4588fff.
         V4589 v4589fff. V4590 v4590fff. V4591 v4591fff.
         V4592 v4592fff. V4593 v4593fff. V4594 v4594fff.
         V4595 v4595fff. V4596 v4596fff. V4597 v4597fff.
         V4598 v4598fff. V4599 v4599fff. V4600 v4600fff.
         V4601 v4601fff. V4602 v4602fff. V4603 v4603fff.
         V4604 v4604fff. V4605 v4605fff. V4606 v4606fff.
         V4607 v4607fff. V4608 v4608fff. V4609 v4609fff.
         V4610 v4610fff. V4611 v4611fff. V4612 v4612fff.
         V4613 v4613fff. V4614 v4614fff. V4615 v4615fff.
         V4616 v4616fff. V4617 v4617fff. V4618 v4618fff.
         V4619 v4619fff. V4620 v4620fff. V4621 v4621fff.
         V4622 v4622fff. V4623 v4623fff. V4624 v4624fff.
         V4625 v4625fff. V4626 v4626fff. V4627 v4627fff.
         V4628 v4628fff. V4629 v4629fff. V4630 v4630fff.
         V4631 v4631fff. V4632 v4632fff. V4633 v4633fff.
         V4634 v4634fff. V4635 v4635fff. V4636 v4636fff.
         V4637 v4637fff. V4638 v4638fff. V4639 v4639fff.
         V4640 v4640fff. V4641 v4641fff. V4642 v4642fff.
         V4643 v4643fff. V4644 v4644fff. V4645 v4645fff.
         V4646 v4646fff. V4647 v4647fff. V4648 v4648fff.
         V4649 v4649fff. V4650 v4650fff. V4651 v4651fff.
         V4652 v4652fff. V4653 v4653fff. V4654 v4654fff.
         V4655 v4655fff. V4656 v4656fff. V4657 v4657fff.
         V4658 v4658fff. V4659 v4659fff. V4660 v4660fff.
         V4661 v4661fff. V4662 v4662fff. V4663 v4663fff.
         V4664 v4664fff. V4665 v4665fff. V4666 v4666fff.
         V4667 v4667fff. V4668 v4668fff. V4669 v4669fff.
         V4670 v4670fff. V4671 v4671fff. V4672 v4672fff.
         V4673 v4673fff. V4674 v4674fff. V4675 v4675fff.
         V4676 v4676fff. V4677 v4677fff. V4678 v4678fff.
         V4679 v4679fff. V4680 v4680fff. V4681 v4681fff.
         V4682 v4682fff. V4683 v4683fff. V4684 v4684fff.
         V4685 v4685fff. V4686 v4686fff. V4687 v4687fff.
         V4688 v4688fff. V4689 v4689fff. V4690 v4690fff.
         V4691 v4691fff. V4692 v4692fff. V4693 v4693fff.
         V4694 v4694fff. V4695 v4695fff. V4696 v4696fff.
         V4697 v4697fff. V4698 v4698fff. V4699 v4699fff.
         V4700 v4700fff. V4701 v4701fff. V4702 v4702fff.
         V4703 v4703fff. V4704 v4704fff. V4705 v4705fff.
         V4706 v4706fff. V4707 v4707fff. V4708 v4708fff.
         V4709 v4709fff. V4710 v4710fff. V4711 v4711fff.
         V4712 v4712fff. V4713 v4713fff. V4714 v4714fff.
         V4715 v4715fff. V4716 v4716fff. V4717 v4717fff.
         V4718 v4718fff. V4719 v4719fff. V4720 v4720fff.
         V4721 v4721fff. V4722 v4722fff. V4723 v4723fff.
         V4724 v4724fff. V4725 v4725fff. V4726 v4726fff.
         V4727 v4727fff. V4728 v4728fff. V4729 v4729fff.
         V4730 v4730fff. V4731 v4731fff. V4732 v4732fff.
         V4733 v4733fff. V4734 v4734fff. V4735 v4735fff.
         V4736 v4736fff. V4737 v4737fff. V4738 v4738fff.
         V4739 v4739fff. V4740 v4740fff. V4741 v4741fff.
         V4742 v4742fff. V4743 v4743fff. V4744 v4744fff.
         V4745 v4745fff. V4746 v4746fff. V4747 v4747fff.
         V4748 v4748fff. V4749 v4749fff. V4750 v4750fff.
         V4751 v4751fff. V4752 v4752fff. V4753 v4753fff.
         V4754 v4754fff. V4755 v4755fff. V4756 v4756fff.
         V4757 v4757fff. V4758 v4758fff. V4759 v4759fff.
         V4764 v4764fff. V4765 v4765fff. V4766 v4766fff.
         V4767 v4767fff. V4768 v4768fff. V4769 v4769fff.
         V4770 v4770fff. V4771 v4771fff. V4772 v4772fff.
         V4773 v4773fff. V4774 v4774fff. V4775 v4775fff.
         V4776 v4776fff. V4777 v4777fff. V4778 v4778fff.
         V4779 v4779fff. V4780 v4780fff. V4781 v4781fff.
         V4782 v4782fff. V4783 v4783fff. V4784 v4784fff.
         V4785 v4785fff. V4786 v4786fff. V4787 v4787fff.
         V4788 v4788fff. V4789 v4789fff. V4790 v4790fff.
         V5004 v5004fff. V5005 v5005fff. V5006 v5006fff.
         V5007 v5007fff. V5008 v5008fff. V5009 v5009fff.
         V5010 v5010fff. V5011 v5011fff. V5012 v5012fff.
         V5013 v5013fff. V5014 v5014fff. V5015 v5015fff.
         V5016 v5016fff. V5017 v5017fff. V5018 v5018fff.
         V5019 v5019fff. V5020 v5020fff. V5021 v5021fff.
         V5022 v5022fff. V5023 v5023fff. V5024 v5024fff.
         V5025 v5025fff. V5026 v5026fff. V5027 v5027fff.
         V5028 v5028fff. V5029 v5029fff. V5030 v5030fff.
         V5031 v5031fff. V5032 v5032fff. V5033 v5033fff.
         V5034 v5034fff. V5035 v5035fff. V5036 v5036fff.
         V5037 v5037fff. V5038 v5038fff. V5039 v5039fff.
         V5040 v5040fff. V5041 v5041fff. V5042 v5042fff.
         V5043 v5043fff. V5044 v5044fff. V5045 v5045fff.
         V5046 v5046fff. V5047 v5047fff. V5048 v5048fff.
         V5049 v5049fff. V5050 v5050fff. V5051 v5051fff.
         V5052 v5052fff. V5053 v5053fff. V5054 v5054fff.
         V5055 v5055fff. V5056 v5056fff. V5057 v5057fff.
         V5058 v5058fff. V5059 v5059fff. V5060 v5060fff.
         V5061 v5061fff. V5062 v5062fff. V5063 v5063fff.
         V5064 v5064fff. V5065 v5065fff. V5066 v5066fff.
         V5067 v5067fff. V5068 v5068fff. V5069 v5069fff.
         V5070 v5070fff. V5071 v5071fff. V5072 v5072fff.
         V5073 v5073fff. V5074 v5074fff. V5075 v5075fff.
         V5076 v5076fff. V5077 v5077fff. V5078 v5078fff.
         V5079 v5079fff. V5080 v5080fff. V5081 v5081fff.
         V5082 v5082fff. V5083 v5083fff. V5084 v5084fff.
         V5085 v5085fff. V5086 v5086fff. V5087 v5087fff.
         V5088 v5088fff. V5089 v5089fff. V5090 v5090fff.
         V5091 v5091fff. V5092 v5092fff. V5093 v5093fff.
         V5094 v5094fff. V5095 v5095fff. V5096 v5096fff.
         V5097 v5097fff. V5098 v5098fff. V5099 v5099fff.
         V5100 v5100fff. V5101 v5101fff. V5102 v5102fff.
         V5103 v5103fff. V5104 v5104fff. V5105 v5105fff.
         V5106 v5106fff. V5107 v5107fff. V5108 v5108fff.
         V5109 v5109fff. V5110 v5110fff. V5111 v5111fff.
         V5112 v5112fff. V5113 v5113fff. V5114 v5114fff.
         V5115 v5115fff. V5116 v5116fff. V5117 v5117fff.
         V5118 v5118fff. V5119 v5119fff. V5120 v5120fff.
         V5121 v5121fff. V5122 v5122fff. V5123 v5123fff.
         V5124 v5124fff. V5125 v5125fff. V5126 v5126fff.
         V5127 v5127fff. V5128 v5128fff. V5129 v5129fff.
         V5130 v5130fff. V5131 v5131fff. V5132 v5132fff.
         V5133 v5133fff. V5134 v5134fff. V5135 v5135fff.
         V5136 v5136fff. V5137 v5137fff. V5138 v5138fff.
         V5139 v5139fff. V5140 v5140fff. V5141 v5141fff.
         V5142 v5142fff. V5143 v5143fff. V5144 v5144fff.
         V5145 v5145fff. V5146 v5146fff. V5147 v5147fff.
         V5148 v5148fff. V5149 v5149fff. V5150 v5150fff.
         V5151 v5151fff. V5152 v5152fff. V5153 v5153fff.
         V5154 v5154fff. V5155 v5155fff. V5156 v5156fff.
         V5157 v5157fff. V5158 v5158fff. V5159 v5159fff.
         V5160 v5160fff. V5161 v5161fff. V5162 v5162fff.
         V5163 v5163fff. V5164 v5164fff. V5165 v5165fff.
         V5166 v5166fff. V5167 v5167fff. V5168 v5168fff.
         V5169 v5169fff. V5170 v5170fff. V5171 v5171fff.
         V5172 v5172fff. V5173 v5173fff. V5174 v5174fff.
         V5175 v5175fff. V5176 v5176fff. V5177 v5177fff.
         V5178 v5178fff. V5179 v5179fff. V5180 v5180fff.
         V5181 v5181fff. V5182 v5182fff. V5183 v5183fff.
         V5184 v5184fff. V5185 v5185fff. V5186 v5186fff.
         V5187 v5187fff. V5188 v5188fff. V5189 v5189fff.
         V5190 v5190fff. V5191 v5191fff. V5192 v5192fff.
         V5193 v5193fff. V5194 v5194fff. V5195 v5195fff.
         V5196 v5196fff. V5197 v5197fff. V5198 v5198fff.
         V5199 v5199fff. V5200 v5200fff. V5201 v5201fff.
         V5202 v5202fff. V5203 v5203fff. V5204 v5204fff.
         V5205 v5205fff. V5206 v5206fff. V5207 v5207fff.
         V5208 v5208fff. V5209 v5209fff. V5210 v5210fff.
         V5211 v5211fff. V5212 v5212fff. V5213 v5213fff.
         V5214 v5214fff. V5215 v5215fff. V5216 v5216fff.
         V5217 v5217fff. V5218 v5218fff. V5219 v5219fff.
         V5220 v5220fff. V5221 v5221fff. V5222 v5222fff.
         V5223 v5223fff. V5224 v5224fff. V5225 v5225fff.
         V5226 v5226fff. V5227 v5227fff. V5228 v5228fff.
         V5229 v5229fff. V5230 v5230fff. V5231 v5231fff.
         V5232 v5232fff. V5233 v5233fff. V5234 v5234fff.
         V5235 v5235fff. V5236 v5236fff. V5237 v5237fff.
         V5238 v5238fff. V5239 v5239fff. V5240 v5240fff.
         V5241 v5241fff. V5242 v5242fff. V5243 v5243fff.
         V5244 v5244fff. V5245 v5245fff. V5246 v5246fff.
         V5247 v5247fff. V5248 v5248fff. V5249 v5249fff.
         V5250 v5250fff. V5251 v5251fff. V5252 v5252fff.
         V5253 v5253fff. V5254 v5254fff. V5255 v5255fff.
         V5256 v5256fff. V5257 v5257fff. V5258 v5258fff.
         V5259 v5259fff. V5260 v5260fff. V5261 v5261fff.
         V5262 v5262fff. V5263 v5263fff. V5264 v5264fff.
         V5265 v5265fff. V5266 v5266fff. V5267 v5267fff.
         V5268 v5268fff. V5269 v5269fff. V5270 v5270fff.
         V5271 v5271fff. V5272 v5272fff. V5273 v5273fff.
         V5274 v5274fff. V5275 v5275fff. V5276 v5276fff.
         V5277 v5277fff. V5278 v5278fff. V5279 v5279fff.
         V5280 v5280fff. V5281 v5281fff. V5282 v5282fff.
         V5283 v5283fff. V5284 v5284fff. V5285 v5285fff.
         V5286 v5286fff. V5287 v5287fff. V5288 v5288fff.
         V5289 v5289fff. V5290 v5290fff. V5291 v5291fff.
         V5292 v5292fff. V5293 v5293fff. V5294 v5294fff.
         V5295 v5295fff. V5296 v5296fff. V5297 v5297fff.
         V5298 v5298fff. V5299 v5299fff. V5300 v5300fff.
         V5301 v5301fff. V5302 v5302fff. V5303 v5303fff.
         V5304 v5304fff. V5305 v5305fff. V5306 v5306fff.
         V5307 v5307fff. V5308 v5308fff. V5309 v5309fff.
         V5310 v5310fff. V5311 v5311fff. V5312 v5312fff.
         V5313 v5313fff. V5314 v5314fff. V5315 v5315fff.
         V5316 v5316fff. V5317 v5317fff. V5318 v5318fff.
         V5319 v5319fff. V5320 v5320fff. V5321 v5321fff.
         V5322 v5322fff. V5323 v5323fff. V5324 v5324fff.
         V5325 v5325fff. V5326 v5326fff. V5327 v5327fff.
         V5328 v5328fff. V5329 v5329fff. V5330 v5330fff.
         V5331 v5331fff. V5332 v5332fff. V5333 v5333fff.
         V5334 v5334fff. V5335 v5335fff. V5336 v5336fff.
         V5337 v5337fff. V5338 v5338fff. V5339 v5339fff.
         V5340 v5340fff. V5341 v5341fff. V5342 v5342fff.
         V5343 v5343fff. V5344 v5344fff. V5345 v5345fff.
         V5346 v5346fff. V5347 v5347fff. V5348 v5348fff.
         V5349 v5349fff. V5350 v5350fff. V5351 v5351fff.
         V5352 v5352fff. V5353 v5353fff. V5354 v5354fff.
         V5355 v5355fff. V5356 v5356fff. V5357 v5357fff.
         V5358 v5358fff. V5359 v5359fff. V5360 v5360fff.
         V5361 v5361fff. V5362 v5362fff. V5363 v5363fff.
         V5364 v5364fff. V5365 v5365fff. V5366 v5366fff.
         V5367 v5367fff. V5368 v5368fff. V5369 v5369fff.
         V5370 v5370fff. V5371 v5371fff. V5372 v5372fff.
         V5373 v5373fff. V5374 v5374fff. V5375 v5375fff.
         V5376 v5376fff. V5377 v5377fff. V5378 v5378fff.
         V5379 v5379fff. V5380 v5380fff. V5381 v5381fff.
         V5382 v5382fff. V5383 v5383fff. V5384 v5384fff.
         V5385 v5385fff. V5386 v5386fff. V5387 v5387fff.
         V5388 v5388fff. V5389 v5389fff. V5390 v5390fff.
         V5391 v5391fff. V5392 v5392fff. V5393 v5393fff.
         V5394 v5394fff. V5395 v5395fff. V5396 v5396fff.
         V5397 v5397fff. V5398 v5398fff. V5399 v5399fff.
         V5400 v5400fff. V5401 v5401fff. V5402 v5402fff.
         V5403 v5403fff. V5404 v5404fff. V5405 v5405fff.
         V5406 v5406fff. V5407 v5407fff. V5408 v5408fff.
         V5409 v5409fff. V5410 v5410fff. V5411 v5411fff.
         V5412 v5412fff. V5413 v5413fff. V5414 v5414fff.
         V5415 v5415fff. V5416 v5416fff. V5417 v5417fff.
         V5418 v5418fff. V5419 v5419fff. V5420 v5420fff.
         V5421 v5421fff. V5422 v5422fff. V5423 v5423fff.
         V5424 v5424fff. V5425 v5425fff. V5426 v5426fff.
         V5427 v5427fff. V5428 v5428fff. V5429 v5429fff.
         V5430 v5430fff. V5431 v5431fff. V5432 v5432fff.
         V5433 v5433fff. V5434 v5434fff. V5435 v5435fff.
         V5436 v5436fff. V5437 v5437fff. V5438 v5438fff.
         V5439 v5439fff. V5440 v5440fff. V5441 v5441fff.
         V5442 v5442fff. V5443 v5443fff. V5444 v5444fff.
         V5445 v5445fff. V5446 v5446fff. V5447 v5447fff.
         V5448 v5448fff. V5449 v5449fff. V5450 v5450fff.
         V5451 v5451fff. V5452 v5452fff. V5453 v5453fff.
         V5454 v5454fff. V5455 v5455fff. V5456 v5456fff.
         V5457 v5457fff. V5458 v5458fff. V5459 v5459fff.
         V5460 v5460fff. V5461 v5461fff. V5462 v5462fff.
         V5463 v5463fff. V5464 v5464fff. V5465 v5465fff.
         V5466 v5466fff. V5467 v5467fff. V5468 v5468fff.
         V5469 v5469fff. V5470 v5470fff. V5471 v5471fff.
         V5472 v5472fff. V5473 v5473fff. V5474 v5474fff.
         V5475 v5475fff. V5476 v5476fff. V5477 v5477fff.
         V5478 v5478fff. V5479 v5479fff. V5480 v5480fff.
         V5481 v5481fff. V5482 v5482fff. V5483 v5483fff.
         V5484 v5484fff. V5485 v5485fff. V5486 v5486fff.
         V5487 v5487fff. V5488 v5488fff. V5489 v5489fff.
         V5490 v5490fff. V5491 v5491fff. V5492 v5492fff.
         V5493 v5493fff. V5494 v5494fff. V5495 v5495fff.
         V5496 v5496fff. V5497 v5497fff. V5498 v5498fff.
         V5499 v5499fff. V5500 v5500fff. V5501 v5501fff.
         V5502 v5502fff. V5503 v5503fff. V5504 v5504fff.
         V5505 v5505fff. V5506 v5506fff. V5507 v5507fff.
         V5508 v5508fff. V5509 v5509fff. V5510 v5510fff.
         V5511 v5511fff. V5512 v5512fff. V5513 v5513fff.
         V5514 v5514fff. V5515 v5515fff. V5516 v5516fff.
         V5517 v5517fff. V5518 v5518fff. V5519 v5519fff.
         V5520 v5520fff. V5521 v5521fff. V5522 v5522fff.
         V5523 v5523fff. V5524 v5524fff. V5525 v5525fff.
         V5526 v5526fff. V5527 v5527fff. V5528 v5528fff.
         V5529 v5529fff. V5530 v5530fff. V5531 v5531fff.
         V5532 v5532fff. V5533 v5533fff. V5534 v5534fff.
         V5535 v5535fff. V5536 v5536fff. V5537 v5537fff.
         V5538 v5538fff. V5539 v5539fff. V5540 v5540fff.
         V5541 v5541fff. V5542 v5542fff. V5543 v5543fff.
         V5544 v5544fff. V5545 v5545fff. V5546 v5546fff.
         V5547 v5547fff. V5548 v5548fff. V5549 v5549fff.
         V5550 v5550fff. V5551 v5551fff. V5552 v5552fff.
         V5553 v5553fff. V5554 v5554fff. V5555 v5555fff.
         V5556 v5556fff. V5557 v5557fff. V5558 v5558fff.
         V5559 v5559fff. V5560 v5560fff. V5561 v5561fff.
         V5562 v5562fff. V5563 v5563fff. V5564 v5564fff.
         V5565 v5565fff. V5566 v5566fff. V5567 v5567fff.
         V5568 v5568fff. V5569 v5569fff. V5570 v5570fff.
         V5571 v5571fff. V5572 v5572fff. V5573 v5573fff.
         V5574 v5574fff. V5575 v5575fff. V5576 v5576fff.
         V5577 v5577fff. V5578 v5578fff. V5579 v5579fff.
         V5580 v5580fff. V5581 v5581fff. V5582 v5582fff.
         V5583 v5583fff. V5584 v5584fff. V5585 v5585fff.
         V5586 v5586fff. V5587 v5587fff. V5588 v5588fff.
         V5589 v5589fff. V5590 v5590fff. V5591 v5591fff.
         V5592 v5592fff. V5593 v5593fff. V5594 v5594fff.
         V5595 v5595fff. V5596 v5596fff. V5597 v5597fff.
         V5598 v5598fff. V5599 v5599fff. V5600 v5600fff.
         V5601 v5601fff. V5602 v5602fff. V5603 v5603fff.
         V5604 v5604fff. V5605 v5605fff. V5606 v5606fff.
         V5607 v5607fff. V5608 v5608fff. V5609 v5609fff.
         V5610 v5610fff. V5611 v5611fff. V5612 v5612fff.
         V5613 v5613fff. V5614 v5614fff. V5615 v5615fff.
         V5616 v5616fff. V5617 v5617fff. V5618 v5618fff.
         V5619 v5619fff. V5620 v5620fff. V5621 v5621fff.
         V5622 v5622fff. V5623 v5623fff. V5624 v5624fff.
         V5625 v5625fff. V5626 v5626fff. V5627 v5627fff.
         V5628 v5628fff. V5629 v5629fff. V5630 v5630fff.
         V5631 v5631fff. V5632 v5632fff. V5665 v5665fff.
         V5666 v5666fff. V5667 v5667fff. V5668 v5668fff.
         V5669 v5669fff. V5670 v5670fff. V5671 v5671fff.
         V5672 v5672fff. V5673 v5673fff. V5674 v5674fff.
         V5675 v5675fff. V5676 v5676fff. V5677 v5677fff.
         V5678 v5678fff. V5679 v5679fff. V5680 v5680fff.
         V5681 v5681fff. V5682 v5682fff.  ;
*/

RUN ;
